*********************************************************************************
* 			THIS PROGRAM MERGE DATA OF LSMS SURVEYS FOR MALAWI				    *
*                      WRITTEN BY LUIS GUILLERMO BECERRA                        *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 6000
cap log close

*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
cd "U:\PSE-Proposal Malaria and paper\INPUT"


global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER V2"
global work 	"..\WORK V2"
global results  "..\RESULTS V2"

global malawiy0 "..\INPUT\LSMS Surveys\Malawi\2004-2005\STATA FILES"
global malawiy1 "..\INPUT\LSMS Surveys\Malawi\2010-2011\STATA FILES"
global malawiy2 "..\INPUT\LSMS Surveys\Malawi\2013\STATA FILES\MWI_2013"
global malawiy3 "..\INPUT\LSMS Surveys\Malawi\2016-2017\STATA FILES"  

****************************************
* MALAWI LSMS 2004-2005
****************************************
****************************************************************************************************************
*HH QUESTIONS AT THE HH and INDIVIDUAL LEVEL. All HH kept so to have a balanced panel not tracking the same individuals
****************************************************************************************************************
*HH: 11280
use "${malawiy0}\Household\sec_a.dta", clear
isid case_id /*Verifying not duplicates*/
rename _all a_=
rename a_a* a*
rename add a_add
rename a_case_id case_id

preserve
use "${malawiy0}\Household\sec_aa.dta", clear
isid case_id /*Verifying not duplicates*/
restore
merge m:m case_id using "${malawiy0}\Household\sec_aa.dta", keep(master using match) gen(merge_aa)
display "Section aa merged"
drop merge_aa /*all matched*/
rename (region reside dist ta ea hhid questnum hhwght type add hhsize psu strata) aa_=
*Comparing double variables
foreach pro in region reside dist ta ea hhid questnum hhwght type add hhsize psu strata {
	compare a_`pro' aa_`pro'
} /*All are the same, aa_* dropped*/
drop aa_region aa_reside aa_dist aa_ta aa_ea aa_hhid aa_questnum aa_hhwght aa_type aa_add aa_hhsize aa_psu aa_strata

*SECTION G: HOUSING
preserve
use "${malawiy0}\Household\sec_g.dta", clear
isid case_id /*Verifying not duplicates*/
restore
merge m:m case_id using "${malawiy0}\Household\sec_g.dta", keep(master using match) gen(merge_g)
display "Section g merged"
drop merge_g /*all matched*/
*Comparing double variables
foreach pro in region reside dist ta ea hhid questnum hhwght type add hhsize psu strata {
	compare a_`pro' `pro'
} /*All are the same, dropped*/
drop region reside dist ta ea hhid questnum hhwght type add hhsize psu strata
 
*Merging data of Community to get info of distance to malaria centers.
*COM CD: ACCESS TO BASIC SERVICES
preserve
use "${malawiy0}\Community\mod_d.dta", clear
isid ta ea dist
restore
rename (a_ta a_ea a_dist) (ta ea dist)
merge m:m ta ea dist using "${malawiy0}\Community\mod_d.dta", keep(master using match) gen(merge_com_d)
tab merge_com_d
drop merge_com_d /*all matched*/

*COM CG1: CHANGES. CG19 treatment of Malaria
preserve
use "${malawiy0}\Community\mod_g.dta", clear
isid ta ea dist
restore
merge m:m ta ea dist using "${malawiy0}\Community\mod_g.dta", keep(master using match) gen(merge_com_g)
rename (ta ea dist village) (a_ta a_ea a_dist cg_village)
tab merge_com_g
drop merge_com_g

*SECTION L: ONLY QUESTION OF MOSQUITO NETS EXPENSES
preserve
use "${malawiy0}\Household\sec_l.dta", clear 
keep if l02==404
isid case_id l02 /*Verifying not duplicates*/
tempfile sec_l
save "`sec_l'", replace
restore

merge m:m case_id using "`sec_l'", keep(master using match) gen(merge_L)
tab merge_L
drop merge_L

*SECTION L: ONLY QUESTION OF LOBOLA
preserve
use "${malawiy0}\Household\sec_l.dta", clear 
keep if l02==413
isid case_id l02 /*Verifying not duplicates*/
rename (l01 l03) (k_lobola k_lobola_pay)
keep k_* case_id
tempfile sec_l2
save "`sec_l2'", replace
restore

merge m:m case_id using "`sec_l2'", keep(master using match) gen(merge_L2)
tab merge_L2
drop merge_L2

*SECTION L: ONLY QUESTION OF MARRIAGE COSTS
preserve
use "${malawiy0}\Household\sec_l.dta", clear 
keep if l02==414
isid case_id l02 /*Verifying not duplicates*/
rename (l01 l03) (k_marriage k_marriage_pay)
keep k_* case_id
tempfile sec_l3
save "`sec_l3'", replace
restore

merge m:m case_id using "`sec_l3'", keep(master using match) gen(merge_L3)
tab merge_L3
drop merge_L3

*Comparing double variables
foreach pro in region reside dist ta ea hhid questnum hhwght type add hhsize psu strata {
	compare a_`pro' `pro'
} /*All are the same, dropped*/
drop region reside dist ta ea hhid questnum hhwght type add hhsize psu strata

*COM CG35. in 2004-2005 is CG50
preserve
	use "${malawiy0}\Community\mod_g50worse.dta", clear
	*isid ea_id com_cg35a com_cg36
	*Coding categories
	drop if item_no==0
	rename (cg50_2 cg51)  (com_cg35a com_cg36)
	label define COM_CG35 1 "DROUGHT" 2 "FLOOD" 3 "CROP DISEASE/PESTS" 4 "LIVESTOCK DISEASE" 5 "HUMAN EPIDEMIC DISEASE" 6 "SHARP CHANGE IN PRICES" 7 "MASSIVE JOB LAY-OFFS" 8 "LOSS OF KEY SOCIAL SERVICE (S)" ///
						  9 "POWER OUTAGE(S)" 10 "OTHER BAD (SPECIFY)" 11 "DEVELOPMENT PROJECT" 12 "NEW EMPLOYMENT OPPORTUNITIES" 13 "NEW HEALTH FACILITY" 14 "NEW ROAD" 15 "NEW SCHOOL" 16 "IMPROVED TRANSPORTATION" ///
						  17 "ON-GRID ELECTRICITY" 18 "OFF-GRID ELECTRICITY" 19 "MAREP" 20 "OTHER GOOD (SPECIFY)"
	label define COM_CG37 1 "ALMOST NONE" 2 "1/4" 3 "1/2" 4 "3/4" 5 "ALMOST ALL"
	recode com_cg35a (9=10) (10=11) (14=15) (15=10)
	label values com_cg35a COM_CG35 
	drop cg52 item_no cg50 /*question of % of people affected is badly reported with mistakes and difficult to match with other surveys. Better drop it*/
	* Some descriptive statistics for important events taken place in the community-ea
	decode com_cg35a, gen(tag)
	levelsof tag, local(rows)
	local nrows : word count `rows'
	matrix M = J(`nrows',1,0)
	matrix colname M = 2004-2005
	matrix rowname M = `rows' 
	*########## EA_events table #########
	tab tag, matcell(ea)
	matrix C=ea+M
	putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
	putexcel A1=matrix(C), names
	
	keep if com_cg35a==1|com_cg35a==2|com_cg35a==5|com_cg35a==6
	*keep if com_cg35==1 /*Keeping only negative shocks. Majority of droughts, floods, epidemics and price_changes were negative*/
	drop tag
	bys dist ta ea com_cg35a: gen t=_n
	
	*Dropping some repeated events
	sort dist ta ea t com_cg35a
	bys dist ta ea: drop if t==2 & (com_cg35a==com_cg35a[_n-1]|com_cg35a==com_cg35a[_n-2]) & (com_cg36==com_cg36[_n-1]| com_cg36==com_cg36[_n-2])
	bys dist ta ea: drop if t==4 & (com_cg35a==com_cg35a[_n-1]|com_cg35a==com_cg35a[_n-2]) & (com_cg36==com_cg36[_n-1]| com_cg36==com_cg36[_n-2])
	bys dist ta ea: drop if t==3 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1]
	drop if com_cg36==. /*missing year*/
	
	gen com_cg35b="drought1" if com_cg35a==1 & t==1
	replace com_cg35b="drought2" if com_cg35a==1 & t==2
	replace com_cg35b="drought3" if com_cg35a==1 & (t==3|t==4)
	replace com_cg35b="flood1" if com_cg35a==2 & t==1
	replace com_cg35b="flood2" if com_cg35a==2 & t==2
	replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
	replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
	replace com_cg35b="price_change1" if com_cg35a==6 & t==1
	replace com_cg35b="price_change2" if com_cg35a==6 & t==2
	replace com_cg35b="price_change3" if com_cg35a==6 & (t==3|t==4)
	
	drop com_cg35a t
	drop if dist==205 & ta==8 & ea==10 & com_cg36==1999 & com_cg35b=="drought3" /*repeated drought for same year*/
	reshape wide com_cg36, i(ea ta dist) j( com_cg35b ) string
	
	label variable com_cg36drought1 "Year 1 Drought reported"
	label variable com_cg36drought2 "Year 2 Drought reported"
	label variable com_cg36drought3 "Year 3 Drought reported"
	*label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
	*label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
	label variable com_cg36flood1 "Year 1 Flood reported"
	label variable com_cg36flood2 "Year 2 Flood reported"
	*label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
	*label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
	label variable com_cg36epidemic1 "Year 1 epidemic reported"
	*label variable com_cg36epidemic2 "Year 2 epidemic reported"
	*label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
	*label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
	label variable com_cg36price_change1 "Year 1 price_change reported"
	label variable com_cg36price_change2 "Year 2 price_change reported"
	label variable com_cg36price_change3 "Year 3 price_change reported"
	*label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
	*label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

	rename (ta ea dist) (a_ta a_ea a_dist)
	tempfile com_cg
	save "`com_cg'", replace
restore

merge m:1 a_ta a_ea a_dist using "`com_cg'", keep(master using match) gen(merge_com_cg)
tab merge_com_cg
drop if merge_com_cg==2
drop merge_com_cg

*COM CE
preserve
	use "${malawiy0}\\Community\mod_e.dta", clear
	isid dist ta ea
	keep dist ta ea ce9- ce15
	drop ce12 ce15 /*Difficult to match with later categories*/
	rename (ce11 ce14) (ce11a ce14a)
	rename ce* com_ce*
	rename (ta ea dist) (a_ta a_ea a_dist)
	tempfile com_ce
	save "`com_ce'", replace
restore

merge m:1 a_ta a_ea a_dist using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CF
preserve
	use "${malawiy0}\Community\mod_f.dta", clear
	isid dist ta ea
	rename cfa cf3
	keep dist ta ea cf2 cf3
	rename cf* com_cf*
	rename (ta ea dist) (a_ta a_ea a_dist)
	tempfile com_cf
	save "`com_cf'", replace
restore

merge m:1 a_ta a_ea a_dist using "`com_cf'", keep(master using match) gen(merge_com_cf)
tab merge_com_cf
drop merge_com_cf

*SECTION U: QUESTIONS OF HH SHOCKS
*Exists but missing in the website

*Merging data of Geovariables for HH. Not provided

save "${work}\malawi_hh_20042005.dta", replace

*INDIVIDUALS: 52716
**SECTION B: HH ROUSTER.
use "${malawiy0}\Household\sec_b.dta", clear
isid case_id memid
*rename (region reside dist ta ea hhid questnum hhwght type add hhsize psu strata) b_=

*SECTION C: EDUCATION, SECTION D: HEALTH, SECTION E: TIME USE AND LABOUR, SECTION V: CHILD ANTHROPOMETRIC.
*Some did not matched completely. 3 master 3 using for merge_c; 12 master 4 using for merge_e; 1422 master for merge_d; 72 master 2 using for merge_ad
foreach pro in c e d ad /*e d ad*/ { 
	preserve
	use "${malawiy0}\Household\sec_`pro'.dta", clear
	isid case_id memid /*Verifying not duplicates*/
	restore
	merge m:m case_id memid using "${malawiy0}\Household\sec_`pro'.dta", keep(master using match) gen(merge_`pro')
	display "Section `pro' merged"
	*drop _merge
}
drop region reside dist ta ea hhid questnum hhwght type add hhsize psu strata /*Decide to keep this from HH data*/
rename total c_total
order case_id memid

*Merging HH and individuals. All matched
merge m:m case_id using "${work}\malawi_hh_20042005.dta", keep(master using match)
drop _merge
svyset a_ea [pweight=a_hhwght], strata(a_strata) singleunit(centered) 

gen survey="Survey-2004-2005"
gen country="Malawi"
order case_id memid survey country a_* a* aa* b* c* d* e* ad*
save "${work}\malawi_ind_20042005.dta", replace

****************************************
* MALAWI LSMS 2010-2011
****************************************
*Agriculture questions at the HH level
use "${malawiy1}\Agriculture\AG_MOD_A_FILT.dta", clear
foreach pro in B C D E F G H {
	*isid case_id
	preserve
	use "${malawiy1}\Agriculture\AG_MOD_`pro'.dta", clear
	duplicates tag case_id, gen(dup_`pro')
	tempfile temp
	save "`temp'", replace
	restore
	merge m:m case_id using "`temp'", keep(master using match) gen(merge_`pro')
	display "Section `pro' merged"
	*drop _merge
}

foreach pro in I J K L M N O P Q {
	*isid case_id 
	merge m:m case_id using "${malawiy1}\Agriculture\AG_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	*drop _merge
	display "Section `pro' merged"
}

foreach pro in R1 R2 S T1 T2  {
	*isid case_id
	merge m:m case_id using "${malawiy1}\Agriculture\AG_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	*drop _merge
	display "Section `pro' merged"
}

merge m:m case_id using "${malawiy1}\Agriculture\AG_NETWORK.dta", keep(master using match) gen(merge_`pro')
*drop _merge
display "Section NETWORK merged"

save "${work}\malawi_ag_20102011.dta", replace

****************************************************************************************************************
*HH QUESTIONS AT THE HH and INDIVIDUAL LEVEL. All HH kept so to have a balanced panel not tracking the same individuals
****************************************************************************************************************
*HH: 12271 
clear
use "${malawiy1}\Household\HH_MOD_A_FILT.dta", clear
isid case_id /*Verifying not duplicates*/
rename (int_outcome_1 int_outcome_2 reside hh_wgt qx_type) hh_a_=
rename (hh_g09 hh_m00 hh_o00 hh_s01 hh_w01) hh_a_= 
*SECTION F: HOUSING
foreach pro in F {
	preserve
	use "${malawiy1}\Household\HH_MOD_`pro'.dta", clear
	isid case_id /*Verifying not duplicates*/
	restore
	merge m:m case_id using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	rename (visit) (hh_f_visit)
	display "Section `pro' merged"
	*drop _merge
}
*Merging IHS-data to get strata and other HH variables
preserve
use "${malawiy1}\ihs3_summary.dta", clear
isid case_id 
restore
merge m:m case_id using "${malawiy1}\ihs3_summary.dta", keep(master using match) gen(merge_ihs)
rename (region urban area district TA strata cluster hhweight hhsize adulteq intmonth intyear month qx_type price_index rexp* ///
 ultrapovline povline poor ultra_poor gap* head* quintil) ihs_=
 
*Merging data of Community to get info of distance to malaria centers.
*COM CD: ACCESS TO BASIC SERVICES
preserve
use "${malawiy1}\Community\COM_CD.dta", clear
isid ea_id
restore
merge m:m ea_id using "${malawiy1}\Community\COM_CD.dta", keep(master using match) gen(merge_com_cd)
tab merge_com_cd
drop merge_com_cd

*COM CG1: CHANGES
preserve
use "${malawiy1}\Community\COM_CG1.dta", clear
isid ea_id
restore
merge m:m ea_id using "${malawiy1}\Community\COM_CG1.dta", keep(master using match) gen(merge_com_cg1)
tab merge_com_cg1
drop merge_com_cg1

*COM CG35
preserve
	use "${malawiy1}\Community\COM_CG2.dta", clear
	*isid ea_id com_cg35a com_cg36
	replace com_cg35a=10 if ea_id=="10202514" & com_cg35a==2 & com_cg37==1 /*repeated flood recorded twice*/
	replace com_cg35a=10 if ea_id=="30506031" & com_cg35a==5 & com_cg37==1 /*repeated epidemic recorded twice*/
	replace com_cg35a=10 if ea_id=="30705391" & com_cg35a==5 & com_cg37==2 /*repeated epidemic recorded twice*/
	
	* Some descriptive statistics for important events taken place in the community-ea
	decode com_cg35a, gen(tag)
	levelsof tag if com_cg35==1, local(rows)
	local nrows : word count `rows'
	matrix M = J(`nrows',1,0)
	matrix colname M = 2010-2011
	matrix rowname M = `rows' 
	*########## EA_events table #########
	tab tag if com_cg35==1, matcell(ea)
	matrix C=ea+M
	putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
	putexcel E1=matrix(C), names
	
	keep if com_cg35a==1|com_cg35a==2|com_cg35a==5|com_cg35a==6
	keep if com_cg35==1 /*Keeping only negative shocks. Majority of droughts, floods, epidemics and price_changes were negative*/
	drop com_cg35a_os com_cg35 tag
	bys ea_id com_cg35a: gen t=_n
	
	*Dropping some repeated events
	bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]
	
	gen com_cg35b="drought1" if com_cg35a==1 & t==1
	replace com_cg35b="drought2" if com_cg35a==1 & t==2
	replace com_cg35b="flood1" if com_cg35a==2 & t==1
	replace com_cg35b="flood2" if com_cg35a==2 & t==2
	replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
	replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
	replace com_cg35b="price_change1" if com_cg35a==6 & t==1
	replace com_cg35b="price_change2" if com_cg35a==6 & t==2
	drop com_cg35a t
	reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string
	
	label variable com_cg36drought1 "Year 1 Drought reported"
	label variable com_cg36drought2 "Year 2 Drought reported"
	label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
	label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
	label variable com_cg36flood1 "Year 1 Flood reported"
	label variable com_cg36flood2 "Year 2 Flood reported"
	label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
	label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
	label variable com_cg36epidemic1 "Year 1 epidemic reported"
	label variable com_cg36epidemic2 "Year 2 epidemic reported"
	label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
	label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
	label variable com_cg36price_change1 "Year 1 price_change reported"
	label variable com_cg36price_change2 "Year 2 price_change reported"
	label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
	label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

	tempfile com_cg
	save "`com_cg'", replace
restore

merge m:1 ea_id using "`com_cg'", keep(master using match) gen(merge_com_cg)
tab merge_com_cg
drop merge_com_cg

*COM CE
preserve
	use "${malawiy1}\Community\COM_CE.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	tempfile com_ce
	save "`com_ce'", replace
restore

merge m:1 ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CF
preserve
	use "${malawiy1}\Community\COM_CF.dta", clear
	isid ea_id
	keep ea_id com_cf02-com_cf06
	tempfile com_cf
	save "`com_cf'", replace
restore

merge m:1 ea_id using "`com_cf'", keep(master using match) gen(merge_com_cf)
tab merge_com_cf
drop merge_com_cf

*COM CH
preserve
	use "${malawiy1}\Community\COM_CH.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch0b_os com_ch07c
	replace com_ch0b_os="" if com_ch0b==118 & com_ch07c==2 /*2 corresponds to NO. This item for other does not apply to question com_ch07c*/
	reshape wide com_ch07c com_ch0b_os , i(ea_id) j( com_ch0b )
	drop com_ch0b_os101 com_ch0b_os102 com_ch0b_os103 com_ch0b_os104 com_ch0b_os105 com_ch0b_os106 com_ch0b_os107 com_ch0b_os108 com_ch0b_os109 com_ch0b_os110 ///
	     com_ch0b_os111 com_ch0b_os112 com_ch0b_os113 com_ch0b_os114 com_ch0b_os115 com_ch0b_os116 com_ch0b_os117
	order ea_id com_ch07c*
	rename com_ch0b_os118 com_ch07c118a
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"
	tempfile com_ch
	save "`com_ch'", replace
restore

merge m:1 ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

*SECTION K: ONLY QUESTION OF MOSQUITO NETS EXPENSES
preserve
use "${malawiy1}\Household\HH_MOD_K.dta", clear /*Also 12271 HH*/
isid case_id hh_k02 /*Verifying not duplicates*/
keep if hh_k02==404
rename (visit ea_id) hh_k_=
tempfile sec_k
save "`sec_k'", replace
restore

merge m:m case_id using "`sec_k'", keep(master using match) gen(merge_K)
tab merge_K
drop merge_K

*SECTION K: ONLY QUESTION OF LOBOLA
preserve
use "${malawiy1}\Household\HH_MOD_K.dta", clear /*Also 12271 HH*/
isid case_id hh_k02 /*Verifying not duplicates*/
keep if hh_k02==415
rename (hh_k01 hh_k03) (k_lobola k_lobola_pay)
keep k_* case_id
tempfile sec_k2
save "`sec_k2'", replace
restore

merge m:m case_id using "`sec_k2'", keep(master using match) gen(merge_K2)
tab merge_K2
drop merge_K2

*SECTION K: ONLY QUESTION OF MARRIAGE COSTS
preserve
use "${malawiy1}\Household\HH_MOD_K.dta", clear /*Also 12271 HH*/
isid case_id hh_k02 /*Verifying not duplicates*/
keep if hh_k02==416
rename (hh_k01 hh_k03) (k_marriage k_marriage_pay)
keep k_* case_id
tempfile sec_k3
save "`sec_k3'", replace
restore

merge m:m case_id using "`sec_k3'", keep(master using match) gen(merge_K3)
tab merge_K3
drop merge_K3

*SECTION U: QUESTIONS OF HH SHOCKS. THERE IS A PROBLEM SO SOME HH RECORDED TWICE THE MOST SEVERE SHOCK OR THE SECOND MOST SEVERE. DISCARD THOSE CASES BETTER

preserve
use "${malawiy1}\Household\HH_MOD_U.dta", clear 
isid case_id hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==1) // keeping the 1 most severe shock
duplicates tag case_id hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep case_id hh_u0a //only the info I need
rename hh_u0a hh_shock1
tempfile sec_u1
save "`sec_u1'", replace
restore

merge m:1 case_id using "`sec_u1'", keep(master using match) gen(merge_U1)
tab merge_U1
drop merge_U1

preserve
use "${malawiy1}\Household\HH_MOD_U.dta", clear 
isid case_id hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==2) // keeping the 2 most severe shock
duplicates tag case_id hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep case_id hh_u0a //only the info I need
rename hh_u0a hh_shock2
tempfile sec_u2
save "`sec_u2'", replace
restore

merge m:1 case_id using "`sec_u2'", keep(master using match) gen(merge_U2)
tab merge_U2
drop merge_U2

preserve
use "${malawiy1}\Household\HH_MOD_U.dta", clear 
isid case_id hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==3) // keeping the 3 most severe shock
duplicates tag case_id hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep case_id hh_u0a //only the info I need
rename hh_u0a hh_shock3
tempfile sec_u3
save "`sec_u3'", replace
restore

merge m:1 case_id using "`sec_u3'", keep(master using match) gen(merge_U3)
tab merge_U3
drop merge_U3

*Merging data of Geovariables for HH. To respect confidentiality of HH, they computed average of household GPS coordinates in each EA, applied a 
*random offset within a specified range of the average EA location and provided the off-set EA latitudes and longitudes
preserve
use "${malawiy1}\Geovariables\HouseholdGeovariables.dta", clear
isid case_id
rename * hh_geo_=
rename hh_geo_case_id case_id
tempfile geos
save "`geos'", replace 
restore
merge m:m case_id using "`geos'", keep(master using match) gen(merge_geo)
tab merge_geo
drop merge_geo

*Working with Weather Variables to homogenize
rename hh_geo_srtm_eaf elevation
rename (hh_geo_srtm_eaf_5_15 hh_geo_lat_modified hh_geo_lon_modified) (hh_geo_srtm_mwi_5_15 hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD)  /*keep name of 2013*/

save "${work}\malawi_hh_20102011.dta", replace

*INDIVIDUALS: 56409
**SECTION B: HH ROUSTER. it seems that some of the questions for the same HH were answered during visit 1, and others during visit 2
use "${malawiy1}\Household\HH_MOD_B.dta", clear
isid case_id id_code
rename (visit qx_type status) hh_b_=

*SECTION C: EDUCATION, SECTION D: HEALTH, SECTION E: TIME USE AND LABOUR, SECTION V: CHILD ANTHROPOMETRIC.
*The 4 datasets have the same identifier with 56218 obs. After merging, 191 (56409-56218) didn't merge with obs in B, so they only have questions B.
foreach pro in C D E V { 
	preserve
	use "${malawiy1}\Household\HH_MOD_`pro'.dta", clear
	isid case_id id_code /*Verifying not duplicates*/
	restore
	merge m:m case_id id_code using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	rename (visit) (hh_`pro'_visit)
	display "Section `pro' merged"
	*drop _merge
}
rename (hh_C_visit hh_D_visit hh_E_visit hh_V_visit) (hh_c_visit hh_d_visit hh_e_visit hh_v_visit)
*Comparing visit variable (for some reason, they differ a bit.
gen dif1=hh_c_visit-hh_d_visit
gen dif2=hh_c_visit-hh_e_visit
gen dif3=hh_c_visit-hh_v_visit
tab dif1 dif2
tab dif1 dif3 /*for C,D, E and V, they are exactly the same*/
drop dif1 dif2 dif3
tab hh_c_visit hh_b_visit /*Keep in mind in the case it is needed later on*/
 
/* 
*HH CONSUMPTION PER ITEM. Not needed yet
foreach pro in G1 {
	merge m:m case_id id_code using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match)
	display "Section `pro' merged"
	drop _merge
}
*SECTION H: FOOD SECURITY, SECTION I: NON-FOOD EXPENDITURES 1 MONTHS, SECTION J: NON FOOD EXPENDITURE 3 MONTHS
foreach pro in G2 G3 H I1 I2 J {
	merge m:m case_id id_code using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match)
	display "Section `pro' merged"
	drop _merge
}
*SECTION K: NON FOOD EXPENDITURE 12 MONTHS, SECTION L: DURABLE GOODS, SECTION M: FARM IMPLEMENTS, SECTION N: HH ENTERPRISES
foreach pro in K L M N1 N2 {
	merge m:m case_id id_code using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match)
	display "Section `pro' merged"
	drop _merge
}
*/
*W does not have id_code identifier, so better aggregate by HH before merging if it wants to be used
/*
foreach pro in W { /*O P Q R S1 S2 T U W X*/
	merge m:m case_id using "${malawiy1}\Household\HH_MOD_`pro'.dta", keep(master using match)
	display "Section `pro' merged"
	drop _merge
}
*/
order case_id id_code

*Merging HH and individuals
merge m:1 case_id using "${work}\malawi_hh_20102011.dta", keep(master using match)
gen merge_B=merge_C
drop _merge merge_C merge_D merge_E merge_F merge_V merge_ihs
svyset ea_id [pweight=hh_a_hh_wgt], strata(ihs_strata) singleunit(centered) 

gen survey="Survey-2010-2011"
gen country="Malawi"
order ea_id case_id id_code survey country hh_a* hh_b* hh_c* hh_d* hh_e* hh_f* hh_v*
save "${work}\malawi_ind_20102011.dta", replace

****************************************
* MALAWI LSMS 2013
****************************************
*HH: 4000
clear
use "${malawiy2}\Household\HH_MOD_A_FILT.dta", clear
isid y2_hhid /*Verifying not duplicates*/
rename (occ HHID case_id ea_id stratum baseline_rural panelweight region district reside dist_to_IHS3location hhsize interview_status qx_type hh_*) hh_a_=
rename (hh_a_hh_a*) (hh_a*)
*SECTION F: HOUSING
foreach pro in F {
	preserve
	use "${malawiy2}\Household\HH_MOD_`pro'.dta", clear
	isid y2_hhid /*Verifying not duplicates*/
	restore
	merge m:m y2_hhid using "${malawiy2}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	rename (occ qx_type interview_status) hh_f_=
	display "Section `pro' merged"
	*drop _merge
}
*Merging IHS-data to get strata and other HH variables
preserve
use "${malawiy2}\IHPSMemberDatabase.dta", clear
isid PID
tab status /*display 1-14165/(15597-22-274)=07424351. This is the attrition result for the individuals traced from 2010. See page 6 in pdf BID*/ 
restore

*Merging data of Community to get info of distance to malaria centers.
*COM CD: ACCESS TO BASIC SERVICES
preserve
	use "${malawiy2}\Community\COM_MOD_D.dta", clear
	isid ea_id
	rename (ea_id occ) (hh_a_ea_id com_cd_occ)
	tempfile com_cd
	save "`com_cd'", replace 
restore

merge m:m hh_a_ea_id using "`com_cd'", keep(master using match) gen(merge_com_cd)
tab merge_com_cd
drop merge_com_cd

*COM CG35
preserve
	use "${malawiy2}\Community\COM_MOD_G.dta", clear
	replace com_cg36=. if com_cg36==201|com_cg36==203 /*Unfortunately, no idea which year it is. Better to missing*/
	replace com_cg37=. if com_cg36==201|com_cg36==203
	replace com_cg35c=. if com_cg36==201|com_cg36==203
	
	* Some descriptive statistics for important events taken place in the community-ea
	decode com_cg35c, gen(tag)
	levelsof tag if occ<6, local(rows)
	local nrows : word count `rows'
	matrix M = J(`nrows',1,0)
	matrix colname M = 2013
	matrix rowname M = `rows' 
	*########## EA_events table #########
	tab tag if occ<6, matcell(ea)
	matrix C=ea+M
	putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
	putexcel I1=matrix(C), names
	drop tag
	
	*isid ea_id com_cg35a com_cg36
	drop if occ>5 /*those are better off events*/
	drop if occ==1 
	keep if com_cg35c==1|com_cg35c==2|com_cg35c==5|com_cg35c==6
	drop occ com_cg35a com_cg35b
	rename com_cg35c com_cg35a
	bys ea_id com_cg35a: gen t=_n
	
	*Dropping some repeated events
	bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]
	
	gen com_cg35b="drought1" if com_cg35a==1 & t==1
	replace com_cg35b="drought2" if com_cg35a==1 & t==2
	replace com_cg35b="flood1" if com_cg35a==2 & t==1
	replace com_cg35b="flood2" if com_cg35a==2 & t==2
	replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
	replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
	replace com_cg35b="price_change1" if com_cg35a==6 & t==1
	replace com_cg35b="price_change2" if com_cg35a==6 & t==2
	drop com_cg35a t
	reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string
	
	label variable com_cg36drought1 "Year 1 Drought reported"
	label variable com_cg36drought2 "Year 2 Drought reported"
	label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
	label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
	label variable com_cg36flood1 "Year 1 Flood reported"
	*label variable com_cg36flood2 "Year 2 Flood reported"
	label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
	*label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
	label variable com_cg36epidemic1 "Year 1 epidemic reported"
	*label variable com_cg36epidemic2 "Year 2 epidemic reported"
	label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
	*label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
	label variable com_cg36price_change1 "Year 1 price_change reported"
	label variable com_cg36price_change2 "Year 2 price_change reported"
	label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
	label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"
	
	rename ea_id hh_a_ea_id
	tempfile com_cg
	save "`com_cg'", replace
restore

merge m:1 hh_a_ea_id using "`com_cg'", keep(master using match) gen(merge_com_cg)
tab merge_com_cg
drop merge_com_cg

*COM CE
preserve
	use "${malawiy2}\Community\COM_MOD_E.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	rename (ea_id) (hh_a_ea_id)
	tempfile com_ce
	save "`com_ce'", replace 
restore

merge m:m hh_a_ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CF1. Question cf04-06 not exist
preserve
	use "${malawiy2}\Community\COM_MOD_F1.dta", clear
	isid ea_id
	keep ea_id com_cf02 com_cf03
	rename (ea_id) (hh_a_ea_id)
	tempfile com_cf1
	save "`com_cf1'", replace 
restore

merge m:m hh_a_ea_id using "`com_cf1'", keep(master using match) gen(merge_com_cf1)
tab merge_com_cf1
drop merge_com_cf1

*COM CH. 
preserve
	use "${malawiy2}\Community\COM_MOD_H.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch07c
	reshape wide com_ch07c , i(ea_id) j( com_ch0b )
	rename (ea_id) (hh_a_ea_id)
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"

	tempfile com_ch
	save "`com_ch'", replace 
restore

merge m:m hh_a_ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

*SECTION K: ONLY QUESTION OF MOSQUITO NETS EXPENSES
preserve
use "${malawiy2}\Household\HH_MOD_K.dta", clear /*Also 4000 HH*/
isid y2_hhid hh_k02 /*Verifying not duplicates*/
keep if hh_k02==404
rename (occ qx_type interview_status) hh_k_=
tempfile sec_kk
save "`sec_kk'", replace
restore

merge m:m y2_hhid using "`sec_kk'", keep(master using match) gen(merge_K)
tab merge_K
drop merge_K

*SECTION K: ONLY QUESTION OF LOBOLA
preserve
use "${malawiy2}\Household\HH_MOD_K.dta", clear /*Also 4000 HH*/
isid y2_hhid hh_k02 /*Verifying not duplicates*/
keep if hh_k02==415
rename (hh_k01 hh_k03) (k_lobola k_lobola_pay)
keep k_* y2_hhid
tempfile sec_kk2
save "`sec_kk2'", replace
restore

merge m:m y2_hhid using "`sec_kk2'", keep(master using match) gen(merge_K2)
tab merge_K2
drop merge_K2

*SECTION K: ONLY QUESTION OF MARRIAGE COSTS
preserve
use "${malawiy2}\Household\HH_MOD_K.dta", clear /*Also 4000 HH*/
isid y2_hhid hh_k02 /*Verifying not duplicates*/
keep if hh_k02==416
rename (hh_k01 hh_k03) (k_marriage k_marriage_pay)
keep k_* y2_hhid
tempfile sec_kk3
save "`sec_kk3'", replace
restore

merge m:m y2_hhid using "`sec_kk3'", keep(master using match) gen(merge_K3)
tab merge_K3
drop merge_K3

*SECTION U: QUESTIONS OF HH SHOCKS. THERE IS A PROBLEM SO SOME HH RECORDED TWICE THE MOST SEVERE SHOCK OR THE SECOND MOST SEVERE. DISCARD THOSE CASES BETTER
preserve
use "${malawiy2}\Household\HH_MOD_U.dta", clear 
isid y2_hhid hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==1) // keeping the 1 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification
duplicates tag y2_hhid hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep y2_hhid hh_u0a //only the info I need
rename hh_u0a hh_shock1
tempfile sec_u1
save "`sec_u1'", replace
restore

merge m:1 y2_hhid using "`sec_u1'", keep(master using match) gen(merge_U1)
tab merge_U1
drop merge_U1

preserve
use "${malawiy2}\Household\HH_MOD_U.dta", clear 
isid y2_hhid hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==2) // keeping the 2 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification
duplicates tag y2_hhid hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep y2_hhid hh_u0a //only the info I need
rename hh_u0a hh_shock2
tempfile sec_u2
save "`sec_u2'", replace
restore

merge m:1 y2_hhid using "`sec_u2'", keep(master using match) gen(merge_U2)
tab merge_U2
drop merge_U2

preserve
use "${malawiy2}\Household\HH_MOD_U.dta", clear 
isid y2_hhid hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==3) // keeping the 3 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification
duplicates tag y2_hhid hh_u02, gen(dup) /*unfortunately, some hh recorded more than 1 severe shock. No idea which one to choose, better drop them*/
drop if dup==1 | dup==2
keep y2_hhid hh_u0a //only the info I need
rename hh_u0a hh_shock3
tempfile sec_u3
save "`sec_u3'", replace
restore

merge m:1 y2_hhid using "`sec_u3'", keep(master using match) gen(merge_U3)
tab merge_U3
drop merge_U3

*Merging data of Geovariables for HH. To respect confidentiality of HH, they computed average of household GPS coordinates in each EA, applied a 
*random offset within a specified range of the average EA location and provided the off-set EA latitudes and longitudes
preserve
use "${malawiy2}\Geovariables\HouseholdGeovariables_IHPS.dta", clear
isid y2_hhid
rename * hh_geo_=
rename hh_geo_y2_hhid y2_hhid
tempfile geo
save "`geo'", replace 
restore
merge m:m y2_hhid using "`geo'", keep(master using match) gen(merge_geo)
tab merge_geo
drop merge_geo

*Working with Weather Variables to homogenize
rename hh_geo_srtm_1k elevation

*Adding question of who respondend Module B of migration question
preserve
use "${malawiy2}\Household\HH_META.dta", clear
isid y2_hhid
keep y2_hhid hh_b_respondent
tempfile resp
save "`resp'", replace
restore

merge m:m y2_hhid using "`resp'", keep(master using match) gen(merge_resp)
tab merge_resp
drop merge_resp

save "${work}\malawi_hh_2013.dta", replace

*INDIVIDUALS: 20220
**SECTION B: HH ROUSTER. it seems that some of the questions for the same HH were answered during visit 1, and others during visit 2
use "${malawiy2}\Household\HH_MOD_B.dta", clear
isid y2_hhid PID 
rename (occ qx_type interview_status hhmember baselinemembercount baselinemember hhsize individualmover moverbasehh) hh_b_=

*SECTION C: EDUCATION, SECTION D: HEALTH, SECTION E: TIME USE AND LABOUR, SECTION V: CHILD ANTHROPOMETRIC.
*The 4 datasets have the same identifier with 20219 in C, D, E and 20217 in V.
foreach pro in C D E V { 
	preserve
	use "${malawiy2}\Household\HH_MOD_`pro'.dta", clear
	isid y2_hhid PID /*Verifying not duplicates*/
	restore
	merge m:m y2_hhid PID using "${malawiy2}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	rename (occ qx_type interview_status) hh_`pro'_=
	display "Section `pro' merged"
	*drop _merge
}

rename *, lower
rename pid PID

*Comparing occ qx_type interview_status if they differ.
tab hh_b_occ hh_c_occ
tab hh_d_occ hh_e_occ
tab hh_b_occ hh_e_occ /*They seem to be the same for the obs that matched*/
gen dif1=hh_c_occ-hh_d_occ
gen dif2=hh_e_occ-hh_v_occ
gen dif3=hh_b_occ-hh_c_occ
tab dif1 dif2
tab dif2 dif3

drop dif1 dif2 dif3 hh_c_occ hh_d_occ hh_e_occ hh_v_occ

order y2_hhid PID

*Merging HH and individuals
merge m:m y2_hhid using "${work}\malawi_hh_2013.dta", keep(master using match) gen(merge_hh)
drop merge_F merge_hh merge_d merge_e hh_a_occ hh_f_occ
svyset hh_a_ea_id [pweight=hh_a_panelweight], strata(hh_a_stratum) singleunit(centered)

gen survey="Survey-2013"
gen country="Malawi"
order y2_hhid PID survey country hh_a* hh_b* hh_c* hh_d* hh_e* hh_f* hh_v*
save "${work}\malawi_ind_2013.dta", replace

****************************************
* MALAWI LSMS 2016/2017
****************************************
*HH: 4000
clear
use "${malawiy3}\Household\HH_MOD_A_FILT.dta", clear
isid HHID /*Verifying not duplicates*/
rename (region district reside interviewDate hh_*) hh_a_=
*rename (hh_a_hh_a*) (hh_a*)
*SECTION F: HOUSING
foreach pro in F {
	preserve
	use "${malawiy3}\Household\HH_MOD_`pro'.dta", clear
	isid HHID /*Verifying not duplicates*/
	restore
	merge m:m case_id HHID using "${malawiy3}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	*rename (occ qx_type interview_status) hh_f_=
	display "Section `pro' merged"
	drop merge_`pro'
}

*Merging data of Community to get info of distance to malaria centers.
*COM CD: ACCESS TO BASIC SERVICES
preserve
	use "${malawiy3}\Community\COM_CD.dta", clear
	isid ea_id
	tempfile com_cd
	save "`com_cd'", replace 
restore

merge m:1 ea_id using "`com_cd'", keep(master using match) gen(merge_com_cd)
tab merge_com_cd
drop merge_com_cd

*COM CG35
preserve
	use "${malawiy3}\Community\COM_CG.dta", clear
	*isid ea_id com_cg35a com_cg36
	drop if occ>5 /*those are better off events*/
	drop if occ==1
	replace com_cg35c=3 if com_cg35c==1 & com_cg35b=="crops disease" /*Mistake recording same event as they were different*/
	replace com_cg35c=10 if ea_id=="30302573" & com_cg35c==2 & com_cg37==4 /*repeated flood recorded twice*/
	replace com_cg35c=10 if ea_id=="30503622" & com_cg35c==2 & com_cg37==3 /*repeated flood recorded twice*/
	replace com_cg35c=10 if ea_id=="20611402" & com_cg35c==6 & com_cg37==2 /*repeated price_change recorded twice*/
	replace com_cg35c=10 if ea_id=="31301809" & com_cg35c==6 & com_cg37==4 /*repeated price_change recorded twice*/ 
	
	* Some descriptive statistics for important events taken place in the community-ea
	decode com_cg35c, gen(tag)
	levelsof tag, local(rows)
	local nrows : word count `rows'
	matrix M = J(`nrows',1,0)
	matrix colname M = 2016-2017
	matrix rowname M = `rows' 
	*########## EA_events table #########
	tab tag, matcell(ea)
	matrix C=ea+M
	putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
	putexcel M1=matrix(C), names
	drop tag
		
	keep if com_cg35c==1|com_cg35c==2|com_cg35c==5|com_cg35c==6
	drop com_cg35a com_cg35b com_cg35c_oth
	rename com_cg35c com_cg35a
	bys ea_id com_cg35a: gen t=_n
	*Dropping some repeated events
	*bys ea_id: drop if t==3 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]
	bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]
	
	gen com_cg35b="drought1" if com_cg35a==1 & t==1
	replace com_cg35b="drought2" if com_cg35a==1 & t==2
	replace com_cg35b="flood1" if com_cg35a==2 & t==1
	replace com_cg35b="flood2" if com_cg35a==2 & t==2
	replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
	replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
	replace com_cg35b="price_change1" if com_cg35a==6 & t==1
	replace com_cg35b="price_change2" if com_cg35a==6 & t==2
	drop com_cg35a t occ
	reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string
	
	label variable com_cg36drought1 "Year 1 Drought reported"
	label variable com_cg36drought2 "Year 2 Drought reported"
	label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
	label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
	label variable com_cg36flood1 "Year 1 Flood reported"
	label variable com_cg36flood2 "Year 2 Flood reported"
	label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
	label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
	label variable com_cg36epidemic1 "Year 1 epidemic reported"
	label variable com_cg36epidemic2 "Year 2 epidemic reported"
	label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
	label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
	label variable com_cg36price_change1 "Year 1 price_change reported"
	label variable com_cg36price_change2 "Year 2 price_change reported"
	label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
	label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"
	
	tempfile com_cg
	save "`com_cg'", replace
restore

merge m:1 ea_id using "`com_cg'", keep(master using match) gen(merge_com_cg)
tab merge_com_cg
drop merge_com_cg

*COM CE
preserve
	use "${malawiy3}\Community\COM_CE.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	tempfile com_ce
	save "`com_ce'", replace 
restore

merge m:m ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CF1. Question cf04-06 not exist
preserve
	use "${malawiy3}\Community\COM_CF1.dta", clear
	isid ea_id
	keep ea_id com_cf02 com_cf03
	tempfile com_cf1
	save "`com_cf1'", replace 
restore

merge m:m ea_id using "`com_cf1'", keep(master using match) gen(merge_com_cf1)
tab merge_com_cf1
drop merge_com_cf1

*COM CH. 
preserve
	use "${malawiy3}\Community\com_ch.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch07c
	reshape wide com_ch07c , i(ea_id) j( com_ch0b )
	gen com_ch07c118a="COMMUNITY BASED CHILD CARE CENTER/NURSE" if com_ch07c1081==1 /*Defined as others*/
	drop com_ch07c1081
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"
	tempfile com_ch
	save "`com_ch'", replace 
restore

merge m:m ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

*SECTION K: ONLY QUESTION OF MOSQUITO NETS EXPENSES
preserve
use "${malawiy3}\Household\HH_MOD_K1.dta", clear /*Also 4000 HH*/
 isid case_id HHID hh_k02 /*Verifying not duplicates*/
keep if hh_k02==404
tempfile sec_kk
save "`sec_kk'", replace
restore

merge m:m case_id HHID using "`sec_kk'", keep(master using match) gen(merge_K)
tab merge_K
drop merge_K

*SECTION K: ONLY QUESTION OF LOBOLA
preserve
use "${malawiy3}\Household\HH_MOD_K1.dta", clear /*Also 4000 HH*/
isid case_id HHID hh_k02 /*Verifying not duplicates*/
keep if hh_k02==415
rename (hh_k01 hh_k03) (k_lobola k_lobola_pay)
keep k_* case_id HHID
tempfile sec_kk2
save "`sec_kk2'", replace
restore

merge m:m case_id HHID using "`sec_kk2'", keep(master using match) gen(merge_K2)
tab merge_K2
drop merge_K2

*SECTION K: ONLY QUESTION OF MARRIAGE COSTS
preserve
use "${malawiy3}\Household\HH_MOD_K1.dta", clear /*Also 4000 HH*/
isid case_id HHID hh_k02 /*Verifying not duplicates*/
keep if hh_k02==416
rename (hh_k01 hh_k03) (k_marriage k_marriage_pay)
keep k_* case_id HHID
tempfile sec_kk3
save "`sec_kk3'", replace
restore

merge m:m case_id HHID using "`sec_kk3'", keep(master using match) gen(merge_K3)
tab merge_K3
drop merge_K3

*SECTION U: QUESTIONS OF HH SHOCKS
preserve
use "${malawiy3}\Household\HH_MOD_U.dta", clear 
isid HHID hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==1) // keeping the 1 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification to match with 2010-2011
keep HHID case_id hh_u0a //only the info I need
rename hh_u0a hh_shock1
tempfile sec_u1
save "`sec_u1'", replace
restore

merge m:1 case_id HHID using "`sec_u1'", keep(master using match) gen(merge_U1)
tab merge_U1
drop merge_U1

preserve
use "${malawiy3}\Household\HH_MOD_U.dta", clear 
isid HHID hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==2) // keeping the 2 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification to match with 2010-2011
keep case_id HHID hh_u0a //only the info I need
rename hh_u0a hh_shock2
tempfile sec_u2
save "`sec_u2'", replace
restore

merge m:1 HHID case_id using "`sec_u2'", keep(master using match) gen(merge_U2)
tab merge_U2
drop merge_U2

preserve
use "${malawiy3}\Household\HH_MOD_U.dta", clear 
isid HHID hh_u0a /*Verifying not duplicates*/
keep if hh_u01==1 & (hh_u02==3) // keeping the 3 most severe shock
recode hh_u0a (1101=101) (1102=102) //recoding some mispecification to match with 2010-2011
keep HHID case_id hh_u0a //only the info I need
rename hh_u0a hh_shock3
tempfile sec_u3
save "`sec_u3'", replace
restore

merge m:1 HHID case_id using "`sec_u3'", keep(master using match) gen(merge_U3)
tab merge_U3
drop merge_U3

*Merging data of Geovariables for HH. To respect confidentiality of HH, they computed average of household GPS coordinates in each EA, applied a 
*random offset within a specified range of the average EA location and provided the off-set EA latitudes and longitudes
preserve
use "${malawiy3}\Geovariables\HouseholdGeovariablesIHS4.dta", clear
isid HHID
rename * hh_geo_=
rename (hh_geo_HHID hh_geo_case_id) (HHID case_id)
tempfile geo
save "`geo'", replace 
restore
merge m:1 HHID case_id using "`geo'", keep(master using match) gen(merge_geo)
tab merge_geo
drop merge_geo

*Working with Weather Variables to homogenize
rename hh_geo_srtm_1k elevation
rename (hh_geo_lat_modified hh_geo_lon_modified) (hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD)  /*keep name of 2013*/

*Adding question of who respondend Module B of migration question
preserve
use "${malawiy3}\Household\HH_METADATA.dta", clear
isid HHID case_id
keep moduleB_respondent case_id HHID
tempfile resp
save "`resp'", replace
restore

merge m:m HHID case_id using "`resp'", keep(master using match) gen(merge_resp)
tab merge_resp
drop merge_resp

save "${work}\malawi_hh_20162017.dta", replace

*INDIVIDUALS: 53885
**SECTION B: HH ROUSTER. it seems that some of the questions for the same HH were answered during visit 1, and others during visit 2
use "${malawiy3}\Household\HH_MOD_B.dta", clear
isid HHID case_id PID 

*SECTION C: EDUCATION, SECTION D: HEALTH, SECTION E: TIME USE AND LABOUR, SECTION V: CHILD ANTHROPOMETRIC.
*The 4 datasets have the same identifier with 53885 in C, D, E and V.
foreach pro in C D E V { 
	preserve
	use "${malawiy3}\Household\HH_MOD_`pro'.dta", clear
	isid HHID case_id PID /*Verifying not duplicates*/
	restore
	merge m:1 HHID case_id PID using "${malawiy3}\Household\HH_MOD_`pro'.dta", keep(master using match) gen(merge_`pro')
	*rename (occ qx_type interview_status) hh_`pro'_=
	display "Section `pro' merged"
	*drop _merge
}

order HHID case_id PID

*Merging HH and individuals
merge m:m HHID case_id using "${work}\malawi_hh_20162017.dta", keep(master using match) gen(merge_hh)
drop merge_*
*svyset ea_id [pweight=hh_a_hh_wgt], strata(hh_a_stratum) singleunit(centered)

gen survey="Survey-2016-2017"
gen country="Malawi"
order HHID case_id PID survey country hh_a* hh_b* hh_c* hh_d* hh_e* hh_f* hh_v*
save "${work}\malawi_ind_20162017.dta", replace




