*********************************************************************************
* 			THIS PROGRAM BUILDS THE DATA SET FOR DROUGHTS AND MASAF USING COMMUNITY QUESTIONNAIRES *
*            TO MERGE LATER ON													*
*                WRITTEN BY LUIS GUILLERMO BECERRA                              *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 11000
set maxvar 30000
cap log close
			
*cd "/home/l.becerra/U/PSE-Proposal Malaria and paper/INPUT"
*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
cd "U:\PSE-Proposal Malaria and paper\INPUT"

global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS\panel_josellin"
global results2  "..\RESULTS V2"

global malawiy0 "..\INPUT\LSMS Surveys\Malawi\2004-2005\STATA FILES"
global malawiy1 "..\INPUT\LSMS Surveys\Malawi\2010-2011\STATA FILES"
global malawiy2 "..\INPUT\LSMS Surveys\Malawi\2013\STATA FILES\MWI_2013"
global malawiy3 "..\INPUT\LSMS Surveys\Malawi\2016-2017\STATA FILES"  

******************
** 2004-2005
******************

*DROUGHT EVENTS
use "${malawiy0}\Community\mod_g50worse.dta", clear
*isid ea_id com_cg35a com_cg36
*Coding categories
drop if item_no==0
rename (cg50_2 cg51)  (com_cg35a com_cg36)
label define COM_CG35 1 "DROUGHT" 2 "FLOOD" 3 "CROP DISEASE/PESTS" 4 "LIVESTOCK DISEASE" 5 "HUMAN EPIDEMIC DISEASE" 6 "SHARP CHANGE IN PRICES" 7 "MASSIVE JOB LAY-OFFS" 8 "LOSS OF KEY SOCIAL SERVICE (S)" ///
					  9 "POWER OUTAGE(S)" 10 "OTHER BAD (SPECIFY)" 11 "DEVELOPMENT PROJECT" 12 "NEW EMPLOYMENT OPPORTUNITIES" 13 "NEW HEALTH FACILITY" 14 "NEW ROAD" 15 "NEW SCHOOL" 16 "IMPROVED TRANSPORTATION" ///
					  17 "ON-GRID ELECTRICITY" 18 "OFF-GRID ELECTRICITY" 19 "MAREP" 20 "OTHER GOOD (SPECIFY)"
label define COM_CG37 1 "ALMOST NONE" 2 "1/4" 3 "1/2" 4 "3/4" 5 "ALMOST ALL"
recode com_cg35a (9=10) (10=11) (14=15) (15=10)
label values com_cg35a COM_CG35 
drop cg52 item_no cg50 /*question of % of people affected is badly reported with mistakes and difficult to match with other surveys. Better drop it*/
* Some descriptive statistics for important events taken place in the community-ea
decode com_cg35a, gen(tag)
levelsof tag, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',1,0)
matrix colname M = 2004-2005
matrix rowname M = `rows' 
*########## EA_events table #########
tab tag, matcell(ea)
matrix C=ea+M
putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
putexcel A1=matrix(C), names

keep if com_cg35a==1|com_cg35a==2|com_cg35a==5|com_cg35a==6
*keep if com_cg35==1 /*Keeping only negative shocks. Majority of droughts, floods, epidemics and price_changes were negative*/
drop tag
bys dist ta ea com_cg35a: gen t=_n

*Dropping some repeated events
sort dist ta ea t com_cg35a
bys dist ta ea: drop if t==2 & (com_cg35a==com_cg35a[_n-1]|com_cg35a==com_cg35a[_n-2]) & (com_cg36==com_cg36[_n-1]| com_cg36==com_cg36[_n-2])
bys dist ta ea: drop if t==4 & (com_cg35a==com_cg35a[_n-1]|com_cg35a==com_cg35a[_n-2]) & (com_cg36==com_cg36[_n-1]| com_cg36==com_cg36[_n-2])
bys dist ta ea: drop if t==3 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1]
drop if com_cg36==. /*missing year*/

gen com_cg35b="drought1" if com_cg35a==1 & t==1
replace com_cg35b="drought2" if com_cg35a==1 & t==2
replace com_cg35b="drought3" if com_cg35a==1 & (t==3|t==4)
replace com_cg35b="flood1" if com_cg35a==2 & t==1
replace com_cg35b="flood2" if com_cg35a==2 & t==2
replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
replace com_cg35b="price_change1" if com_cg35a==6 & t==1
replace com_cg35b="price_change2" if com_cg35a==6 & t==2
replace com_cg35b="price_change3" if com_cg35a==6 & (t==3|t==4)

drop com_cg35a t
drop if dist==205 & ta==8 & ea==10 & com_cg36==1999 & com_cg35b=="drought3" /*repeated drought for same year*/
reshape wide com_cg36, i(ea ta dist) j( com_cg35b ) string

label variable com_cg36drought1 "Year 1 Drought reported"
label variable com_cg36drought2 "Year 2 Drought reported"
*label variable com_cg36drought3 "Year 3 Drought reported"
*label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
*label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
label variable com_cg36flood1 "Year 1 Flood reported"
label variable com_cg36flood2 "Year 2 Flood reported"
*label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
*label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
label variable com_cg36epidemic1 "Year 1 epidemic reported"
*label variable com_cg36epidemic2 "Year 2 epidemic reported"
*label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
*label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
label variable com_cg36price_change1 "Year 1 price_change reported"
label variable com_cg36price_change2 "Year 2 price_change reported"
label variable com_cg36price_change3 "Year 3 price_change reported"
*label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
*label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

*COM CE. MASAF questions
preserve
	use "${malawiy0}\\Community\mod_e.dta", clear
	isid dist ta ea
	keep dist ta ea ce9- ce15
	drop ce12 ce15 /*Difficult to match with later categories*/
	rename (ce11 ce14) (ce11a ce14a)
	rename ce* com_ce*
	tempfile com_ce
	save "`com_ce'", replace
restore

merge m:1 ta ea dist using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*Generating eaid
tostring ta, gen(ta1)
tostring ea, gen(ea1)
foreach x in 1 2 3 4 5 6 7 8 9 {
	replace ta1="0`x'" if ta1=="`x'"
	replace ea1="00`x'" if ea1=="`x'"
}
foreach x in 10 11 12 13 14	15 16 17 18	19 20 21 22	23 24 25 26	27 ///
		28 29 30 31 32 33 34 35 36 37 38 39 40 41 43 44 45 46 47 48 49 50 51 ///
		52 53 54 55	56 58 59 60	61 62 63 64	66 67 68 69	70 72 73 74	75 76 78 ///
		81 82 83 84 86 89 90 91	98 {
	replace ea1="0`x'" if ea1=="`x'"
}
tostring dist, gen(dist1)

gen eaid=dist1+ta1+ea1

drop dist dist1 ta ta1 ea1 ea 	
rename com_ce9 com_ce09

gen survey="Survey-2004-2005"

tempfile malawi_y0
save "`malawi_y0'", replace

******************
** 2010-2011
******************

*DROUGHT EVENTS
*COM CG35
use "${malawiy1}\Community\COM_CG2.dta", clear
replace com_cg35a=10 if ea_id=="10202514" & com_cg35a==2 & com_cg37==1 /*repeated flood recorded twice*/
replace com_cg35a=10 if ea_id=="30506031" & com_cg35a==5 & com_cg37==1 /*repeated epidemic recorded twice*/
replace com_cg35a=10 if ea_id=="30705391" & com_cg35a==5 & com_cg37==2 /*repeated epidemic recorded twice*/

*isid ea_id com_cg35a com_cg36

* Some descriptive statistics for important events taken place in the community-ea
decode com_cg35a, gen(tag)
levelsof tag if com_cg35==1, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',1,0)
matrix colname M = 2010-2011
matrix rowname M = `rows' 
*########## EA_events table #########
tab tag if com_cg35==1, matcell(ea)
matrix C=ea+M
putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
putexcel E1=matrix(C), names

keep if com_cg35a==1|com_cg35a==2|com_cg35a==5|com_cg35a==6
keep if com_cg35==1 /*Keeping only negative shocks. Majority of droughts, floods, epidemics and price_changes were negative*/
drop com_cg35a_os com_cg35 tag
bys ea_id com_cg35a: gen t=_n

*Dropping some repeated events
bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]

gen com_cg35b="drought1" if com_cg35a==1 & t==1
replace com_cg35b="drought2" if com_cg35a==1 & t==2
replace com_cg35b="flood1" if com_cg35a==2 & t==1
replace com_cg35b="flood2" if com_cg35a==2 & t==2
replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
replace com_cg35b="price_change1" if com_cg35a==6 & t==1
replace com_cg35b="price_change2" if com_cg35a==6 & t==2
drop com_cg35a t
reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string

label variable com_cg36drought1 "Year 1 Drought reported"
label variable com_cg36drought2 "Year 2 Drought reported"
label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
label variable com_cg36flood1 "Year 1 Flood reported"
label variable com_cg36flood2 "Year 2 Flood reported"
label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
label variable com_cg36epidemic1 "Year 1 epidemic reported"
label variable com_cg36epidemic2 "Year 2 epidemic reported"
label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
label variable com_cg36price_change1 "Year 1 price_change reported"
label variable com_cg36price_change2 "Year 2 price_change reported"
label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

*COM CE. MASAF questions
preserve
	use "${malawiy1}\Community\COM_CE.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	tempfile com_ce
	save "`com_ce'", replace
restore

merge m:1 ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CH. MASAF questions 2
preserve
	use "${malawiy1}\Community\COM_CH.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch0b_os com_ch07c
	replace com_ch0b_os="" if com_ch0b==118 & com_ch07c==2 /*2 corresponds to NO. This item for other does not apply to question com_ch07c*/
	reshape wide com_ch07c com_ch0b_os , i(ea_id) j( com_ch0b )
	drop com_ch0b_os101 com_ch0b_os102 com_ch0b_os103 com_ch0b_os104 com_ch0b_os105 com_ch0b_os106 com_ch0b_os107 com_ch0b_os108 com_ch0b_os109 com_ch0b_os110 ///
	     com_ch0b_os111 com_ch0b_os112 com_ch0b_os113 com_ch0b_os114 com_ch0b_os115 com_ch0b_os116 com_ch0b_os117
	order ea_id com_ch07c*
	rename com_ch0b_os118 com_ch07c118a
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"
	tempfile com_ch
	save "`com_ch'", replace
restore

merge m:1 ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

rename ea_id eaid

gen survey="Survey-2010-2011"

tempfile malawi_y1
save "`malawi_y1'", replace

******************
** 2013
******************

*DROUGHT EVENTS
*COM CG35
use "${malawiy2}\Community\COM_MOD_G.dta", clear
replace com_cg36=. if com_cg36==201|com_cg36==203 /*Unfortunately, no idea which year it is. Better to missing*/
replace com_cg37=. if com_cg36==201|com_cg36==203
replace com_cg35c=. if com_cg36==201|com_cg36==203

* Some descriptive statistics for important events taken place in the community-ea
decode com_cg35c, gen(tag)
levelsof tag if occ<6, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',1,0)
matrix colname M = 2013
matrix rowname M = `rows' 
*########## EA_events table #########
tab tag if occ<6, matcell(ea)
matrix C=ea+M
putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
putexcel I1=matrix(C), names
drop tag

*isid ea_id com_cg35a com_cg36
drop if occ>5 /*those are better off events*/
drop if occ==1 
keep if com_cg35c==1|com_cg35c==2|com_cg35c==5|com_cg35c==6
drop occ com_cg35a com_cg35b
rename com_cg35c com_cg35a
bys ea_id com_cg35a: gen t=_n

*Dropping some repeated events
bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]

gen com_cg35b="drought1" if com_cg35a==1 & t==1
replace com_cg35b="drought2" if com_cg35a==1 & t==2
replace com_cg35b="flood1" if com_cg35a==2 & t==1
replace com_cg35b="flood2" if com_cg35a==2 & t==2
replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
replace com_cg35b="price_change1" if com_cg35a==6 & t==1
replace com_cg35b="price_change2" if com_cg35a==6 & t==2
drop com_cg35a t
reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string

label variable com_cg36drought1 "Year 1 Drought reported"
label variable com_cg36drought2 "Year 2 Drought reported"
label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
label variable com_cg36flood1 "Year 1 Flood reported"
*label variable com_cg36flood2 "Year 2 Flood reported"
label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
*label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
label variable com_cg36epidemic1 "Year 1 epidemic reported"
*label variable com_cg36epidemic2 "Year 2 epidemic reported"
label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
*label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
label variable com_cg36price_change1 "Year 1 price_change reported"
label variable com_cg36price_change2 "Year 2 price_change reported"
label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

rename ea_id hh_a_ea_id

*COM CE. MASAF questions
preserve
	use "${malawiy2}\Community\COM_MOD_E.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	rename (ea_id) (hh_a_ea_id)
	tempfile com_ce
	save "`com_ce'", replace 
restore

merge m:m hh_a_ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CH. MASAF questions 2
preserve
	use "${malawiy2}\Community\COM_MOD_H.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch07c
	reshape wide com_ch07c , i(ea_id) j( com_ch0b )
	rename (ea_id) (hh_a_ea_id)
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"

	tempfile com_ch
	save "`com_ch'", replace 
restore

merge m:m hh_a_ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

rename hh_a_ea_id eaid
gen survey="Survey-2013"

tempfile malawi_y2
save "`malawi_y2'", replace

******************
** 2016-2017
******************

*DROUGHT EVENTS
*COM CG35

*use "${malawiy3}\Community\COM_CG_old.dta", clear /*This file had problem not recording good or bad shocks. LSMS sent me the updated file time after with the corrections*/
*isid ea_id com_cg35a com_cg36
*drop if occ>5 /*those are better off events*/
*drop if occ==1 

use "${malawiy3}\Community\COM_CG.dta", clear
*isid ea_id com_cg35a com_cg36
drop if occ>5 /*those are better off events*/
drop if occ==1
replace com_cg35c=3 if com_cg35c==1 & com_cg35b=="crops disease" /*Mistake recording same event as they were different*/
replace com_cg35c=10 if ea_id=="30302573" & com_cg35c==2 & com_cg37==4 /*repeated flood recorded twice*/
replace com_cg35c=10 if ea_id=="30503622" & com_cg35c==2 & com_cg37==3 /*repeated flood recorded twice*/
replace com_cg35c=10 if ea_id=="20611402" & com_cg35c==6 & com_cg37==2 /*repeated price_change recorded twice*/
replace com_cg35c=10 if ea_id=="31301809" & com_cg35c==6 & com_cg37==4 /*repeated price_change recorded twice*/ 

* Some descriptive statistics for important events taken place in the community-ea
decode com_cg35c, gen(tag)
levelsof tag, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',1,0)
matrix colname M = 2016-2017
matrix rowname M = `rows' 
*########## EA_events table #########
tab tag, matcell(ea)
matrix C=ea+M
putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("EA_events") 
putexcel M1=matrix(C), names
drop tag
	
keep if com_cg35c==1|com_cg35c==2|com_cg35c==5|com_cg35c==6
drop com_cg35a com_cg35b com_cg35c_oth
rename com_cg35c com_cg35a
bys ea_id com_cg35a: gen t=_n
*Dropping some repeated events
*bys ea_id: drop if t==3 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]
bys ea_id: drop if t==2 & com_cg35a==com_cg35a[_n-1] & com_cg36==com_cg36[_n-1] & com_cg37==com_cg37[_n-1]

gen com_cg35b="drought1" if com_cg35a==1 & t==1
replace com_cg35b="drought2" if com_cg35a==1 & t==2
replace com_cg35b="flood1" if com_cg35a==2 & t==1
replace com_cg35b="flood2" if com_cg35a==2 & t==2
replace com_cg35b="epidemic1" if com_cg35a==5 & t==1
replace com_cg35b="epidemic2" if com_cg35a==5 & t==2
replace com_cg35b="price_change1" if com_cg35a==6 & t==1
replace com_cg35b="price_change2" if com_cg35a==6 & t==2
drop com_cg35a t occ
reshape wide com_cg36 com_cg37 , i(ea_id) j( com_cg35b ) string

label variable com_cg36drought1 "Year 1 Drought reported"
label variable com_cg36drought2 "Year 2 Drought reported"
label variable com_cg37drought1 "Share Community affected by 1 Drought reported"
label variable com_cg37drought2 "Share Community affected by 2 Drought reported"
label variable com_cg36flood1 "Year 1 Flood reported"
label variable com_cg36flood2 "Year 2 Flood reported"
label variable com_cg37flood1 "Share Community affected by 1 Flood reported"
label variable com_cg37flood2 "Share Community affected by 2 Flood reported"
label variable com_cg36epidemic1 "Year 1 epidemic reported"
label variable com_cg36epidemic2 "Year 2 epidemic reported"
label variable com_cg37epidemic1 "Share Community affected by 1 epidemic reported"
label variable com_cg37epidemic2 "Share Community affected by 2 epidemic reported"
label variable com_cg36price_change1 "Year 1 price_change reported"
label variable com_cg36price_change2 "Year 2 price_change reported"
label variable com_cg37price_change1 "Share Community affected by 1 price_change reported"
label variable com_cg37price_change2 "Share Community affected by 2 price_change reported"

*COM CE. MASAF questions
preserve
	use "${malawiy3}\Community\COM_CE.dta", clear
	isid ea_id
	keep ea_id com_ce09-com_ce15
	tempfile com_ce
	save "`com_ce'", replace 
restore

merge m:m ea_id using "`com_ce'", keep(master using match) gen(merge_com_ce)
tab merge_com_ce
drop merge_com_ce

*COM CH. MASAF questions 2
preserve
	use "${malawiy3}\Community\com_ch.dta", clear
	isid ea_id com_ch0b
	keep ea_id com_ch0b com_ch07c
	reshape wide com_ch07c , i(ea_id) j( com_ch0b )
	gen com_ch07c118a="COMMUNITY BASED CHILD CARE CENTER/NURSE" if com_ch07c1081==1 /*Defined as others*/
	drop com_ch07c1081
	label variable com_ch07c101 "ROAD: CONSTRUCTION"
	label variable com_ch07c102 "ROAD: MAINTENANCE"
	label variable com_ch07c103 "BRIDGE: CONSTRUCTION"
	label variable com_ch07c104 "BRIDGE: MAINTENANCE"
	label variable com_ch07c105 "PRIMARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c106 "PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT"
	label variable com_ch07c107 "SECONDARY SCHOOL: CONSTRUCTION"
	label variable com_ch07c108 "SECONDARY SCHOOL: MAINTENANCE/IMPROVEME"
	label variable com_ch07c109 "HEALTH CENTER/CLINIC/DISPENSARY: CONSTR"
	label variable com_ch07c110 "HEALTH CENTER/CLINIC/DISPENSARY: MAINTE"
	label variable com_ch07c111 "PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI"
	label variable com_ch07c112 "PIPED WATER/BOREHOLES/WELLS: MAINTENANC"
	label variable com_ch07c113 "ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM"
	label variable com_ch07c114 "MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I"
	label variable com_ch07c115 "PUBLIC TRANSPORTATION: INITIATION/IMPRO"
	label variable com_ch07c116 "AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI"
	label variable com_ch07c117 "LAW ENFORCEMENT: INITIATION/ IMPROVEMEN"
	label variable com_ch07c118 "OTHER (SPECIFY)"
	tempfile com_ch
	save "`com_ch'", replace 
restore

merge m:m ea_id using "`com_ch'", keep(master using match) gen(merge_com_ch)
tab merge_com_ch
drop merge_com_ch

rename ea_id eaid
gen survey="Survey-2016-2017"

append using "`malawi_y0'", gen(append)
drop append
append using "`malawi_y1'", gen(append)
drop append
append using "`malawi_y2'", gen(append)
drop append

*Reshape to long to have a panel
foreach eve in drought flood epidemic price_change { /*drought flood epidemic price_change*/
	preserve
		*collapse (mean) com_cg*`eve'*, by(survey eaid)
		keep eaid survey com_cg36`eve'* com_cg37`eve'*
		reshape long com_cg36`eve' com_cg37`eve', i(eaid survey) j(event)
		rename com_cg36`eve' year
		drop if year==. /*dropping missings better*/
		gen com_cg36`eve'=1 if year!=.
		drop event
		
		tempfile events
		save "`events'", replace
		save "${work2}\eve_com_`eve'.dta", replace 
	restore
}

*saving file with MASAF info
preserve
	drop com_cg36* com_cg37*
	gen year=2016 if survey=="Survey-2016-2017"
	replace year=2013 if survey=="Survey-2013"
	replace year=2010 if survey=="Survey-2010-2011"
	replace year=2004 if survey=="Survey-2004-2005"
	
	/*
	CATEGORY 1
	com_ch07c101	ROAD: CONSTRUCTION
	com_ch07c102	ROAD: MAINTENANCE
	com_ch07c103	BRIDGE: CONSTRUCTION
	com_ch07c104	BRIDGE: MAINTENANCE
	com_ch07c115	PUBLIC TRANSPORTATION: INITIATION/IMPRO
	
	CATEGORY 2
	com_ch07c105	PRIMARY SCHOOL: CONSTRUCTION
	com_ch07c106	PRIMARY SCHOOL: MAINTENANCE/IMPROVEMENT
	com_ch07c107	SECONDARY SCHOOL: CONSTRUCTION
	com_ch07c108	SECONDARY SCHOOL: MAINTENANCE/IMPROVEME
	com_ch07c113	ORPHANAGE: CONSTRUCTION/ MAINTENANCE/IM
		
	CATEGORY 3	
	com_ch07c109	HEALTH CENTER/CLINIC/DISPENSARY: CONSTR
	com_ch07c110	HEALTH CENTER/CLINIC/DISPENSARY: MAINTE
	
	CATEGORY 4
	com_ch07c111	PIPED WATER/BOREHOLES/WELLS: CONSTRUCTI
	com_ch07c112	PIPED WATER/BOREHOLES/WELLS: MAINTENANC
	com_ch07c114	MAIZE MILL: CONSTRUCTION/ MAINTENANCE/I
	com_ch07c116	AGRICULTURAL/FISHERY/ LIVESTOCK EXTENSI
	
	CATEGORY 5
	com_ch07c117	LAW ENFORCEMENT: INITIATION/ IMPROVEMEN
	com_ch07c118	OTHER (SPECIFY)
	*/
	*Redfining some categories better
	
	forvalues x=101/118 { /*To use later*/
	 gen a`x'=0
	 replace a`x'=1 if com_ch07c`x'==1
	}
	replace com_ch07c118=1 if (com_ch07c118a!="")
	gen masaf=0
	replace masaf=1 if com_ch07c101==1|com_ch07c102==1|com_ch07c103==1|com_ch07c104==1|com_ch07c115==1|com_ch07c105==1|com_ch07c106==1|com_ch07c107==1|com_ch07c108==1|com_ch07c113==1| ///
					com_ch07c109==1|com_ch07c110==1|com_ch07c111==1|com_ch07c112==1|com_ch07c114==1|com_ch07c116==1|com_ch07c117==1|com_ch07c118==1
	egen masaf_sum=rowtotal(a*)
	gen masaf1=0
	replace masaf1=1 if com_ch07c101==1|com_ch07c102==1|com_ch07c103==1|com_ch07c104==1|com_ch07c115==1
	egen masaf1_sum=rowtotal(a101 a102 a103 a104 a115)
	gen masaf2=0
	replace masaf2=1 if com_ch07c105==1|com_ch07c106==1|com_ch07c107==1|com_ch07c108==1|com_ch07c113==1
	egen masaf2_sum=rowtotal(a105 a106 a107 a108 a113)
	gen masaf3=0
	replace masaf3=1 if com_ch07c109==1|com_ch07c110==1
	egen masaf3_sum=rowtotal(a109 a110)
	gen masaf4=0
	replace masaf4=1 if com_ch07c111==1|com_ch07c112==1|com_ch07c114==1|com_ch07c116==1
	egen masaf4_sum=rowtotal(a111 a112 a114 a116)
	gen masaf5=0
	replace masaf5=1 if com_ch07c117==1|com_ch07c118==1
	egen masaf5_sum=rowtotal(a117 a118)
	label variable masaf  "1 if at least one MASAF project, 0 otherwise"
	label variable masaf1 "1 if at least one MASAF project//ROAD-BRIDGE-PUBLIC TRANSPORT, 0 otherwise"
	label variable masaf2 "1 if at least one MASAF project//PRIMARY SCHO-SECONDARY SCHO-ORPHAHAGE, 0 otherwise"
	label variable masaf3 "1 if at least one MASAF project//HEALTH CENTER, 0 otherwise"
	label variable masaf4 "1 if at least one MASAF project//PIPED WATER-MAIZE MILL-AGRO FISH, 0 otherwise"
	label variable masaf5 "1 if at least one MASAF project//OTHERS, 0 otherwise"
	label variable masaf_sum  "Total number of MASAF projects"
	label variable masaf1_sum "Total number of MASAF projects//ROAD-BRIDGE-PUBLIC TRANSPORT"
	label variable masaf2_sum "Total number of MASAF projects//PRIMARY SCHO-SECONDARY SCHO-ORPHAHAGE"
	label variable masaf3_sum "Total number of MASAF projects//HEALTH CENTER"
	label variable masaf4_sum "Total number of MASAF projects//PIPED WATER-MAIZE MILL-AGRO FISH"
	label variable masaf5_sum "Total number of MASAF projects//OTHERS"
	drop com_ch07* a*
	*Until here, I will only keep com_ce09 as wages and other questions could have mistakes. If I use them I need to homogenize and drop mistakes
	drop com_ce10-com_ce15
	
	gen masaf_work=0
	replace masaf_work=1 if com_ce09==1
	drop com_ce09
	label variable masaf_work "Is there a MASAF programme.which hires residents who are in need of work?"
	*Extracting district code
	gen dist_o=substr(eaid,1,3)
	drop if dist_o=="106" /*Dropping Likoma*/
	replace dist_o="1"+dist_o
	destring dist_o, replace
	*Collapsing by dist_o
	collapse (mean) masaf* , by(dist_o year) 
	label variable masaf "% of communities in the dist_o with at least one MASAF project"
	label variable masaf_sum "average # of MASAF projects in the communities of the dist_o"
	label variable masaf_work "% of communities in the dist_o with at least one MASAF project-HIRE TO WORK"
	label variable masaf1 "% of communities in the dist_o with at least one MASAF project//ROAD-BRIDGE-PUBLIC TRANSPORT"
	label variable masaf1_sum "average # of MASAF projects(ROAD-BRIDGE-PUBLIC TRANSPORT) in the communities of the dist_o"
	label variable masaf2 "% of communities in the dist_o with at least one MASAF project//PRIMARY SCHO-SECONDARY SCHO-ORPHAHAGE"
	label variable masaf2_sum "average # of MASAF projects(PRIM -SECON SCHO-ORPHAHAGE) in the communities of the dist_o"
	label variable masaf3 "% of communities in the dist_o with at least one MASAF project//HEALTH CENTER"
	label variable masaf3_sum "average # of MASAF projects(HEALTH CENTER) in the communities of the dist_o"
	label variable masaf4 "% of communities in the dist_o with at least one MASAF project//PIPED WATER-MAIZE MILL-AGRO FISH"
	label variable masaf4_sum "average # of MASAF projects(PIPED WATER-MAIZE MILL-AGRO FISH) in the communities of the dist_o"
	label variable masaf5 "% of communities in the dist_o with at least one MASAF project//OTHERS"
	label variable masaf5_sum "average # of MASAF projects(OTHERS) in the communities of the dist_o"
	
	*Creating much simpler variables
	gen masaf_dum1=0
	replace masaf_dum1=1 if masaf!=0
	label variable masaf_dum1 "1 if there are MASAF projects in the communities of the dist_o, 0 otherwise"
	gen masaf_dum2=0
	replace masaf_dum2=1 if masaf_work!=0
	label variable masaf_dum2 "1 if there are MASAF projects(only HIRE TO WORK) in the communities of the dist_o, 0 otherwise"
	gen masaf_dum3=0
	replace masaf_dum3=1 if masaf!=0|masaf_work!=0
	label variable masaf_dum3 "1 if there are MASAF projects(all+ HIRE TO WORK) in the communities of the dist_o, 0 otherwise"
	save "${work2}\com_masaf.dta", replace 
restore

*Organzing data as panel. I will collapse here to have all the eaid cases as a sample to merge later
gen year=2016
collapse (mean) year, by(eaid survey)
expandcl 18, cluster(eaid survey) gen(aa)
drop aa year
bys eaid survey: gen t=_n
rename t year

replace year=year+1998

*merging to get info
foreach eve in drought flood epidemic price_change {
	merge m:1 survey eaid year using "${work2}\eve_com_`eve'.dta", keep(master using match) gen(merge_`eve')
	tab merge_`eve'
}

label values com_cg37* cg37 

*merge m:1 survey eaid year using "${work2}\com_masaf.dta", keep(master using match) gen(merge_masaf)

drop if year==1994 /*events in 1994 out of sample*/
drop merge*

*Extracting district code
gen dist_o=substr(eaid,1,3)

*Filling up zeros for event variables
foreach var of varlist com_cg36drought com_cg36flood com_cg36epidemic com_cg36price_change {
	replace `var'=0 if `var'==.
}

drop if dist_o=="106" /*Dropping Likoma*/
replace dist_o="1"+dist_o


*use "${work2}\com_events_masaf.dta", clear

drop com_cg37* /*intensity of the event*/

*drop com_ch07c118a /*others masaf*/
gen sum_com_cg36drought = com_cg36drought
gen sum_com_cg36flood   = com_cg36flood
gen sum_com_cg36epidemic= com_cg36epidemic
gen sum_com_cg36price_change=com_cg36price_change
collapse (mean) com_* (sum) sum_*, by(dist_o survey year) 
rename sum_* *_sum

order survey dist_o year com_cg36* 

*Defining measures of drought
*** drought1=1 if at least one EA of that district reported a drought event for that year; 0 otherwise
*** drought2=1 if more than the 10% of the EA of that district reported a drought event for that year; 0 otherwise
*** drought3=1 if more than the 20% of the EA of that district reported a drought event for that year; 0 otherwise
foreach eve in drought flood epidemic price_change { 
	gen `eve'1=0
	replace `eve'1=1 if com_cg36`eve'!=0
	gen `eve'2=0
	replace `eve'2=1 if com_cg36`eve'>0.1 /*10%*/
	gen `eve'3=0
	replace `eve'3=1 if com_cg36`eve'>0.2 /*20%*/
	}
label variable drought1 "1 if at least one EA of that district reported a drought event for that year; 0 otherwise"
label variable drought2 "1 if > 10% of the EA of that district reported a drought event for that year; 0 otherwise"
label variable drought3 "1 if > 20% of the EA of that district reported a drought event for that year; 0 otherwise"
	
*Keeping only what I need
drop com_*

destring dist_o, replace

save "${work2}\com_events.dta", replace

