*********************************************************************************
* 			THIS PROGRAM CREATES VARS DATA OF LSMS SURVEYS FOR MALAWI    	    *
*      IT CREATES THE VARS OF INTEREST + CREATES THE CROSS-SECTION PANEL        *
*                      WRITTEN BY LUIS GUILLERMO BECERRA                        *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 6000
cap log close

*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
*cd "U:\PSE-Proposal Malaria and paper\INPUT"
cd "C:\Users\PSE-Proposal Malaria and paper\INPUT"


global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS"
global results2  "..\RESULTS V2"

****************************************************************************************************************
*HH QUESTIONS AT THE HH and INDIVIDUAL LEVEL. CROSS-SECTION BY YEAR AND COUNTRY
****************************************************************************************************************
***********************************
*		MALAWI 2004-2005
*********************************** 
use "${work2}\malawi_ind_20042005.dta", clear

*Renaming education variables to match later on
rename (c12 c13 c17) (edu_highest edu_highest1 edu_lastyear)

*Renaming variables to match later on

rename (cd45 	 cd46a     cd46b     cd47     cd48a     cd48b     cd_49    cd_51a    cd51b     cd_52    cd54      cd_55    cg19) ///
       (com_cd48 com_cd49a com_cd49b com_cd50 com_cd51a com_cd51b com_cd52 com_cd60a com_cd60b com_cd61 com_cd62  com_cd63 com_cg15 )
rename (e19 c19a) (hh_e19b hh_c14)   /*For c14 I will use only the first reason as later surveys only gave 1 reason*/
rename d35 hh_d40 /*Pregnant in the last 24 months*/
rename b23 hh_b24 /*Marital Status*/
global comm0 "com_cd48 com_cd49a com_cd49b com_cd50 com_cd51a com_cd51b com_cd52 com_cd60a com_cd60b com_cd61 com_cd62  com_cd63 com_cg15 cd_50 cd53" /*list of community questions*/
global comm0a "com_ce* com_cf* com_cg36*"
*HEALTH SECTION
replace d05a=1 if d05aoth=="YELLOW FEVER " /*This is Malaria. 2 cases. Already was recorded before, no changes*/
replace d05a=30 if d05a==99 /*it should be other disease*/
replace d27a=1 if d27aoth=="YELLOW FEVER" | d27aoth=="MALARIA"/*This is Malaria. 5 cases.Already was recorded before, no changes*/
replace d27b=1 if d27both=="CELLEBRAL MARALIA" /*1 case. Already was recorded before, no changes*/
rename (d04    d05a    d05b    d26    d27a    d27b    d28a    d28b) ///
	   (hh_d04 hh_d05a hh_d05b hh_d33 hh_d34a hh_d34b hh_d35a hh_d35b)
global health0 "hh_d04 hh_d05a hh_d05b hh_d33 hh_d34a hh_d34b hh_d35a hh_d35b"
*HOUSING
rename (g03a g04a g39 g40 g41 l01 l02 l03) (hh_f03a hh_f04a hh_f44 hh_f45 hh_f47 hh_k01 hh_k02 hh_k03)
global housing0 "hh_f03a hh_f04a hh_f44 hh_f45 hh_f47 hh_k01 hh_k02 hh_k03 edu_highest edu_highest1 edu_lastyear"
global mechanism0 "k_lobola* k_marriage* hh_e19b hh_c14 hh_d40 hh_b24"

keep case_id- a_strata a14a- a14c b* $comm0 $health0 $housing0 $comm0a $mechanism0
label list strata
label define strata 206 "Lilongwe", modify /*Modified names to match later on with posterior Surveys.*/
label define strata 303 "Zomba", modify
label define strata 305 "Blantyre", modify

label define strata 107 "Mzuzu City", modify /*Modified to match later on with posterior Surveys.It was 401*/
replace a_strata=107 if a_strata==401
label define strata 210 "Lilongwe City", modify /*Modified to match later on with posterior Surveys.It was 402*/
replace a_strata=210 if a_strata==402
label define strata 314 "Zomba City", modify /*Modified to match later on with posterior Surveys.It was 403*/
replace a_strata=314 if a_strata==403
label define strata 315 "Blantyre City", modify /*Modified to match later on with posterior Surveys.It was 404*/
replace a_strata=315 if a_strata==404

*Information of date of interview corresponds to the one of first visit
																*******************************
																*		MIGRATION             *
     															*******************************
*Question about migration but not at the level of district
rename (b12 b12b b20) (hh_b09 hh_b10b hh_b14)

gen mig_ind=0
tab hh_b09
tab hh_b09, nolabel
/* Defining Migration by individual (WAY 1)
1: This village
2: Other village in this district
3: Village in other district
4: This town or urban centre 
5: Other town or urban centre in this dist
6: Town or urban centre in other district
7: Outside malawi
*/
replace mig_ind=1 if hh_b09==3 | hh_b09==6 
replace mig_ind=2 if (hh_b09==2 | hh_b09==5) 
replace mig_ind=2 if mig_ind==1 & hh_b10b==a_strata /*I include those moving inside district*/
replace mig_ind=3 if hh_b09==7
label var mig_ind "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"

*replace mig_ind=2 if mig_ind==0 & hh_b10b!=. /*Replacing 8 who moved inside district*/
*########## TABLE 1A #########: Migrants by District
levelsof hh_b10b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b10b, gen(tag)
replace hh_b10b=. if tag=="Zomba" & mig_ind==0
replace tag="" if tag=="Zomba" & mig_ind==0
*Replacing missclassification in international migrants
sort hh_b10b
levelsof tag, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag mig_ind, matcell(migind1)
matrix C=migind1+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T1migind1_m", replace)  //modify
putexcel P1=matrix(C), names
*HH size
rename memid id_code
sort case_id id_code
bys case_id: gen hhsize=_N
gen dif=a_hhsize-hhsize /*After comparing the variable hhsize from ihs survey, it defers in many cases. I prefer to use mine, which matches with info we have*/
drop a_hhsize dif
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind==1
bys case_id: egen mtotal=total(n)
label var mtotal "Total Number of migrants in the HH (for between district, mig_ind=1)"
gen mig_hh=mtotal/hhsize
gen mig_hht=0
replace mig_hht=1 if mig_hh==1
label var mig_hh "% of HH that migrated (mtotal/hhsize)"
label var mig_hht "Whole HH that migrated (mtotal/hhsize=1)"
drop n
*Descriptive Statistics by HH. hh_b01==1 has member number for hh head
*########## TABLE 2A #########: Migrants by HH
matrix M1 = J(13,1,0)
matrix colname M1 = Total_migrants
matrix rowname M1 = 0 1 2 3 4 5 6 7 8 9 10 11 12
tab mtotal if b04==1, matcell(tab1)
matrix C1=tab1+M1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T2total_mig_m", replace) // modify
putexcel P1=matrix(C1) , names
*########## TABLE 3A #########: Migrants statistics by hhsize
estpost tabstat mig_hh mtotal if mig_hh!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh)',e(mtotal)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T3total_mig_hhsize_m", replace) //modify
putexcel P1=matrix(C) , names

*******************************************************
*Migration2 index based on district info, more acquare.
*******************************************************  
tab hh_b14
tab hh_b14, nolabel
/* Defining Migration by individual (WAY 2)
1: This Village
2: OTHER VILLAGE IN THIS DISTRICT
3: VILLAGE IN OTHER DISTRICT
4: This town or urban centre
5: OTHER TOWN OR URBAN CENTER IN  THIS DIS
6: TOWN OR URBAN CENTRE IN OTHER DISTRICT
7: OUTSIDE MALAWI
*/

gen mig_ind2=0
replace mig_ind2=1 if hh_b14==3 | hh_b14==6
replace mig_ind2=2 if (hh_b14==2 | hh_b14==5) 
*replace mig_ind2=2 if mig_ind2==1 & hh_b15b==a_strata /*I include those moving inside district*/
replace mig_ind2=3 if hh_b14==7
label var mig_ind2 "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"
*replace mig_ind2=2 if mig_ind2==0 & hh_b15b!=. /*Replacing 3 who does not have question hh_b14*/

*Migration self-declared as rural or uban
gen mig_rural=0
replace mig_rural=1 if hh_b14==2 | hh_b14==3
gen mig_urban=0
replace mig_urban=1 if hh_b14==5 | hh_b14==6

	/* NO INFO
	levelsof hh_b15b, local(rows)
	local nrows : word count `rows'
	matrix M = J(`nrows',3,0)
	decode hh_b15b, gen(tag2)
	sort hh_b15b
	levelsof tag2, local(tags2)
	matrix colname M = 1 2 3
	matrix rowname M = `tags2' 
	*########## TABLE 4A #########: Migrants by District
	tab tag2 mig_ind2, matcell(migind2)
	matrix C=migind2+M
	putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T4migind2_m", replace) //modify 
	putexcel A1=matrix(C) 
	*/

*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind2==1
bys case_id: egen mtotal2=total(n)
label var mtotal2 "Total Number of migrants in the HH (for between district, mig_ind2=1)"
gen mig_hh2=mtotal2/hhsize
gen mig_hht2=0
replace mig_hht2=1 if mig_hh2==1
label var mig_hh2 "% of HH that migrated (mtotal/hhsize)"
label var mig_hht2 "Whole HH that migrated (mtotal/hhsize=1)"
drop n
*Descriptive Statistics by HH. hh_b01 has member number
*########## TABLE 5A #########: Migrants by HH
matrix M2 = J(14,1,0)
matrix colname M2 = total_migrants
matrix rowname M2 = 0 1 2 3 4 5 6 7 8 9 10 11 12 13
tab mtotal2 if b04==1, matcell(tab2)
matrix C2=tab2+M2
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T5total_mig2_m", replace) //modify 
putexcel P1=matrix(C2) 
*########## TABLE 6A #########: Migrants statistics by hhsize
estpost tabstat mig_hh2 mtotal2 if mig_hh2!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh2)',e(mtotal2)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T6total_mig_hhsize2_m", replace) //modify
putexcel P1=matrix(C)

*########## TABLE 7A #########: Whole HH migrating
tab mig_hht if b04==1, matcell(tab1)
tab mig_hht2 if b04==1, matcell(tab2)
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T7Whole_mig_hh_m", replace) //modify
putexcel P1=matrix(tab1)
putexcel P7=matrix(tab2)

*########## TABLE 8A #########: Migrants by year of movement
gen years=b18
replace years=. if mig_ind2==0
levelsof years, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
matrix colname M = 1 2 3
matrix rowname M = `rows' 

tab b18 mig_ind2 if mig_ind2!=0, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T8migind2_m", replace) //modify
putexcel P1=matrix(C)

********************************
* KEEPING VARS FOR CROSS-PANEL *
********************************
gen a_member=id_code
rename (case_id id_code a_psu a_hhwght a_strata  a_reside a_ta a_region a_type a_member b03 b04 b05a b05b b06c b06b a14a a14b a14c b18 b19 hh_b10b) ///
       (hhid    pid   eaid weight   district   rural    ta   region   area    member sex rel_to_head age_years age_months born_years born_months ///
		day_interv month_interv year_interv years_migrate reason_migrate dist_born)     
keep hhid pid survey country eaid weight district rural ta region area member hhsize sex rel_to_head age_years age_months ///
		born_years born_months day_interv month_interv year_interv years_migrate reason_migrate dist_born mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
		$comm0 $comm0a $health0 $housing0 hh_b14 $mechanism0
order hhid pid survey country day_interv month_interv year_interv eaid weight district rural ta region area member hhsize sex rel_to_head age_years age_months ///
		born_years born_months years_migrate reason_migrate dist_born mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
		$comm0 $comm0a $health0 $housing0 hh_b14 $mechanism0

tostring pid, replace force
*tostring eaid, replace force
decode district, gen(dist_name)
*re-arraging variables to verify no mistakes
decode sex, gen(sexi)
tostring month_interv, gen(monthi)
decode rel_to_head, gen(rel_to_headi)
decode rural, gen(rurali)
tostring born_months, gen(born_monthi)
decode region, gen(regioni)
decode area, gen(areani)

*Generating new variables as string to check later if they were not label-names changes
foreach x in $comm0 $health0 $housing0 {
		capture decode `x', gen(st`x')
		if _rc gen st`x' = string(`x')
}

tempfile malawi_y0
save "`malawi_y0'", replace

***********************************
*		MALAWI 2010-2011
*********************************** 
use "${work2}\malawi_ind_20102011.dta", clear

*Renaming education variables and language to match later on
rename (hh_c08 hh_c09 hh_c12 hh_b22) (edu_highest edu_highest1 edu_lastyear language_hh)

*Renaming variables to match later on
global comm1 "com_cd48 com_cd49a com_cd49b com_cd50 com_cd51a com_cd51b com_cd52 com_cd53 com_cd55 com_cd56 com_cd60a com_cd60b com_cd61 com_cd62 com_cd63 com_cg15" /*list of community questions*/
global comm1a "com_ce* com_cf* com_ch* com_cg36* com_cg37*"

replace hh_d05a=1 if hh_d05a_os=="YELLOW FEVER" | hh_d05a_os=="CELEBRAL MALARIA" /*This is Malaria of course. 4 cases*/
replace hh_d34a=1 if hh_d34a_os=="YELLOW FEVER" | hh_d34a_os=="CEREBRAL MALARIA" /*This is Malaria of course. 2 cases*/
global health1 "hh_d04 hh_d05a hh_d05b hh_d33 hh_d34a hh_d34b hh_d35a hh_d35b"

global housing1 "hh_f03a hh_f04a hh_f44 hh_f45 hh_f46 hh_f47 hh_k01 hh_k02 hh_k03 elevation hh_shock1 hh_shock2 hh_shock3 edu_highest edu_highest1 edu_lastyear language_hh"

global geo1 "hh_geo*"

global mechanism1 "k_lobola* k_marriage* hh_e19b hh_c14 hh_d40 hh_b24" 

keep ea_id case_id id_code survey country hh_a_reside hh_a_hh_wgt hh_a_qx_type hh_a01 hh_a02 hh_a02b hh_a23_1 hh_a23_2 hh_b_qx_type hh_b01-hh_b15b ihs_hhsize ///
     ihs_region- ihs_cluster hh_a23a_1 hh_a23b_1 hh_a23c_1 $comm1 $comm1a $health1 $housing1 $geo1 $mechanism1
label list HH_A01
label define HH_A01 305 "Blantyre", modify
label define HH_B10B 305 "Blantyre", modify
label define HH_B15B 305 "Blantyre", modify

*Information of date of interview corresponds to the one of first visit
																*******************************
																*		MIGRATION             *
     															*******************************
gen mig_ind=0
tab hh_b09
tab hh_b09, nolabel
/* Defining Migration by individual (WAY 1)
1: This village
2: Other village in this district
3: Village in other district
4: This town or urban centre 
5: Other town or urban centre in this dist
6: Town or urban centre in other district
7: Outside malawi
*/
replace mig_ind=1 if hh_b09==3 | hh_b09==6 
replace mig_ind=2 if (hh_b09==2 | hh_b09==5) 
replace mig_ind=2 if mig_ind==1 & hh_b10b==hh_a01 /*I include those moving inside district*/
replace mig_ind=3 if hh_b09==7
label var mig_ind "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"
replace mig_ind=2 if mig_ind==0 & hh_b10b!=. /*Replacing 8 who moved inside district*/
*########## TABLE 1A #########: Migrants by District
levelsof hh_b10b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b10b, gen(tag)
replace tag="108" if hh_b10b==108
replace tag="200" if hh_b10b==200
*Replacing missclassification in international migrants
replace mig_ind=3 if tag=="China"
replace mig_ind=3 if tag=="Mozambique"
replace mig_ind=3 if tag=="Other Country(Specify)"
replace mig_ind=3 if tag=="Tanzania"
replace mig_ind=3 if tag=="Zambia"
replace mig_ind=3 if tag=="Zimbabwe"
sort hh_b10b
levelsof tag, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag mig_ind, matcell(migind1)
matrix C=migind1+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T1migind1_m", replace) //modify 
putexcel A1=matrix(C)
*HH size
sort case_id id_code
bys case_id: gen hhsize=_N
gen dif=ihs_hhsize-hhsize /*After comparing the variable hhsize from ihs survey, it defers in many cases. I prefer to use mine, which matches with info we have*/
drop ihs_hhsize dif
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind==1
bys case_id: egen mtotal=total(n)
label var mtotal "Total Number of migrants in the HH (for between district, mig_ind=1)"
gen mig_hh=mtotal/hhsize
gen mig_hht=0
replace mig_hht=1 if mig_hh==1
label var mig_hh "% of HH that migrated (mtotal/hhsize)"
label var mig_hht "Whole HH that migrated (mtotal/hhsize=1)"
drop n
*Descriptive Statistics by HH. hh_b01 has member number
*########## TABLE 2A #########: Migrants by HH
matrix M1 = J(13,1,0)
matrix colname M1 = Total_migrants
matrix rowname M1 = 0 1 2 3 4 5 6 7 8 9 10 11 12
tab mtotal if hh_b01==1, matcell(tab1)
matrix C1=tab1+M1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T2total_mig_m", replace) //modify 
putexcel A1=matrix(C1) 
*########## TABLE 3A #########: Migrants statistics by hhsize
estpost tabstat mig_hh mtotal if mig_hh!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh)',e(mtotal)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T3total_mig_hhsize_m", replace) //modify 
putexcel A1=matrix(C)

*******************************************************
*Migration2 index based on district info, more acquare.
*******************************************************  
tab hh_b14
tab hh_b14, nolabel
/* Defining Migration by individual (WAY 2)
2: OTHER VILLAGE IN THIS DISTRICT
3: VILLAGE IN OTHER DISTRICT
5: OTHER TOWN OR URBAN CENTER IN  THIS DIS
6: TOWN OR URBAN CENTRE IN OTHER DISTRICT
7: OUTSIDE MALAWI
*/

gen mig_ind2=0
replace mig_ind2=1 if hh_b14==3 | hh_b14==6
replace mig_ind2=2 if (hh_b14==2 | hh_b14==5) 
replace mig_ind2=2 if mig_ind2==1 & hh_b15b==hh_a01 /*I include those moving inside district*/
replace mig_ind2=3 if hh_b14==7
label var mig_ind2 "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"
replace mig_ind2=2 if mig_ind2==0 & hh_b15b!=. /*Replacing 3 who does not have question hh_b14*/

*Migration self-declared as rural or uban
gen mig_rural=0
replace mig_rural=1 if hh_b14==2 | hh_b14==3
gen mig_urban=0
replace mig_urban=1 if hh_b14==5 | hh_b14==6

levelsof hh_b15b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b15b, gen(tag2)
*Replacing missclassification in international migrants and others
replace mig_ind2=3 if tag2=="China" & mig_ind2!=3
replace mig_ind2=3 if tag2=="Mozambique" & mig_ind2!=3
replace mig_ind2=3 if tag2=="Other Country(Specify)" & mig_ind2!=3
replace mig_ind2=3 if tag2=="South Africa" & mig_ind2!=3
replace mig_ind2=3 if tag2=="Tanzania" & mig_ind2!=3
replace mig_ind2=3 if tag2=="Zambia" & mig_ind2!=3
replace mig_ind2=3 if tag2=="Zimbabwe" & mig_ind2!=3
replace mig_ind2=1 if mig_ind2==3 & tag2=="Mangochi"
replace mig_ind2=1 if mig_ind2==3 & tag2=="Mulanje"
replace mig_ind2=1 if mig_ind2==3 & tag2=="Nkhota kota"
replace mig_ind2=1 if mig_ind2==3 & tag2=="Salima"
replace hh_b15b=hh_a01 if mig_ind2==2 & hh_b15b==. /*Assigning the same district of origin for those migrating inside district. They didn't have info*/
replace mig_ind2=1 if mig_ind2==2 & hh_b15b!=hh_a01 & hh_b15b!=. /*Those guys recorded a different migrant_district but probably wrongly recorded as inside district migrants*/

sort hh_b15b
levelsof tag2, local(tags2)
matrix colname M = 1 2 3
matrix rowname M = `tags2' 
*########## TABLE 4A #########: Migrants by District
tab tag2 mig_ind2, matcell(migind2)
matrix C=migind2+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T4migind2_m", replace) //modify 
putexcel A1=matrix(C) 

*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind2==1
bys case_id: egen mtotal2=total(n)
label var mtotal2 "Total Number of migrants in the HH (for between district, mig_ind2=1)"
gen mig_hh2=mtotal2/hhsize
gen mig_hht2=0
replace mig_hht2=1 if mig_hh2==1
label var mig_hh2 "% of HH that migrated (mtotal/hhsize)"
label var mig_hht2 "Whole HH that migrated (mtotal/hhsize=1)"
drop n
*Descriptive Statistics by HH. hh_b01 has member number
*########## TABLE 5A #########: Migrants by HH
matrix M2 = J(13,1,0)
matrix colname M2 = total_migrants
matrix rowname M2 = 0 1 2 3 4 5 6 7 8 9 10 11 12
tab mtotal2 if hh_b01==1, matcell(tab2)
matrix C2=tab2+M2
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T5total_mig2_m", replace) //modify 
putexcel A1=matrix(C2) 
*########## TABLE 6A #########: Migrants statistics by hhsize
estpost tabstat mig_hh2 mtotal2 if mig_hh2!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh2)',e(mtotal2)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T6total_mig_hhsize2_m", replace) //modify
putexcel A1=matrix(C)

*########## TABLE 7A #########: Whole HH migrating
tab mig_hht if hh_b01==1, matcell(tab1)
tab mig_hht2 if hh_b01==1, matcell(tab2)
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T7Whole_mig_hh_m", replace) //modify
putexcel A1=matrix(tab1)
putexcel A7=matrix(tab2)

*########## TABLE 8A #########: Migrants by year of movement
gen years=hh_b12
replace years=. if mig_ind2==0
levelsof years, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
matrix colname M = 1 2 3
matrix rowname M = `rows' 

tab hh_b12 mig_ind2 if mig_ind2!=0, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T8migind2_m", replace) //modify
putexcel A1=matrix(C)

********************************
* KEEPING VARS FOR CROSS-PANEL *
********************************
rename (case_id id_code ea_id hh_a_hh_wgt hh_a01 hh_a_reside hh_a02 hh_a02b ihs_region ihs_area ihs_cluster hh_b01 hh_b03 hh_b04 ///
		hh_b05a hh_b05b hh_b06b hh_b06a hh_b12 hh_b13 hh_b13_os hh_b10b hh_b15b hh_a23a_1 hh_a23b_1 hh_a23c_1) ///
       (hhid pid eaid weight district rural ta dist_ta region area cluster member sex rel_to_head age_years age_months born_years ///
	   born_months years_migrate reason_migrate reason_migrate_other dist_born dist_move day_interv month_interv year_interv)
keep hhid pid survey country eaid weight district rural ta dist_ta region area cluster member hhsize sex rel_to_head age_years age_months ///
born_years born_months years_migrate reason_migrate reason_migrate_other dist_born dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
	day_interv month_interv year_interv $comm1 $comm1a $health1 $housing1 $geo1 hh_b14 $mechanism1
order hhid pid survey country day_interv month_interv year_interv eaid weight district rural ta dist_ta region area cluster member hhsize sex rel_to_head age_years age_months ///
		born_years born_months years_migrate reason_migrate reason_migrate_other dist_born dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
		$comm1 $comm1a $health1 $housing1 $geo1 hh_b14 $mechanism1

tostring pid, replace

*re-arraging variables to verify no mistakes
decode sex, gen(sexi)
tostring month_interv, gen(monthi)
decode rel_to_head, gen(rel_to_headi)
decode rural, gen(rurali)
tostring born_months, gen(born_monthi)
decode region, gen(regioni)
decode area, gen(areani)
decode reason_migrate, gen(reasoni)
decode district, gen(dist_name)
decode dist_born, gen(dist_born_name)
decode dist_move, gen(dist_move_name)

*Generating new variables as string to check later if they were not label-names changes
foreach x in $comm1 $health1 $housing1 {
		capture decode `x', gen(st`x')
		if _rc gen st`x' = string(`x')
}

tempfile malawi_y1
save "`malawi_y1'", replace

***********************************
*		MALAWI 2016-2017
***********************************
use "${work2}\malawi_ind_20162017.dta", clear

*Renaming education and language variables to match later on
rename (hh_c08 hh_c09 hh_c12 hh_b22) (edu_highest edu_highest1 edu_lastyear language_hh)

gen hh_f46=1 if hh_f47!=. /*Missing variable. If they say they have kids <5 years old treated it means they have kids <5 years old*/
label list hh_f44
label values hh_f46 hh_f44

*Renaming variables to match later on. com_60b missing
global comm3 "com_cd48 com_cd49a com_cd49b com_cd50 com_cd51a com_cd51b com_cd52 com_cd55 com_cd56 com_cd60a com_cd61 com_cd62 com_cd63"
global comm3a "com_ce* com_cf* com_ch* com_cg36* com_cg37*"
global health3 "hh_d04 hh_d05a hh_d05b hh_d33 hh_d34a hh_d34b hh_d35a hh_d35b"
global housing3 "hh_f03a hh_f04a hh_f44 hh_f45 hh_f46 hh_f47 hh_k01 hh_k02 hh_k03 elevation hh_shock1 hh_shock2 hh_shock3 edu_highest edu_highest1 edu_lastyear language_hh"
global geo3 "hh_geo*"
global mechanism3 "k_lobola* k_marriage* hh_e19b hh_c14 hh_b24 hh_b26a_1 hh_b26b_1 hh_b26c_1 moduleB_respondent" /*NA question d40*/

drop hh_b05_2 hh_b05_2_1 hh_b04a

replace hh_b10b=516 if hh_b10_oth=="ZIMBABWE"
drop hh_b10_oth /*Get rid of the other countries as others*/
label define hh_b10a 501 "Angola" 502 "Australia" 503 "Botswana" 504 "Canada" 505 "China" 506 "Lesotho" 507 "Mozambique" 508 "Namibia" 509 "New Zealand" 510 "South Africa" 511 "Swaziland" 512 "Tanzania" ///
         513 "United" 514 "United States of America(USA)" 515 "Zambia" 516 "Zimbabwe" 517 "Other Country(Specify)", modify
replace hh_b10a=hh_b10b if hh_b10a==. & hh_b10b!=.
drop hh_b10b
rename hh_b10a hh_b10b
decode hh_b10b, gen(hh_b10a)

replace hh_b13=10 if hh_b13_oth=="BUSINESS REASONS" | hh_b13_oth=="MOVEMENTOFCAPITALFROMZOMBATOLILONGWE"
replace hh_b13=2 if hh_b13_oth=="CAME TO LIVE WITH PARENTS" | hh_b13_oth=="CAME TO LIVE WITH RELATIVE"| hh_b13_oth=="CAME TO LIVE WITH SPOUSE"
replace hh_b13=6 if hh_b13_oth=="DIVORCE"
replace hh_b13=9 if hh_b13_oth=="LOOK FOR EMPLOYMENT"
replace hh_b13=4 if hh_b13_oth=="MARRIAGE"
replace hh_b13=11 if hh_b13_oth=="MOVED TO OWN LAND / HOUSE"
replace hh_b13=12 if hh_b13_oth=="OWNILLNESS"

drop hh_b13_oth /*Other options as other better*/

label define hh_b15a 501 "Angola" 502 "Australia" 503 "Botswana" 504 "Canada" 505 "China" 506 "Lesotho" 507 "Mozambique" 508 "Namibia" 509 "New Zealand" 510 "South Africa" 511 "Swaziland" 512 "Tanzania" ///
         513 "United" 514 "United States of America(USA)" 515 "Zambia" 516 "Zimbabwe" 517 "Other Country(Specify)" 106 "Likoma", modify
replace hh_b15a=hh_b15b if hh_b15a==. & hh_b15b!=.
drop hh_b15b
rename hh_b15a hh_b15b
decode hh_b15b, gen(hh_b15a)
drop hh_b15b_oth

*Fixing date of first interview
gen hh_a23a_3=substr(hh_a_interviewDate,1,4)
gen hh_a23a_2=substr(hh_a_interviewDate,6,2)
gen hh_a23a_1=substr(hh_a_interviewDate,9,2)

destring hh_a23a_3, replace
destring hh_a23a_2, replace
destring hh_a23a_1, replace
drop hh_a_interviewDate

keep HHID case_id PID survey country ea_id hh_a_hh_wgt hh_a_region hh_a_district hh_a_reside hh_b03- hh_b15b hh_a23a_1 hh_a23a_2 hh_a23a_3 $comm3 $comm3a $health3 $housing3 $geo3 $mechanism3
label define hh_b10b 305 "Blantyre", modify
label define hh_b15b 305 "Blantyre", modify

*For the date of interview in 2013, the first attempt is the main one, and 2, or 3 attempt collected info 2-4 days after (almost the same)
*It was used the date of interview in the first visit
																*******************************
																*		MIGRATION             *
    															*******************************														
gen mig_ind=0
tab hh_b09
tab hh_b09, nolabel
/* Defining Migration by individual (1)
1: This village
2: Other village in this district
3: Village in other district
4: This town or urban centre 
5: Other town or urban centre in this dist
6: Town or urban centre in other district
7: Outside malawi
*/
replace mig_ind=1 if hh_b09==3 | hh_b09==6 
replace mig_ind=2 if (hh_b09==2 | hh_b09==5) 
replace mig_ind=2 if mig_ind==1 & hh_b10b==hh_a_district /*I include those moving inside district*/
replace mig_ind=3 if hh_b09==7
label var mig_ind "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"

levelsof hh_b10b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b10b, gen(tag)

*########## TABLE 1B #########: Migrants by District
sort hh_b10b
levelsof tag, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag mig_ind, matcell(migind1)
matrix C=migind1+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T1migind1_m", replace) //modify
putexcel K1=matrix(C)

*HH size
sort HHID PID
bys HHID: gen hhsize=_N
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind==1
bys HHID: egen mtotal=total(n)
label var mtotal "Total Number of migrants in the HH (for between district, mig_ind=1)"
gen mig_hh=mtotal/hhsize
gen mig_hht=0
replace mig_hht=1 if mig_hh==1
label var mig_hh "% of HH that migrated (mtotal/hhsize)"
label var mig_hht "Whole HH that migrated (mtotal/hhsize=1)"
drop n

*Descriptive Statistics by HH. I created a HH member number (this differs from hh_b01)
*########## TABLE 2B #########: Migrants by HH
sort HHID PID
bys HHID: gen member=_n
matrix M1 = J(13,1,0)
matrix colname M1 = Total_migrants
matrix rowname M1 = 0 1 2 3 4 5 6 7 8 9 10 11 12 
tab mtotal if member==1, matcell(tab1)
matrix C1=tab1+M1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T2total_mig_m", replace) //modify
putexcel K1=matrix(C1)

*########## TABLE 3B #########: Migrants statistics by hhsize
estpost tabstat mig_hh mtotal if mig_hh!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh)',e(mtotal)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T3total_mig_hhsize_m", replace) //modify
putexcel K1=matrix(C)

*Migration based on district info, more acquare.  
tab hh_b14
tab hh_b14, nolabel
/* Defining Migration by individual (2)
2: OTHER VILLAGE IN THIS DISTRICT
3: VILLAGE IN OTHER DISTRICT
5: OTHER TOWN OR URBAN CENTER IN  THIS DIS
6: TOWN OR URBAN CENTRE IN OTHER DISTRICT
7: OUTSIDE MALAWI
*/

gen mig_ind2=0
replace mig_ind2=1 if hh_b14==3 | hh_b14==6
replace mig_ind2=2 if (hh_b14==2 | hh_b14==5)
replace mig_ind2=2 if mig_ind2==1  & hh_b15b==hh_a_district /*I include those moving inside district*/
replace mig_ind2=3 if hh_b14==7
label var mig_ind2 "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"

*Migration self-declared as rural or uban
gen mig_rural=0
replace mig_rural=1 if hh_b14==2 | hh_b14==3
gen mig_urban=0
replace mig_urban=1 if hh_b14==5 | hh_b14==6

*Replacing those with 0, but we know that they migrated matching mig_ind
replace mig_ind2=mig_ind if mig_ind2==0 & hh_b15b!=.
levelsof hh_b15b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b15b, gen(tag2)
replace mig_ind2=3 if mig_ind2==1 & hh_b15b>500 & hh_b15b!=. /*Those are also international migrants*/

replace hh_b15b=hh_a_district if mig_ind2==2 & hh_b15b==. /*Assigning the same district of origin for those migrating inside district. They didn't have info*/
replace mig_ind2=1 if mig_ind2==2 & hh_b15b!=hh_a_district & hh_b15b!=. /*Those guys recorded a different migrant_district but probably wrongly recorded as inside district migrants*/

*########## TABLE 4B #########: Migrants by District
sort hh_b10b
levelsof tag2, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag2 mig_ind2, matcell(migind2)
matrix C=migind2+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T4migind2_m", replace) //modify
putexcel K1=matrix(C)
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind2==1
bys HHID: egen mtotal2=total(n)
label var mtotal2 "Total Number of migrants in the HH (for between district, mig_ind2=1)"
gen mig_hh2=mtotal2/hhsize
gen mig_hht2=0
replace mig_hht2=1 if mig_hh2==1
label var mig_hh2 "% of HH that migrated (mtotal/hhsize)"
label var mig_hht2 "Whole HH that migrated (mtotal/hhsize=1)"
drop n

*Descriptive Statistics by HH. hh_b01 has member number
*########## TABLE 5B #########: Migrants by HH
matrix M2 = J(11,1,0)
matrix colname M2 = total_migrants
matrix rowname M2 = 0 1 2 3 4 5 6 7 8 9 10 
tab mtotal2 if member==1, matcell(tab2)
matrix C2=tab2+M2
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T5total_mig2_m", replace) //modify
putexcel K1=matrix(C2)
*########## TABLE 6B #########: Migrants statistics by hhsize
estpost tabstat mig_hh2 mtotal2 if mig_hh2!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh2)',e(mtotal2)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T6total_mig_hhsize2_m", replace) //modify
putexcel K1=matrix(C)

*########## TABLE 7B #########: Whole HH migrating
tab mig_hht if member==1, matcell(tab1)
tab mig_hht2 if member==1, matcell(tab2)
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T7Whole_mig_hh_m", replace) //modify
putexcel K1=matrix(tab1)
putexcel K7=matrix(tab2)

*########## TABLE 8B #########: Migrants by year of movement
gen years=hh_b12
replace years=. if mig_ind2==0
levelsof years, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
matrix colname M = 1 2 3
matrix rowname M = `rows' 

tab hh_b12 mig_ind2 if mig_ind2!=0, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T8migind2_m", replace) //modify
putexcel K1=matrix(C)

********************************
* KEEPING VARS FOR CROSS-PANEL *
********************************
rename case_id case_id20162017
rename (HHID PID hh_a_hh_wgt ea_id hh_a_region hh_a_district hh_a_reside hh_b03 hh_b04 hh_b05a hh_b05b hh_b06b hh_b06a hh_b12 hh_b13 hh_b10b hh_b15b hh_a23a_1 hh_a23a_2 hh_a23a_3) ///
	   (hhid pid weight eaid region district rural sex rel_to_head age_years age_months born_years born_months years_migrate reason_migrate dist_born dist_move day_interv month_interv year_interv)
keep hhid pid case_id20162017 survey country eaid weight region district rural member hhsize sex rel_to_head age_years age_months ///
	 born_years born_months years_migrate reason_migrate dist_born dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
	 day_interv month_interv year_interv $comm3 $comm3a $health3 $housing3 $geo3 hh_b14 $mechanism3
order hhid pid survey country day_interv month_interv year_interv eaid weight region district rural member hhsize sex rel_to_head age_years age_months ///
	 born_years born_months dist_born years_migrate reason_migrate dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
	 $comm3 $comm3a $health3 $housing3 $geo3 hh_b14 $mechanism3

*re-arraging variables to verify no mistakes
tostring pid, replace
decode sex, gen(sexi)
tostring month_interv, gen(monthi)
decode rel_to_head, gen(rel_to_headi)
decode rural, gen(rurali)
decode born_months, gen(born_monthi)
decode region, gen(regioni)
decode reason_migrate, gen(reasoni)
decode district, gen(dist_name)
decode dist_born, gen(dist_born_name)
decode dist_move, gen(dist_move_name)

*Generating new variables as string to check later if they were not label-names changes
foreach x in $comm3 $health3 $housing3 {
		capture decode `x', gen(st`x')
		if _rc gen st`x' = string(`x')
}

tempfile malawi_y3
save "`malawi_y3'", replace

***********************************
*		MALAWI 2013
***********************************
use "${work2}\malawi_ind_2013.dta", clear

*Renaming education and language variables to match later on
rename (hh_c08 hh_c09 hh_c12 hh_b22) (edu_highest edu_highest1 edu_lastyear language_hh)

rename hh_b_respondent moduleB_respondent /*To match with 2016-2017 name. It has info of respondent*/

*Renaming variables to match later on
global comm2 "com_cd48 com_cd49a com_cd49b com_cd50 com_cd51a com_cd51b com_cd52 com_cd55 com_cd56 com_cd60a com_cd60b com_cd61 com_cd62 com_cd63"
global comm2a "com_ce* com_cf* com_ch* com_cg36* com_cg37*"
global health2 "hh_d04 hh_d05a hh_d05b hh_d33 hh_d34a hh_d34b hh_d35a hh_d35b"
global housing2 "hh_f03a hh_f04a hh_f44 hh_f45 hh_f46 hh_f47 hh_k01 hh_k02 hh_k03 elevation hh_shock1 hh_shock2 hh_shock3 edu_highest edu_highest1 edu_lastyear language_hh"
global geo2 "hh_geo*"
global mechanism2 "k_lobola* k_marriage* hh_e19b hh_d40 hh_b24 moduleB_respondent" /*not hh_c14 question*/

keep y2_hhid PID survey country hh_a_ea_id hh_a_stratum hh_a_baseline_rural hh_a_hh_wgt hh_a_region hh_a_district hh_a_reside ///
hh_a_hhsize hh_a10a hh_a10b hh_b_hhsize hh_b01- hh_b15b hh_a23a_1 hh_a23a_2 hh_a23a_3 $comm2 $comm2a $health2 $housing2 $geo2 $mechanism2
label define HH_B10B 305 "BLANTYRE", modify
label define HH_B15B 305 "BLANTYRE", modify

*For the date of interview in 2013, the first attempt is the main one, and 2, or 3 attempt collected info 2-4 days after (almost the same)
*It was used the date of interview in the first visit
																*******************************
																*		MIGRATION             *
     															*******************************
gen mig_ind=0
tab hh_b09
tab hh_b09, nolabel
/* Defining Migration by individual (1)
1: This village
2: Other village in this district
3: Village in other district
4: This town or urban centre 
5: Other town or urban centre in this dist
6: Town or urban centre in other district
7: Outside malawi
*/
replace mig_ind=1 if hh_b09==3 | hh_b09==6 
replace mig_ind=2 if (hh_b09==2 | hh_b09==5) 
replace mig_ind=2 if mig_ind==1 & hh_b10b==hh_a_district /*I include those moving inside district*/
replace mig_ind=3 if hh_b09==7
label var mig_ind "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"

replace hh_b10b=515 if hh_b10b==105 & mig_ind==3 /*Verified that this is migrant from ZAMBIA*/
levelsof hh_b10b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b10b, gen(tag)
*Replacing missclassification in international migrants
replace mig_ind=1 if tag=="NTCHEU" & mig_ind==3

*########## TABLE 1B #########: Migrants by District
sort hh_b10b
levelsof tag, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag mig_ind, matcell(migind1)
matrix C=migind1+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T1migind1_m", replace) //modify
putexcel F1=matrix(C)

*HH size
sort y2_hhid PID
bys y2_hhid: gen hhsize=_N
gen dif=hh_a_hhsize-hh_b_hhsize
tab dif
drop dif hh_b_hhsize /*Both are the same*/
gen dif=hh_a_hhsize-hhsize /*After comparing the variable hhsize from the one of survey, it defers in many cases. I prefer to use mine, which matches with info we have*/
drop hh_a_hhsize dif
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind==1
bys y2_hhid: egen mtotal=total(n)
label var mtotal "Total Number of migrants in the HH (for between district, mig_ind=1)"
gen mig_hh=mtotal/hhsize
gen mig_hht=0
replace mig_hht=1 if mig_hh==1
label var mig_hh "% of HH that migrated (mtotal/hhsize)"
label var mig_hht "Whole HH that migrated (mtotal/hhsize=1)"
drop n

*Descriptive Statistics by HH. I created a HH member number (this differs from hh_b01)
*########## TABLE 2B #########: Migrants by HH
sort y2_hhid PID
bys y2_hhid: gen member=_n
matrix M1 = J(15,1,0)
matrix colname M1 = Total_migrants
matrix rowname M1 = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 
tab mtotal if member==1, matcell(tab1)
matrix C1=tab1+M1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T2total_mig_m", replace) //modify
putexcel F1=matrix(C1)

*########## TABLE 3B #########: Migrants statistics by hhsize
estpost tabstat mig_hh mtotal if mig_hh!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh)',e(mtotal)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T3total_mig_hhsize_m", replace) //modify
putexcel F1=matrix(C)

*Migration based on district info, more acquare.  
tab hh_b14
tab hh_b14, nolabel
/* Defining Migration by individual (2)
2: OTHER VILLAGE IN THIS DISTRICT
3: VILLAGE IN OTHER DISTRICT
5: OTHER TOWN OR URBAN CENTER IN  THIS DIS
6: TOWN OR URBAN CENTRE IN OTHER DISTRICT
7: OUTSIDE MALAWI
*/

gen mig_ind2=0
replace mig_ind2=1 if hh_b14==3 | hh_b14==6
replace mig_ind2=2 if (hh_b14==2 | hh_b14==5)
replace mig_ind2=2 if mig_ind2==1  & hh_b15b==hh_a_district /*I include those moving inside district*/
replace mig_ind2=3 if hh_b14==7
label var mig_ind2 "0: NoMig. 1: Between Dist-MIG. 2: Inside Dist-MIG 3: International MIG"

*Migration self-declared as rural or uban
gen mig_rural=0
replace mig_rural=1 if hh_b14==2 | hh_b14==3
gen mig_urban=0
replace mig_urban=1 if hh_b14==5 | hh_b14==6

*Replacing names that had code instead of correct decode (5 changes) 
replace hh_b15b=202 if mig_ind2==1 & hh_b15b==3 
replace hh_b15b=206 if mig_ind2==1 & hh_b15b==20 
*Replacing those with 0, but we know that they migrated matching mig_ind
replace mig_ind2=mig_ind if mig_ind2==0 & hh_b15b!=.
levelsof hh_b15b, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
decode hh_b15b, gen(tag2)
replace mig_ind2=1 if mig_ind2==3 & tag2=="SALIMA"
replace mig_ind2=3 if mig_ind2==1 & hh_b15b>500 & hh_b15b!=. /*Those are also international migrants*/
replace hh_b15b=hh_a_district if mig_ind2==2 & hh_b15b==. /*Assigning the same district of origin for those migrating inside district. They didn't have info*/
replace mig_ind2=1 if mig_ind2==2 & hh_b15b!=hh_a_district & hh_b15b!=. /*Those guys recorded a different migrant_district but probably wrongly recorded as inside district migrants*/

*########## TABLE 4B #########: Migrants by District
sort hh_b10b
levelsof tag2, local(tags)
matrix colname M = 1 2 3
matrix rowname M = `tags' 
tab tag2 mig_ind2, matcell(migind2)
matrix C=migind2+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T4migind2_m", replace) //modify
putexcel F1=matrix(C)
*Migration by HH, only for between district migrants
gen n=0
replace n=1 if mig_ind2==1
bys y2_hhid: egen mtotal2=total(n)
label var mtotal2 "Total Number of migrants in the HH (for between district, mig_ind2=1)"
gen mig_hh2=mtotal2/hhsize
gen mig_hht2=0
replace mig_hht2=1 if mig_hh2==1
label var mig_hh2 "% of HH that migrated (mtotal/hhsize)"
label var mig_hht2 "Whole HH that migrated (mtotal/hhsize=1)"
drop n
*Descriptive Statistics by HH. hh_b01 has member number
*########## TABLE 5B #########: Migrants by HH
matrix M2 = J(15,1,0)
matrix colname M2 = total_migrants
matrix rowname M2 = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14
tab mtotal2 if member==1, matcell(tab2)
matrix C2=tab2+M2
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T5total_mig2_m", replace) //modify
putexcel F1=matrix(C2)
*########## TABLE 6B #########: Migrants statistics by hhsize
estpost tabstat mig_hh2 mtotal2 if mig_hh2!=0, by(hhsize) statistics(mean)
ereturn list 
mat C=[e(mig_hh2)',e(mtotal2)']
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T6total_mig_hhsize2_m", replace) //modify
putexcel F1=matrix(C)

*########## TABLE 7B #########: Whole HH migrating
tab mig_hht if member==1, matcell(tab1)
tab mig_hht2 if member==1, matcell(tab2)
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T7Whole_mig_hh_m", replace) //modify
putexcel F1=matrix(tab1)
putexcel F7=matrix(tab2)

*########## TABLE 8B #########: Migrants by year of movement
gen years=hh_b12
replace years=. if mig_ind2==0
levelsof years, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
matrix colname M = 1 2 3
matrix rowname M = `rows' 

tab hh_b12 mig_ind2 if mig_ind2!=0, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T8migind2_m", replace) //modify
putexcel F1=matrix(C)

********************************
* KEEPING VARS FOR CROSS-PANEL *
********************************
rename (y2_hhid PID hh_a_ea_id hh_a_baseline_rural hh_a_hh_wgt hh_a_region hh_a_district hh_a_reside hh_a10a hh_a10b hh_b03 ///
        hh_b04 hh_b05a hh_b05b hh_b06b hh_b06a hh_b12 hh_b13 hh_b10b hh_b15b hh_a23a_1 hh_a23a_2 hh_a23a_3) ///
       (hhid pid eaid baseline_rural weight region district rural ta taid sex rel_to_head age_years age_months born_years born_months ///
	    years_migrate reason_migrate dist_born dist_move day_interv month_interv year_interv)
keep hhid pid survey country eaid baseline_rural weight region district rural ta taid member hhsize sex rel_to_head age_years age_months ///
	 born_years born_months years_migrate reason_migrate dist_born dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
	 day_interv month_interv year_interv $comm2 $comm2a $health2 $housing2 $geo2 hh_b14 $mechanism2
order hhid pid survey country day_interv month_interv year_interv eaid baseline_rural weight region district rural ta taid member hhsize sex rel_to_head age_years age_months ///
	 born_years born_months dist_born years_migrate reason_migrate dist_move mig_ind mtotal mig_hh mig_hht mig_ind2 mtotal2 mig_hh2 mig_hht2 mig_rural mig_urban ///
	 $comm2 $comm2a $health2 $housing2 $geo2 hh_b14 $mechanism2
 
*re-arraging variables to verify no mistakes
decode sex, gen(sexi)
decode month_interv, gen(monthi)
decode rel_to_head, gen(rel_to_headi)
decode rural, gen(rurali)
decode born_months, gen(born_monthi)
decode region, gen(regioni)
decode reason_migrate, gen(reasoni)
decode district, gen(dist_name)
decode dist_born, gen(dist_born_name)
decode dist_move, gen(dist_move_name)

*Generating new variables as string to check later if they were not label-names changes
foreach x in $comm2 $health2 $housing2 {
		capture decode `x', gen(st`x')
		if _rc gen st`x' = string(`x')
}

append using "`malawi_y0'", gen(append)
drop append
append using "`malawi_y1'", gen(append)
drop append
append using "`malawi_y3'", gen(append)
drop append

order hhid- dist_born dist_move years_migrate reason_migrate reason_migrate_other com* stcom*

*Checking some statistics for the timing of interviews. Apparently they were made between sep-aug 
tab month_interv year_interv if survey=="Survey-2013"
tab month_interv year_interv if survey=="Survey-2010-2011"
tab month_interv year_interv if survey=="Survey-2016-2017"

*DEFINING SAMPLE. IT CORRESPONDS TO THOSE WHO:
*SURVEYED IN 2013-2014 AND MIGRATED 2, 3 AND 4 YEARS AGO (WE CAN INFO OF INCOME FOR THEM IN PREVIOUS SURVEYS)
*SURVEYED IN 2011-2012 AND MIGRATED 1, 2 YEARS AGO (WE CAN INFO OF INCOME FOR THEM IN PREVIOUS SURVEYS)
*SURVEYED IN 2010-2011 AND MIGRATED 1 YEARS AGO (WE CAN INFO OF INCOME FOR THEM IN PREVIOUS SURVEYS)
gen sample=0
replace sample=1 if survey=="Survey-2013" & mig_ind2==1 & (years_migrate==3 | years_migrate==9)
replace sample=1 if survey=="Survey-2010-2011" & mig_ind2==1 & (years_migrate==6)
replace sample=1 if survey=="Survey-2016-2017" & mig_ind2==1 & (years_migrate==3 | years_migrate==6 | years_migrate==12) 
replace sample=0 if dist_move==. /*I dropped some few cases with missings in dist_move*/
*Checking duplicated HH members that reported migration in several waves. Otherwise, we will count them twice or more.
sort hhid pid survey
duplicates tag hhid pid if sample==1, gen(dup1) 
by hhid pid: gen t1=1 if dist_move[_n]==dist_move[_n+1] & sample==1 & dup1==1
replace sample=0 if t1==1
drop t1 dup1

*Generating variable with sample info of survey to be used. If they are migrants in wave4(2013-2014),
* but migrated 4 years back, we have to use info of wave1(2009-2010).
gen sample_survey=""
replace sample_survey="Survey-2010-2011" if sample==1 & years_migrate==3 & survey=="Survey-2013"
replace sample_survey="Survey-2004-2005" if sample==1 & years_migrate==9 & survey=="Survey-2013"
replace sample_survey="Survey-2004-2005" if sample==1 & years_migrate==6 & survey=="Survey-2010-2011"
replace sample_survey="Survey-2013" if sample==1 & years_migrate==3 & survey=="Survey-2016-2017"
replace sample_survey="Survey-2010-2011" if sample==1 & years_migrate==6 & survey=="Survey-2016-2017"
replace sample_survey="Survey-2004-2005" if sample==1 & years_migrate==12 & survey=="Survey-2016-2017"

*########## TABLE 9A #########: Migrants sample of individuals by year of migration
*levelsof survey, local(sur)
*local nsur : word count `sur'
matrix M = J(4,3,0)
matrix colname M = "Survey-2010-2011" "Survey-2013" "Survey-2016-2017"
matrix rowname M =  3 6 9 12
tab years_migrate survey if sample==1, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T9mig_sample", replace) //modify
putexcel A1=matrix(C)

*########## TABLE 10A #########: Migrants sample-Whole HH migrated
matrix W=J(2,2,0)
tab mig_hht2 if member==1,matcell(all)
tab mig_hht2 if sample==1 & member==1, matcell(sample)
matrix W=[all,sample]
matrix colname W = "All Sample" "Our Sample"
matrix rowname W =  0 1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T10whole_mig_sample", replace) //modify
putexcel A1=matrix(W)

*Generating Monthly date to define timing when they migrated. Then, I define sample according to the period the survey was conducted.
*Apr2013-Nov2013, Mar2010-Mar2011, Mar2004-Mar2005
gen migra=year_interv-years_migrate
replace migra=. if years_migrate>=100
gen t = ym(migra,month_interv)
format t %tm
drop migra
gen sample2=0
replace sample2=1 if survey=="Survey-2013"      & mig_ind2==1 & (( t>=tm(2010m3) & t<=tm(2011m3) ) | ( t>=tm(2004m3) & t<=tm(2005m3) ) )
replace sample2=1 if survey=="Survey-2010-2011" & mig_ind2==1 & (( t>=tm(2004m3) & t<=tm(2005m3) ) )
replace sample2=1 if survey=="Survey-2016-2017" & mig_ind2==1 & (( t>=tm(2013m4) & t<=tm(2013m11) ) | ( t>=tm(2010m3) & t<=tm(2011m3) ) | ( t>=tm(2004m3) & t<=tm(2005m3) ) )
replace sample2=0 if dist_move==. /*I dropped some few cases with missings in dist_move*/
*Checking duplicated HH members that reported migration in several waves. Otherwise, we will count them twice or more.
sort hhid pid survey
duplicates tag hhid pid if sample2==1, gen(dup2) 
by hhid pid: gen t2=1 if dist_move[_n]==dist_move[_n+1] & sample2==1 & dup2==1
replace sample2=0 if t2==1
drop t2 dup2

*Generating variable with sample info of survey to be used. If they are migrants in wave4(2013-2014),
* but migrated 4 years back, we have to use info of wave1(2009-2010).
gen sample2_survey=""
replace sample2_survey="Survey-2013"      if sample2==1 & ( t>=tm(2013m4) & t<=tm(2013m11) ) & survey=="Survey-2016-2017"
replace sample2_survey="Survey-2010-2011" if sample2==1 & ( t>=tm(2010m3) & t<=tm(2011m3) ) & survey=="Survey-2016-2017"
replace sample2_survey="Survey-2004-2005" if sample2==1 & ( t>=tm(2004m3) & t<=tm(2005m3) ) & survey=="Survey-2016-2017"
replace sample2_survey="Survey-2010-2011" if sample2==1 & ( t>=tm(2010m3) & t<=tm(2011m3) ) & survey=="Survey-2013"
replace sample2_survey="Survey-2004-2005" if sample2==1 & ( t>=tm(2004m3) & t<=tm(2005m3) ) & survey=="Survey-2013"
replace sample2_survey="Survey-2004-2005" if sample2==1 & ( t>=tm(2004m3) & t<=tm(2005m3) ) & survey=="Survey-2010-2011"

*########## TABLE 9D #########: Migrants sample of individuals by year of migration
generate t2= string(t, "%tm")
replace t2="" if sample2==0
levelsof t2, local(rows)
local nrows : word count `rows'
matrix M = J(`nrows',3,0)
matrix colname M =  "Survey-2010-2011" "Survey-2013" "Survey-2016-2017"
matrix rowname M =  `rows'
tab t2 survey if sample2==1, matcell(migyear)
matrix C=migyear+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T9mig_sample", replace) //modify
putexcel A12=matrix(C)

*########## TABLE 10D #########: Migrants sample-Whole HH migrated
matrix W=J(2,2,0)
tab mig_hht2 if member==1,matcell(all)
tab mig_hht2 if sample2==1 & member==1, matcell(sample)
matrix W=[all,sample]
matrix colname W = "All Sample" "Our Sample"
matrix rowname W =  0 1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T10whole_mig_sample", replace) //modify
putexcel A12=matrix(W)

*######################
*Extra info of total number of individuals, located in Table 7
tab mig_ind2 if survey=="Survey-2010-2011", matcell(total)
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T7Whole_mig_hh_m", replace) //modify
putexcel A13=matrix(total)
tab mig_ind2 if survey=="Survey-2013", matcell(total)
putexcel F13=matrix(total)
tab mig_ind2 if survey=="Survey-2016-2017", matcell(total)
putexcel K13=matrix(total)
tab mig_ind2 if survey=="Survey-2004-2005", matcell(total)
putexcel P13=matrix(total)


*Checking if sample2 has some district with just codes and no number
* Table 4 "T4migind2_m" of excel file shows that for Malawi there is not problem with some missings codes-district name. OK

*Checking variables are well labeled
tab sex
tab sexi /*OK*/
drop sexi
tab month_interv
tab monthi
drop monthi /*OK*/
tab rel_to_head
tab rel_to_headi
drop rel_to_headi /*OK*/
tab rural
tab rurali /*mistakes 0,1,2. URBAN 1, RURAL 2*/
replace rural=1 if rurali=="Urban" | rurali=="urban"
replace rural=2 if rurali=="Rural" | rurali=="rural"
drop rurali
tab born_months
tab born_monthi /*OK. Just leave all missing as the same*/
replace born_months=. if born_months==99
drop born_monthi
tab region
tab regioni /*OK*/
drop regioni
drop baseline_rural /*Only exists for 2013*/
drop area areani /*Information didn't match at all. Different question in the different surveys*/
tab reason_migrate
tab reasoni /*OK*/
drop reasoni

*Fixing missings for ta
*gen tat=substr(eaid,4,2)
*destring tat, replace
*replace ta=tat if ta==.
*drop tat

*To keep in mind. Strata is almost the same as dist in 2004/2005, except that it separate Mzimba/Mzuzu City, Lilongwe/Lilongwe City, Zomba/Zomba City and 
*Blantyre/Blantyre City. Although dist matches with the information of case_id, I prefer strata rather than dist to our purpose of having better classification
replace dist_name="Nkhata Bay" if dist_name=="Nkhatabay"
replace dist_name="Nkhotakota" if dist_name=="Nkhota kota"
replace dist_name="Zomba" if dist_name=="Zomba Non-City"

*Comparing community question ok with labels
foreach x of varlist com_cd* com_cg15 {
	capture decode `x', gen(fake`x')
	if _rc==0 {
		replace st`x'=lower(st`x')
		display "`x'"
		tab `x'
		tab st`x'
	}
}
drop fake*
 
*com_cd62 corresponds to cd54 in 2004/2005 1 yes, 2 no. Correct
*com_cd61 corresponds to cd52 in 2004/2005 1 Gov 2 Church 3 Private
replace com_cd61=. if com_cd61==0

*Fixing those with problems 
replace com_cd52=1 if stcom_cd52=="1" | stcom_cd52=="always available" /*for 2004/2005 this question is yes or not (1 or 2) while in other waves was always, sometimes, never (1 2 3)*/
replace com_cd52=3 if stcom_cd52=="2" | stcom_cd52=="never available"
replace com_cd52=2 if stcom_cd52=="sometimes available"
drop stcom* dist_name dist_born_name dist_move_name stcd*

*Now sec D,K F
*Comparing questions ok with labels. SEC D
foreach x of varlist hh_d04-hh_d35b {
	capture decode `x', gen(fake`x')
	if _rc==0 {
		replace st`x'=lower(st`x')
		display "`x'"
		tab `x'
		tab st`x'
	}
}
drop fake* 
*Redifining some missing categories
label define HH_D05A 31 "ANAEMIA/BILHARZIA" 32 "PAIN IN LIMBS,JOINTS,OR SWELLING" 33 "MEASLES/CHICKEN POX" 34 "MENINGITIS" 35 "PARALYSIS" ///
36 "MALNUTRITION" 99 "NO OTHER ILLNESS REPORTED", modify
label define HH_D05B 31 "ANAEMIA/BILHARZIA" 32 "PAIN IN LIMBS,JOINTS,OR SWELLING" 33 "MEASLES/CHICKEN POX" 34 "MENINGITIS" 35 "PARALYSIS" ///
36 "MALNUTRITION" 99 "NO OTHER ILLNESS REPORTED", modify
label define HH_D34A 16 "SKIN PROBLEM" 17 "FAINTING/EPILEPSY" 18 "DEAF" 19 "DENTAL PROBLEM" 20 "PROBLEM WITH INTERNAL ORGANS" ///
21 "SEXUALLY TRANSMITTED INFECTION (STI)" 22 "RELATED PROBLEMS/H.B.PRESSURE" 23 "PAIN OF LIMBS, JOINTS OR SWELLINGS" ///
24 "MALNUTRITION" 25 "EYE SIGHT PROBLEMS" 26 "PARALYSIS/STROKE" 99 "NO OTHER ILLNESS GIVEN", modify
replace hh_d34a=14 if hh_d34a==23
replace hh_d34a=23 if sthh_d34a=="pain of limbs, joints or swellings"
replace hh_d34a=15 if sthh_d34a=="other"
label define HH_D34B 16 "SKIN PROBLEM" 17 "FAINTING/EPILEPSY" 18 "DEAF" 19 "DENTAL PROBLEM" 20 "PROBLEM WITH INTERNAL ORGANS" ///
21 "SEXUALLY TRANSMITTED INFECTION (STI)" 22 "RELATED PROBLEMS/H.B.PRESSURE" 23 "PAIN OF LIMBS, JOINTS OR SWELLINGS" ///
24 "MALNUTRITION" 25 "EYE SIGHT PROBLEMS" 26 "PARALYSIS/STROKE" 99 "NO OTHER ILLNESS GIVEN", modify
replace hh_d34b=15 if sthh_d34b=="other"
replace hh_d34b=23 if sthh_d34b=="pain of limbs, joints or swellings"

*Comparing questions ok with labels. SEC F and K
foreach x of varlist hh_f03a-hh_k03 {
	capture decode `x', gen(fake`x')
	if _rc==0 {
		replace st`x'=lower(st`x')
		display "`x'"
		tab `x'
		tab st`x'
	}
}
drop fake* 
*adding extra category
label define HH_F47 9 "NO CHILDREN UNDER 5",modify
drop st*

*Changing names to match with other countries
rename (hh_f04a hh_f03a) (rent_301 rent_302)

*Standarizing health variables
label define COM_CD48 1 "Yes, Within the village / street" 2 "No, Not within the village / street" 3 "Not applicable", modify
replace com_cd48=3 if com_cd48==0
replace com_cd49a=com_cd49a/1000 if com_cd49b==1 & com_cd49a!=. /*meters to KM. Some multiplied by 0 did not change*/
replace com_cd49a=com_cd49a*1.60934 if com_cd49b==3 /*milles to KM*/
replace com_cd49a=0 if com_cd48==1 & com_cd49a==. /*Putting 0 for those health inside the village and missing*/
drop com_cd49b
label var com_cd49a "What is the distance to nearest place where one can purchase common medicine(KM)"

label define COM_CD50 1 "Yes, Within the village / street" 2 "No, Not within the village / street" 3 "Not applicable", modify
replace com_cd51a=com_cd51a/1000 if com_cd51b==1 /*meters to KM. Some multiplied by 0 did not change*/
replace com_cd51a=com_cd51a*1.60934 if com_cd51b==3 /*milles to KM*/
replace com_cd51a=0 if com_cd50==1 & com_cd51a==. /*Putting 0 for those health inside the village and missing*/
drop com_cd51b
label var com_cd51a "What is the distance to nearest place where there is a health clinic (Chipat) KM"
label define COM_CD53 1 "GOVERNMENT FACILITY" 2 "RELIGIOUS PRIVATE FACILITY", modify
replace com_cd53=2 if com_cd53==3

label define COM_CD55 1 "Yes, Within the village / street" 2 "No, Not within the village / street" 3 "Not applicable", modify
replace com_cd60a=com_cd60a/1000 if com_cd60b==1 /*meters to KM. Some multiplied by 0 did not change*/
replace com_cd60a=com_cd60a*1.60934 if com_cd60b==3 /*milles to KM*/
replace com_cd60a=0 if com_cd60b==0 & com_cd60a==. /*Putting 0 for those health inside the village and missing*/
drop com_cd60b
label var com_cd60a "What is the distance to nearest health facility with a medical doc (KM)"
label define COM_CD61 1 "GOVERNMENT FACILITY" 2 "RELIGIOUS PRIVATE FACILITY", modify
replace com_cd61=2 if com_cd61==3 

*Homogenizing another variable to match with TANZANIA and UGANDA
gen hea_ava=3
*0 for those with no within, or at least one no within and the other missing
replace hea_ava=0 if (com_cd50==2 & com_cd55==2) | (com_cd50==2 & com_cd55==.) | (com_cd50==. & com_cd55==2 )
*1 when one is within and other nothing else OR viceversa
replace hea_ava=1 if (com_cd50==1 & com_cd55!=1) | (com_cd50!=1 & com_cd55==1)
*2 if there are both health centre. Within
replace hea_ava=2 if com_cd50==1 & com_cd55==1 
label define health 0 "No Health Centre within village" 1 "Any Health Centre" 2 "Two health Centre(Pri-gov)" 3 "Not Applicable"
label values hea_ava health
*Generating extra to include missing when summing
gen dis50=com_cd51a
replace dis50=0 if com_cd51a==. & com_cd60a!=.
gen dis55=com_cd60a
replace dis55=0 if com_cd60a==. & com_cd51a!=.
*Create variable to that has the min distance all the time that there is a missing in one dist category and the other no
gen to=dis50+dis55
egen min=rowmin(dis50-dis55)
*Distance
gen hea_dis_min=.
*0 and 1 options defined before for hea_ava
replace hea_dis_min=min if hea_ava==0 & ((com_cd51a!=. & com_cd60a!=.) | (com_cd51a==. & com_cd60a==.))
replace hea_dis_min=to  if hea_ava==0 & ((com_cd51a==. & com_cd60a!=.) | (com_cd51a!=. & com_cd60a==.))
replace hea_dis_min=min if (hea_ava==1 & com_cd51a!=. & com_cd60a!=.)
replace hea_dis_min=to  if  hea_ava==1 & ((com_cd51a!=. & com_cd60a==.) | (com_cd51a==. & com_cd60a!=.))
replace hea_dis_min=min if  hea_ava==2 & com_cd51a!=. & com_cd60a!=.
*Keeping those No applicable in the case they have info of distance. I kept it
replace hea_dis_min=min if  hea_ava==3 & (com_cd51a!=. & com_cd60a!=.)
drop to min dis50 dis55

*Homogenizing Avertive Behaviour Questions (BEDNETS)
gen use_bednet=hh_f44
copydesc hh_f44 use_bednet
replace use_bednet=2 if use_bednet==4 
replace use_bednet=1 if use_bednet==. & hh_f45==1
replace use_bednet=0 if use_bednet==2
label define bednet 1 "YES" 0 "NO, UNKNOWN" 
label values use_bednet bednet
gen bednet_treat1=hh_f45
copydesc hh_f44 bednet_treat1
replace bednet_treat1=. 
replace bednet_treat1=1 if hh_f45==2
replace bednet_treat1=2 if hh_f45==1 | hh_f45==3
replace bednet_treat1=3 if hh_f45==6 
replace bednet_treat1=3 if use_bednet==0 & bednet_treat1==.
replace bednet_treat1=3 if use_bednet==1 & hh_f45==. /*Those that say YES bednet but missing in hh_f45*/
label define treat 1 "YES UNTREATED NET" 2 "YES TREATED NET" 3 "NO, UNKNOWN"
label values bednet_treat1 treat

gen bednet_treat2=bednet_treat1
copydesc bednet_treat1 bednet_treat2
replace bednet_treat2=.
replace bednet_treat2=1 if bednet_treat1==1 | bednet_treat1==2
replace bednet_treat2=2 if hh_f45==2
replace bednet_treat2=3 if hh_f45==6 
replace bednet_treat2=3 if use_bednet==0 & bednet_treat1==.
replace bednet_treat2=3 if use_bednet==1 & hh_f45==.
label define treat2 1 "YES" 2 "NO" 3 "NOT SURE"
label values bednet_treat2 treat2
 
*BEDNETS EXPENDITURES
drop hh_k02
rename hh_k01 purchase_bednet
rename hh_k03 pay_in_bednet

*Calculating statistics for Avertive Behaviour
bys hhid survey: egen bedtotal1=total(use_bednet)
label var bedtotal1 "Total Number of HH members using Bednets. Individual level"
gen bedtotal_per1=bedtotal1/hhsize
label var bedtotal_per1 "% of HH members using Bednets. Individual level"

*This measure takes into account for HH level and it's more comparable with Tanzania and Uganda. First measure assumes all member of the HH used bednet
gen bedtotal_per2=bedtotal_per1
label var bedtotal_per2 "% of HH members using Bednets.If at least 1 member use bednet, whole HH takes 1"

*########## TABLE 11 #########: All sample and our migrant sample. Question is at the HH level
matrix W=J(2,2,0)
tab bedtotal_per2 if member==1 & survey!="Survey-2004-2005", matcell(all) /*2004-2005 does not belong to the migrant sample*/
tab bedtotal_per2 if sample2==1 & member==1 & survey!="Survey-2004-2005", matcell(sample)
matrix W=[all,sample]
matrix colname W = "All Sample" "Our Sample"
matrix rowname W =  0 1
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T11%HH_bednet", replace) //modify
putexcel A2=matrix(W)

*Homogenizing Reasons to Migrate
label list HH_B13
label define REASON_MIGRATE 1 "WORK RELATED/LOOK FOR WORK" 2 "SCHOOL/STUDIES" 3 "MARRIAGE" 4 "FAMILY REASONS/FOLLOW JOIN FAMILY" ///
5 "LAND/PLOT/OTHER LAND RELATED" 6 "OTHERS"
gen reason_migrate1=.
replace reason_migrate1=1 if reason_migrate==7 | reason_migrate==8 | reason_migrate==9 | reason_migrate==10 
replace reason_migrate1=2 if reason_migrate==3
replace reason_migrate1=3 if reason_migrate==4 
replace reason_migrate1=4 if reason_migrate==1 | reason_migrate==2| reason_migrate==19
replace reason_migrate1=5 if reason_migrate==11| reason_migrate==18
replace reason_migrate1=6 if reason_migrate==5 | reason_migrate==6 | reason_migrate==12 | reason_migrate==13 | reason_migrate==14| reason_migrate==15| reason_migrate==16| reason_migrate==17| reason_migrate==20
label values reason_migrate1 REASON_MIGRATE
drop reason_migrate
rename reason_migrate1 reason_migrate

*########## TABLE 12 #########: All sample and our migrant sample. Statistics of kids vs adults
*Generating a variable to calculate age in months for some missings in years but info in months(babies and also someother)
gen age_b1=.
replace age_b1=ym(year_interv, month_interv) if (age_years==. & age_months!=.) | (age_years==. & age_months==.) /*Replacing only these guys*/
gen age_b2=.
replace age_b2=ym(born_years, born_months) if (age_years==. & age_months!=.) | (age_years==. & age_months==.)
format age_b1 age_b2 %tm
gen dif_age=int((age_b1-age_b2)/12)
replace age_years=dif_age if age_years==. & dif_age!=. /*Replacing age for those  missing*/
drop age_b1 age_b2 dif_age
*Defining brackets of age
gen age_bracket=.
replace age_bracket=1 if age_years<=5 & age_years!=.
replace age_bracket=2 if age_years>=6 & age_years<=10 & age_years!=.
replace age_bracket=3 if age_years>=11 & age_years<=17 & age_years!=.
replace age_bracket=4 if age_years>=18 & age_years<=25 & age_years!=.
replace age_bracket=5 if age_years>=26 & age_years<=35 & age_years!=.
replace age_bracket=6 if age_years>=36 & age_years<=45 & age_years!=.
replace age_bracket=7 if age_years>=46 & age_years<=55 & age_years!=.
replace age_bracket=8 if age_years>=56 & age_years<=65 & age_years!=.
replace age_bracket=9 if age_years>=66 & age_years<=75 & age_years!=.
replace age_bracket=10 if age_years>=76 & age_years!=.
label define AGE_BRACKET 1 "<=5" 2 "6-10" 3 "11-17" 4 "18-25" 5 "26-35" 6 "36-45" 7 "46-55" 8 "56-65" 9 "66-75" 10 ">=76" 
label values age_bracket AGE_BRACKET
*Defining matrix to save results
matrix W=J(10,7,0)
tab age_bracket survey, matcell(all) 
tab age_bracket survey if sample2==1, matcell(sample)
matrix W=[all,sample]
matrix colname W = "All-2004-2005" "All-2010-2011" "All-2013" "All-2016-2017" "sample2-2010-2011" "sample2-2013" "sample2-2016-2017"
matrix rowname W =  "<=5" "6-10" "11-17" "18-25" "26-35" "36-45" "46-55" "56-65" "66-75" ">=76" 
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T12kidsvsadult", replace) //modify
putexcel A2=matrix(W)

*########################### DEFINING A VARIABLE FOR HH WITH KIDS <5 YEARDS OLD
sort country survey hhid pid
gen a=0
replace a=1 if age_bracket==1 /*dummy with kids less than 5 years old*/
bys survey hhid: egen hh_kids5=sum(a) /*Summing all the kids <5 in the hh*/
gen kids5=0
replace kids5=1 if hh_kids5!=0
gen per_hhkids5=0
replace per_hhkids5=hh_kids5/hhsize
drop a hh_kids5
label var kids5 "1: if at least 1 kid <5 years. 0: otherwise"
label var per_hhkids5 "% of kids with < 5 years old"

*########################### DEFINING A NEW CATEGORY FOR WHOLE HH IF THEY MIGRATED TO SAME DISTRICT AND MIGRATED AT THE SAME TIME
sort country survey hhid pid
bys survey hhid: egen ave_move=mean(dist_move)
bys survey hhid: egen ave_move_year=mean(years_migrate)
gen mig_hht3=0
replace mig_hht3=1 if mig_hh2==1 & dist_move==ave_move /*Same as mig_hht2 but restricting those migrating to same district*/
label var mig_hht3 "Whole HH (mtotal/hhsize=1), migrating to same district"
gen mig_hht4=0
replace mig_hht4=1 if mig_hh2==1 & dist_move==ave_move & ave_move_year==years_migrate /*Same as mig_hht2 but restricting migrants of same district, same time*/
bys survey hhid: egen tot_size=sum(mig_hht4) /*hhsize has to be generated based on the sample mig_hht4, not with respect to hhsize */
replace mig_hht4=0 if mig_hht4==1 & tot_size==1 /*Getting rid of HH of 1 person*/
label var mig_hht4 "Whole HH(mtotal/hhsize=1) migrating same district,same year, and hhsize>1"

*################################ DEFINING EXTRA VARS FOR HAVING SIBLINGS(BROTHER-SISTER IN THE HH). ALTERNATIVE TO WHOLE HH MIGRATED
sort country survey hhid pid
gen a=0 if sex!=. & rel_to_head!=.
replace a=1 if sex!=. & rel_to_head==3
bys survey hhid: egen sum_sib=sum(a)
gen sibling=0 
replace sibling=1 if sum_sib>=2

gen b=0 if sex!=. & rel_to_head!=.
replace b=1 if sex==1 & rel_to_head==3
bys survey hhid: egen sum_siboy=sum(b)
gen sibling_boy=0 
replace sibling_boy=1 if sum_siboy>=2

gen c=0 if sex!=. & rel_to_head!=.
replace c=1 if sex==2 & rel_to_head==3
bys survey hhid: egen sum_sigirl=sum(c)
gen sibling_girl=0 
replace sibling_girl=1 if sum_sigirl>=2
drop a b c sum_si*

*################################ DEFINING EXTRA VARS FOR COUPLE OF THE HH MOVING TOGETHER. ALTERNATIVE TO WHOLE HH MIGRATED
gen head=1 if rel_to_head==1
gen partner=1 if rel_to_head==2
bys survey hhid: egen heady=sum(head) 
bys survey hhid: egen partnery=sum(partner)

gen couple=1 if heady==1 & partnery==1 & dist_move==ave_move & ave_move_year==years_migrate & dist_move!=. & (rel_to_head==1|rel_to_head==2) //head and partner and moving together
replace couple=0 if couple==.

bys survey hhid: egen sumcouple=sum(couple)

gen mig_couple=0
replace mig_couple=1 if mig_hh2!=0 & dist_move==ave_move & ave_move_year==years_migrate & sumcouple>1 /*Similar to mig_hht4 but only for couple-migrants of same district, same time*/
replace mig_couple=0 if mig_couple==1 & hhsize==1 /*Getting rid of HH of 1 person. Here HHsize not variable tot_size as in mig_hht4*/
label var mig_couple "In my HH the couple migrated same district,same year, and hhsize>1"
drop head heady partner partnery couple sumcouple

*########################### DEFINING A CATEGORY FOR COMPLETION OF EDUCATION. I will use edu_highest=What class are you in or what was the highest class level you ever attended?
gen eduhigh=.
replace eduhigh=edu_highest if edu_highest!=.
label values eduhigh HH_C08

gen eduyears=.
replace eduyears=0 if eduhigh==0
replace eduyears=1 if eduhigh==1
replace eduyears=2 if eduhigh==2
replace eduyears=3 if eduhigh==3
replace eduyears=4 if eduhigh==4
replace eduyears=5 if eduhigh==5
replace eduyears=6 if eduhigh==6
replace eduyears=7 if eduhigh==7
replace eduyears=8 if eduhigh==8
replace eduyears=9 if eduhigh==9
replace eduyears=10 if eduhigh==10
replace eduyears=11 if eduhigh==11
replace eduyears=12 if eduhigh==12
replace eduyears=13 if eduhigh==13
replace eduyears=14 if eduhigh==14
replace eduyears=15 if eduhigh==15
replace eduyears=16 if eduhigh==16
replace eduyears=17 if eduhigh==17
replace eduyears=18 if eduhigh==18
replace eduyears=19 if eduhigh==19
replace eduyears=15 if eduhigh==20
replace eduyears=16 if eduhigh==21
replace eduyears=17 if eduhigh==22
replace eduyears=18 if eduhigh==23

***********************************************************************************
** Adding language_hh to all individuals in the HH
***********************************************************************************
sort survey hhid pid 
bys survey hhid: egen lang=sum(language_hh)
bys survey hhid: replace language_hh=lang if language_hh==.
replace language_hh=. if language_hh==0
drop lang
***********************************************************************************
** Adding work activity of hh_head to all individuals in the HH
***********************************************************************************
sort survey hhid pid 
bys survey hhid: egen work_hh=sum(hh_e19b) if rel_to_head==1
bys survey hhid: egen work_hh1=sum(work_hh)
replace work_hh1=. if work_hh1==0
clonevar work_hh_head=hh_e19b
bys survey hhid: replace work_hh_head=. if rel_to_head!=1 
bys survey hhid: replace work_hh_head=work_hh1 if work_hh_head==.
drop work_hh work_hh1

gen work_hh_head_ag=0 if work_hh_head!=.
replace work_hh_head_ag=1 if work_hh_head>=60 & work_hh_head<=64 /*Agro categories*/
label var work_hh_head_ag "1/0 for HH head doing agro as main activity"

************************************************************************************
** Adding ModuleB respondent and HH_sex to all individuals in the HH 
************************************************************************************
sort survey hhid pid 
clonevar sex_hh_head=sex
bys survey hhid: egen sex_hh1=sum(sex) if rel_to_head==1
bys survey hhid: egen sex_hh2=sum(sex_hh1)
replace sex_hh2=. if sex_hh2==0 /*33 with missing HH head*/
replace sex_hh2=. if sex_hh2==6 /*Strange case of one HH with 2 HH heads, better to missing*/
replace sex_hh_head=.
replace sex_hh_head=sex_hh2 if sex_hh2!=.
drop sex_hh1 sex_hh2

gen id_2013= substr(pid,-2,.) if survey=="Survey-2013" /*id of person in questionnaire*/
destring id_2013, replace
sort hhid rel_to_head id_2013
by hhid (rel_to_head id_2013): gen id_2013_2=_n if survey=="Survey-2013"  /*organizing data better in case of overlaps*/

gen id=.
replace id=id_2013_2 if survey=="Survey-2013" 
gen pid20162017=pid if survey=="Survey-2016-2017"
destring pid20162017, replace
replace id=pid20162017 if survey=="Survey-2016-2017"
drop id_2013_2 id_2013 pid20162017

sort country survey hhid id 

gen moduleB_resp=.
bys hhid: replace moduleB_resp=rel_to_head if moduleB_respondent==id & moduleB_respondent!=.

bys survey hhid: egen summ=sum(moduleB_resp) if survey=="Survey-2013" | survey=="Survey-2016-2017"
drop moduleB_resp id
rename summ  moduleB_resp
label values moduleB_resp HH_B04
replace moduleB_resp=. if moduleB_resp==0 /*some missings*/

****************************
**** ADDING RIGA LSMS ****** NO 2013 NO 2016-2017
****************************
merge m:1 hhid survey country using "${work}\malawi_cross_panel_rigahh.dta", keep(master using match) gen(merge_m)
replace Y=. if Y<0 /*Some HH have negative income. Changed to missings*/
replace Yag=. if Yag<0 /*Some HH have negative income. Changed to missings*/
tab survey merge_m /*almost all matched for waves 1-2. Big part of missings are for wave3 as expected*/ 
format Y Yag %12.0f

gen Yag_per=Yag/Y /*Y only for 2004-2005 and 2010-2011*/

*****************************
** MAKING DYADIC FRAMEWORK
*****************************
*Destination
gen dist_d=district
copydesc district dist_d 
label var dist_d "District Destination"

*Origin
gen dist_o=dist_move
copydesc dist_move dist_o
label var dist_o "District Origin"

****** INCOME*****
******************
* Calculating average income by district and using joinby to add it. Add for HH, then by district
sort country survey hhid pid 

foreach x in Y Yag {
	bys survey hhid: gen `x'm = `x'/hhsize /*Income by HH member*/
	format `x'm %12.0f
	******Adjusting by real exchange rate. Check File \INPUT\WDI\WDI exchange rate-PPP.xlsx for the values. I used the average of both years
	gen `x'm_tan=. /*In Tanzanian Schillings*/
	format `x'm_tan %12.0f
	replace `x'm_tan=`x'm*((1.797760434+1.557711694)/2) if survey=="Survey-2004-2005" /*Real Terms in money of 2010*/
	replace `x'm_tan=`x'm*((1.000000000+0.929170947)/2) if survey=="Survey-2010-2011"
	replace `x'm_tan=`x'm_tan*((8.810837610+9.226367762)/2) if survey=="Survey-2004-2005" /*Adjusting by real exchange rate*/
	replace `x'm_tan=`x'm_tan*((9.274077727+9.503148642)/2) if survey=="Survey-2010-2011"
	gen `x'm_us=. /*In US Dollars*/
	format `x'm_us %12.0f
	replace `x'm_us=`x'm*((1.797760434+1.557711694)/2) if survey=="Survey-2004-2005" /*Real Terms in money of 2010*/
	replace `x'm_us=`x'm*((1.000000000+0.929170947)/2) if survey=="Survey-2010-2011"
	replace `x'm_us=`x'm_us*((0.0058968980+0.00605302)/2) if survey=="Survey-2004-2005" /*Adjusting by real exchange rate*/
	replace `x'm_us=`x'm_us*((0.006645107+0.006665752)/2) if survey=="Survey-2010-2011"
}
preserve
	collapse (mean) Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us hhsize, by(survey dist_d hhid) cw /*cw does not take into account missings*/
	collapse (mean) Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us [fw=hhsize], by(survey dist_d) cw /*fw takes into account that a HH of 3 earns on average 15000, each receives 5000*/
	drop if dist_d==.
	rename survey sample2_survey
	save "${work2}\malawi_income.dta", replace
restore

rename (Ym Yagm) (Yme Yagme)
drop Ym_tan Ym_us Yagm_tan Yagm_us

merge m:1 sample2_survey dist_d using "${work2}\malawi_income.dta", keep(master using match) gen(merge_Y) /*Adding destination*/
* We couldn't recover some missing district codes for people of sample2; that's why we have some without Y info. Also, few cases that were not sampled in surveys(77 districts in some surveys instead of 80)
drop if hhid=="" 
rename (Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us) (Ym_d Ym_tan_d Ym_us_d Yagm_d Yagm_tan_d Yagm_us_d) 
label var Ym_d "Real Annual Income Destination in previous wave according to sample definition2"
label var Ym_tan_d "Real Annual Income Destination in previous wave-sample def2(Tanzanian Schilling)"
label var Ym_us_d "Real Annual Income Destination in previous wave-sample def2(US Dollars)"
label var Yagm_d "Real Annual Agro Income Destination in previous wave according to sample definition2"
label var Yagm_tan_d "Real Annual Agro Income Destination in previous wave-sample def2(Tanzanian Schilling)"
label var Yagm_us_d "Real Annual Agro Income Destination in previous wave-sample def2(US Dollars)"

preserve
use "${work2}\malawi_income.dta", clear
rename dist_d dist_o
save "${work2}\malawi_income.dta", replace
restore
joinby sample2_survey dist_o using "${work2}\malawi_income.dta", unmatched(master) /*Adding Origin*/
rename (Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us) (Ym_o Ym_tan_o Ym_us_o Yagm_o Yagm_tan_o Yagm_us_o) 
label var Ym_o "Real Annual Income Destination in previous wave-sample def2"
label var Ym_tan_o "Real Annual Income Origin in previous wave-sample def2(Tanzanian Schilling)"
label var Ym_us_o "Real Annual Income Origin in previous wave-sample def2(US Dollars)"
label var Yagm_o "Real Annual Agro Income Destination in previous wave-sample def2"
label var Yagm_tan_o "Real Annual Agro Income Origin in previous wave-sample def2(Tanzanian Schilling)"
label var Yagm_us_o "Real Annual Agro Income Origin in previous wave-sample def2(US Dollars)"

****** POPULATION*****
******************
*Calculating population by district and using join by to add it. Add for HH, then by district
sort country survey hhid pid
preserve
	collapse (mean) hhsize weight, by(survey dist_d hhid) cw /*cw does not take into account missings*/
	*Using weigths
	collapse (sum) pop_dist1=hhsize [pw=weight], by(survey dist_d) cw /*Sampling weight*/
	drop if dist_d==.
	save "${work2}\malawi_population.dta", replace
restore

sort country survey hhid pid
preserve
	collapse (mean) hhsize weight, by(survey dist_d hhid) cw /*cw does not take into account missings*/
	*No weigths, just multiplying
	gen pop_dist2=.
	replace pop_dist2=hhsize*weight
	collapse (sum) pop_dist2, by(survey dist_d) cw 
	drop if dist_d==.
	merge 1:1 survey dist_d using "${work2}\malawi_population.dta", keep(master using match) gen(merge_pop1)
	drop merge_pop1 pop_dist2 /*All values are the same, except for some decimal points.*/
	rename pop_dist1 pop_dist_d
	save "${work2}\malawi_population.dta", replace 
restore

*Adding population in destination
merge m:1 survey dist_d using "${work2}\malawi_population.dta", keep(master using match) gen(merge_pop2)
label var pop_dist_d "Population in the Destination-District"
drop merge_m merge_Y _merge merge_pop2

****** MALARIA*****
*******************
*Adding Malaria-Disease Prevalence. I don't update 2016-2017 because I don't need them. They are already available
*Destination
preserve
	use "${work}\MALARIA_MAP_DIST2.dta", clear
	keep if country=="Malawi"
	keep if survey=="Survey-2004-2005" | survey=="Survey-2010-2011" 
	drop year mean_*
	rename survey sample2_survey
	tempfile DPP2
	save "`DPP2'", replace 
restore
merge m:1 country sample2_survey dist_d using "`DPP2'", keep(master using match) gen(merge_dist2) 
drop if merge_dist2==2
drop merge_dist2 dist2
foreach x in pre inc spr bed art {
	rename ave_`x' ave_`x'_d
	label var ave_`x'_d "Average Disease `x' (Malaria Atlas) Destination in previous wave-sample2"
}

*Origin
preserve
	use "${work}\MALARIA_MAP_DIST2.dta", clear
	keep if country=="Malawi"
	keep if survey=="Survey-2004-2005" | survey=="Survey-2010-2011"
	drop year mean_*
	rename survey sample2_survey
	rename dist_d dist_o
	tempfile DP2
	save "`DP2'", replace 
restore
joinby country sample2_survey dist_o using "`DP2'", unmatched(master)
drop _merge dist2
foreach x in pre inc spr bed art {
	rename ave_`x' ave_`x'_o
	label var ave_`x'_o "Average Disease `x' (Malaria Atlas) Origin in previous wave-sample2"
}

****** MIGRATION FLOWS IN OUR SAMPLE *****
******************************************
sort sample2_survey dist_d dist_o hhid pid
by sample2_survey dist_d dist_o: egen mig_flow=sum(sample2) if sample2==1
label var mig_flow "Total number of migrants by destination-district for sample2"

*Adding variable of rural-urban district
gen rur=0 if rural!=.
replace rur=1 if rural==2
gen urb=0 if rural!=.
replace urb=1 if rural==1
sort survey dist_o 
bys dist_o: egen ru=sum(rur)
bys dist_o: egen ur=sum(urb)
bys dist_o: gen dis_ru_p_o =ru/(ru+ur)
gen dis_rural_o=0 if rural!=.
replace dis_rural_o=1 if dis_ru_p_o>0.5
label var dis_rural_o "Dummy if district is rural or not. More than 50% of individuals are rural"
label var dis_ru_p_o "% of Rural individuals in the origin-district"
drop rur urb ru ur

*########## TABLE 13 #########: All sample and our migrant sample for rural-urban
matrix W=J(2,4,0)
tab rural, matcell(allr)
tab rural if sample2==1, matcell(sampler)
tab dis_rural_o, matcell(allrd)
tab dis_rural_o if sample2==1, matcell(samplerd)
matrix W=[allr,sampler,allrd,samplerd]
matrix colname W = "All-# of rural" "Sample2-# of rural" "All-Dist they live is rural" "Sample2-Dist they live is rural"
matrix rowname W =  Urban Rural
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("T13_%rural", replace) //modify 
putexcel A2=matrix(W)
graph drop _all
hist dis_ru_p_o, fraction title("Histogram: % of Rural individuals in the origin-district(as fraction)") subtitle("Malawi-All Sample") ///
			note("Source: Own calculations based on LSMS-ISA") name(malawi) legend(position(4) size(medium))

* A file which has all districts and will contain just zeros to match later on
preserve
	gen a=0
	collapse (mean) a, by(dist_d)
	drop if dist_d==.
	tempfile anchor
	save "`anchor'", replace
	rename dist_d dist_o
	cross using "`anchor'" /*This generates 31*31 combinations of mig flows*/
	expand 2, gen(dup) /*Generating a duplicate to put info for the 2 surveys*/
	expand 2 if dup==1, gen(dup1)
	gen survey="Survey-2013" if dup==0 & dup1==0
	replace survey="Survey-2010-2011" if dup==1 & dup1==1
	replace survey="Survey-2004-2005" if dup==1 & dup1==0
	drop dup dup1
	rename survey sample2_survey
	save "`anchor'", replace
restore

* Collapsing to get info of bilateral migrant flows by district
preserve
	keep if sample2==1
	collapse (mean) mig_flow pop_dist_d Ym* Yagm* ave* dis_rural_o dis_ru_p_o, by(sample2_survey dist_d dist_o)
	order sample2_survey dist_d dist_o
	* Using joinby to include zeros when no migration flows
	joinby sample2_survey dist_d dist_o using "`anchor'", unmatched(both)  /*I have to include obs that didn't match*/
	replace mig_flow=a if mig_flow==.
	drop _merge a
	gen country="Malawi"

	*Recoding dist_d and dist_o to avoid problems while merging with other countries. 1000 for Malawi, 2000 for Tanzania and 3000 for Uganda
	decode dist_d, gen(dist_dname)
	decode dist_o, gen(dist_oname)
	gen dist_dd=dist_d+1000
	gen dist_oo=dist_o+1000
	drop dist_d dist_o
	rename (dist_dd dist_oo) (dist_d dist_o)

	save "${work2}\malawi_mig_flow.dta", replace 
restore

*Making some Descriptive Statistics
*Share of income components
sort country survey hhid pid
local row=1
foreach var in agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other {
	bys survey hhid: gen `var'_m = `var'/hhsize /*Income by HH member*/
	format `var'_m %12.0f
	gen s_`var'_m=.
	replace s_`var'_m=`var'_m/Yme if Yme>=0
	*By survey
	estpost tabstat s_`var'_m, statistics(n sum mean sd min max) columns(statistics) listwise
	matrix V1=(e(count)',e(sum)',e(mean)',e(sd)',e(min)',e(max)')'
	estpost tabstat s_`var'_m, by(survey) statistics(n sum mean sd min max) columns(statistics) listwise
	matrix V2=(e(count)',e(sum)',e(mean)',e(sd)',e(min)',e(max)')'
	putexcel set "${results2}\mig_stats.xls", sheet("Malawi_income_share", replace) //modify /*Exporting to Excel*/ 
	putexcel A`row'=matrix(V1) C`row'=matrix(V2)
	local row=`row'+7
	}
	
save "${work2}\malawi_cross_panel.dta", replace

****** CENTROIDS *****
**********************
use "${work2}\malawi_mig_flow.dta", clear
*Destination
preserve
	use "${work}\CENTROIDS_WGS84_d.dta", clear
	keep if country=="Malawi"
	drop id dist_dname
	tempfile centroid_d
	save "`centroid_d'", replace 
restore

merge m:1 country dist_d using "`centroid_d'", keep(master using match) gen(merge_cen1) 
drop merge_cen1
rename (lon_wgs84 lat_wgs84) (lon_d lat_d)
label var lon_d "Longitud in Degrees WGS84-Destination"
label var lat_d "Latitud in Degrees WGS84-Destination"
*Origin
preserve
	use "${work}\CENTROIDS_WGS84_d.dta", clear
	keep if country=="Malawi"
	drop id dist_dname
	rename dist_d dist_o
	tempfile centroid_o
	save "`centroid_o'", replace 
restore
merge m:1 country dist_o using "`centroid_o'", keep(master using match) gen(merge_cen2) 
drop merge_cen2
rename (lon_wgs84 lat_wgs84) (lon_o lat_o)
label var lon_o "Longitud in Degrees WGS84-Origin"
label var lat_o "Latitud in Degrees WGS84-Origin"

********************************************************************************************
** A MOVEMENT ORIGIN-O TO DESTINY-D WITH NO MIGRANTS STILL HAS TO HAVE DP AND Y, BUT MIG=0
********************************************************************************************
***INCOME***. Not Yet for 2013 or 2016-2017
*Origin Y
preserve
	use "${work2}\malawi_income.dta", clear
	gen dist_oo=dist_o+1000
	drop dist_o
	rename (dist_oo) (dist_o) /*This is the anchor to merge*/
	tempfile y_o
	save "`y_o'", replace 
restore

merge m:1 sample2_survey dist_o using "`y_o'", keep(master using match) gen(merge_y_o) /*Neno district does not have income in 2004/2005, no surveyed*/
drop merge_y_o
foreach x in Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us {
replace `x'_o=`x' if `x'_o==.
}
drop Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us

*Destination Y
preserve
	use "${work2}\malawi_income.dta", clear
	gen dist_oo=dist_o+1000
	drop dist_o
	rename (dist_oo) (dist_d) /*This is the anchor to merge*/
	tempfile y_d
	save "`y_d'", replace 
restore

merge m:1 sample2_survey dist_d using "`y_d'", keep(master using match) gen(merge_y_d) /*Neno district does not have income in 2004/2005, no surveyed*/
drop merge_y_d
foreach x in Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us {
replace `x'_d=`x' if `x'_d==.
}
drop Ym Ym_tan Ym_us Yagm Yagm_tan Yagm_us

***MALARIA***
*Destination DP
preserve
	use "${work}\MALARIA_MAP_DIST2.dta", clear
	keep if country=="Malawi"
	keep if survey=="Survey-2004-2005" | survey=="Survey-2010-2011"
	drop year mean_*
	rename survey sample2_survey
	gen dist_oo=dist_d+1000
	drop dist_d dist2
	rename (dist_oo) (dist_d) /*This is the anchor to merge*/
	tempfile dp_d
	save "`dp_d'", replace 
restore

merge m:1 country sample2_survey dist_d using "`dp_d'", keep(master using match) gen(merge_dp_d)
drop if merge_dp_d==2 /*This is Likoma, erase*/
drop merge_dp_d
foreach x in pre inc spr bed art {
replace ave_`x'_d=ave_`x' if ave_`x'_d==.
drop ave_`x'
}
*Origin DP
preserve
	use "${work}\MALARIA_MAP_DIST2.dta", clear
	keep if country=="Malawi"
	keep if survey=="Survey-2004-2005" | survey=="Survey-2010-2011"
	drop year mean_*
	rename survey sample2_survey
	gen dist_oo=dist_d+1000
	drop dist_d dist2
	rename (dist_oo) (dist_o) /*This is the anchor to merge*/
	tempfile dp_o
	save "`dp_o'", replace 
restore

merge m:1 country sample2_survey dist_o using "`dp_o'", keep(master using match) gen(merge_dp_o)
drop if merge_dp_o==2 /*This is Likoma, erase*/
drop merge_dp_o
foreach x in pre inc spr bed art {
replace ave_`x'_o=ave_`x' if ave_`x'_o==.
drop ave_`x'
}

save "${work2}\malawi_mig_flow.dta", replace 
