*********************************************************************************
* THIS PROGRAM READS EXCEL FILES GENERATED IN GEE-FILE CHRIPS AND MODIS-TERRA   *
* IT USES CHRIPS DATASET (RAIN) AND MODIS-TERRA DATASET (TEMP)                  *
* IT ALSO USES CRU DATA FROM http://catalogue.ceda.ac.uk/uuid/58a8802721c94c66ae45c3baa4d814d0
*           WRITTEN BY LUIS GUILLERMO BECERRA			                        *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 6000
cap log close


global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER"
global paper2	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS\panel_josellin"
global results2  "..\RESULTS V2"

global rain "..\\INPUT\Rainfall-CHRIPS"
global cru "..\\WORK\CRU"
global temp "..\\INPUT\Temp-MODIS TERRA"

foreach pro in spmap shp2dta mif2dta spgrid spkde mylabels reg2hdfe tmpdir { /*Install if needed missing ado files*/
	capture which `pro'
	if _rc ssc install `pro'
}

*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
cd "U:\PSE-Proposal Malaria and paper\INPUT"


*Importing files of Rainfall-CHRIPS previously downloaded from GEE file. Check folder Malaria in my google Drive
local fi=1
local allfiles : dir "${rain}\" files "*.csv" /*Folder with files*/ 
		foreach f of local allfiles {
			display "`f'"
			local fname=reverse(substr(reverse("`f'"),5,.))
			display "`fname'"
			local year=substr("`fname'",23,.) /*Reverse to get rid of .csv and then reverse again*/
			display `year'
			display "${rain}\\`f'"
			
			import delimited using "${rain}\\`f'", varnames(1) rowrange(:245) colrange(:67) clear case(lower)
			gen year="`year'"
			destring year, replace
			rename dname_2006 dname
			*rename (*`year'*) **
			
			drop systemindex 
			if `fi'>1 {
				  append using "${work}\WEATHER.dta"
				  save "${work}\WEATHER.dta", replace
				  local fi=`fi'+1
				  }
				  else {
				  save "${work}\WEATHER.dta", replace /*First file with the first year as the initial file for append*/
				  local fi=`fi'+1
				  }	 
}

*Re-arranging names
replace name_1=name_2 if name_0=="Malawi" & name_2!=""
replace name_0="Uganda" if dname!=""
replace dname=name_1 if name_0=="Malawi"
replace dname=name_2 if name_0=="Tanzania"
replace name_0=cntry_name if cntry_name=="Tanzania"
replace dname=admin_name if cntry_name=="Tanzania"
drop admin_name cntry_name name_1 name_2
rename (name_0 dname) (country dist2)
			
*Preparing names to fix later
replace dist2="BUKWO" if dist2=="BUKWA"
replace dist2="MARACHA" if dist2=="MARACHA (NYADRI)"
replace dist2="SEMBABULE" if dist2=="SSEMBABULE"
gen disti=proper(dist2)
replace dist2=disti if country=="Uganda"
drop disti

*Assigning codes
gen dist_d=.
*Uganda district names
replace dist_d=314 if dist2=="Abim" & country=="Uganda"
replace dist_d=301 if dist2=="Adjumani" & country=="Uganda"
replace dist_d=315 if dist2=="Amolatar" & country=="Uganda"
replace dist_d=216 if dist2=="Amuria" & country=="Uganda"
replace dist_d=316 if dist2=="Amuru" & country=="Uganda"
replace dist_d=302 if dist2=="Apac" & country=="Uganda"
replace dist_d=303 if dist2=="Arua" & country=="Uganda"
replace dist_d=217 if dist2=="Budaka" & country=="Uganda"
replace dist_d=218 if dist2=="Bududa" & country=="Uganda"
replace dist_d=201 if dist2=="Bugiri" & country=="Uganda"
replace dist_d=219 if dist2=="Bukedea" & country=="Uganda"
replace dist_d=220 if dist2=="Bukwo" & country=="Uganda"
replace dist_d=416 if dist2=="Buliisa" & country=="Uganda"
replace dist_d=401 if dist2=="Bundibugyo" & country=="Uganda"
replace dist_d=402 if dist2=="Bushenyi" & country=="Uganda"
replace dist_d=202 if dist2=="Busia" & country=="Uganda"
replace dist_d=221 if dist2=="Butaleja" & country=="Uganda"
replace dist_d=317 if dist2=="Dokolo" & country=="Uganda"
replace dist_d=304 if dist2=="Gulu" & country=="Uganda"
replace dist_d=403 if dist2=="Hoima" & country=="Uganda"
replace dist_d=417 if dist2=="Ibanda" & country=="Uganda"
replace dist_d=203 if dist2=="Iganga" & country=="Uganda"
replace dist_d=418 if dist2=="Isingiro" & country=="Uganda"
replace dist_d=204 if dist2=="Jinja" & country=="Uganda"
replace dist_d=318 if dist2=="Kaabong" & country=="Uganda"
replace dist_d=404 if dist2=="Kabale" & country=="Uganda"
replace dist_d=405 if dist2=="Kabarole" & country=="Uganda"
replace dist_d=213 if dist2=="Kaberamaido" & country=="Uganda"
replace dist_d=101 if dist2=="Kalangala" & country=="Uganda"
replace dist_d=222 if dist2=="Kaliro" & country=="Uganda"
replace dist_d=102 if dist2=="Kampala" & country=="Uganda"
replace dist_d=205 if dist2=="Kamuli" & country=="Uganda"
replace dist_d=413 if dist2=="Kamwenge" & country=="Uganda"
replace dist_d=414 if dist2=="Kanungu" & country=="Uganda"
replace dist_d=206 if dist2=="Kapchorwa" & country=="Uganda"
replace dist_d=406 if dist2=="Kasese" & country=="Uganda"
replace dist_d=207 if dist2=="Katakwi" & country=="Uganda"
replace dist_d=112 if dist2=="Kayunga" & country=="Uganda"
replace dist_d=407 if dist2=="Kibaale" & country=="Uganda"
replace dist_d=103 if dist2=="Kiboga" & country=="Uganda"
replace dist_d=419 if dist2=="Kiruhura" & country=="Uganda"
replace dist_d=408 if dist2=="Kisoro" & country=="Uganda"
replace dist_d=305 if dist2=="Kitgum" & country=="Uganda"
replace dist_d=319 if dist2=="Koboko" & country=="Uganda"
replace dist_d=306 if dist2=="Kotido" & country=="Uganda"
replace dist_d=208 if dist2=="Kumi" & country=="Uganda"
replace dist_d=415 if dist2=="Kyenjojo" & country=="Uganda"
replace dist_d=307 if dist2=="Lira" & country=="Uganda"
replace dist_d=104 if dist2=="Luwero" & country=="Uganda"
replace dist_d=114 if dist2=="Lyantonde" & country=="Uganda"
replace dist_d=223 if dist2=="Manafwa" & country=="Uganda"
replace dist_d=320 if dist2=="Maracha" & country=="Uganda"
replace dist_d=105 if dist2=="Masaka" & country=="Uganda"
replace dist_d=409 if dist2=="Masindi" & country=="Uganda"
replace dist_d=214 if dist2=="Mayuge" & country=="Uganda"
replace dist_d=209 if dist2=="Mbale" & country=="Uganda"
replace dist_d=410 if dist2=="Mbarara" & country=="Uganda"
replace dist_d=115 if dist2=="Mityana" & country=="Uganda"
replace dist_d=308 if dist2=="Moroto" & country=="Uganda"
replace dist_d=309 if dist2=="Moyo" & country=="Uganda"
replace dist_d=106 if dist2=="Mpigi" & country=="Uganda"
replace dist_d=107 if dist2=="Mubende" & country=="Uganda"
replace dist_d=108 if dist2=="Mukono" & country=="Uganda"
replace dist_d=311 if dist2=="Nakapiripirit" & country=="Uganda"
replace dist_d=116 if dist2=="Nakaseke" & country=="Uganda"
replace dist_d=109 if dist2=="Nakasongola" & country=="Uganda"
replace dist_d=224 if dist2=="Namutumba" & country=="Uganda"
replace dist_d=310 if dist2=="Nebbi" & country=="Uganda"
replace dist_d=411 if dist2=="Ntungamo" & country=="Uganda"
replace dist_d=321 if dist2=="Oyam" & country=="Uganda"
replace dist_d=312 if dist2=="Pader" & country=="Uganda"
replace dist_d=210 if dist2=="Pallisa" & country=="Uganda"
replace dist_d=110 if dist2=="Rakai" & country=="Uganda"
replace dist_d=412 if dist2=="Rukungiri" & country=="Uganda"
replace dist_d=111 if dist2=="Sembabule" & country=="Uganda"
replace dist_d=215 if dist2=="Sironko" & country=="Uganda"
replace dist_d=211 if dist2=="Soroti" & country=="Uganda"
replace dist_d=212 if dist2=="Tororo" & country=="Uganda"
replace dist_d=113 if dist2=="Wakiso" & country=="Uganda"
replace dist_d=313 if dist2=="Yumbe" & country=="Uganda"

*Malawi district names
replace dist_d=101 if dist2=="Chitipa" & country=="Malawi"
replace dist_d=102 if dist2=="Karonga" & country=="Malawi"
replace dist_d=103 if dist2=="Nkhata Bay" & country=="Malawi"
replace dist_d=104 if dist2=="Rumphi" & country=="Malawi"
replace dist_d=105 if dist2=="Mzimba" & country=="Malawi"
replace dist_d=107 if dist2=="Mzuzu City" & country=="Malawi"
replace dist_d=201 if dist2=="Kasungu" & country=="Malawi"
replace dist_d=202 if dist2=="Nkhotakota" & country=="Malawi"
replace dist_d=203 if dist2=="Ntchisi" & country=="Malawi"
replace dist_d=204 if dist2=="Dowa" & country=="Malawi"
replace dist_d=205 if dist2=="Salima" & country=="Malawi"
replace dist_d=206 if dist2=="Lilongwe" & country=="Malawi"
replace dist_d=207 if dist2=="Mchinji" & country=="Malawi"
replace dist_d=208 if dist2=="Dedza" & country=="Malawi"
replace dist_d=209 if dist2=="Ntcheu" & country=="Malawi"
replace dist_d=210 if dist2=="Lilongwe City" & country=="Malawi"
replace dist_d=301 if dist2=="Mangochi" & country=="Malawi"
replace dist_d=302 if dist2=="Machinga" & country=="Malawi"
replace dist_d=303 if dist2=="Zomba" & country=="Malawi"
replace dist_d=304 if dist2=="Chiradzulu" & country=="Malawi"
replace dist_d=305 if dist2=="Blantyre" & country=="Malawi"
replace dist_d=306 if dist2=="Mwanza" & country=="Malawi"
replace dist_d=307 if dist2=="Thyolo" & country=="Malawi"
replace dist_d=308 if dist2=="Mulanje" & country=="Malawi"
replace dist_d=309 if dist2=="Phalombe" & country=="Malawi"
replace dist_d=310 if dist2=="Chikwawa" & country=="Malawi"
replace dist_d=311 if dist2=="Nsanje" & country=="Malawi"
replace dist_d=312 if dist2=="Balaka" & country=="Malawi"
replace dist_d=313 if dist2=="Neno" & country=="Malawi"
replace dist_d=314 if dist2=="Zomba City" & country=="Malawi"
replace dist_d=315 if dist2=="Blantyre City" & country=="Malawi"
replace dist_d=000 if dist2=="Likoma" & country=="Malawi" /*LSMS does not have info for Likoma-island*/

*Tanzania district names. Making names uppercase for Tanzania
gen disti=upper(dist2)
replace dist2=disti if country=="Tanzania"
replace dist2="CHAKECHAKE" if dist2=="CHAKE CHAKE"
replace dist2="MBALALI" if dist2=="MBARALI"
replace dist2="MICHWEWENI" if dist2=="MICHEWENI"
replace dist2="MISENYE" if dist2=="MISSENYI"
replace dist2="URAMBA" if dist2=="URAMBO"
replace dist2="KASKAZINI 'A'" if dist2=="ZANZIBAR NORTH 'A'"
replace dist2="KASKAZINI 'B'" if dist2=="ZANZIBAR NORTH 'B'"
replace dist2="KATI" if dist2=="ZANZIBAR SOUTH - CENTRAL"
replace dist2="KUSINI" if dist2=="ZANZIBAR SOUTH - SOUTH"
replace dist2="MAGHARIBI" if dist2=="ZANZIBAR TOWN - WEST"
replace dist2="MJINI" if dist2=="ZANZIBAR TOWN - URBAN"

replace dist_d=22 if dist2=="ARUMERU" & country=="Tanzania"
replace dist_d=23 if dist2=="ARUSHA" & country=="Tanzania"
replace dist_d=211 if dist2=="BABATI" & country=="Tanzania"
replace dist_d=61 if dist2=="BAGAMOYO" & country=="Tanzania"
replace dist_d=171 if dist2=="BARIADI" & country=="Tanzania"
replace dist_d=184 if dist2=="BIHARAMULO" & country=="Tanzania"
replace dist_d=182 if dist2=="BUKOBA RURAL" & country=="Tanzania"
replace dist_d=186 if dist2=="BUKOBA URBAN" & country=="Tanzania"
replace dist_d=175 if dist2=="BUKOMBE" & country=="Tanzania"
replace dist_d=204 if dist2=="BUNDA" & country=="Tanzania"
replace dist_d=551 if dist2=="CHAKECHAKE" & country=="Tanzania"
replace dist_d=187 if dist2=="CHATO" & country=="Tanzania"
replace dist_d=121 if dist2=="CHUNYA" & country=="Tanzania"
replace dist_d=14 if dist2=="DODOMA RURAL" & country=="Tanzania"
replace dist_d=15 if dist2=="DODOMA URBAN" & country=="Tanzania"
replace dist_d=196 if dist2=="GEITA" & country=="Tanzania"
replace dist_d=35 if dist2=="HAI" & country=="Tanzania"
replace dist_d=212 if dist2=="HANANG" & country=="Tanzania"
replace dist_d=46 if dist2=="HANDENI" & country=="Tanzania"
replace dist_d=142 if dist2=="IGUNGA" & country=="Tanzania"
replace dist_d=72 if dist2=="ILALA" & country=="Tanzania"
replace dist_d=125 if dist2=="ILEJE" & country=="Tanzania"
replace dist_d=198 if dist2=="ILEMELA" & country=="Tanzania"
replace dist_d=131 if dist2=="IRAMBA" & country=="Tanzania"
replace dist_d=111 if dist2=="IRINGA RURAL" & country=="Tanzania"
replace dist_d=116 if dist2=="IRINGA URBAN" & country=="Tanzania"
replace dist_d=174 if dist2=="KAHAMA" & country=="Tanzania"
replace dist_d=181 if dist2=="KARAGWE" & country=="Tanzania"
replace dist_d=24 if dist2=="KARATU" & country=="Tanzania"
replace dist_d=511 if dist2=="KASKAZINI 'A'" & country=="Tanzania"
replace dist_d=512 if dist2=="KASKAZINI 'B'" & country=="Tanzania"
replace dist_d=521 if dist2=="KATI" & country=="Tanzania"
replace dist_d=522 if dist2=="KUSINI" & country=="Tanzania"
replace dist_d=531 if dist2=="MAGHARIBI" & country=="Tanzania"
replace dist_d=532 if dist2=="MJINI" & country=="Tanzania"
replace dist_d=162 if dist2=="KASULU" & country=="Tanzania"
replace dist_d=62 if dist2=="KIBAHA" & country=="Tanzania"
replace dist_d=161 if dist2=="KIBONDO" & country=="Tanzania"
replace dist_d=163 if dist2=="KIGOMA RURAL" & country=="Tanzania"
replace dist_d=164 if dist2=="KIGOMA URBAN" & country=="Tanzania"
replace dist_d=47 if dist2=="KILINDI" & country=="Tanzania"
replace dist_d=117 if dist2=="KILOLO" & country=="Tanzania"
replace dist_d=53 if dist2=="KILOMBERO" & country=="Tanzania"
replace dist_d=51 if dist2=="KILOSA" & country=="Tanzania"
replace dist_d=81 if dist2=="KILWA" & country=="Tanzania"
replace dist_d=71 if dist2=="KINONDONI" & country=="Tanzania"
replace dist_d=63 if dist2=="KISARAWE" & country=="Tanzania"
replace dist_d=178 if dist2=="KISHAPU" & country=="Tanzania"
replace dist_d=215 if dist2=="KITETO" & country=="Tanzania"
replace dist_d=11 if dist2=="KONDOA" & country=="Tanzania"
replace dist_d=13 if dist2=="KONGWA" & country=="Tanzania"
replace dist_d=42 if dist2=="KOROGWE" & country=="Tanzania"
replace dist_d=194 if dist2=="KWIMBA" & country=="Tanzania"
replace dist_d=123 if dist2=="KYELA" & country=="Tanzania"
replace dist_d=82 if dist2=="LINDI RURAL" & country=="Tanzania"
replace dist_d=86 if dist2=="LINDI URBAN" & country=="Tanzania"
replace dist_d=84 if dist2=="LIWALE" & country=="Tanzania"
replace dist_d=115 if dist2=="LUDEWA" & country=="Tanzania"
replace dist_d=41 if dist2=="LUSHOTO" & country=="Tanzania"
replace dist_d=66 if dist2=="MAFIA" & country=="Tanzania"
replace dist_d=192 if dist2=="MAGU" & country=="Tanzania"
replace dist_d=113 if dist2=="MAKETE" & country=="Tanzania"
replace dist_d=133 if dist2=="MANYONI" & country=="Tanzania"
replace dist_d=93 if dist2=="MASASI" & country=="Tanzania"
replace dist_d=172 if dist2=="MASWA" & country=="Tanzania"
replace dist_d=127 if dist2=="MBALALI" & country=="Tanzania"
replace dist_d=122 if dist2=="MBEYA RURAL" & country=="Tanzania"
replace dist_d=128 if dist2=="MBEYA URBAN" & country=="Tanzania"
replace dist_d=103 if dist2=="MBINGA" & country=="Tanzania"
replace dist_d=126 if dist2=="MBOZI" & country=="Tanzania"
replace dist_d=213 if dist2=="MBULU" & country=="Tanzania"
replace dist_d=176 if dist2=="MEATU" & country=="Tanzania"
replace dist_d=542 if dist2=="MICHWEWENI" & country=="Tanzania"
replace dist_d=188 if dist2=="MISENYE" & country=="Tanzania"
replace dist_d=197 if dist2=="MISUNGWI" & country=="Tanzania"
replace dist_d=48 if dist2=="MKINGA" & country=="Tanzania"
replace dist_d=552 if dist2=="MKOANI" & country=="Tanzania"
replace dist_d=64 if dist2=="MKURANGA" & country=="Tanzania"
replace dist_d=21 if dist2=="MONDULI" & country=="Tanzania"
replace dist_d=52 if dist2=="MOROGORO RURAL" & country=="Tanzania"
replace dist_d=55 if dist2=="MOROGORO URBAN" & country=="Tanzania"
replace dist_d=36 if dist2=="MOSHI URBAN" & country=="Tanzania"
replace dist_d=34 if dist2=="MOSHI RURAL" & country=="Tanzania"
replace dist_d=151 if dist2=="MPANDA" & country=="Tanzania"
replace dist_d=12 if dist2=="MPWAPWA" & country=="Tanzania"
replace dist_d=95 if dist2=="MTWARA URBAN" & country=="Tanzania"
replace dist_d=91 if dist2=="MTWARA RURAL" & country=="Tanzania"
replace dist_d=112 if dist2=="MUFINDI" & country=="Tanzania"
replace dist_d=43 if dist2=="MUHEZA" & country=="Tanzania"
replace dist_d=183 if dist2=="MULEBA" & country=="Tanzania"
replace dist_d=203 if dist2=="MUSOMA RURAL" & country=="Tanzania"
replace dist_d=205 if dist2=="MUSOMA URBAN" & country=="Tanzania"
replace dist_d=56 if dist2=="MVOMERO" & country=="Tanzania"
replace dist_d=32 if dist2=="MWANGA" & country=="Tanzania"
replace dist_d=83 if dist2=="NACHINGWEA" & country=="Tanzania"
replace dist_d=105 if dist2=="NAMTUMBO" & country=="Tanzania"
replace dist_d=92 if dist2=="NEWALA" & country=="Tanzania"
replace dist_d=185 if dist2=="NGARA" & country=="Tanzania"
replace dist_d=25 if dist2=="NGORONGORO" & country=="Tanzania"
replace dist_d=114 if dist2=="NJOMBE" & country=="Tanzania"
replace dist_d=153 if dist2=="NKASI" & country=="Tanzania"
replace dist_d=193 if dist2=="NYAMAGANA" & country=="Tanzania"
replace dist_d=141 if dist2=="NZEGA" & country=="Tanzania"
replace dist_d=45 if dist2=="PANGANI" & country=="Tanzania"
replace dist_d=31 if dist2=="ROMBO" & country=="Tanzania"
replace dist_d=85 if dist2=="RUANGWA" & country=="Tanzania"
replace dist_d=65 if dist2=="RUFIJI" & country=="Tanzania"
replace dist_d=124 if dist2=="RUNGWE" & country=="Tanzania"
replace dist_d=33 if dist2=="SAME" & country=="Tanzania"
replace dist_d=195 if dist2=="SENGEREMA" & country=="Tanzania"
replace dist_d=202 if dist2=="SERENGETI" & country=="Tanzania"
replace dist_d=173 if dist2=="SHINYANGA RURAL" & country=="Tanzania"
replace dist_d=177 if dist2=="SHINYANGA URBAN" & country=="Tanzania"
replace dist_d=145 if dist2=="SIKONGE" & country=="Tanzania"
replace dist_d=214 if dist2=="SIMANJIRO" & country=="Tanzania"
replace dist_d=132 if dist2=="SINGIDA RURAL" & country=="Tanzania"
replace dist_d=134 if dist2=="SINGIDA URBAN" & country=="Tanzania"
replace dist_d=102 if dist2=="SONGEA RURAL" & country=="Tanzania"
replace dist_d=104 if dist2=="SONGEA URBAN" & country=="Tanzania"
replace dist_d=152 if dist2=="SUMBAWANGA RURAL" & country=="Tanzania"
replace dist_d=154 if dist2=="SUMBAWANGA URBAN" & country=="Tanzania"
replace dist_d=146 if dist2=="TABORA URBAN" & country=="Tanzania"
replace dist_d=94 if dist2=="TANDAHIMBA" & country=="Tanzania"
replace dist_d=44 if dist2=="TANGA" & country=="Tanzania"
replace dist_d=201 if dist2=="TARIME" & country=="Tanzania"
replace dist_d=73 if dist2=="TEMEKE" & country=="Tanzania"
replace dist_d=101 if dist2=="TUNDURU" & country=="Tanzania"
replace dist_d=191 if dist2=="UKEREWE" & country=="Tanzania"
replace dist_d=54 if dist2=="ULANGA" & country=="Tanzania"
replace dist_d=144 if dist2=="URAMBA" & country=="Tanzania"
replace dist_d=143 if dist2=="UYUI" & country=="Tanzania"
replace dist_d=541 if dist2=="WETE" & country=="Tanzania"

*Makng the anchor district code
gen dist_oo=.
replace dist_oo=dist_d+1000 if country=="Malawi"
replace dist_oo=dist_d+2000 if country=="Tanzania"
replace dist_oo=dist_d+3000 if country=="Uganda"
drop dist_d dist2
rename (dist_oo) (dist_d) /*This is the anchor to merge*/
rename disti dist_name

*Reshaping data to long
reshape long rain_sum rain_mean rain_min rain_max rain_count, i(dist_d dist_name country year) j(month)

*Generating additional variables
gen rain_range=rain_max-rain_min

label var rain_sum "Rainfall Sum per month, then Ave per district-CHRIPS (mm)"
label var rain_mean "Rainfall Mean per month, then Ave per district-CHRIPS (mm)"
label var rain_min "Rainfall Min per month, then Ave per district-CHRIPS (mm)"
label var rain_max "Rainfall Max per month, then Ave per district-CHRIPS (mm)"
label var rain_range "Rainfall Range (max-min) per month, then Ave per district-CHRIPS (mm)"
label var rain_count "Rainfall count # days with rainfall per month, then Ave per district-CHRIPS (mm)"

replace rain_count=0 if rain_count==. // Those cases means a month with zero rainfall days, not missing

rename rain* ave_rain_chrips*
rename ave_rain_chrips_count c_ave_rain_chrips_count

save "${work}\WEATHER.dta", replace

**********************************************************************************************************
****WORKING WITH TEMP-MODIS
**********************************************************************************************************
*Importing files of TEMP-MODIS previously downloaded from GEE file. Check folder Malaria in my google Drive
local fi=1
local allfiles : dir "${temp}\" files "*.csv" /*Folder with files*/ 
		foreach f of local allfiles {
			display "`f'"
			local fname=reverse(substr(reverse("`f'"),5,.))
			display "`fname'"
			local year=substr("`fname'",22,.) /*Reverse to get rid of .csv and then reverse again*/
			display `year'
			display "${temp}\\`f'"
			
			import delimited using "${temp}\\`f'", varnames(1) rowrange(:245) colrange(:67) clear case(lower)
			gen year="`year'"
			destring year, replace
			rename dname_2006 dname
			*rename (*`year'*) **
			
			drop systemindex 
			if `fi'>1 {
				  append using "${work}\TEMP_MODIS.dta"
				  save "${work}\TEMP_MODIS.dta", replace
				  local fi=`fi'+1
				  }
				  else {
				  save "${work}\TEMP_MODIS.dta", replace /*First file with the first year as the initial file for append*/
				  local fi=`fi'+1
				  }	 
}

*Re-arranging names
replace name_1=name_2 if name_0=="Malawi" & name_2!=""
replace name_0="Uganda" if dname!=""
replace dname=name_1 if name_0=="Malawi"
replace dname=name_2 if name_0=="Tanzania"
replace name_0=cntry_name if cntry_name=="Tanzania"
replace dname=admin_name if cntry_name=="Tanzania"
drop admin_name cntry_name name_1 name_2
rename (name_0 dname) (country dist2)
			
*Preparing names to fix later
replace dist2="BUKWO" if dist2=="BUKWA"
replace dist2="MARACHA" if dist2=="MARACHA (NYADRI)"
replace dist2="SEMBABULE" if dist2=="SSEMBABULE"
gen disti=proper(dist2)
replace dist2=disti if country=="Uganda"
drop disti

*Assigning codes
gen dist_d=.
*Uganda district names
replace dist_d=314 if dist2=="Abim" & country=="Uganda"
replace dist_d=301 if dist2=="Adjumani" & country=="Uganda"
replace dist_d=315 if dist2=="Amolatar" & country=="Uganda"
replace dist_d=216 if dist2=="Amuria" & country=="Uganda"
replace dist_d=316 if dist2=="Amuru" & country=="Uganda"
replace dist_d=302 if dist2=="Apac" & country=="Uganda"
replace dist_d=303 if dist2=="Arua" & country=="Uganda"
replace dist_d=217 if dist2=="Budaka" & country=="Uganda"
replace dist_d=218 if dist2=="Bududa" & country=="Uganda"
replace dist_d=201 if dist2=="Bugiri" & country=="Uganda"
replace dist_d=219 if dist2=="Bukedea" & country=="Uganda"
replace dist_d=220 if dist2=="Bukwo" & country=="Uganda"
replace dist_d=416 if dist2=="Buliisa" & country=="Uganda"
replace dist_d=401 if dist2=="Bundibugyo" & country=="Uganda"
replace dist_d=402 if dist2=="Bushenyi" & country=="Uganda"
replace dist_d=202 if dist2=="Busia" & country=="Uganda"
replace dist_d=221 if dist2=="Butaleja" & country=="Uganda"
replace dist_d=317 if dist2=="Dokolo" & country=="Uganda"
replace dist_d=304 if dist2=="Gulu" & country=="Uganda"
replace dist_d=403 if dist2=="Hoima" & country=="Uganda"
replace dist_d=417 if dist2=="Ibanda" & country=="Uganda"
replace dist_d=203 if dist2=="Iganga" & country=="Uganda"
replace dist_d=418 if dist2=="Isingiro" & country=="Uganda"
replace dist_d=204 if dist2=="Jinja" & country=="Uganda"
replace dist_d=318 if dist2=="Kaabong" & country=="Uganda"
replace dist_d=404 if dist2=="Kabale" & country=="Uganda"
replace dist_d=405 if dist2=="Kabarole" & country=="Uganda"
replace dist_d=213 if dist2=="Kaberamaido" & country=="Uganda"
replace dist_d=101 if dist2=="Kalangala" & country=="Uganda"
replace dist_d=222 if dist2=="Kaliro" & country=="Uganda"
replace dist_d=102 if dist2=="Kampala" & country=="Uganda"
replace dist_d=205 if dist2=="Kamuli" & country=="Uganda"
replace dist_d=413 if dist2=="Kamwenge" & country=="Uganda"
replace dist_d=414 if dist2=="Kanungu" & country=="Uganda"
replace dist_d=206 if dist2=="Kapchorwa" & country=="Uganda"
replace dist_d=406 if dist2=="Kasese" & country=="Uganda"
replace dist_d=207 if dist2=="Katakwi" & country=="Uganda"
replace dist_d=112 if dist2=="Kayunga" & country=="Uganda"
replace dist_d=407 if dist2=="Kibaale" & country=="Uganda"
replace dist_d=103 if dist2=="Kiboga" & country=="Uganda"
replace dist_d=419 if dist2=="Kiruhura" & country=="Uganda"
replace dist_d=408 if dist2=="Kisoro" & country=="Uganda"
replace dist_d=305 if dist2=="Kitgum" & country=="Uganda"
replace dist_d=319 if dist2=="Koboko" & country=="Uganda"
replace dist_d=306 if dist2=="Kotido" & country=="Uganda"
replace dist_d=208 if dist2=="Kumi" & country=="Uganda"
replace dist_d=415 if dist2=="Kyenjojo" & country=="Uganda"
replace dist_d=307 if dist2=="Lira" & country=="Uganda"
replace dist_d=104 if dist2=="Luwero" & country=="Uganda"
replace dist_d=114 if dist2=="Lyantonde" & country=="Uganda"
replace dist_d=223 if dist2=="Manafwa" & country=="Uganda"
replace dist_d=320 if dist2=="Maracha" & country=="Uganda"
replace dist_d=105 if dist2=="Masaka" & country=="Uganda"
replace dist_d=409 if dist2=="Masindi" & country=="Uganda"
replace dist_d=214 if dist2=="Mayuge" & country=="Uganda"
replace dist_d=209 if dist2=="Mbale" & country=="Uganda"
replace dist_d=410 if dist2=="Mbarara" & country=="Uganda"
replace dist_d=115 if dist2=="Mityana" & country=="Uganda"
replace dist_d=308 if dist2=="Moroto" & country=="Uganda"
replace dist_d=309 if dist2=="Moyo" & country=="Uganda"
replace dist_d=106 if dist2=="Mpigi" & country=="Uganda"
replace dist_d=107 if dist2=="Mubende" & country=="Uganda"
replace dist_d=108 if dist2=="Mukono" & country=="Uganda"
replace dist_d=311 if dist2=="Nakapiripirit" & country=="Uganda"
replace dist_d=116 if dist2=="Nakaseke" & country=="Uganda"
replace dist_d=109 if dist2=="Nakasongola" & country=="Uganda"
replace dist_d=224 if dist2=="Namutumba" & country=="Uganda"
replace dist_d=310 if dist2=="Nebbi" & country=="Uganda"
replace dist_d=411 if dist2=="Ntungamo" & country=="Uganda"
replace dist_d=321 if dist2=="Oyam" & country=="Uganda"
replace dist_d=312 if dist2=="Pader" & country=="Uganda"
replace dist_d=210 if dist2=="Pallisa" & country=="Uganda"
replace dist_d=110 if dist2=="Rakai" & country=="Uganda"
replace dist_d=412 if dist2=="Rukungiri" & country=="Uganda"
replace dist_d=111 if dist2=="Sembabule" & country=="Uganda"
replace dist_d=215 if dist2=="Sironko" & country=="Uganda"
replace dist_d=211 if dist2=="Soroti" & country=="Uganda"
replace dist_d=212 if dist2=="Tororo" & country=="Uganda"
replace dist_d=113 if dist2=="Wakiso" & country=="Uganda"
replace dist_d=313 if dist2=="Yumbe" & country=="Uganda"

*Malawi district names
replace dist_d=101 if dist2=="Chitipa" & country=="Malawi"
replace dist_d=102 if dist2=="Karonga" & country=="Malawi"
replace dist_d=103 if dist2=="Nkhata Bay" & country=="Malawi"
replace dist_d=104 if dist2=="Rumphi" & country=="Malawi"
replace dist_d=105 if dist2=="Mzimba" & country=="Malawi"
replace dist_d=107 if dist2=="Mzuzu City" & country=="Malawi"
replace dist_d=201 if dist2=="Kasungu" & country=="Malawi"
replace dist_d=202 if dist2=="Nkhotakota" & country=="Malawi"
replace dist_d=203 if dist2=="Ntchisi" & country=="Malawi"
replace dist_d=204 if dist2=="Dowa" & country=="Malawi"
replace dist_d=205 if dist2=="Salima" & country=="Malawi"
replace dist_d=206 if dist2=="Lilongwe" & country=="Malawi"
replace dist_d=207 if dist2=="Mchinji" & country=="Malawi"
replace dist_d=208 if dist2=="Dedza" & country=="Malawi"
replace dist_d=209 if dist2=="Ntcheu" & country=="Malawi"
replace dist_d=210 if dist2=="Lilongwe City" & country=="Malawi"
replace dist_d=301 if dist2=="Mangochi" & country=="Malawi"
replace dist_d=302 if dist2=="Machinga" & country=="Malawi"
replace dist_d=303 if dist2=="Zomba" & country=="Malawi"
replace dist_d=304 if dist2=="Chiradzulu" & country=="Malawi"
replace dist_d=305 if dist2=="Blantyre" & country=="Malawi"
replace dist_d=306 if dist2=="Mwanza" & country=="Malawi"
replace dist_d=307 if dist2=="Thyolo" & country=="Malawi"
replace dist_d=308 if dist2=="Mulanje" & country=="Malawi"
replace dist_d=309 if dist2=="Phalombe" & country=="Malawi"
replace dist_d=310 if dist2=="Chikwawa" & country=="Malawi"
replace dist_d=311 if dist2=="Nsanje" & country=="Malawi"
replace dist_d=312 if dist2=="Balaka" & country=="Malawi"
replace dist_d=313 if dist2=="Neno" & country=="Malawi"
replace dist_d=314 if dist2=="Zomba City" & country=="Malawi"
replace dist_d=315 if dist2=="Blantyre City" & country=="Malawi"
replace dist_d=000 if dist2=="Likoma" & country=="Malawi" /*LSMS does not have info for Likoma-island*/

*Tanzania district names. Making names uppercase for Tanzania
gen disti=upper(dist2)
replace dist2=disti if country=="Tanzania"
replace dist2="CHAKECHAKE" if dist2=="CHAKE CHAKE"
replace dist2="MBALALI" if dist2=="MBARALI"
replace dist2="MICHWEWENI" if dist2=="MICHEWENI"
replace dist2="MISENYE" if dist2=="MISSENYI"
replace dist2="URAMBA" if dist2=="URAMBO"
replace dist2="KASKAZINI 'A'" if dist2=="ZANZIBAR NORTH 'A'"
replace dist2="KASKAZINI 'B'" if dist2=="ZANZIBAR NORTH 'B'"
replace dist2="KATI" if dist2=="ZANZIBAR SOUTH - CENTRAL"
replace dist2="KUSINI" if dist2=="ZANZIBAR SOUTH - SOUTH"
replace dist2="MAGHARIBI" if dist2=="ZANZIBAR TOWN - WEST"
replace dist2="MJINI" if dist2=="ZANZIBAR TOWN - URBAN"

replace dist_d=22 if dist2=="ARUMERU" & country=="Tanzania"
replace dist_d=23 if dist2=="ARUSHA" & country=="Tanzania"
replace dist_d=211 if dist2=="BABATI" & country=="Tanzania"
replace dist_d=61 if dist2=="BAGAMOYO" & country=="Tanzania"
replace dist_d=171 if dist2=="BARIADI" & country=="Tanzania"
replace dist_d=184 if dist2=="BIHARAMULO" & country=="Tanzania"
replace dist_d=182 if dist2=="BUKOBA RURAL" & country=="Tanzania"
replace dist_d=186 if dist2=="BUKOBA URBAN" & country=="Tanzania"
replace dist_d=175 if dist2=="BUKOMBE" & country=="Tanzania"
replace dist_d=204 if dist2=="BUNDA" & country=="Tanzania"
replace dist_d=551 if dist2=="CHAKECHAKE" & country=="Tanzania"
replace dist_d=187 if dist2=="CHATO" & country=="Tanzania"
replace dist_d=121 if dist2=="CHUNYA" & country=="Tanzania"
replace dist_d=14 if dist2=="DODOMA RURAL" & country=="Tanzania"
replace dist_d=15 if dist2=="DODOMA URBAN" & country=="Tanzania"
replace dist_d=196 if dist2=="GEITA" & country=="Tanzania"
replace dist_d=35 if dist2=="HAI" & country=="Tanzania"
replace dist_d=212 if dist2=="HANANG" & country=="Tanzania"
replace dist_d=46 if dist2=="HANDENI" & country=="Tanzania"
replace dist_d=142 if dist2=="IGUNGA" & country=="Tanzania"
replace dist_d=72 if dist2=="ILALA" & country=="Tanzania"
replace dist_d=125 if dist2=="ILEJE" & country=="Tanzania"
replace dist_d=198 if dist2=="ILEMELA" & country=="Tanzania"
replace dist_d=131 if dist2=="IRAMBA" & country=="Tanzania"
replace dist_d=111 if dist2=="IRINGA RURAL" & country=="Tanzania"
replace dist_d=116 if dist2=="IRINGA URBAN" & country=="Tanzania"
replace dist_d=174 if dist2=="KAHAMA" & country=="Tanzania"
replace dist_d=181 if dist2=="KARAGWE" & country=="Tanzania"
replace dist_d=24 if dist2=="KARATU" & country=="Tanzania"
replace dist_d=511 if dist2=="KASKAZINI 'A'" & country=="Tanzania"
replace dist_d=512 if dist2=="KASKAZINI 'B'" & country=="Tanzania"
replace dist_d=521 if dist2=="KATI" & country=="Tanzania"
replace dist_d=522 if dist2=="KUSINI" & country=="Tanzania"
replace dist_d=531 if dist2=="MAGHARIBI" & country=="Tanzania"
replace dist_d=532 if dist2=="MJINI" & country=="Tanzania"
replace dist_d=162 if dist2=="KASULU" & country=="Tanzania"
replace dist_d=62 if dist2=="KIBAHA" & country=="Tanzania"
replace dist_d=161 if dist2=="KIBONDO" & country=="Tanzania"
replace dist_d=163 if dist2=="KIGOMA RURAL" & country=="Tanzania"
replace dist_d=164 if dist2=="KIGOMA URBAN" & country=="Tanzania"
replace dist_d=47 if dist2=="KILINDI" & country=="Tanzania"
replace dist_d=117 if dist2=="KILOLO" & country=="Tanzania"
replace dist_d=53 if dist2=="KILOMBERO" & country=="Tanzania"
replace dist_d=51 if dist2=="KILOSA" & country=="Tanzania"
replace dist_d=81 if dist2=="KILWA" & country=="Tanzania"
replace dist_d=71 if dist2=="KINONDONI" & country=="Tanzania"
replace dist_d=63 if dist2=="KISARAWE" & country=="Tanzania"
replace dist_d=178 if dist2=="KISHAPU" & country=="Tanzania"
replace dist_d=215 if dist2=="KITETO" & country=="Tanzania"
replace dist_d=11 if dist2=="KONDOA" & country=="Tanzania"
replace dist_d=13 if dist2=="KONGWA" & country=="Tanzania"
replace dist_d=42 if dist2=="KOROGWE" & country=="Tanzania"
replace dist_d=194 if dist2=="KWIMBA" & country=="Tanzania"
replace dist_d=123 if dist2=="KYELA" & country=="Tanzania"
replace dist_d=82 if dist2=="LINDI RURAL" & country=="Tanzania"
replace dist_d=86 if dist2=="LINDI URBAN" & country=="Tanzania"
replace dist_d=84 if dist2=="LIWALE" & country=="Tanzania"
replace dist_d=115 if dist2=="LUDEWA" & country=="Tanzania"
replace dist_d=41 if dist2=="LUSHOTO" & country=="Tanzania"
replace dist_d=66 if dist2=="MAFIA" & country=="Tanzania"
replace dist_d=192 if dist2=="MAGU" & country=="Tanzania"
replace dist_d=113 if dist2=="MAKETE" & country=="Tanzania"
replace dist_d=133 if dist2=="MANYONI" & country=="Tanzania"
replace dist_d=93 if dist2=="MASASI" & country=="Tanzania"
replace dist_d=172 if dist2=="MASWA" & country=="Tanzania"
replace dist_d=127 if dist2=="MBALALI" & country=="Tanzania"
replace dist_d=122 if dist2=="MBEYA RURAL" & country=="Tanzania"
replace dist_d=128 if dist2=="MBEYA URBAN" & country=="Tanzania"
replace dist_d=103 if dist2=="MBINGA" & country=="Tanzania"
replace dist_d=126 if dist2=="MBOZI" & country=="Tanzania"
replace dist_d=213 if dist2=="MBULU" & country=="Tanzania"
replace dist_d=176 if dist2=="MEATU" & country=="Tanzania"
replace dist_d=542 if dist2=="MICHWEWENI" & country=="Tanzania"
replace dist_d=188 if dist2=="MISENYE" & country=="Tanzania"
replace dist_d=197 if dist2=="MISUNGWI" & country=="Tanzania"
replace dist_d=48 if dist2=="MKINGA" & country=="Tanzania"
replace dist_d=552 if dist2=="MKOANI" & country=="Tanzania"
replace dist_d=64 if dist2=="MKURANGA" & country=="Tanzania"
replace dist_d=21 if dist2=="MONDULI" & country=="Tanzania"
replace dist_d=52 if dist2=="MOROGORO RURAL" & country=="Tanzania"
replace dist_d=55 if dist2=="MOROGORO URBAN" & country=="Tanzania"
replace dist_d=36 if dist2=="MOSHI URBAN" & country=="Tanzania"
replace dist_d=34 if dist2=="MOSHI RURAL" & country=="Tanzania"
replace dist_d=151 if dist2=="MPANDA" & country=="Tanzania"
replace dist_d=12 if dist2=="MPWAPWA" & country=="Tanzania"
replace dist_d=95 if dist2=="MTWARA URBAN" & country=="Tanzania"
replace dist_d=91 if dist2=="MTWARA RURAL" & country=="Tanzania"
replace dist_d=112 if dist2=="MUFINDI" & country=="Tanzania"
replace dist_d=43 if dist2=="MUHEZA" & country=="Tanzania"
replace dist_d=183 if dist2=="MULEBA" & country=="Tanzania"
replace dist_d=203 if dist2=="MUSOMA RURAL" & country=="Tanzania"
replace dist_d=205 if dist2=="MUSOMA URBAN" & country=="Tanzania"
replace dist_d=56 if dist2=="MVOMERO" & country=="Tanzania"
replace dist_d=32 if dist2=="MWANGA" & country=="Tanzania"
replace dist_d=83 if dist2=="NACHINGWEA" & country=="Tanzania"
replace dist_d=105 if dist2=="NAMTUMBO" & country=="Tanzania"
replace dist_d=92 if dist2=="NEWALA" & country=="Tanzania"
replace dist_d=185 if dist2=="NGARA" & country=="Tanzania"
replace dist_d=25 if dist2=="NGORONGORO" & country=="Tanzania"
replace dist_d=114 if dist2=="NJOMBE" & country=="Tanzania"
replace dist_d=153 if dist2=="NKASI" & country=="Tanzania"
replace dist_d=193 if dist2=="NYAMAGANA" & country=="Tanzania"
replace dist_d=141 if dist2=="NZEGA" & country=="Tanzania"
replace dist_d=45 if dist2=="PANGANI" & country=="Tanzania"
replace dist_d=31 if dist2=="ROMBO" & country=="Tanzania"
replace dist_d=85 if dist2=="RUANGWA" & country=="Tanzania"
replace dist_d=65 if dist2=="RUFIJI" & country=="Tanzania"
replace dist_d=124 if dist2=="RUNGWE" & country=="Tanzania"
replace dist_d=33 if dist2=="SAME" & country=="Tanzania"
replace dist_d=195 if dist2=="SENGEREMA" & country=="Tanzania"
replace dist_d=202 if dist2=="SERENGETI" & country=="Tanzania"
replace dist_d=173 if dist2=="SHINYANGA RURAL" & country=="Tanzania"
replace dist_d=177 if dist2=="SHINYANGA URBAN" & country=="Tanzania"
replace dist_d=145 if dist2=="SIKONGE" & country=="Tanzania"
replace dist_d=214 if dist2=="SIMANJIRO" & country=="Tanzania"
replace dist_d=132 if dist2=="SINGIDA RURAL" & country=="Tanzania"
replace dist_d=134 if dist2=="SINGIDA URBAN" & country=="Tanzania"
replace dist_d=102 if dist2=="SONGEA RURAL" & country=="Tanzania"
replace dist_d=104 if dist2=="SONGEA URBAN" & country=="Tanzania"
replace dist_d=152 if dist2=="SUMBAWANGA RURAL" & country=="Tanzania"
replace dist_d=154 if dist2=="SUMBAWANGA URBAN" & country=="Tanzania"
replace dist_d=146 if dist2=="TABORA URBAN" & country=="Tanzania"
replace dist_d=94 if dist2=="TANDAHIMBA" & country=="Tanzania"
replace dist_d=44 if dist2=="TANGA" & country=="Tanzania"
replace dist_d=201 if dist2=="TARIME" & country=="Tanzania"
replace dist_d=73 if dist2=="TEMEKE" & country=="Tanzania"
replace dist_d=101 if dist2=="TUNDURU" & country=="Tanzania"
replace dist_d=191 if dist2=="UKEREWE" & country=="Tanzania"
replace dist_d=54 if dist2=="ULANGA" & country=="Tanzania"
replace dist_d=144 if dist2=="URAMBA" & country=="Tanzania"
replace dist_d=143 if dist2=="UYUI" & country=="Tanzania"
replace dist_d=541 if dist2=="WETE" & country=="Tanzania"

*Makng the anchor district code
gen dist_oo=.
replace dist_oo=dist_d+1000 if country=="Malawi"
replace dist_oo=dist_d+2000 if country=="Tanzania"
replace dist_oo=dist_d+3000 if country=="Uganda"
drop dist_d dist2
rename (dist_oo) (dist_d) /*This is the anchor to merge*/
rename disti dist_name

*Reshaping data to long
reshape long temp_mean temp_min temp_max temp_count_range temp_count_lim, i(dist_d dist_name country year) j(month)

//https://gis.stackexchange.com/questions/72524/how-do-i-convert-the-lst-values-on-the-modis-lst-image-to-degree-celsius
//To go to DN(digital numbers) like in MODIS pixels to Kelvin, multiply by 0.02 the scale factor
foreach var in temp_mean temp_min temp_max {
	replace `var'=(`var'*0.02)-273.15 //Digital Number to Kelvin to Celsius
}
replace temp_count_range=0 if temp_count_range==. // they are not missing just zero days with temperature between 14-18C or above 34C
replace temp_count_lim=0 if temp_count_lim==.

label var temp_mean "Temperature Mean per month, then Ave per district-Celsius"
label var temp_min "Temperature Min per month, then Ave per district-Celsius"
label var temp_max "Temperature Max per month, then Ave per district-Celsius"
label var temp_count_range "# days with temp between 14-18C per month, then Ave per district"
label var temp_count_lim "# days with temp above 34C per month, then Ave per district"

rename temp* ave_temp_modis*
rename ave_temp_modis_count_* c_ave_temp_modis_count_*

save "${work}\TEMP_MODIS.dta", replace

*Merging RAINFALL-CHRIPS AND TEMP-MODIS
use "${work}\WEATHER.dta", clear
merge 1:1 dist_d year month using "${work}\TEMP_MODIS.dta", keep(master using match) gen(merge_temp)

save "${work}\WEATHER.dta", replace
****************************************************************************
****************************************************************************
*--------------------------------------------------------------------------*
* NOW WORKING WITH CRU DATA TO GET MORE VARIABLES OF WEATHER. 
* -------------------------------------------------------------------------*
****************************************************************************
****************************************************************************
*Importing files of CRU previously downloaded from website. See http://artefacts.ceda.ac.uk/badc_datadocs/cru/WPS_CRU.html for description
* and transferred to a table using Zonal Statistics in ArcGis. See file PRO/Weather_CRU.py
local fi=1
local allfiles : dir "${cru}\" files "*.xls" /*Folder with files*/ 
		foreach f of local allfiles {
			display "`f'"
			local var=substr("`f'",1,3)
			display "`var'"
			local year=substr("`f'",4,4) 
			display "`year'"
			local month=substr("`f'",8,2) 
			display "`month'"
			display "${cru}\\`f'"		
			
			import excel using "${cru}\\`f'", cellrange(:F245) sheet("`var'`year'`month'") firstrow  clear case(lower)
			gen year="`year'"
			destring year, replace
			gen month="`month'"
			destring month, replace
			gen cru="`var'"
			drop rowid zonecode count area
			
			if `fi'>1 {
				  append using "${work}\WEATHER_CRU.dta"
				  save "${work}\WEATHER_CRU.dta", replace
				  local fi=`fi'+1
				  }
				  else {
				  save "${work}\WEATHER_CRU.dta", replace /*First file with the first year as the initial file for append*/
				  local fi=`fi'+1
				  }	 
	}

*Organizing file
gen country=""
replace country=substr(con_dist, 1, strpos(con_dist, "_") - 1)
gen dist2=""
replace dist2=substr(con_dist, strpos(con_dist, "_") + 1, .)
drop con_dist

*Reshaping better
reshape wide mean, i(country dist2 year month) j(cru) string
rename mean* cru_*
label var cru_dtr "Diurnal Temperature Range (degrees Celsius)-Monthly average"
label var cru_pet "Potential Evapotranspiration (mm/day)-Monthly average"
label var cru_pre "Precipitation (mm/month)-Monthly average"
label var cru_tmn "Near-surface Temperature minimum (degrees Celsius)-Monthly average"
label var cru_tmp "Near-surface Temperature (degrees Celsius)-Monthly average"
label var cru_tmx "Near-surface Temperature maximum (degrees Celsius)-Monthly average"
label var cru_vap "Vapour Pressure (hPa)-Monthly average"
label var cru_wet "Wet day frequency (days)-Monthly average"

*Preparing names to fix later
replace dist2="BUKWO" if dist2=="BUKWA"
replace dist2="MARACHA" if dist2=="MARACHA (NYADRI)"
replace dist2="SEMBABULE" if dist2=="SSEMBABULE"

gen disti=proper(dist2)
replace dist2=disti if country=="Uganda"
drop disti

*Assigning codes
gen dist_d=.
*Uganda district names
replace dist_d=314 if dist2=="Abim" & country=="Uganda"
replace dist_d=301 if dist2=="Adjumani" & country=="Uganda"
replace dist_d=315 if dist2=="Amolatar" & country=="Uganda"
replace dist_d=216 if dist2=="Amuria" & country=="Uganda"
replace dist_d=316 if dist2=="Amuru" & country=="Uganda"
replace dist_d=302 if dist2=="Apac" & country=="Uganda"
replace dist_d=303 if dist2=="Arua" & country=="Uganda"
replace dist_d=217 if dist2=="Budaka" & country=="Uganda"
replace dist_d=218 if dist2=="Bududa" & country=="Uganda"
replace dist_d=201 if dist2=="Bugiri" & country=="Uganda"
replace dist_d=219 if dist2=="Bukedea" & country=="Uganda"
replace dist_d=220 if dist2=="Bukwo" & country=="Uganda"
replace dist_d=416 if dist2=="Buliisa" & country=="Uganda"
replace dist_d=401 if dist2=="Bundibugyo" & country=="Uganda"
replace dist_d=402 if dist2=="Bushenyi" & country=="Uganda"
replace dist_d=202 if dist2=="Busia" & country=="Uganda"
replace dist_d=221 if dist2=="Butaleja" & country=="Uganda"
replace dist_d=317 if dist2=="Dokolo" & country=="Uganda"
replace dist_d=304 if dist2=="Gulu" & country=="Uganda"
replace dist_d=403 if dist2=="Hoima" & country=="Uganda"
replace dist_d=417 if dist2=="Ibanda" & country=="Uganda"
replace dist_d=203 if dist2=="Iganga" & country=="Uganda"
replace dist_d=418 if dist2=="Isingiro" & country=="Uganda"
replace dist_d=204 if dist2=="Jinja" & country=="Uganda"
replace dist_d=318 if dist2=="Kaabong" & country=="Uganda"
replace dist_d=404 if dist2=="Kabale" & country=="Uganda"
replace dist_d=405 if dist2=="Kabarole" & country=="Uganda"
replace dist_d=213 if dist2=="Kaberamaido" & country=="Uganda"
replace dist_d=101 if dist2=="Kalangala" & country=="Uganda"
replace dist_d=222 if dist2=="Kaliro" & country=="Uganda"
replace dist_d=102 if dist2=="Kampala" & country=="Uganda"
replace dist_d=205 if dist2=="Kamuli" & country=="Uganda"
replace dist_d=413 if dist2=="Kamwenge" & country=="Uganda"
replace dist_d=414 if dist2=="Kanungu" & country=="Uganda"
replace dist_d=206 if dist2=="Kapchorwa" & country=="Uganda"
replace dist_d=406 if dist2=="Kasese" & country=="Uganda"
replace dist_d=207 if dist2=="Katakwi" & country=="Uganda"
replace dist_d=112 if dist2=="Kayunga" & country=="Uganda"
replace dist_d=407 if dist2=="Kibaale" & country=="Uganda"
replace dist_d=103 if dist2=="Kiboga" & country=="Uganda"
replace dist_d=419 if dist2=="Kiruhura" & country=="Uganda"
replace dist_d=408 if dist2=="Kisoro" & country=="Uganda"
replace dist_d=305 if dist2=="Kitgum" & country=="Uganda"
replace dist_d=319 if dist2=="Koboko" & country=="Uganda"
replace dist_d=306 if dist2=="Kotido" & country=="Uganda"
replace dist_d=208 if dist2=="Kumi" & country=="Uganda"
replace dist_d=415 if dist2=="Kyenjojo" & country=="Uganda"
replace dist_d=307 if dist2=="Lira" & country=="Uganda"
replace dist_d=104 if dist2=="Luwero" & country=="Uganda"
replace dist_d=114 if dist2=="Lyantonde" & country=="Uganda"
replace dist_d=223 if dist2=="Manafwa" & country=="Uganda"
replace dist_d=320 if dist2=="Maracha" & country=="Uganda"
replace dist_d=105 if dist2=="Masaka" & country=="Uganda"
replace dist_d=409 if dist2=="Masindi" & country=="Uganda"
replace dist_d=214 if dist2=="Mayuge" & country=="Uganda"
replace dist_d=209 if dist2=="Mbale" & country=="Uganda"
replace dist_d=410 if dist2=="Mbarara" & country=="Uganda"
replace dist_d=115 if dist2=="Mityana" & country=="Uganda"
replace dist_d=308 if dist2=="Moroto" & country=="Uganda"
replace dist_d=309 if dist2=="Moyo" & country=="Uganda"
replace dist_d=106 if dist2=="Mpigi" & country=="Uganda"
replace dist_d=107 if dist2=="Mubende" & country=="Uganda"
replace dist_d=108 if dist2=="Mukono" & country=="Uganda"
replace dist_d=311 if dist2=="Nakapiripirit" & country=="Uganda"
replace dist_d=116 if dist2=="Nakaseke" & country=="Uganda"
replace dist_d=109 if dist2=="Nakasongola" & country=="Uganda"
replace dist_d=224 if dist2=="Namutumba" & country=="Uganda"
replace dist_d=310 if dist2=="Nebbi" & country=="Uganda"
replace dist_d=411 if dist2=="Ntungamo" & country=="Uganda"
replace dist_d=321 if dist2=="Oyam" & country=="Uganda"
replace dist_d=312 if dist2=="Pader" & country=="Uganda"
replace dist_d=210 if dist2=="Pallisa" & country=="Uganda"
replace dist_d=110 if dist2=="Rakai" & country=="Uganda"
replace dist_d=412 if dist2=="Rukungiri" & country=="Uganda"
replace dist_d=111 if dist2=="Sembabule" & country=="Uganda"
replace dist_d=215 if dist2=="Sironko" & country=="Uganda"
replace dist_d=211 if dist2=="Soroti" & country=="Uganda"
replace dist_d=212 if dist2=="Tororo" & country=="Uganda"
replace dist_d=113 if dist2=="Wakiso" & country=="Uganda"
replace dist_d=313 if dist2=="Yumbe" & country=="Uganda"

*Malawi district names
replace dist_d=101 if dist2=="Chitipa" & country=="Malawi"
replace dist_d=102 if dist2=="Karonga" & country=="Malawi"
replace dist_d=103 if dist2=="Nkhata Bay" & country=="Malawi"
replace dist_d=104 if dist2=="Rumphi" & country=="Malawi"
replace dist_d=105 if dist2=="Mzimba" & country=="Malawi"
replace dist_d=107 if dist2=="Mzuzu City" & country=="Malawi"
replace dist_d=201 if dist2=="Kasungu" & country=="Malawi"
replace dist_d=202 if dist2=="Nkhotakota" & country=="Malawi"
replace dist_d=203 if dist2=="Ntchisi" & country=="Malawi"
replace dist_d=204 if dist2=="Dowa" & country=="Malawi"
replace dist_d=205 if dist2=="Salima" & country=="Malawi"
replace dist_d=206 if dist2=="Lilongwe" & country=="Malawi"
replace dist_d=207 if dist2=="Mchinji" & country=="Malawi"
replace dist_d=208 if dist2=="Dedza" & country=="Malawi"
replace dist_d=209 if dist2=="Ntcheu" & country=="Malawi"
replace dist_d=210 if dist2=="Lilongwe City" & country=="Malawi"
replace dist_d=301 if dist2=="Mangochi" & country=="Malawi"
replace dist_d=302 if dist2=="Machinga" & country=="Malawi"
replace dist_d=303 if dist2=="Zomba" & country=="Malawi"
replace dist_d=304 if dist2=="Chiradzulu" & country=="Malawi"
replace dist_d=305 if dist2=="Blantyre" & country=="Malawi"
replace dist_d=306 if dist2=="Mwanza" & country=="Malawi"
replace dist_d=307 if dist2=="Thyolo" & country=="Malawi"
replace dist_d=308 if dist2=="Mulanje" & country=="Malawi"
replace dist_d=309 if dist2=="Phalombe" & country=="Malawi"
replace dist_d=310 if dist2=="Chikwawa" & country=="Malawi"
replace dist_d=311 if dist2=="Nsanje" & country=="Malawi"
replace dist_d=312 if dist2=="Balaka" & country=="Malawi"
replace dist_d=313 if dist2=="Neno" & country=="Malawi"
replace dist_d=314 if dist2=="Zomba City" & country=="Malawi"
replace dist_d=315 if dist2=="Blantyre City" & country=="Malawi"
replace dist_d=000 if dist2=="Likoma" & country=="Malawi" /*LSMS does not have info for Likoma-island*/

*Tanzania district names. Making names uppercase for Tanzania
gen disti=upper(dist2)
replace dist2=disti if country=="Tanzania"
replace dist2="CHAKECHAKE" if dist2=="CHAKE CHAKE"
replace dist2="MBALALI" if dist2=="MBARALI"
replace dist2="MICHWEWENI" if dist2=="MICHEWENI"
replace dist2="MISENYE" if dist2=="MISSENYI"
replace dist2="URAMBA" if dist2=="URAMBO"
replace dist2="KASKAZINI 'A'" if dist2=="ZANZIBAR NORTH 'A'"
replace dist2="KASKAZINI 'B'" if dist2=="ZANZIBAR NORTH 'B'"
replace dist2="KATI" if dist2=="ZANZIBAR SOUTH - CENTRAL"
replace dist2="KUSINI" if dist2=="ZANZIBAR SOUTH - SOUTH"
replace dist2="MAGHARIBI" if dist2=="ZANZIBAR TOWN - WEST"
replace dist2="MJINI" if dist2=="ZANZIBAR TOWN - URBAN"

replace dist_d=22 if dist2=="ARUMERU" & country=="Tanzania"
replace dist_d=23 if dist2=="ARUSHA" & country=="Tanzania"
replace dist_d=211 if dist2=="BABATI" & country=="Tanzania"
replace dist_d=61 if dist2=="BAGAMOYO" & country=="Tanzania"
replace dist_d=171 if dist2=="BARIADI" & country=="Tanzania"
replace dist_d=184 if dist2=="BIHARAMULO" & country=="Tanzania"
replace dist_d=182 if dist2=="BUKOBA RURAL" & country=="Tanzania"
replace dist_d=186 if dist2=="BUKOBA URBAN" & country=="Tanzania"
replace dist_d=175 if dist2=="BUKOMBE" & country=="Tanzania"
replace dist_d=204 if dist2=="BUNDA" & country=="Tanzania"
replace dist_d=551 if dist2=="CHAKECHAKE" & country=="Tanzania"
replace dist_d=187 if dist2=="CHATO" & country=="Tanzania"
replace dist_d=121 if dist2=="CHUNYA" & country=="Tanzania"
replace dist_d=14 if dist2=="DODOMA RURAL" & country=="Tanzania"
replace dist_d=15 if dist2=="DODOMA URBAN" & country=="Tanzania"
replace dist_d=196 if dist2=="GEITA" & country=="Tanzania"
replace dist_d=35 if dist2=="HAI" & country=="Tanzania"
replace dist_d=212 if dist2=="HANANG" & country=="Tanzania"
replace dist_d=46 if dist2=="HANDENI" & country=="Tanzania"
replace dist_d=142 if dist2=="IGUNGA" & country=="Tanzania"
replace dist_d=72 if dist2=="ILALA" & country=="Tanzania"
replace dist_d=125 if dist2=="ILEJE" & country=="Tanzania"
replace dist_d=198 if dist2=="ILEMELA" & country=="Tanzania"
replace dist_d=131 if dist2=="IRAMBA" & country=="Tanzania"
replace dist_d=111 if dist2=="IRINGA RURAL" & country=="Tanzania"
replace dist_d=116 if dist2=="IRINGA URBAN" & country=="Tanzania"
replace dist_d=174 if dist2=="KAHAMA" & country=="Tanzania"
replace dist_d=181 if dist2=="KARAGWE" & country=="Tanzania"
replace dist_d=24 if dist2=="KARATU" & country=="Tanzania"
replace dist_d=511 if dist2=="KASKAZINI 'A'" & country=="Tanzania"
replace dist_d=512 if dist2=="KASKAZINI 'B'" & country=="Tanzania"
replace dist_d=521 if dist2=="KATI" & country=="Tanzania"
replace dist_d=522 if dist2=="KUSINI" & country=="Tanzania"
replace dist_d=531 if dist2=="MAGHARIBI" & country=="Tanzania"
replace dist_d=532 if dist2=="MJINI" & country=="Tanzania"
replace dist_d=162 if dist2=="KASULU" & country=="Tanzania"
replace dist_d=62 if dist2=="KIBAHA" & country=="Tanzania"
replace dist_d=161 if dist2=="KIBONDO" & country=="Tanzania"
replace dist_d=163 if dist2=="KIGOMA RURAL" & country=="Tanzania"
replace dist_d=164 if dist2=="KIGOMA URBAN" & country=="Tanzania"
replace dist_d=47 if dist2=="KILINDI" & country=="Tanzania"
replace dist_d=117 if dist2=="KILOLO" & country=="Tanzania"
replace dist_d=53 if dist2=="KILOMBERO" & country=="Tanzania"
replace dist_d=51 if dist2=="KILOSA" & country=="Tanzania"
replace dist_d=81 if dist2=="KILWA" & country=="Tanzania"
replace dist_d=71 if dist2=="KINONDONI" & country=="Tanzania"
replace dist_d=63 if dist2=="KISARAWE" & country=="Tanzania"
replace dist_d=178 if dist2=="KISHAPU" & country=="Tanzania"
replace dist_d=215 if dist2=="KITETO" & country=="Tanzania"
replace dist_d=11 if dist2=="KONDOA" & country=="Tanzania"
replace dist_d=13 if dist2=="KONGWA" & country=="Tanzania"
replace dist_d=42 if dist2=="KOROGWE" & country=="Tanzania"
replace dist_d=194 if dist2=="KWIMBA" & country=="Tanzania"
replace dist_d=123 if dist2=="KYELA" & country=="Tanzania"
replace dist_d=82 if dist2=="LINDI RURAL" & country=="Tanzania"
replace dist_d=86 if dist2=="LINDI URBAN" & country=="Tanzania"
replace dist_d=84 if dist2=="LIWALE" & country=="Tanzania"
replace dist_d=115 if dist2=="LUDEWA" & country=="Tanzania"
replace dist_d=41 if dist2=="LUSHOTO" & country=="Tanzania"
replace dist_d=66 if dist2=="MAFIA" & country=="Tanzania"
replace dist_d=192 if dist2=="MAGU" & country=="Tanzania"
replace dist_d=113 if dist2=="MAKETE" & country=="Tanzania"
replace dist_d=133 if dist2=="MANYONI" & country=="Tanzania"
replace dist_d=93 if dist2=="MASASI" & country=="Tanzania"
replace dist_d=172 if dist2=="MASWA" & country=="Tanzania"
replace dist_d=127 if dist2=="MBALALI" & country=="Tanzania"
replace dist_d=122 if dist2=="MBEYA RURAL" & country=="Tanzania"
replace dist_d=128 if dist2=="MBEYA URBAN" & country=="Tanzania"
replace dist_d=103 if dist2=="MBINGA" & country=="Tanzania"
replace dist_d=126 if dist2=="MBOZI" & country=="Tanzania"
replace dist_d=213 if dist2=="MBULU" & country=="Tanzania"
replace dist_d=176 if dist2=="MEATU" & country=="Tanzania"
replace dist_d=542 if dist2=="MICHWEWENI" & country=="Tanzania"
replace dist_d=188 if dist2=="MISENYE" & country=="Tanzania"
replace dist_d=197 if dist2=="MISUNGWI" & country=="Tanzania"
replace dist_d=48 if dist2=="MKINGA" & country=="Tanzania"
replace dist_d=552 if dist2=="MKOANI" & country=="Tanzania"
replace dist_d=64 if dist2=="MKURANGA" & country=="Tanzania"
replace dist_d=21 if dist2=="MONDULI" & country=="Tanzania"
replace dist_d=52 if dist2=="MOROGORO RURAL" & country=="Tanzania"
replace dist_d=55 if dist2=="MOROGORO URBAN" & country=="Tanzania"
replace dist_d=36 if dist2=="MOSHI URBAN" & country=="Tanzania"
replace dist_d=34 if dist2=="MOSHI RURAL" & country=="Tanzania"
replace dist_d=151 if dist2=="MPANDA" & country=="Tanzania"
replace dist_d=12 if dist2=="MPWAPWA" & country=="Tanzania"
replace dist_d=95 if dist2=="MTWARA URBAN" & country=="Tanzania"
replace dist_d=91 if dist2=="MTWARA RURAL" & country=="Tanzania"
replace dist_d=112 if dist2=="MUFINDI" & country=="Tanzania"
replace dist_d=43 if dist2=="MUHEZA" & country=="Tanzania"
replace dist_d=183 if dist2=="MULEBA" & country=="Tanzania"
replace dist_d=203 if dist2=="MUSOMA RURAL" & country=="Tanzania"
replace dist_d=205 if dist2=="MUSOMA URBAN" & country=="Tanzania"
replace dist_d=56 if dist2=="MVOMERO" & country=="Tanzania"
replace dist_d=32 if dist2=="MWANGA" & country=="Tanzania"
replace dist_d=83 if dist2=="NACHINGWEA" & country=="Tanzania"
replace dist_d=105 if dist2=="NAMTUMBO" & country=="Tanzania"
replace dist_d=92 if dist2=="NEWALA" & country=="Tanzania"
replace dist_d=185 if dist2=="NGARA" & country=="Tanzania"
replace dist_d=25 if dist2=="NGORONGORO" & country=="Tanzania"
replace dist_d=114 if dist2=="NJOMBE" & country=="Tanzania"
replace dist_d=153 if dist2=="NKASI" & country=="Tanzania"
replace dist_d=193 if dist2=="NYAMAGANA" & country=="Tanzania"
replace dist_d=141 if dist2=="NZEGA" & country=="Tanzania"
replace dist_d=45 if dist2=="PANGANI" & country=="Tanzania"
replace dist_d=31 if dist2=="ROMBO" & country=="Tanzania"
replace dist_d=85 if dist2=="RUANGWA" & country=="Tanzania"
replace dist_d=65 if dist2=="RUFIJI" & country=="Tanzania"
replace dist_d=124 if dist2=="RUNGWE" & country=="Tanzania"
replace dist_d=33 if dist2=="SAME" & country=="Tanzania"
replace dist_d=195 if dist2=="SENGEREMA" & country=="Tanzania"
replace dist_d=202 if dist2=="SERENGETI" & country=="Tanzania"
replace dist_d=173 if dist2=="SHINYANGA RURAL" & country=="Tanzania"
replace dist_d=177 if dist2=="SHINYANGA URBAN" & country=="Tanzania"
replace dist_d=145 if dist2=="SIKONGE" & country=="Tanzania"
replace dist_d=214 if dist2=="SIMANJIRO" & country=="Tanzania"
replace dist_d=132 if dist2=="SINGIDA RURAL" & country=="Tanzania"
replace dist_d=134 if dist2=="SINGIDA URBAN" & country=="Tanzania"
replace dist_d=102 if dist2=="SONGEA RURAL" & country=="Tanzania"
replace dist_d=104 if dist2=="SONGEA URBAN" & country=="Tanzania"
replace dist_d=152 if dist2=="SUMBAWANGA RURAL" & country=="Tanzania"
replace dist_d=154 if dist2=="SUMBAWANGA URBAN" & country=="Tanzania"
replace dist_d=146 if dist2=="TABORA URBAN" & country=="Tanzania"
replace dist_d=94 if dist2=="TANDAHIMBA" & country=="Tanzania"
replace dist_d=44 if dist2=="TANGA" & country=="Tanzania"
replace dist_d=201 if dist2=="TARIME" & country=="Tanzania"
replace dist_d=73 if dist2=="TEMEKE" & country=="Tanzania"
replace dist_d=101 if dist2=="TUNDURU" & country=="Tanzania"
replace dist_d=191 if dist2=="UKEREWE" & country=="Tanzania"
replace dist_d=54 if dist2=="ULANGA" & country=="Tanzania"
replace dist_d=144 if dist2=="URAMBA" & country=="Tanzania"
replace dist_d=143 if dist2=="UYUI" & country=="Tanzania"
replace dist_d=541 if dist2=="WETE" & country=="Tanzania"

*Making the anchor district code
gen dist_oo=.
replace dist_oo=dist_d+1000 if country=="Malawi"
replace dist_oo=dist_d+2000 if country=="Tanzania"
replace dist_oo=dist_d+3000 if country=="Uganda"
drop dist_d disti
rename dist2 dist_name
rename (dist_oo) (dist_d) /*This is the anchor to merge*/

save "${work}\WEATHER_CRU.dta", replace

*-----------------------------------------------------------------------
************************************************************************
*********************MERGING CHRIPS WITH CRU****************************
************************************************************************
*-----------------------------------------------------------------------
use "${work}\WEATHER.dta", clear
merge 1:1 dist_d year month using "${work}\WEATHER_CRU.dta", keep(master using match) gen(merge_cru)

*Collapsing to get annual data
*collapse (mean) ave_rain* cru*, by(dist_d country year)

saveold "${work}\WEATHER.dta", replace

*-----------------------------------------------------------------------
************************************************************************
*********************CHECKING CHANGES BY YEAR***************************
************************************************************************
*-----------------------------------------------------------------------
use "${work}\WEATHER.dta", clear
replace dist_d=dist_d-1000 if country=="Malawi"
replace dist_d=dist_d-2000 if country=="Tanzania"
replace dist_d=dist_d-3000 if country=="Uganda"
*Making locals per dist and country. I organized them before to match with the id coming from ${work}\MAL_TAN_UGA_c
local malawi "312 305 310 304 101 208 204 102 201 0 206 302 301 207 308 306 105 313 103 202 311 209 203 309 104 205 307 303 315 210 107 314"
local tanzania1 `"61 171 131 181 161 81 71 11 41 21 141 31 201 101 191 142 72 162 62 178 42 192 22 12 112 32 92 202 63 13 123 113 133 93 103 176 83 153 193 33 73 143 175 204 14"'
local tanzania2 `"174 24 117 194 84 172 64 124 94 54 144 35 125 115 105 185 25 85 65 195 145 46 66 126 56 47 127 197 51 151 45 212 213 214 215 521 522 196 198 183 53 121 91"'
local tanzania3 `"177 82 122 132 102 152 23 116 163 203 173 34 114 134 104 154 44 15 55 95 205 186 86 36 146 128 164 52 551 511 531 541 512 542 532 552 211 111 187 184 182 188 48 43"'
local tanzania `"`tanzania1' `tanzania2' `tanzania3'"'
display `"`tanzania'"'
local uganda1 `"314 301 315 216 316 302 303 217 218 201 219 220 416 401 402 202 221 317 304 403 417 203 418 204 318 404 405 213 101 222 102 205 413 414 206 406 207 112 407"'
local uganda2 `"103 419 408 305 319 306 208 415 307 104 114 223 320 105 409 214 209 410 115 308 309 106 107 108 311 116 109 224 310 411 321 312 210 110 412 215 211 111 212 113 313"'
local uganda `"`uganda1' `uganda2'"'
display `"`uganda'"'
gen id=0
*Malawi id
local i=1
foreach x of local malawi {
	replace id=`i' if country=="Malawi" & dist_d==`x'
	local i=`i'+1
}
*Tanzania id
local i=33
foreach x of local tanzania {
	replace id=`i' if country=="Tanzania" & dist_d==`x'
	local i=`i'+1
}
*Uganda id
local i=165
foreach x of local uganda {
	replace id=`i' if country=="Uganda" & dist_d==`x'
	local i=`i'+1
}

*Generating anomalies by month for mean_rainfall and mean_temp. For all sample, not district
foreach x in ave_rain_chrips_mean ave_temp_modis_mean cru_dtr cru_pet cru_pre cru_tmp cru_vap cru_wet {
	summ `x' // CHRIPS is for 1981 onwards. CRU 1970 onwards. TEMP-MODIS from 2001
	gen a1_`x'=0
	gen a2_`x'=0
	return list
	replace a1_`x'=(`x'-r(mean))
	replace a2_`x'=(`x'-r(mean))/r(sd)
	label variable a1_`x' "Anomalies(deviation) weather-mean_LR(weather)"
	label variable a2_`x' "Anomalies(deviation_standard) [weather-mean_LR(weather)]/sd_LR(weather)"
}


*collapsing by district and year(time-variability)
replace dist_d=dist_d+1000 if country=="Malawi"
replace dist_d=dist_d+2000 if country=="Tanzania"
replace dist_d=dist_d+3000 if country=="Uganda"

*Preparing dataset to use in R-software and compute SPEI and SPI as in vicente Serrano
preserve /*SPEI*/
	drop a1_* a2_* merge*
	keep dist_d country year month cru* /*cru data does not have missings*/
	gen pre_pet= cru_pre-cru_pet
	gen pre=cru_pre
	drop cru*
	drop if dist_d==1000 /*Likoma island*/
	drop country
	reshape wide pre pre_pet, i(year month) j(dist_d)
	*drop year month
	keep pre_pet* year month
	*Saving pre_pet. for some reason, I couldn't save the pre_pet* variables only
	export delimited "${work2}\PRE_PET_CRU_monthly.csv", delimiter(",") replace 
	export delimited "${work2}\PRE_PET_CRU_monthly.txt", delimiter(tab) replace
restore

preserve /*SPI*/
	drop a1_* a2_* merge*
	keep dist_d country year month cru* /*cru data does not have missings*/
	gen pre_pet= cru_pre-cru_pet
	gen pre=cru_pre
	drop cru*
	drop if dist_d==1000 /*Likoma island*/
	drop country
	reshape wide pre pre_pet, i(year month) j(dist_d)
	*drop year month
	*Saving pre only
	drop pre_pet*
	export delimited "${work2}\PRE_CRU_monthly.csv", delimiter(",") replace 
	export delimited "${work2}\PRE_CRU_monthly.txt", delimiter(tab) replace
restore

preserve /*SPI CHRIPS*/
	drop a1_* a2_* merge*
	keep dist_d country year month ave_rain_chrips_sum
	drop if ave_rain_chrips_sum==.
	drop if dist_d==1000 /*Likoma island*/
	drop country
	rename ave_rain_chrips_sum pre_chrips
	reshape wide pre_chrips, i(year month) j(dist_d)
	*drop year month
	export delimited "${work2}\PRE_CHRIPS_monthly.csv", delimiter(",") replace 
	export delimited "${work2}\PRE_CHRIPS_monthly.txt", delimiter(tab) replace
restore

preserve /*SPEI CHRIPS-MODIS TEMP*/
	drop a1_* a2_* merge*
	keep dist_d country year month ave_temp_modis_mean ave_temp_modis_max ave_temp_modis_min ave_rain_chrips_sum
	drop if ave_temp_modis_mean==.
	*Merging with coordinates 
	merge m:1 dist_d using "${work}\CENTROIDS_WGS84_d.dta", keep(master using match) gen(merge_coord)	
	drop if dist_d==1000 /*Likoma island*/
	drop country
	rename (ave_temp_modis_mean ave_temp_modis_max ave_temp_modis_min ave_rain_chrips_sum) (temp_modis_mean temp_modis_max temp_modis_min pre_chrips)
	drop id merge* dist_dname
	reshape wide temp_modis_mean temp_modis_max temp_modis_min pre_chrips lon_wgs84 lat_wgs84 , i(year month) j(dist_d)
	*drop year month
	export delimited "${work2}\CHRIPS_MODIS_monthly.csv", delimiter(",") replace 
	export delimited "${work2}\CHRIPS_MODIS_monthly.txt", delimiter(tab) replace
restore

*Graph for the paper PAPER1_V2_mig_drought
preserve
	collapse (mean)  ave_temp_modis_mean, by(country year month)
	gen monthly=ym(year,month)
	format monthly %tm
	label variable ave_temp_modis_mean "Average temperature MODIS"
	graph drop _all
	graph twoway (line ave_temp_modis_mean monthly) (lfit ave_temp_modis_mean monthly) if country=="Malawi" & year>2000, ylabel(15(5)45, gmax angle(horizontal)) ///
            ytitle("Temp") title("Temperature in Malawi 2001-2016") subtitle("Average of all districts by month", size(medsmall)) saving("${paper2}/PAPER/ave_temp_malawi.gph", replace) name(ave_temp_malawi) plotregion(fcolor(gray*0.05)) graphregion(fcolor(gray*0.05)) 
             /*note("Source: MODIS Land Surface Temperature. " "Using satellite images MOD11A1.006 at 1km of resolution", size(small)) */

restore

*Defining year 2016 from May2015-April2016, year 2015 from May2014-April2015
sort dist_d year month
bys dist_d: gen monthly=ym(year,month)
format monthly %tm
bys dist_d monthly: gen monthly_gro=monthly+8
format monthly_gro %tm

*year
gen date_gro = dofm(monthly_gro)
format date_gro %d
gen year_gro=year(date_gro)
gen month_gro=month(date_gro)

collapse (mean)ave* cru* a1_* a2_* (sum)c_* (sd) sd_ave_rain_chrips_mean=ave_rain_chrips_mean sd_ave_rain_chrips_sum=ave_rain_chrips_sum sd_ave_temp_modis_mean=ave_temp_modis_mean sd_cru_pre=cru_pre sd_cru_tmp=cru_tmp, by(country dist_d id dist_name year_gro)
rename year_gro year
*for X in any sd_ave_rain_chrips_mean sd_ave_rain_chrips_sum sd_ave_temp_modis_mean sd_cru_pre sd_cru_tmp: replace X=X^2

saveold "${work}\WEATHER_mean_yearly.dta", replace 

*generating DP change by year
sort country dist_d year
bys country dist_d: gen d_mean_rain=ave_rain_chrips_mean-ave_rain_chrips_mean[_n-1]
gen ch_rain_positive=0
replace ch_rain_positive=1 if d_mean_rain>0 & d_mean_rain!=.

bys country: tab year ch_rain_positive if year>2000 // This shows changes for 

*Now the maps of positive change (CHANGE)
local years "2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013"
graph drop _all
		foreach var in d_mean_rain { 
			foreach t of local years {
			spmap `var' using "${work}\DISTRY_F_c.dta" if year==`t', id(id) clmethod(custom) clbreaks(-20 -10 0 10 20) /// 
			title(" {bf:Change +/- in Rainfall `t' (mm)}", size(Large)) subtitle("Districts: Malawi, Tanzania and Uganda") ///
			note("Source: Own calculations based on the  {it:Malaria Atlas MAP}") ///
			caption("Change year to year (-20 to -10 (mm)) in Rainfall" "Change year to year (-10 to 0 (mm)) in Rainfall" "Change year to year (0 to 10 (mm)) in Rainfall" "Change year to year (10 to 20 (mm)) in Rainfall", size(medsmall) box justification(left)) ///
			legstyle(1) legtit("change_rain_mean") legcount fcolor(blue*1.2 blue*0.5 red*0.5 red*1.2) ///
			name(ch_`var'_`t') plotregion(icolor(gray*0.05)) graphregion(icolor(gray*0.05)) legend(position(7) size(medsmall)) ocolor(black ..) osize(thin ..) ///
			polygon(data("${work}\MAL_TAN_UGA_c") fcolor(none) ocolor(blue) osize(thick)) saving("${results}/maps/ch_`var'_`t'.gph", replace)
			}
		}
		
*Now the maps of anomalies
local years "2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013"
graph drop _all
		foreach var in a2_ave_rain_chrips_mean { 
			foreach t of local years {
			spmap `var' using "${work}\DISTRY_F_c.dta" if year==`t', id(id) clmethod(custom) clbreaks(-1 -0.5 0 0.5 1.5) /// 
			title(" {bf:Anomalies `t' }", size(Large)) subtitle("Districts: Malawi, Tanzania and Uganda") ///
			note("Source: Own calculations based on the  {it:CHRIPS}") ///
			caption("Historical anomalies (-1 to -0.5) in Rainfall" "Historical anomalies (-0.5 to 0) in Rainfall" "Historical anomalies (0 to 0.5) in Rainfall" "Historical Anomalies (0.5 to 1.5) in Rainfall", size(medsmall) box justification(left)) ///
			legstyle(1) legtit("anomalies_rain_mean") legcount fcolor(blue*1.2 blue*0.5 red*0.5 red*1.2) ///
			name(anom_rain_`t') plotregion(icolor(gray*0.05)) graphregion(icolor(gray*0.05)) legend(position(7) size(medsmall)) ocolor(black ..) osize(thin ..) ///
			polygon(data("${work}\MAL_TAN_UGA_c") fcolor(none) ocolor(blue) osize(thick)) // saving("${results}/maps/ch_`var'_`t'.gph", replace)
			}
		}
		
*Checking average per country
collapse (mean)ave* cru* a1_* a2_* c_*, by(country year)
gen con=0
replace con=1 if country=="Malawi"
replace con=2 if country=="Tanzania"
replace con=3 if country=="Uganda"
label define country 1 "Malawi" 2 "Tanzania" 3 "Uganda"
label values con country
label var cru_dtr "Diurnal Temperature Range (degrees Celsius)-Monthly average"
label var cru_pet "Potential Evapotranspiration (mm/day)-Monthly average"
label var cru_pre "Precipitation (mm/month)-Monthly average"
label var cru_tmn "Near-surface Temperature minimum (degrees Celsius)-Monthly average"
label var cru_tmp "Near-surface Temperature (degrees Celsius)-Monthly average"
label var cru_tmx "Near-surface Temperature maximum (degrees Celsius)-Monthly average"
label var cru_vap "Vapour Pressure (hPa)-Monthly average"
label var cru_wet "Wet day frequency (days)-Monthly average"

graph drop _all
foreach x in ave_rain_chrips_sum cru_dtr cru_pet cru_pre cru_tmn cru_tmp cru_vap cru_wet {
		xtline `x' if year>1999, i(con) t(year) overlay name(ave_`x')
	}
	
	*PONTENTIALLY, USE 2005 DROUGHT IN MALAWI WHICH WAS FOLLOWED BY AN INCREASE IN MALARIA. THIS YEAR IS MORE CLEAR IN MALAWI

*I constructed the SPI and SPEI indeces in R as in Vicente Ferrano using his R-package and exported data to dta. It was easier
*CRU
clear
local fi=1
foreach x in spei3_cru_fitted spei6_cru_fitted spei12_cru_fitted spei24_cru_fitted ///
			 spi3_cru_fitted spi6_cru_fitted spi12_cru_fitted spi24_cru_fitted {
			 
			 use "${work2}\\`x'.dta", clear
			 gen monthly = ym(1969,12) + _n
			 format monthly %tm
			 drop year month
			 display "`x'"
			 local fit=reverse(substr(reverse("`x'"),8,.))
			 cap rename pre_pet* `fit'_*
			 cap rename pre* `fit'_*
			 tempfile spei`x'
			 save "spei`x'", replace			 
			
			if `fi'>1 {	
				  use "${work2}\SPEI_SPI_CRU.dta", clear
				  merge 1:1 monthly using "spei`x'", keep(master using match) gen(merge_a)
				  drop merge_a
				  save "${work2}\SPEI_SPI_CRU.dta", replace
				  local fi=`fi'+1
				  }
				  else {
				  save "${work2}\SPEI_SPI_CRU.dta", replace /*First file with the first file as the initial file for merge*/
				  local fi=`fi'+1
				  }	
	}

*CHRIPS
clear
local fi=1
foreach x in spi3_chrips_fitted spi6_chrips_fitted spi12_chrips_fitted spi24_chrips_fitted {
			 
			 use "${work2}\\`x'.dta", clear
			 gen monthly = ym(1980,12) + _n
			 format monthly %tm
			 drop year month
			 display "`x'"
			 local fit=reverse(substr(reverse("`x'"),8,.))
			 cap rename pre_chrips* `fit'_*
			 tempfile spei`x'
			 save "spei`x'", replace			 
			
			if `fi'>1 {	
				  use "${work2}\SPEI_SPI_CHRIPS.dta", clear
				  merge 1:1 monthly using "spei`x'", keep(master using match) gen(merge_a)
				  drop merge_a
				  save "${work2}\SPEI_SPI_CHRIPS.dta", replace
				  local fi=`fi'+1
				  }
				  else {
				  save "${work2}\SPEI_SPI_CHRIPS.dta", replace /*First file with the first file as the initial file for merge*/
				  local fi=`fi'+1
				  }	
	}
	
clear
use "${work2}\SPEI_SPI_CRU.dta", clear	
merge 1:1 monthly using "${work2}\SPEI_SPI_CHRIPS.dta", keep(master using match) gen(merge_a)
drop merge_a
rename *chrips_* *chrips*
rename *cru_* *cru*
*Reshaping data to long
reshape long spei3_cru spei6_cru spei12_cru spei24_cru spi3_cru spi6_cru spi12_cru spi24_cru spi3_chrips spi6_chrips spi12_chrips spi24_chrips, i(monthly) j(dist_o)
sort dist_o monthly

*year and month
gen date = dofm(monthly)
format date %d
gen month=month(date)
gen year=year(date)

*Merging with SPEI using CHRIPS and temp MODIS. PET according to Hargreaves
preserve
	use "${work2}\spei24_har_fitted.dta", clear
	*Reshaping data to long
	reshape long spei_har, i(year month) j(dist_o)
	sort dist_o year month
	tempfile spei24_har_fitted
	save "`spei24_har_fitted'", replace
restore

merge 1:1 year month dist_o using "`spei24_har_fitted'", keep(master using match) gen(merge_har)
drop merge_har

*Merging with SPEI using CHRIPS and temp MODIS. PET according to Thornthwaite
preserve
	use "${work2}\spei24_tho_fitted.dta", clear
	*Reshaping data to long
	reshape long spei_tho, i(year month) j(dist_o)
	sort dist_o year month
	tempfile spei24_tho_fitted
	save "`spei24_tho_fitted'", replace
restore

merge 1:1 year month dist_o using "`spei24_tho_fitted'", keep(master using match) gen(merge_tho)
drop merge_tho

*Merging with SPI using CHRIPS for 2001-2016. 
preserve
	use "${work2}\spi24_chrips_2001_2016_fitted.dta", clear
	*Reshaping data to long
	reshape long spi_chrips_2001_2016, i(year month) j(dist_o)
	sort dist_o year month
	tempfile spei24_2001_2016_fitted
	save "`spei24_2001_2016_fitted'", replace
restore

merge 1:1 year month dist_o using "`spei24_2001_2016_fitted'", keep(master using match) gen(merge_2001_2016)
drop merge_2001_2016

rename (spei_har spei_tho spi_chrips_2001_2016) (spei24har spei24tho spi24_0116)

*Creating inverse of indeces https://www.mdpi.com/2072-4292/7/8/10917/htm, drought variable and drought variable for growing season nov-march as in Asfaw et al for Malawi 2017
rename spi*_chrips spi*chr
rename sp*_cru sp*cru

*Defining year 2016 from May2015-April2016, year 2015 from May2014-April2015
sort dist_o monthly
bys dist_o monthly: gen monthly_gro=monthly+8
format monthly_gro %tm

*year
gen date_gro = dofm(monthly_gro)
format date_gro %d
gen year_gro=year(date_gro)
gen month_gro=month(date_gro)

foreach x in spei3cru spei6cru spei12cru spei24cru spi3cru spi6cru spi12cru spi24cru spi3chr spi6chr spi12chr spi24chr spei24har spei24tho spi24_0116 {
	*Inverse
	gen `x'_i=`x'*(-1)
	label variable `x'_i "inverse of the index"
	
	*Include index average for growing season
	gen `x'_igro=.
	replace `x'_igro=`x'_i if month_gro>=7 & month_gro<=11
	label variable `x'_igro "inverse of the index only for growing season Nov(t-1)-Mar(t)"
		
	*Katrin's suggestion
	gen `x'_ipos=`x'_i
	replace `x'_ipos=0 if `x'_i<0 & `x'_ipos!=.
	gen `x'_ineg=`x'_i
	replace `x'_ineg=0 if `x'_i>0 & `x'_ineg!=.
	
	*droughts mild
	gen `x'_dro=0 if `x'!=.
	replace `x'_dro=1 if `x'<=-1
	label variable `x'_dro "1 if the index<=-1 in that month"
	sort dist_o year_gro month_gro
	bys dist_o: gen `x'_dro_l2=.
	bys dist_o: replace `x'_dro_l2=`x'_dro if month_gro>=7 & month_gro<=11 /*after agro season*/
	label variable `x'_dro_l2 "`x' lagged 2 (drought<=1) for agro season nov-mar"
	*droughts extreme
	gen `x'_droext=0 if `x'!=.
	replace `x'_droext=1 if `x'<=-2
	label variable `x'_droext "1 if the index<=-2 in that month"
	sort dist_o year_gro month_gro
	bys dist_o: gen `x'_dro_l2ext=.
	bys dist_o: replace `x'_dro_l2ext=`x'_droext if month_gro>=7 & month_gro<=11 /*after agro season*/
	label variable `x'_dro_l2ext "`x' lagged 2 (drought<=2) for agro season nov-mar"

}
*Collapsing to Annual data
collapse (mean) sp*, by(dist_o year_gro)
rename year_gro year

*define drought when at least there was one month with drought during that year
foreach x in spei3cru spei6cru spei12cru spei24cru spi3cru spi6cru spi12cru spi24cru spi3chr spi6chr spi12chr spi24chr spei24har spei24tho spi24_0116 {
	*Droughts Mild
	gen `x'_dro_d=0
	replace `x'_dro_d=1 if `x'_dro>0
	label variable `x'_dro_d "1 if at least one month with drought(<=-1) in that year; 0 otherwise"
	gen `x'_dro_d2=0
	replace `x'_dro_d2=1 if `x'_dro_l2>0
	label variable `x'_dro_d2 "1 if at least one month with drought(<=-1) in that agro season; 0 otherwise"
	*Droughts Extreme
	gen `x'_dro_dext=0
	replace `x'_dro_dext=1 if `x'_droext>0
	label variable `x'_dro_dext "1 if at least one month with drought(<=-2) in that year; 0 otherwise"
	gen `x'_dro_d2ext=0
	replace `x'_dro_d2ext=1 if `x'_dro_l2ext>0
	label variable `x'_dro_d2ext "1 if at least one month with drought(<=-2) in that agro season; 0 otherwise"
	
	*labels for the other variables
	label variable `x'_i "Inverse of the index `x'(mean)"
	label variable `x'_igro "Inverse of the index `x' during agro season(mean)"
	label variable `x'_ipos "Inverse of the index `x' only for positive values and 0 for <0(mean)"
	label variable `x'_ineg "Inverse of the index `x' only for negative values and 0 for >0(mean)"
	label variable `x'_dro "% of months with droughts(<=-1) in that year for index `x'"
	label variable `x'_dro_l2 "% of months with droughts(<=-1) in that year only in agro season for index `x'"
	label variable `x'_droext "% of months with droughts(<=-2) in that year for index `x'"
	label variable `x'_dro_l2ext "% of months with droughts(<=-2) in that year only in agro season for index `x'"
}
 
*Descriptive Statistics
estpost tabstat sp* if dist_o<2000 & year>=2000, statistics(n sum mean sd min max) columns(statistics) listwise /*Malawi only*/
matrix V1=(e(count)',e(sum)',e(mean)',e(sd)',e(min)',e(max)')'
putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("SPEI_MALAWI") /*Exporting to Excel*/
putexcel A1 = matrix(V1), names

*Correlations
corr *cru if dist_o<2000 & year>=2000
putexcel A10 = matrix(r(C)), names

corr spi* if dist_o<2000 & year>=2000
putexcel A20 = matrix(r(C)), names

*Descriptive Statistics for drought dummies per year
preserve /*Adding EA droughts in the graph*/
	use "${work2}\com_events.dta", clear
	collapse (sum) drought*, by(year dist_o)
	replace drought1=1 if drought1==2 /*some overlaps. Each dist_o should only have 1 drought per year according to the defintion we use*/
	replace drought2=1 if drought2==2
	replace drought3=1 if drought3==2
	tempfile ea_drought
	save "`ea_drought'", replace
restore

preserve
keep if dist_o<2000 & year>=2000
drop if year==2017

merge 1:1 year dist_o using "`ea_drought'", keep(master using match) gen(merge_ea)

collapse (sum) spi12chr_dro_d spi12chr_dro_d2 spi12chr_dro_dext spi12chr_dro_d2ext drought*, by(year)
graph drop _all
twoway (bar spi12chr_dro_d    year, fcolor(green) lcolor(green))  (bar spi12chr_dro_d2    year, fcolor(none) lcolor(red) ) ///
	   (bar spi12chr_dro_dext year, fcolor(yellow) lcolor(yellow)) (bar spi12chr_dro_d2ext year, fcolor(none) lcolor(blue) ), ///
title("Drought Events per year and district", tstyle(size(medium)) box) subtitle("Total of districts=31")  note("Source: Own Calculations based on SPI.") name(droughts_year_dist_o1) ///
		legend(order(1 "Drought during year <-1" 2 "Drought agro season <-1" 3 "Drought during year <-2" 4 "Drought agro season <-2")) xlabel(2000(1)2016, angle(90)) ///		
		xtitle("Year") ytitle("Total districts with droughts") saving("${paper2}/PAPER/droughts_year_dist_o1.gph", replace)

twoway (line spi12chr_dro_d    year, fcolor(green) lcolor(green)  )  (line spi12chr_dro_d2    year, fcolor(none) lcolor(red) lpattern(dash) lwidth(medthick)) ///
	   (line spi12chr_dro_dext year, fcolor(yellow) lcolor(yellow) lwidth(thick)) (line spi12chr_dro_d2ext year, fcolor(none) lcolor(blue) lpattern(dash)) ///
	   (line drought1    year, fcolor(black) lcolor(black)  ) (line drought3    year, fcolor(black) lcolor(black) lpattern(dot) ), ///
title("Drought Events per year and district", tstyle(size(medium)) box) subtitle("Total of districts=31")  note("Source: Own Calculations based on SPI and LSMS data.") name(droughts_year_dist_o2) ///
		legend(order(1 "Drought in year (SPI<=-1)" 2 "Drought agro season (SPI<=-1)" 3 "Drought in year (SPI<=-2)" 4 "Drought agro season (SPI<=-2)" 5 "Drought1 in >1 EA in dist_o" 6 "Drought3 in 20% of EA in dist_o") textwidth(90)) ///
		xlabel(2000(1)2016, angle(90)) 	xtitle("Year") ytitle("Total districts with droughts") saving("${paper2}/PAPER/droughts_year_dist_o2.gph", replace)
		
restore


***************************
*MAPS OF DROUGHTS ********
****************************
gen country="Malawi" if dist_o<2000
replace country="Tanzania" if dist_o>2000 & dist_o<3000
replace country="Uganda" if dist_o>3000
gen dist_d=dist_o
replace dist_d=dist_d-1000 if country=="Malawi"
replace dist_d=dist_d-2000 if country=="Tanzania"
replace dist_d=dist_d-3000 if country=="Uganda"
*Making locals per dist and country. I organized them before to match with the id coming from ${work}\MAL_TAN_UGA_c
local malawi "312 305 310 304 101 208 204 102 201 0 206 302 301 207 308 306 105 313 103 202 311 209 203 309 104 205 307 303 315 210 107 314"
local tanzania1 `"61 171 131 181 161 81 71 11 41 21 141 31 201 101 191 142 72 162 62 178 42 192 22 12 112 32 92 202 63 13 123 113 133 93 103 176 83 153 193 33 73 143 175 204 14"'
local tanzania2 `"174 24 117 194 84 172 64 124 94 54 144 35 125 115 105 185 25 85 65 195 145 46 66 126 56 47 127 197 51 151 45 212 213 214 215 521 522 196 198 183 53 121 91"'
local tanzania3 `"177 82 122 132 102 152 23 116 163 203 173 34 114 134 104 154 44 15 55 95 205 186 86 36 146 128 164 52 551 511 531 541 512 542 532 552 211 111 187 184 182 188 48 43"'
local tanzania `"`tanzania1' `tanzania2' `tanzania3'"'
display `"`tanzania'"'
local uganda1 `"314 301 315 216 316 302 303 217 218 201 219 220 416 401 402 202 221 317 304 403 417 203 418 204 318 404 405 213 101 222 102 205 413 414 206 406 207 112 407"'
local uganda2 `"103 419 408 305 319 306 208 415 307 104 114 223 320 105 409 214 209 410 115 308 309 106 107 108 311 116 109 224 310 411 321 312 210 110 412 215 211 111 212 113 313"'
local uganda `"`uganda1' `uganda2'"'
display `"`uganda'"'
gen id=0
*Malawi id
local i=1
foreach x of local malawi {
	replace id=`i' if country=="Malawi" & dist_d==`x'
	local i=`i'+1
}
*Tanzania id
local i=33
foreach x of local tanzania {
	replace id=`i' if country=="Tanzania" & dist_d==`x'
	local i=`i'+1
}
*Uganda id
local i=165
foreach x of local uganda {
	replace id=`i' if country=="Uganda" & dist_d==`x'
	local i=`i'+1
}

local years "2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016"
graph drop _all
foreach t of local years {
	foreach x in 3 6 12 24 { 
		local vars "spei`x'cru spi`x'cru spi`x'chr"
		local list_vars_map ""
		foreach var of local vars {
			
			spmap `var' using "${work}\DISTRY_F_c.dta" if year==`t' & dist_o<2000, id(id) clmethod(custom) clbreaks(-4 -3 -2 -1 0 1 2 3 4) /// 
			title(" {bf:Drought index `var' `t' }", size(Large)) subtitle("Districts: Malawi") ///
			fcolor(red*1.2 red*0.9 red*0.6 red*0.2 blue*0.2 blue*0.6 blue*0.9 blue*1.2) caption("", size(small) box justification(left)) /// 
			legstyle(1) legtit("Drought_Index_Mean") legcount legend(position(7) size(vsmall))   ///
			name(drought_`var'_`x'_`t') plotregion(icolor(gray*0.05)) graphregion(icolor(gray*0.05)) ocolor(black ..) osize(thin ..) 
			//saving("${results2}/maps/index_`var'_`t'.gph", replace) polygon(data("${work}\MAL_TAN_UGA_c") fcolor(none) ocolor(blue) osize(thick)) 
			*Saving var names to combine maps later
			local list_vars_map "`list_vars_map' drought_`var'_`x'_`t'"
			}
		*Combining maps
		graph combine `list_vars_map' , cols(3) saving("${results2}/2000_maps/drought`x'_`t'.gph", replace) note("Source: Own calculations based on {it:CRU and CHRIPS}", size(vsmall)) ///
					name(drought`x'_`t') plotregion(fcolor(gray*0.05)) graphregion(fcolor(gray*0.05))
	}
}

*Map for paper
local years "2001 2006 2011 2016"
graph drop _all
foreach x in 12 24 { 
	local list_vars_map ""
	foreach t of local years {
		local vars "spi`x'chr"
		
		foreach var of local vars {
			
			spmap `var' using "${work}\DISTRY_F_c.dta" if year==`t' & dist_o<2000, id(id) clmethod(custom) clbreaks(-4 -3 -2 -1 0 1 2 3 4) /// 
			title(" {bf:Drought index `var' `t' }", size(small)) subtitle("Districts: Malawi", size(small)) ///
			fcolor(red*1.2 red*0.9 red*0.6 red*0.2 blue*0.2 blue*0.6 blue*0.9 blue*1.2) caption("", size(small) box justification(left)) /// 
			legstyle(1) legtit("Index") legcount legend(position(7) size(vsmall))   ///
			name(drought_`var'_`x'_`t') plotregion(icolor(gray*0.05)) graphregion(icolor(gray*0.05)) ocolor(black ..) osize(thin ..) ///
			//saving("${paper2}/PAPER/index_`var'_`t'.gph", replace) polygon(data("${work}\MAL_TAN_UGA_c") fcolor(none) ocolor(blue) osize(thick)) 
			*Saving var names to combine maps later
			local list_vars_map "`list_vars_map' drought_`var'_`x'_`t'"
			}
			}
		*Combining maps
		graph combine `list_vars_map' , cols(4) saving("${paper2}/PAPER/drought_chrips_`x'.gph", replace) note("Source: Own calculations based on {it:CHRIPS}", size(vsmall)) ///
					name(drought_chrips_`x') plotregion(fcolor(gray*0.05)) graphregion(fcolor(gray*0.05))
}

*Map for presentation
local years "2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016"
graph drop _all
foreach x in 12 { 
	foreach t of local years {
		local vars "spi`x'chr"
		
		foreach var of local vars {
			
			spmap `var' using "${work}\DISTRY_F_c.dta" if year==`t' & dist_o<2000, id(id) clmethod(custom) clbreaks(-4 -3 -2 -1 0 1 2 3 4) /// 
			title(" {bf:Drought index `var' `t' }", size(vlarge)) subtitle("Districts: Malawi", size(large)) ///
			fcolor(red*1.2 red*0.9 red*0.6 red*0.2 blue*0.2 blue*0.6 blue*0.9 blue*1.2) caption("", size(medium) box justification(left)) /// 
			legstyle(1) legtit("Index SPI") legcount legend(position(7) size(medium))   ///
			name(drought_`var'_`x'_`t') plotregion(icolor(gray*0.05)) graphregion(icolor(gray*0.05)) ocolor(black ..) osize(thin ..) ///
			saving("${paper2}/PRESENTATION/index_`var'_`t'.gph", replace)
			// polygon(data("${work}\MAL_TAN_UGA_c") fcolor(none) ocolor(blue) osize(thick)) 
			}
		}
}

drop id dist_d country
rename year yearly /*to match later on*/
*erase "${work2}\SPEI_SPI_CHRIPS.dta" 
*erase "${work2}\SPEI_SPI_CRU.dta"
save "${work2}\SPEI_SPI.dta", replace


























