*********************************************************************************
* 			THIS PROGRAM MERGE THE 3 COUNTRIES CROSS-SECTION PANEL 				*
*                WRITTEN BY LUIS GUILLERMO BECERRA                              *
*THE SAME AS 6000 BUT FOR MIG AND NO MIG- You have to run 2000 before running this
* 							
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 11000
set maxvar 30000
cap log close

*cd "/home/l.becerra/U/PSE-Proposal Malaria and paper/INPUT"
*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
*cd "U:\PSE-Proposal Malaria and paper\INPUT"
cd "C:\Users\PSE-Proposal Malaria and paper\INPUT"

global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS"
global results2  "..\RESULTS V2"

*****INSTALLING PACKAGES NEEDED FOR REGRESSIONS

	*Run to install package to calculate distances
	net from http://www-personal.umich.edu/~nicholsa/stata
	net install vincenty

/*	* Install ftools (remove program if it existed previously)
	cap ado uninstall moresyntax
	cap ado uninstall ftools
	net install ftools, from("https://github.com/sergiocorreia/ftools/tree/master/src")

	* Install reghdfe 4.x
	cap ado uninstall reghdfe
	net install reghdfe, from("https://github.com/sergiocorreia/reghdfe/tree/master/src")

	* Install boottest for Stata 11 and 12
	if (c(version)<13) cap ado uninstall boottest
	if (c(version)<13) ssc install boottest

	* Install moremata (sometimes used by ftools but not needed for reghdfe)
	cap ssc install moremata

	* Install ivreg2, the core package
	ssc install ivreg2

	* Finally, install this package
	cap ado uninstall ivreg2hdfe
	cap ado uninstall ivreghdfe
	net install ivreghdfe, from(https://github.com/sergiocorreia/ivreg2_demo/raw/master/)
*/
	*Install file for postestimation esttab-estout 
	ssc install erepost
	
*MALAWI
use "${work2}/malawi_cross_panel.dta", replace
global malawi "hhid pid survey country month_interv year_interv eaid region district rural member hhsize sex dist_move years_migrate reason_migrate mig_ind2 mig_hh2 mig_hht2 mig_hht3 mig_hht4 age_years age_bracket kids5 per_hhkids5 dist_d dist_o elevation hh_shock1 hh_shock2 hh_shock3 eduhigh eduyears language_hh mig_rural mig_urban hh_b14"
global malawi_geo_com "hh_geo* com_* k_* hh_e19b work_hh_head* Y Yag agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other Yag_per hh_c14 hh_d40 hh_b24 hh_b26* case_id20162017 rel_to_head sex_hh_head moduleB_resp" 
keep $malawi $malawi_geo_com
tostring rural, replace force
replace rural="Rural" if rural=="2"
replace rural="Urban" if rural=="1"
tostring years_migrate, replace force
foreach var of varlist district region dist_move {
	decode `var', gen(`var'_)
	drop `var'
	rename `var'_ `var'
}

*Recoding dist_d and dist_o to avoid problems while merging with other countries. 1000 for Malawi, 2000 for Tanzania and 3000 for Uganda
decode dist_d, gen(dist_dname)
decode dist_o, gen(dist_oname)
gen dist_dd=dist_d+1000
gen dist_oo=dist_o+1000
drop dist_d dist_o
rename (dist_dd dist_oo) (dist_d dist_o)

*TANZANIA
preserve
	use "${work}/tanzania_cross_panel.dta", replace
	global tanzania "hhid pid survey country month_interv year_interv eaid region district rural member hhsize sex dist_move years_migrate reason_migrate mig_ind2 mig_hh2 mig_hht2 mig_hht3 mig_hht4 age_years age_bracket kids5 per_hhkids5 dist_d dist_o elevation eduhigh eduyears"
	keep $tanzania
	tostring pid, replace
	tostring eaid, replace force
	tostring years_migrate, gen(years_migrate_)
	replace years_migrate_="LIVED HERE SINCE BIRTH" if years_migrate==99
	drop years_migrate
	rename years_migrate_ years_migrate
	foreach var of varlist district region dist_move {
		decode `var', gen(`var'_)
		drop `var'
		rename `var'_ `var'
	}
	*Recoding dist_d and dist_o to avoid problems while merging with other countries. 1000 for Malawi, 2000 for Tanzania and 3000 for Uganda
	decode dist_d, gen(dist_dname)
	decode dist_o, gen(dist_oname)
	gen dist_dd=dist_d+2000
	gen dist_oo=dist_o+2000
	drop dist_d dist_o
	rename (dist_dd dist_oo) (dist_d dist_o)
	tempfile tan
	save "`tan'", replace 
restore

append using "`tan'", gen(append)
drop append

*UGANDA 
preserve
	use "${work}/uganda_cross_panel.dta", replace
	global uganda "hhid pid survey country month_interv year_interv eaid region district rural member hhsize sex dist_move years_migrate reason_migrate mig_ind2 mig_hh2 mig_hht2 mig_hht3 mig_hht4 age_years age_bracket kids5 per_hhkids5 dist_d dist_o elevation eduhigh eduyears"
	keep $uganda

	tostring rural, replace force
	replace rural="Rural" if rural=="1"
	replace rural="Urban" if rural=="0"
	tostring years_migrate, gen(years_migrate_)
	replace years_migrate_="LIVED HERE SINCE BIRTH" if years_migrate==100
	drop years_migrate
	rename years_migrate_ years_migrate
	foreach var of varlist district region dist_move {
		decode `var', gen(`var'_)
		drop `var'
		rename `var'_ `var'
	}
	*Recoding dist_d and dist_o to avoid problems while merging with other countries. 1000 for Malawi, 2000 for Tanzania and 3000 for Uganda
	decode dist_d, gen(dist_dname)
	decode dist_o, gen(dist_oname)
	gen dist_dd=dist_d+3000
	gen dist_oo=dist_o+3000
	drop dist_d dist_o
	rename (dist_dd dist_oo) (dist_d dist_o)
	tempfile uga
	save "`uga'", replace 
restore

append using "`uga'", gen(append)
drop append

*Generating Monthly date to define timing when they migrated. Then, I define sample according to the period the survey was conducted.
replace years_migrate="100" if years_migrate=="LIVED HERE SINCE BIRTH"
destring years_migrate, replace
gen migra=year_interv-years_migrate
replace migra=. if years_migrate>=100
gen timing = ym(migra,month_interv)
format timing %tm
drop migra
*Defining sample between and within migrants but getting rid of temporal migrants of less than 1 year, and those before 1998 as first survey if for 2004-2005 and questions of droughts EA is for 5 years ago.
gen sample3=0
replace sample3=1 if (mig_ind2==1 | mig_ind2==2) & timing>=tm(1999m1) & (years_migrate!=0 & years_migrate!=.)
*replace sample3=0 if sample3==1 & dist_o==.
*Generating year variable to merge with DP and Nightlights
gen date = dofm(timing)
format date %d
gen year=year(date)
drop date

*########################### DEFINING A VARIABLE FOR HH WITH KIDS <5 YEARDS OLD. DEFINING BETTER THE AGE WHEN THEY MIGRATED AND USES YEAR VARIABLE WHEN THEY MIGRATED
sort country survey hhid pid
gen age_years_mig=age_years-years_migrate if age_years!=. & years_migrate!=. & years_migrate<100
replace age_years_mig=0 if age_years_mig==-1
replace age_years_mig=. if age_years_mig<-1 /*those are persons who did not exist when the family migrated*/
gen a=0
replace a=1 if age_years_mig<=5 & age_years_mig!=. /*dummy with kids less than 5 years old*/
bys survey hhid: egen hh_kids5_mig=sum(a) /*Summing all the kids <5 in the hh*/
gen kids5_mig=0
replace kids5_mig=1 if hh_kids5_mig!=0
gen per_hhkids5_mig=0
replace per_hhkids5_mig=hh_kids5_mig/hhsize
drop a hh_kids5_mig
label var kids5_mig "1: if at least 1 kid <5 years. 0: otherwise. For migrants, in the year they migrated"
label var per_hhkids5_mig "% of kids with < 5 years old. For migrants, in the year they migrated"

*duplicates migrants
duplicates tag country hhid pid if sample3==1, gen(dup)
tab dup sample3
tab dup country
********** Important sample of duplicates, only for Uganda. Good to do a robustness check controlling for HH characteristics ****
tab mig_ind2 if dup!=0 & sample3==1 

*Generating a variable for hh-individual in each country
egen id=group(country hhid pid)
egen id_HH=group(country hhid)
br hhid pid survey country mig_ind2 dist_d dist_o timing sample3 dup id if sample3==1 & dup==1 | dup==2 /*Seeing duplicates for all*/
gen sample3_dup=sample3
*Fixing duplicates. Remember that 2004/2005 does not have info for dist_move if mig_ind2==1 between district
*dup==0
bys id: replace sample3_dup=0 if dup==0 & dist_o==. & survey!="Survey-2004-2005" & mig_ind2==1 /*only the between district migrants after 2004/2005*/
bys id: replace sample3_dup=0 if dup==0 & dist_d==.
bys id: replace sample3_dup=0 if dup==0 & timing==. /*There were 82 observations with timing missing. Better not to include them*/
*dup==2
bys id: replace sample3_dup=0 if dup==2 & dist_o==.
bys id: replace sample3_dup=0 if dup==2 & dist_d==.
bys id: replace sample3_dup=0 if dup==2 & timing==. /*There were 6 observations with timing missing. Better not to include them*/
*dup==1
bys id: replace sample3_dup=0 if dup==1 & dist_o==.
bys id: replace sample3_dup=0 if dup==1 & dist_d==.
bys id: replace sample3_dup=0 if dup==1 & timing==. /*There were 11 observations with timing missing. Better not to include them*/
drop dup
duplicates tag hhid pid if sample3_dup==1, gen(dup) 
*Dealing with same migrants recorded twice or three times
sort id country survey /*Careful, if I don't sort problems. HAve to replace 3748/2=1874*/
bys id (dup survey) : gen t=_n if dup==1
bys id (survey): replace sample3_dup=0 if dup==1 & t==1 /*Keeping the duplicate of the latest survey*/
drop t
bys id (dup survey) : gen t=_n if dup==2
bys id (survey): replace sample3_dup=0 if dup==2 & (t==1 | t==2) /*Keeping the duplicate of the latest survey*/
drop dup
duplicates tag hhid pid if sample3_dup==1, gen(dup) /*Now, not duplicates*/
*After checking, some guys recorded district codes that don't exist. Better not to take them into account. 13 migrants
replace sample3_dup=0 if (dist_o==3000 | dist_o==3001 | dist_o==3003 | dist_o==3004 | dist_o==3011 | dist_o==3020 | dist_o==3100 | dist_o==3133) & sample3_dup==1

*Have to exclude migrants from Kitgum and Gulu in Uganda, that faced conflict 1987-2007. See Blattman paper
tab reason_mig if sample3_dup==1 & (dist_d==3304 | dist_d==3305 | dist_o==3304 |dist_o==3305) & year<2008
replace sample3_dup=0 if (dist_d==3304 | dist_d==3305 | dist_o==3304 |dist_o==3305) & year<2008 /*217 migrants excluded*/

**************************************************************************************************************
** FIXING DUPLICATES AS THEY WERE NOT REMOVED FOR MALAWI CORRECTLY BEFORE; USING PANEL SAMPLE OF LSMS BETTER
**************************************************************************************************************
preserve
	/*
	*PANEL ONLY HH
	*2010
	use "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_a_filt_10.dta", clear
	keep HHID case_id ea_id
	gen survey2010=2010

	*2013
	merge 1:m HHID using "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_a_filt_13.dta", keep(master using match) gen(merge_2013)
	gen survey2013=2013 if merge_2013==3|merge_2013==2
	keep HHID case_id ea_id survey2010 survey2013 y2_hhid

	*2016
	merge 1:m HHID y2_hhid using "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_a_filt_16.dta", keep(master using match) gen(merge_2016)
	gen survey2016=2016 if merge_2016==3|merge_2016==2
	keep HHID survey2010 y2_hhid survey2013 survey2016 y3_hhid
	
	*/
	
	*PANEL HH AND PID
	*2010
	use "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_b_10.dta", clear
	keep HHID PID case_id id_code /*case_id id_code are to match with cross-section data*/
	gen survey2010=2010
	save "${work2}/HHPID_panel_malawi_2010.dta", replace /*saving file just to keep the order*/
	
	*2013. Match HHID and PID
	use "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_b_13.dta", clear 
	merge m:1 y2_hhid using "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_a_filt_13.dta", keep(master using match) gen(merge_hhid2013)
	keep y2_hhid PID HHID /*all matched*/
	gen survey2013=2013
	save "${work2}/HHPID_panel_malawi_2013.dta", replace

	*2016. Match HHID and PID
	use "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_b_16.dta", clear 
	merge m:1 y3_hhid using "${input}\LSMS Surveys\Malawi\Panel 2010-2013-2016\STATA FILES\hh_mod_a_filt_16.dta", keep(master using match) gen(merge_hhid2016)
	keep y3_hhid y2_hhid PID HHID case_id id_code /*all matched*/
	rename (case_id id_code) (case_id20162017 id_code20162017) /*That's the name I included to easy recognize it*/
	gen survey2016=2016
	save "${work2}/HHPID_panel_malawi_2016.dta", replace
	
	
	*Merging all. See Information document to match by PID all rounds
	use "${work2}/HHPID_panel_malawi_2010.dta", clear
	*2013
	merge 1:1 PID using "${work2}/HHPID_panel_malawi_2013.dta", keep(master using match) gen(merge_hhid2013)
	*2016
	merge 1:1 PID using "${work2}/HHPID_panel_malawi_2016.dta", keep(master using match) gen(merge_hhid2016)
	
	*Dropping those in panel with data in only 1 wave. They are not repeated
	drop if (survey2010==. & survey2013==.) | (survey2013==. & survey2016==.) | (survey2010==. & survey2016==.) 
	drop merge*
	tostring id_code, replace
	gen country="Malawi"
	*Identifying all the possible cases of waves. 
	gen duplex="1013" if survey2010==2010 & survey2013==2013
	replace duplex="1016" if survey2010==2010 & survey2016==2016
	replace duplex="1316" if survey2013==2013 & survey2016==2016
	replace duplex="101316" if survey2010==2010 & survey2013==2013 & survey2016==2016
	tab duplex /*1316 option is for only those in 2013 and 2016. If I identify in 2013 and drop them in that year. OK, but I also have to drop those in 2010*/

	save "${work2}/HHPID_panel_malawi_2010_2013_2016.dta", replace
restore

*2010 adding PID unique identifier. IT was added in the new release with the panel data
preserve
	use "${input}\LSMS Surveys\Malawi\2010-2011\STATA FILES NEW RELEASE 2019\Panel\Household\hh_mod_b.dta", clear
	keep case_id id_code pid hhid
	tostring id_code, replace
	rename (hhid pid) (HHID_panel PID_panel)
	rename (case_id id_code) (hhid pid)
	gen country="Malawi"
	gen survey="Survey-2010-2011"
	tempfile mal_2010
	save "`mal_2010'", replace
restore

merge 1:1 country survey hhid pid using "`mal_2010'", keep(master using match) gen(merge_addpid2010)
drop merge_addpid2010 /*all panel individual's id were added*/

*2013 already has PID for panel, it's the same as pid for merging, but HHID_panel is missing.
gen y2_hhid=hhid if country=="Malawi" & survey=="Survey-2013" /*y2_hhid PID are the original names of the survey 2013*/
gen PID=pid if country=="Malawi" & survey=="Survey-2013"

merge m:1 y2_hhid PID using "${work2}/HHPID_panel_malawi_2013.dta", keep(master using match) gen(hhid_2013)
tab  hhid_2013 country 
tab survey hhid_2013 /*all matches are for Malawi 2013*/
replace PID_panel=PID if country=="Malawi" & survey=="Survey-2013" & hhid_2013==3 /*replacing only for the matched panel*/
replace HHID_panel=HHID if country=="Malawi" & survey=="Survey-2013" & hhid_2013==3 /*replacing only for the matched panel*/
drop hhid_2013 PID HHID y2_hhid survey2013

		/* THIS DID NOT WORK

		*2016 HHID PID
		*case_id20162017 and id_code20162017 are the original names for HH and ID of the survey 2016-2017 for Malawi. I added them before
		gen id_code20162017=pid if country=="Malawi" & survey=="Survey-2016-2017"
		destring id_code20162017, replace
		*merge m:1 case_id20162017 id_code20162017 using "${work2}/HHPID_panel_malawi_2016.dta", keep(master using match) gen(hhid_2016)

		*The previous line did not work, but I can merge 2016 by using the panel data with case_id of 2010 and with y2_hhid for 2013
		*I will not identify the people in 2016 but I can identify them in 2010 or 2013 and remove them, until I ask to the LSMS team
		*Identifing duplicates in 2010 
		drop *20162017
		gen case_id=hhid if country=="Malawi" & survey=="Survey-2010-2011"
		gen id_code=pid if country=="Malawi" & survey=="Survey-2010-2011"
		merge m:m case_id id_code using "${work2}/HHPID_panel_malawi_2010_2013_2016.dta", keep(master using match) gen(dup_2010)
		drop if dup_2010==2
		duplicates tag case_id id_code if case_id!="", gen(duply)
		tab duply /*no duplicates, all matches are 1:1*/
		drop duply case_id id_code HHID PID y2_hhid y3_hhid

		gen duply="20102013" if survey2010==2010 & survey2013==2013
		replace duply="20102016" if survey2010==2010 & survey2016==2016
		replace duply="201020132016" if survey2010==2010 & survey2013==2013 & survey2016==2016
		drop survey2* *20162017 dup_2010

		*Identifing duplicates in 2013 
		gen y2_hhid=hhid if country=="Malawi" & survey=="Survey-2013"
		gen PID=pid if country=="Malawi" & survey=="Survey-2013"
		merge m:m y2_hhid PID using "${work2}/HHPID_panel_malawi_2010_2013_2016.dta", keep(master using match) gen(dup_2013) /*using y2_hhid or y2_hhid PID have same results*/
		drop y3_hhid id_code20162017 case_id20162017 case_id id_code HHID

		*/

******************************************
*DROPPING DUPLICATES FOR EVERYBODY IN 2010-2013 or 2010-2013-2016. I will delete in the next steps those in 2013-2016
******************************************
duplicates tag country PID_panel if PID_panel!="", gen(dup_all) 
	
tab dup_all survey
tab survey mig_ind2 if dup_all==1 /*Apparently there are some missclassification error in the type of migrants between rounds.*/

drop if dup_all==1 & survey=="Survey-2010-2011" /*dropping migrants-no migrant duplicates in 2010-2013 or 2010-2013-2016*/

*****************************************
* DROPPING ONLY DUPLICATES FOR 2013-2016 IDENTIFIED BEFORE IN THE PANEL MERGE
*****************************************
preserve
	use "${work2}/HHPID_panel_malawi_2010_2013_2016.dta", clear
	keep if duplex=="1316"
	drop survey* *20162017 case_id id_code y3_hhid HHID
	tempfile mal_20132016
	save "`mal_20132016'", replace
restore

gen y2_hhid=hhid if country=="Malawi" & survey=="Survey-2013"
gen PID=pid if country=="Malawi" & survey=="Survey-2013"
merge m:1 y2_hhid PID using "`mal_20132016'", keep(master using match) gen(dup_20132016) /*using y2_hhid or y2_hhid PID have same results. All matches ok*/
tab dup_all duplex /*All duplicates duplex were not duplicates before, correct*/
drop if duplex=="1316" /*dropping duplicates that were in 2013 where at least I can identify them. I can't in 2016*/
drop dup_all y2_hhid PID duplex dup_20132016


/**CREATING ALL POSSIBLE MIGRANT FLOWS. EACH MIGRANT HAS N-1 (# DISTRICTS -1) OPTIONS TO MIGRATE, BUT THEY ONLY WENT TO ONE. SEE FAFCHAMPS-SHILPI (2012)

* A file which has all districts and will contain just zeros to match later on
preserve
	gen a=0
	collapse (mean) a, by(dist_d country) /*Here I have all districts by country*/
	drop if dist_d==.
	tempfile anchor
	save "`anchor'", replace
	rename dist_d dist_o
	rename country country_1
	cross using "`anchor'" /*This generates 143*143 combinations of mig flows*/
	keep if country==country_1 /*This gives me just the 32*32+132*132+80*80 flows I need*/
	drop country_1
	order country dist_d dist_o a
	rename dist_d dist_d1 /*Changing dist_d name to see all possible combinations*/
	tempfile anchor
	save "`anchor'", replace
restore
*/
******************************
**************NO LIKOMA ISLAND
********************************
drop if dist_d==1106 /*Dropping Likoma*/

*Table P1 for PAPER1_V2_mig_drought
matrix M = J(4,4,0)
matrix colname M = 2004-2005 2010-2011 2013 2016-2017
matrix rowname M = 0 1 2 3
tab mig_ind2 survey if country=="Malawi", matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("P1", replace) //modify
putexcel A1=matrix(C), names

**************************************************
**DESCRIPTIVE STATISTICS FOR MECHANIMS. I GET SAME RESULTS AS IN FILE 6000_***
**************************************************
*This values coincides with our values later on for within and between migrants
gen tt=1 if (dist_d==1106) | (sample3_dup==0 & (mig_ind2==1|mig_ind2==2)) /*this variable takes those migrants we removed from sample before. We also removed the district of Likoma island*/

*Table Mechanisms for PAPER1_V2_mig_drought
matrix M = J(4,2,0)
matrix colname M = no_agro_work_head agro_work_head
matrix rowname M = no_mig mig_between mig_within mig_interna
tab mig_ind2 work_hh_head_ag if tt!=1, matcell(total) /*Migrants and not migrants and below by reason_migrate*/
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A1=matrix(C), names

tab mig_ind2 work_hh_head_ag if tt!=1 & reason_migrate==1, matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A7=matrix(C), names

tab mig_ind2 work_hh_head_ag if tt!=1 & reason_migrate==3, matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A13=matrix(C), names

tab mig_ind2 work_hh_head_ag if tt!=1 & reason_migrate==4, matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A19=matrix(C), names

*Table Mechanisms for PAPER1_V2_mig_drought
sum Yag_per if Yag_per<=1 & Yag_per!=. & tt!=1 & mig_ind2==0
putexcel A26 = "Yag_per - no_mig"
putexcel B26 = `r(N)', nformat(number_d2)
putexcel C26 = `r(mean)', nformat(number_d2)
putexcel D26 = `r(sd)', nformat(number_d2)
putexcel E26 = `r(min)', nformat(number_d2)
putexcel F26 = `r(max)', nformat(number_d2)

sum Yag_per if Yag_per<=1 & Yag_per!=. & tt!=1 & mig_ind2==1
putexcel A27 = "Yag_per - mig_between"
putexcel B27 = `r(N)', nformat(number_d2)
putexcel C27 = `r(mean)', nformat(number_d2)
putexcel D27 = `r(sd)', nformat(number_d2)
putexcel E27 = `r(min)', nformat(number_d2)
putexcel F27 = `r(max)', nformat(number_d2)

sum Yag_per if Yag_per<=1 & Yag_per!=. & tt!=1 & mig_ind2==2
putexcel A28 = "Yag_per - mig_within"
putexcel B28 = `r(N)', nformat(number_d2)
putexcel C28 = `r(mean)', nformat(number_d2)
putexcel D28 = `r(sd)', nformat(number_d2)
putexcel E28 = `r(min)', nformat(number_d2)
putexcel F28 = `r(max)', nformat(number_d2)

sum Yag_per if Yag_per<=1 & Yag_per!=. & tt!=1 & mig_ind2==3
putexcel A29 = "Yag_per - mig_international"
putexcel B29 = `r(N)', nformat(number_d2)
putexcel C29 = `r(mean)', nformat(number_d2)
putexcel D29 = `r(sd)', nformat(number_d2)
putexcel E29 = `r(min)', nformat(number_d2)
putexcel F29 = `r(max)', nformat(number_d2)

label define mig_label 0 "NoMIG." 1 "Between Dist-MIG." 2 "Within Dist-MIG." 3 "International MIG."
label values mig_ind2 mig_label

estpost tabstat Yag_per if Yag_per<=1 & Yag_per!=. & tt!=1 , by(mig_ind2)  statistics(count mean sd max min) 
est store mecha1b
esttab mecha1b using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism1b.tex", ///
		cells("count(fmt(0) label(Obs.)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(0) label(Min)) max(fmt(0) label(Max))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide nomtitle	///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-6} \addlinespace[-2ex]))  /// 
		prehead("\begin{tabular}{l*{6}{c}} \toprule \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\") 

************************************************
** % of transfer-gov transfer on the HH income and % of noagro income. Migrants depend less on agro than no migrants and transfer-remittances are in general not important for everybody
************************************************
gen Ytransfer_per=transfer/Y

estpost tabstat Ytransfer_per if Ytransfer_per<=1 & Ytransfer_per!=. & tt!=1 & Ytransfer_per>=0, by(mig_ind2)  statistics(count mean sd max min) 
est store mecha1b_transfer
esttab mecha1b_transfer using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism1b_transfer.tex", ///
		cells("count(fmt(0) label(Obs.)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(0) label(Min)) max(fmt(0) label(Max))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide nomtitle	///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-6} \addlinespace[-2ex]))  /// 
		prehead("\begin{tabular}{l*{6}{c}} \toprule \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\") 

gen Ynoag_per=(nonagr_wge+selfemp)/Y
estpost tabstat Ynoag_per if Ynoag_per<=1 & Ynoag_per!=. & tt!=1 & Ynoag_per>=0, by(mig_ind2)  statistics(count mean sd max min) 
est store mecha1b_noag
esttab mecha1b_noag using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism1b_noag.tex", ///
		cells("count(fmt(0) label(Obs.)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(0) label(Min)) max(fmt(0) label(Max))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide nomtitle	///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-6} \addlinespace[-2ex]))  /// 
		prehead("\begin{tabular}{l*{6}{c}} \toprule \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\") 
		
*********************************************
* Question hh_c14: reason why drop out school
*********************************************
tab hh_c14 /*option 4: marriage-pregnant*/
gen noedu_mar_preg=0 if hh_c14!=.
replace noedu_mar_preg=1 if hh_c14==4
label var noedu_mar_preg "1 if individual left school for marriage-pregnancy 0 others"
tab mig_ind2 noedu_mar_preg if tt!=1, matcell(total)
matrix M = J(4,2,0)
matrix colname M = drop_out_others drop_out_mar_preg
matrix rowname M = no_mig mig_between mig_within mig_interna
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A51=matrix(C), names

estpost tab mig_ind2 noedu_mar_preg if tt!=1
est store mecha3a
esttab mecha3a using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism3a.tex", cells("b(fmt(0) label(Observ.)) rowpct(fmt(1) label(Percentage))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule  & \multicolumn{2}{c}{Drop-out school - other reasons} & \multicolumn{2}{c}{Drop-out school for marriage-pregnancy} & \multicolumn{2}{c}{Total} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \cmidrule(lr){6-7} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\") 

***********************************************
* Question hh_d40: pregnancy in the last 24 months
**************************************************
tab mig_ind2 hh_d40 if tt!=1, matcell(total)
matrix M = J(4,2,0)
matrix colname M = pregnancy_24_months no_pregnancy_24_months
matrix rowname M = no_mig mig_between mig_within mig_interna
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A85=matrix(C), names

estpost tab mig_ind2 hh_d40 if tt!=1
est store mecha4a
esttab mecha4a using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism4a.tex", cells("b(fmt(0) label(Observ.)) rowpct(fmt(1) label(Percentage))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule  & \multicolumn{2}{c}{Pregnancy} & \multicolumn{2}{c}{No pregnancy} & \multicolumn{2}{c}{Total} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \cmidrule(lr){6-7} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\") 

***********************************************
* Question hh_b24: marital status
**************************************************
tab mig_ind2 hh_b24 if tt!=1, matcell(total)
matrix M = J(4,6,0)
matrix colname M = marry_mono marry_poly separated divorced widow never_married
matrix rowname M = no_mig mig_between mig_within mig_interna
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A116=matrix(C), names

label define marry_label 1 "Monogamous" 2 "Polygamous" 3 "Separated" 4 "Divorced" 5 "Widowed" 6 "Never Married"
label values hh_b24 marry_label

estpost tab mig_ind2 hh_b24 if tt!=1
est store mecha5a
esttab mecha5a using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism5a.tex", cells("b(fmt(0) label(Observ.))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-8} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{8}{c}} \toprule  & Monogamous & Polygamous & Separated & Divorced & Widowed & Never married & Total \\ \cmidrule(lr){2-8} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-8} \addlinespace[-2ex] \\")

*********************************************************
**** HERE I WILL KEEP THE SAMPLE TO ALL MIGRANTS AND NO MIGRANTS
********************************************************
drop if country=="Malawi" & mig_ind2==0 & year!=. /*dropped no migrants in one question but declaring a year to migrate. Better to exlude them to avoid mistakes*/
*keep if sample3_dup==1 /*Using only sample of migrants*/
drop if country=="Malawi" & mig_ind2!=0 & sample3_dup==0 /*getting rid of any migrant duplicated and that did not satisfy the catergories above, migrants before 1999 etc*/
*keep if ((sample3_dup==1)|(sample3_dup==0 & mig_ind2==0)) /*getting rid of international migrants, and migrants before 1999*/
*joinby dist_o using "`anchor'"
*drop dup a
*tab country sample3_dup if dist_d==dist_d1 /*This is the real sample of migrants for whom I made the alternative flows*/
di "******** SAMPLE OF MIGRANTS ******"
*di 29967*32+10179*132+10288*80 
tab country mig_ind2 if sample3_dup==1
di "******** SAMPLE OF MIGRANTS-NO MIGRANTS ******"
tab country mig_ind2 
*Defining real migrants and no alternative options
gen mig_real=1 /*to use later*/
*replace mig_real=1 if dist_d==dist_d1
label var mig_real "1: real migration took place 0: dist_d-dist_o did not happen-alternative"
drop t
*rename dist_d dist_dx
*rename dist_d1 dist_d

		/*
		*merging with DP-MALARIA ORIGIN
		preserve
			use "${work}/MALARIA_MAP_DIST2_MEI.dta", clear
			keep year country mean_* dist_d p_mean* high_mal
			rename (dist_d) (dist_o) /*This is the anchor to merge*/
			*Lagged variables
			sort dist_o year
			foreach x in pre inc spr bed art {
				by dist_o: gen L_mean_`x'=mean_`x'[_n-1]
			}
			foreach x in a b c d e {
				by dist_o: gen L_p_mean_pre_`x'=p_mean_pre_`x'[_n-1]
			}
			tempfile dp_o
			save "`dp_o'", replace
		restore

		merge m:1 country year dist_o using "`dp_o'", keep(master using match) gen(merge_dp_o)
		drop if merge_dp_o==2 /*Those that did not match. Not all district recorded origin migrants of course*/
		drop merge_dp_o
		foreach x in pre inc spr bed art {
			rename mean_`x' mean_`x'_o
			rename L_mean_`x' L_mean_`x'_o
		}
		*renaming the MEI index predicted for origin
		rename (p_mean* L_p_mean*) =_o
		rename high_mal high_mal_o

		*merging with DP-MALARIA DESTINATION
		preserve
			use "${work}/MALARIA_MAP_DIST2_MEI.dta", clear
			keep year country mean_* dist_d p_mean* high_mal
			*Lagged variables
			sort dist_d year
			foreach x in pre inc spr bed art {
				by dist_d: gen L_mean_`x'=mean_`x'[_n-1]
			}
			foreach x in a b c d e {
				by dist_d: gen L_p_mean_pre_`x'=p_mean_pre_`x'[_n-1]
			}
			tempfile dp_d
			save "`dp_d'", replace
		restore

		merge m:1 country year dist_d using "`dp_d'", keep(master using match) gen(merge_dp_d)
		drop if merge_dp_d==2 /*Those that did not match. Not all district recorded origin migrants of course*/
		drop merge_dp_d
		foreach x in pre inc spr bed art {
			rename mean_`x' mean_`x'_d
			rename L_mean_`x' L_mean_`x'_d
		}
		*renaming the MEI index predicted for destination
		rename (p_mean_pre_a p_mean_pre_b p_mean_pre_c p_mean_pre_d p_mean_pre_e L_p_mean_pre_a L_p_mean_pre_b L_p_mean_pre_c L_p_mean_pre_d L_p_mean_pre_e)  =_d
		rename high_mal high_mal_d
		*merging with NIGHTLIGHTS-Y ORIGIN. nl variable already has +0.01
		preserve
			use "${work}/NIGHTLIGHT.dta", clear
			drop cf_nl_mean cf_nl_sum raw_high9_mean raw_high9_sum raw_nl_mean raw_nl_sum n_pixels dist_name sample2_survey lstable_nl_mean lstable_nl_sum lYm_us lYagm_us
			rename (dist_d) (dist_o) /*This is the anchor to merge*/
			*Lagged variables
			sort dist_o year
			foreach x in stable_nl_mean stable_nl_sum Ym_us Yagm_us asinstable_nl_mean asinstable_nl_sum pop_count_mean pop_count_sum pop_density_mean {
				by dist_o: gen L_`x'=`x'[_n-1]
			}
			tempfile light_o
			save "`light_o'", replace
		restore

		merge m:1 country year dist_o using "`light_o'", keep(master using match) gen(merge_light_o)
		drop if merge_light_o==2 /*Those that did not match. Not all district recorded origin migrants of course*/
		drop merge_light_o

		foreach x in stable_nl_mean stable_nl_sum Ym_us Yagm_us asinstable_nl_mean asinstable_nl_sum topog_mean topog_max distance_mean sickle_mean pop_count_mean pop_count_sum pop_density_mean ///
					L_stable_nl_mean L_stable_nl_sum L_Ym_us L_Yagm_us L_asinstable_nl_mean L_asinstable_nl_sum L_pop_count_mean L_pop_count_sum L_pop_density_mean {
		rename `x' `x'_o
		}

		*merging with NIGHTLIGHTS-Y DESTINATION. nl variable already has +0.01
		preserve
			use "${work}/NIGHTLIGHT.dta", clear
			drop cf_nl_mean cf_nl_sum raw_high9_mean raw_high9_sum raw_nl_mean raw_nl_sum n_pixels dist_name sample2_survey lstable_nl_mean lstable_nl_sum lYm_us lYagm_us
			*Lagged variables
			sort dist_d year
			foreach x in stable_nl_mean stable_nl_sum Ym_us Yagm_us asinstable_nl_mean asinstable_nl_sum pop_count_mean pop_count_sum pop_density_mean {
				by dist_d: gen L_`x'=`x'[_n-1]
			}
			tempfile light_d
			save "`light_d'", replace
		restore

		merge m:1 country year dist_d using "`light_d'", keep(master using match) gen(merge_light_d)
		drop if merge_light_d==2 /*Those that did not match. Not all district recorded origin migrants of course*/
		drop merge_light_d

		foreach x in stable_nl_mean stable_nl_sum Ym_us Yagm_us asinstable_nl_mean asinstable_nl_sum topog_mean topog_max distance_mean sickle_mean pop_count_mean pop_count_sum pop_density_mean ///
					L_stable_nl_mean L_stable_nl_sum L_Ym_us L_Yagm_us L_asinstable_nl_mean L_asinstable_nl_sum L_pop_count_mean L_pop_count_sum L_pop_density_mean {
		rename `x' `x'_d
		}

		*/
*Renaming year as year of migration
rename year year_mig
label var year_mig "Year when individual decided to migrate"

		/*
		*** vars FOR REGRESSIONS ***
		gen dif_nl_mean=ln(stable_nl_mean_d)-ln(stable_nl_mean_o)
		gen dif_nl_sum=ln(stable_nl_sum_d)-ln(stable_nl_sum_o)
		gen dif_Ym_us=ln(Ym_us_d)-ln(Ym_us_o)
		gen dif_Yagm_us=ln(Yagm_us_d)-ln(Yagm_us_o)
		gen dif_nls_mean=asinstable_nl_mean_d-asinstable_nl_mean_o
		gen dif_nls_sum=asinstable_nl_sum_d-asinstable_nl_sum_o

		sort country hhid pid

		foreach x in pre inc spr bed art {
			gen dif_`x'=mean_`x'_d-mean_`x'_o
			label var dif_`x' "mean_`x'_d-mean_`x'_o"
		}
		foreach x in a b c d e {
			gen dif_mei_`x'=p_mean_pre_`x'_d-p_mean_pre_`x'_o
			label var dif_mei_`x' "p_mean_pre_`x'_d-p_mean_pre_`x'_o"
			gen L_dif_mei_`x'=L_p_mean_pre_`x'_d-L_p_mean_pre_`x'_o
			label var L_dif_mei_`x' "dif_mei_`x' a year back"
		}

		*Lagged variables
		gen L_dif_nl_mean=ln(L_stable_nl_mean_d)-ln(L_stable_nl_mean_o)
		gen L_dif_nl_sum=ln(L_stable_nl_sum_d)-ln(L_stable_nl_sum_o)
		gen L_dif_Ym_us=ln(L_Ym_us_d)-ln(L_Ym_us_o)
		gen L_dif_Yagm_us=ln(L_Yagm_us_d)-ln(L_Yagm_us_o)
		gen L_dif_nls_mean=L_asinstable_nl_mean_d-L_asinstable_nl_mean_o
		gen L_dif_nls_sum=L_asinstable_nl_sum_d-L_asinstable_nl_sum_o

		foreach x in pre inc spr bed art {
			gen L_dif_`x'=L_mean_`x'_d-L_mean_`x'_o
			label var L_dif_`x' "dif_`x' a year back"
		}

		*Generating another dif_pre adjusting by altitude destiny-origin (topog_mean). Also, adding population and distance
		gen dif_pre_alt=(mean_pre_d-mean_pre_o)*(topog_mean_d-topog_mean_o)
		label var dif_pre_alt "(mean_pre_d-mean_pre_o)*(mean_altitude_d-mean_altitude_o)"
		gen dif_alt=topog_mean_d-topog_mean_o
		label var dif_alt "mean_altitude_d-mean_altitude_o"
		gen dif_dis_roads=distance_mean_d-distance_mean_o
		label var dif_dis_roads "mean_distance_roads_d-mean_distance_roads_o"
		gen dif_sickle=sickle_mean_d-sickle_mean_o
		label var dif_sickle "mean_Sickle_d-mean_Sickle_o"
		*Population
		gen dif_pop=pop_count_mean_d-pop_count_mean_o
		label var dif_pop "mean_pop_d-mean_pop_o(per 1km)"
		gen dif_pop_den=pop_density_mean_d- pop_density_mean_o
		label var dif_pop_den "mean_pop_den_d-mean_pop_den_o(per 1kmx1km)"
		gen L_dif_pop=L_pop_count_mean_d-L_pop_count_mean_o
		label var L_dif_pop "L_mean_pop_d-L_mean_pop_o(per 1km)"
		gen L_dif_pop_den=L_pop_density_mean_d- L_pop_density_mean_o
		label var L_dif_pop_den "L_mean_pop_den_d-L_mean_pop_den_o(per 1kmx1km)"

		*/
*Migration data
gen between_mig=.
replace between_mig=1 if mig_ind2==1
replace between_mig=0 if mig_ind2==2
label var between_mig "1: Between Migration; 0: Within Migration"

****** CENTROIDS *****
**********************
*Destination
preserve
	use "${work}/CENTROIDS_WGS84_d.dta", clear
	drop id dist_dname
	tempfile centroid_d
	save "`centroid_d'", replace 
restore
merge m:1 country dist_d using "`centroid_d'", keep(master using match) gen(merge_cen1)
drop if merge_cen1==2 
drop merge_cen1
rename (lon_wgs84 lat_wgs84) (lon_d lat_d)
label var lon_d "Longitud in Degrees WGS84-Destination"
label var lat_d "Latitud in Degrees WGS84-Destination"
*Origin
preserve
	use "${work}/CENTROIDS_WGS84_d.dta", clear
	drop id dist_dname
	rename dist_d dist_o
	tempfile centroid_o
	save "`centroid_o'", replace 
restore
merge m:1 country dist_o using "`centroid_o'", keep(master using match) gen(merge_cen2) /*8398 with no info of origin for Malawi 2004/2005 as not info exists in surveys*/
drop merge_cen2
rename (lon_wgs84 lat_wgs84) (lon_o lat_o)
label var lon_o "Longitud in Degrees WGS84-Origin"
label var lat_o "Latitud in Degrees WGS84-Origin"

*********** CALCULATING DISTANCE USING GREAT-CIRCLE FORMULA (HAVERSINE AND VINCENTY)
vincenty lat_d lon_d lat_o lon_o, v(vin_distance) hav(hav_distance) inkm
label var vin_distance "Vicenty Distance Destination-Origin"
label var hav_distance "Haversine Distance Destination-Origin"
*Vincenty distance yields missing when both origin and destination are the same. Need to replace to zero distance, like in hav_distance
replace vin_distance=0 if vin_distance==. & hav_distance==0

		/*
		*xtsum for within and between variation. 
		*Within variation – variation over time or given individual (time-variant).
		*Between variation – variation across individual (time-invariant).
		*Overall variation : variation overtime and individuals.
		preserve
			keep if dist_d==dist_dx
			*Setting XTSET
			xtset id year_mig

			foreach var of varlist between_mig dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance {
				display "*********************"
				display "The Variable is `var'"
				display "*********************"
				xtsum `var'
				sort id year_mig
				bys country: xtsum `var'
			}
		restore

		*TABLE: DESCRIPTIVE STATISTICS. See Table 3 in Fafchapms-Shilpi (2012). Still to do the table if we use it

		preserve /*Collapsing like this controls for the fact that each country has different set of alternative districts*/
				collapse (mean) dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance, by(id between_mig mig_real) 
				gen mimi=0
				replace mimi=1 if mig_real==0
				drop mig_real
				rename mimi mig_real /*ttest does mean(0)-mean(1), so I flipped the variable*/

				*Making Table to save results
						*Between Migrants
				matrix define between=J(6,3,.) 
					matrix colnames between= coefficient_0 coefficient_1 P_value 
					matrix rownames between= dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance
				local j=1
				foreach var of varlist dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance {
					local col=1
					display "*****************************************************************"
					display " `var' Actual Destination-Alternative Destination for Between_Mig=1"
					display "*****************************************************************"
							ttest `var' if between_mig==1, by(mig_real) 
							matrix between[`j',`col']=round(r(mu_1), .001)
							matrix between[`j',`col'+1]=round(r(mu_2), .001)
							matrix between[`j',`col'+2]=round(r(p), .001)
							local j=`j'+1
							}
				matrix list between

						*Within Migrants
				matrix define within=J(6,3,.) 
					matrix colnames within= coefficient_0 coefficient_1 P_value 
					matrix rownames within= dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance
				local j=1
				foreach var of varlist dif_nl_mean dif_nl_sum dif_Ym_us dif_Yagm_us dif_pre vin_distance {
					local col=1
					display "*****************************************************************"
					display " `var' Actual Destination-Alternative Destination for Between_Mig=0"
					display "*****************************************************************"
							ttest `var' if between_mig==0, by(mig_real) 
							matrix within[`j',`col']=round(r(mu_1), .001)
							matrix within[`j',`col'+1]=round(r(mu_2), .001)
							matrix within[`j',`col'+2]=round(r(p), .001)
							local j=`j'+1
							}
				matrix list within
				putexcel set "${results2}/MIG_descriptive.xlsx", modify sheet("T14witvsbet") 
				putexcel A3=matrix(between)
				putexcel E3=matrix(within)
		restore
		*/


*Generating FE by country and country-survey
*country
gen con=0
replace con=1 if country=="Malawi"
replace con=2 if country=="Tanzania"
replace con=3 if country=="Uganda"
label define country 1 "Malawi" 2 "Tanzania" 3 "Uganda"
label values con country

tab country, generate(d_country)
rename (d_country1 d_country2 d_country3) (d_Malawi d_Tanzania d_Uganda)
*country+survey
gen str country_survey = country + "-" +  survey
tab country_survey, generate(d_coun_sur)	
rename (d_coun_sur1 d_coun_sur2 d_coun_sur3 d_coun_sur4 d_coun_sur5 d_coun_sur6 d_coun_sur7 d_coun_sur8 d_coun_sur9 d_coun_sur10 d_coun_sur11) ///
	   (d_mal_sur1 d_mal_sur2 d_mal_sur3 d_mal_sur4 d_tan_sur1 d_tan_sur2 d_tan_sur3 d_uga_sur1 d_uga_sur2 d_uga_sur3 d_uga_sur4)
gen con_sur=0
replace con_sur=11 if country_survey=="Malawi-Survey-2004-2005"
replace con_sur=12 if country_survey=="Malawi-Survey-2010-2011"
replace con_sur=13 if country_survey=="Malawi-Survey-2013"
replace con_sur=14 if country_survey=="Malawi-Survey-2016-2017"
replace con_sur=21 if country_survey=="Tanzania-Survey-2008-2009"
replace con_sur=22 if country_survey=="Tanzania-Survey-2010-2011"
replace con_sur=23 if country_survey=="Tanzania-Survey-2012-2013"
replace con_sur=31 if country_survey=="Uganda-Survey-2009-2010"
replace con_sur=32 if country_survey=="Uganda-Survey-2010-2011"
replace con_sur=33 if country_survey=="Uganda-Survey-2011-2012"
replace con_sur=34 if country_survey=="Uganda-Survey-2013-2014"
label define surveys 11 "Malawi-Survey-2004-2005" 12 "Malawi-Survey-2010-2011" 13 "Malawi-Survey-2013" 14 "Malawi-Survey-2016-2017" 21 "Tanzania-Survey-2008-2009" 22 "Tanzania-Survey-2010-2011" 23 "Tanzania-Survey-2012-2013" ///
					 31 "Uganda-Survey-2009-2010" 32 "Uganda-Survey-2010-2011" 33 "Uganda-Survey-2011-2012" 34 "Uganda-Survey-2013-2014"
label values con_sur surveys
*To prove that both con_sur and country_survey are the same. I run:
sum d_mal_sur* d_tan_sur* d_uga_sur*
sum i.con_sur

*Saving huge dataset only for Malawi
keep if country=="Malawi"

save "${work2}/mignomig_individuals_malawi.dta", replace 








