*********************************************************************************
* 			THIS PROGRAM BUILDS A PANEL DATA SET AS SUGGESTED BY JOSELLIN THUILLIEZ *
*			AND RUNS THE REGRESSIONS FOR INDIVIDUAL ANALYSIS
*			uses file "${work}/mig_individuals.dta" in 8000_... do file rUN THIS BEFORE
*		Identical to 9001_... file but using CRU-CHRIPS data
*                WRITTEN BY LUIS GUILLERMO BECERRA                              *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 11000
set maxvar 32000
cap log close
			
*cd "/home/l.becerra/U/PSE-Proposal Malaria and paper/INPUT"
*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
*cd "U:\PSE-Proposal Malaria and paper\INPUT"
cd "C:\Users\PSE-Proposal Malaria and paper\INPUT"

global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER"
global paper2	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS\panel_josellin"
global results2  "..\RESULTS V2"

*****INSTALLING PACKAGES NEEDED FOR REGRESSIONS

	*Run to install package to calculate distances
	net from http://www-personal.umich.edu/~nicholsa/stata
	net install vincenty

/*	* Install ftools (remove program if it existed previously)
	cap ado uninstall moresyntax
	cap ado uninstall ftools
	
	
	rreia/ftools/tree/master/src")

	* Install reghdfe 4.x
	cap ado uninstall reghdfe
	net install reghdfe, from("https://github.com/sergiocorreia/reghdfe/tree/master/src")

	* Install boottest for Stata 11 and 12
	if (c(version)<13) cap ado uninstall boottest
	if (c(version)<13) ssc install boottest

	* Install moremata (sometimes used by ftools but not needed for reghdfe)
	cap ssc install moremata

	* Install ivreg2, the core package
	ssc install ivreg2

	* Finally, install this package
	cap ado uninstall ivreg2hdfe
	cap ado uninstall ivreghdfe
	net install ivreghdfe, from(https://github.com/sergiocorreia/ivreg2_demo/raw/master/)
	
	ssc install reghdfe
*/
*Install file for postestimation esttab-estout 
ssc install erepost
ssc install latab
ssc install balancetable
	
use "${work2}/mignomig_individuals_malawi.dta", replace

*keep if between_mig==1 & dist_o!=dist_d
*keep if mig_real==1 // keeping only migrants without considering the alternatives of migrating to other districts

keep id id_HH eaid survey country region dist_o year_mig dist_d mig_real reason_migrate vin_distance d_Malawi d_Tanzania d_Uganda country_survey d_mal_sur1-d_uga_sur4 con_sur mig_hht4 con age_years age_bracket sex rural ///
		kids5 per_hhkids5 kids5_mig per_hhkids5_mig eduyears eduhigh hhsize hh_shock* hh_geo_dist* hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD dist_dname dist_oname mig_ind2 mig_rural mig_urban language_hh hh_b14 k_* ///
		hh_e19b work_hh_head* Y* Yag* agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other hh_c14 noedu_mar_preg hh_d40 hh_b24 hh_b26* rel_to_head sex_hh_head moduleB_resp
rename (agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other)  Y_=
drop if dist_d==1106 /*Dropping Likoma*/

*Fix missing dist_o for mig_ind2==2
replace dist_o=dist_d if mig_ind2==2 & survey=="Survey-2004-2005"
replace dist_oname=dist_dname if mig_ind2==2 & survey=="Survey-2004-2005"

*Fix missing dist_o for no migrants
replace dist_o=dist_d if mig_ind2==0
replace dist_oname=dist_dname if mig_ind2==0

*Fixing variable of migration 1/0
replace mig_real=0 if mig_ind2==0

replace reason_migrate=. if mig_ind2==0 /*some missclassified*/

*Filling the gaps to have balanced panel 1999-2016
gen year=year_mig
replace year=2000 if mig_ind2==0 /*Assigning year=2000 for no migrants ut only to do the panel. As there are people from 1999-2016 tsset fills out the panel*/
tsset id year, yearly 
tsfill, full

foreach var of varlist survey country con mig_hht4 dist_o dist_d country_survey con_sur year_mig age_years age_bracket sex rural eduyears eduhigh vin_distance ///
						eaid region kids5* per_hhkids5* hhsize mig_ind2 mig_rural mig_urban language_hh ///
					   reason_migrate hh_shock* hh_geo_dist* hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD dist_dname dist_oname hh_b14 k_* hh_e19b work_hh_head* Y* hh_c14 noedu_mar_preg hh_d40 ///
					   hh_b24 hh_b26* id_HH rel_to_head sex_hh_head moduleB_resp {
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
}		
drop d_Malawi d_Tanzania d_Uganda d_tan* d_uga* d_mal*

save "${work2}\temporal_mignomig.dta", replace 
use "${work2}\temporal_mignomig.dta", clear

replace vin_distance=0 if dist_d==dist_o

*Merging with main events in the community (drought-floods-epidemics-price_change)
merge m:1 survey dist_o year using "${work2}\com_events.dta", keep(master using match) gen(merge_event)
drop merge_event

*Merging with masaf in the community
merge m:1 dist_o year using "${work2}\com_masaf.dta", keep(master using match) gen(merge_masaf)
drop merge_masaf

**********************************************************
* CHECKING ROLL BACK MALARIA PROGRAM AT NATIONAL LEVEL FOR MAL-TAN-UGA
*********************************************************************
gen rollback=0
replace rollback=1 if country=="Malawi" & year>=2006
*replace rollback=1 if country=="Tanzania" & year>=2003
*replace rollback=1 if country=="Uganda" & year>=2004
label var rollback "Starting year of Roll Back Malaria Program"		
		
*Creating 2 versions of mig_real
rename mig_real mig_real1
gen mig_real2=mig_real1 
bys id: replace mig_real1=0 if year<year_mig
bys id: replace mig_real1=1 if year>year_mig  
replace mig_real2=0 if mig_real2==.	
replace mig_real1=0 if mig_real1==.
sort id year survey con* 
order id year survey con* country* region eaid rural sex hhsize rural mig_real* year_mig reason_migrate mig_hht4 dist* vin_distance age* edu*  kids5* per_hhkids5* rollback hh_shock*

*Redifinig the age categories based on the age they have in each year
gen age_years2=. 
replace age_years2=age_years if survey=="Survey-2004-2005" & year==2004
replace age_years2=age_years if survey=="Survey-2010-2011" & year==2010
replace age_years2=age_years if survey=="Survey-2013" & year==2013
replace age_years2=age_years if survey=="Survey-2016-2017" & year==2016
bys id (year): replace age_years2=age_years2[_n-1]+1 if age_years2==.

local i=0 /*I did in this way as by goes for each year, until complete all missings*/
forvalues i = 1/17 {
	bys id (year): replace age_years2=age_years2[_n+1]-1 if age_years2==.
	local i= `i' +1
}
replace age_years2=. if age_years2<0

gen age_migrate=0
replace age_migrate=age_years - (2016-year_mig) if survey=="Survey-2016-2017" /*Migrants in 2016-2017 Survey*/
replace age_migrate=age_years - (2013-year_mig) if survey=="Survey-2013" /*Migrants in 2013 Survey*/
replace age_migrate=age_years - (2010-year_mig) if survey=="Survey-2010-2011" /*Migrants in 2010-2011 Survey*/
replace age_migrate=age_years - (2004-year_mig) if survey=="Survey-2004-2005" /*Migrants in 2004-2005 Survey*/
replace age_migrate=0 if age_migrate==-1 /*Those that were in the mother's womb*/
replace age_migrate=. if age_migrate<0 /*Those 23 with negative age of migration. Better to missing*/

gen age_bracket5=.
replace age_bracket5=1 if age_migrate>=10 & age_migrate<=17 & age_migrate!=.
replace age_bracket5=2 if age_migrate>=18 & age_migrate<=27 & age_migrate!=.
replace age_bracket5=3 if age_migrate>=28 & age_migrate<=37 & age_migrate!=.
replace age_bracket5=4 if age_migrate>=38 & age_migrate<=47 & age_migrate!=.
replace age_bracket5=5 if age_migrate>=48 & age_migrate<=57 & age_migrate!=.
label define AGE_BRACKET5 1 "age (10-17)" 2 "age (18-27)" 3 "age (28-37)" 4 "age (38-47)" 5 "age (48-57)" 
label values age_bracket5 AGE_BRACKET5 

*New moving AGE_Brackets to capture migrants-no migrants
gen age_bracket6=. 
replace age_bracket6=1 if age_years2>=10 & age_years2<=17 & age_years2!=.
replace age_bracket6=2 if age_years2>=18 & age_years2<=27 & age_years2!=.
replace age_bracket6=3 if age_years2>=28 & age_years2<=37 & age_years2!=.
replace age_bracket6=4 if age_years2>=38 & age_years2<=47 & age_years2!=.
replace age_bracket6=5 if age_years2>=48 & age_years2<=57 & age_years2!=.

label values age_bracket6 AGE_BRACKET5 

*Defining those migrating 5 years ago or less in the surveys. To keep similar age idea as in Baez-Mueller et al
gen age_ago=0
replace age_ago =age_years-age_migrate
label var age_ago "age_years-age_migrate"

*Redefining sex
label define sexx 1 "FEMALE" 0 "MALE"
gen sexx=.
replace sexx=1 if sex==2
replace sexx=0 if sex==1
drop sex
rename sexx sex
label values sex sexx

*Renaming year to avoid confusion
rename year yearly
sort id yearly
gen drought4=0
sort id yearly
bys id: replace drought4=1 if drought1[_n+1]==1 /*Lagged drought*/
label variable drought4 "drought1(t-1)"

*Generating ea different id for FE
egen ea_ID=group(eaid)

*Between district dummy
gen within_dist=0
replace within_dist=1 if mig_ind2==2

*Variable of Primary education
gen primary=(eduyears>7)
replace primary=. if eduyears==.

*Fixing some bad classifications for hh_b14. Better to missing. They declared moving inside district but report of dist_o dist_d says it was between district.
replace hh_b14=. if mig_ind2==1 & (hh_b14==5|hh_b14==7)
replace hh_b14=. if mig_ind2==2 & (hh_b14==3|hh_b14==6)

tab hh_b14 mig_ind2 /*Correctly classified*/

*Including data of droughts SPEI SPI indeces
merge m:1 dist_o yearly using "${work2}\SPEI_SPI.dta", keep(master using match) gen(merge_temp)
drop if merge_temp==2 /*those are for Uganda, Tanzania and Malawi(before 2000)*/
drop merge_temp
sort id yearly

*Table. Droughts vs no droughts district at origin to test parallel trends
preserve
	use "${work}\WEATHER_mean_yearly.dta", clear
	keep if country=="Malawi"
	keep dist_d year *chrips* *modis*
	keep if year>1998
	rename (year dist_d) (yearly dist_o)
	tempfile wea
	save "`wea'", replace
restore
merge m:1 dist_o yearly using "`wea'", keep(master using match) gen(merge_weather)  
drop if merge_weather==2
drop merge_weather /*The not matches are for 2004-2005 survey which did not report dist_o*/

*Creating environment for the Balance Table
tabulate age_bracket6, generate(age_bracket_)
label variable age_bracket_1 "age-bracket(10-17)"
label variable age_bracket_2 "age-bracket(18-27)"
label variable age_bracket_3 "age-bracket(28-37)"
label variable age_bracket_4 "age-bracket(38-47)"
label variable age_bracket_5 "age-bracket(48-57)"
label variable mig_real2 "Migration Dummy"
label variable drought1 "Drought reported in one EA or more in the dist-o"
label variable drought2	"Drought reported in 10\% of more of EA"
label var spi12chr_dro_d2 "Dummy spi12-drought-agro (<-1)"
label var spi12chr_dro_d2ext "Dummy spi12-drought-agro (<-2)"

global balance1 "ave_rain_chrips_max ave_rain_chrips_mean ave_rain_chrips_min ave_rain_chrips_sum a2_ave_rain_chrips_mean sd_ave_rain_chrips_mean sd_ave_rain_chrips_sum ave_temp_modis_max ave_temp_modis_mean ave_temp_modis_min a2_ave_temp_modis_mean sd_ave_temp_modis_mean"
global balance2 "sex eduyears primary vin_distance per_hhkids5 mig_rural mig_urban hhsize age_bracket_1 age_bracket_2 age_bracket_3 age_bracket_4 age_bracket_5"
global balance "$balance2 $balance1"

label var ave_rain_chrips_max "Mean of monthly maximum rainfall during year(mm)-CHIRPS" 
label var ave_rain_chrips_mean "Mean of monthly average rainfall during year(mm)-CHIRPS"
label var ave_rain_chrips_min "Mean of monthly minimim rainfall during year(mm)-CHIRPS"
label var ave_rain_chrips_sum "Mean of monthly cumulative rainfall during year(mm)-CHIRPS"
label var ave_temp_modis_max "Mean of monthly maximum temperature during year(degrees)-MODIS"
label var ave_temp_modis_mean "Mean of monthly average temperature during year(degrees)-MODIS"
label var ave_temp_modis_min "Mean of monthly minimum temperature during year(degrees)-MODIS"
label var a2_ave_rain_chrips_mean "Anomalies-Mean of monthly average rainfall during year(mm)-CHIRPS"
label var a2_ave_temp_modis_mean "Anomalies-Mean of monthly average temperature during year(degrees)-MODIS"
label var sd_ave_rain_chrips_mean "SD of monthly average rainfall during year(mm)-CHIRPS"
label var sd_ave_rain_chrips_sum "SD of monthly cumulative rainfall during year(mm)-CHIRPS"
label var sd_ave_temp_modis_mean "SD of monthly average temperature during year(degrees)-MODIS"

label var sex "Sex of the individual"
label var eduyears "Number of years of education"
label var primary "Dummy for at least primary education"
label var vin_distance "Vincenty distance dist-origin to dist-destination"
label var per_hhkids5 "Percentage of kids less than 5 years old in the Household"
label var mig_rural "Dummy for migrants coming from rural areas"
label var mig_urban "Dummy for migrants coming from urban areas"
label var hhsize "Size of the Household"

*Using EA measure. I added {l*{4}c} by {Hclclclc} in the tex file to import in overleaf. Import it directly now
*estimates table _all, p stats(N)	
balancetable drought1 $balance using "${results2}\9002_panel_year_drought_o\balance_table\balance_EA.tex" if age_bracket6<6 & (mig_ind2==1|mig_ind2==2), replace fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///
			prehead("\begin{tabular}{l*{4}c}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Between-Within-district Migrants} \\")
balancetable drought1 $balance using "${results2}\9002_panel_year_drought_o\balance_table\balance_EA.tex" if age_bracket6<6 & mig_ind2==0, append fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs  ///				
			prehead("\begin{tabular}{Hclclclc}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: No Migrants} \\")
			
*Using SPI measure
*estimates table _all, p stats(N) /*spi24chr_dro_d2*/
balancetable spi12chr_dro_d2  $balance using "${results2}\9002_panel_year_drought_o\balance_table\balance_SPI.tex" if age_bracket6<6 & (mig_ind2==1|mig_ind2==2), replace fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///
			prehead("\begin{tabular}{l*{4}c}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Between-Within-district Migrants} \\")
balancetable spi12chr_dro_d2  $balance using "${results2}\9002_panel_year_drought_o\balance_table\balance_SPI.tex" if age_bracket6<6 & mig_ind2==0, append fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///				
			prehead("\begin{tabular}{Hclclclc}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: No Migrants} \\")

*Anther Table-Descriptive Statistics. From sex onwards, statistics can be interpreted as to only migrants
*Table1

global descriptive "mig_real2 drought1 drought2 spi12chr_dro_d2 spi12chr_dro_d2ext ave_rain_chrips_mean ave_rain_chrips_sum ave_temp_modis_mean sex eduyears primary vin_distance per_hhkids5 mig_rural mig_urban hhsize age_bracket_*"
estpost summ $descriptive
est store table_des1
esttab table_des1 using "${results2}/9002_panel_year_drought_o/balance_table/descriptive_stats1.tex", cells("count(fmt(0) label(Observations)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(2) label(Min)) max(fmt(2) label(Max))") ///
		booktabs nonum label nostar unstack noobs compress nogaps alignment(c) replace substitute("<-" "$<-$" ) mlabel(none)  nomtitles nodepvars ///
		prehead("\begin{tabular}{l*{6}{c}} \toprule\\") ///
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\")

*Table2
estpost tabstat $descriptive, by(mig_ind2) statistics(mean sd) columns(statistics) listwise
est store table_des2
esttab table_des2 using "${results2}/9002_panel_year_drought_o/balance_table/descriptive_stats2.tex", nonumber nonotes mlabels(none) ///
		main(mean %12.2f) aux(sd %12.2f) nostar unstack noobs label compress nogaps alignment(c) replace booktabs substitute("<-" "$<-$" ) nomtitles nodepvars ///
		prehead("\begin{tabular}{l*{5}{c}} \toprule\\") /// 
		posthead(" & No migrants & Between Migrants & Within Migrants & All Migrants  \\ \cmidrule(lr){1-5} \addlinespace[-2ex] \\")   
	
*Table3		
estpost tabstat $descriptive, stats(n mean sd min max) columns(statistics) listwise
est store table_des3
esttab table_des3 using "${results2}/9002_panel_year_drought_o/balance_table/descriptive_stats3.tex", nonumber nonote mlabels(none) wide ///
		cells("count(fmt(0) label(Observations)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(2) label(Min)) max(fmt(2) label(Max))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs substitute("<-" "$<-$" ) ///
		prehead("\begin{tabular}{l*{6}{c}} \toprule\\") ///
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\") 

*Kernel density of migration by age. 
graph drop _all
twoway lpoly mig_real1 age_years2 if (mig_ind2==0|mig_ind2==1 | mig_ind2==2) & (age_years2>=10 & age_years2<65) & spi24chr_dro_d==0, kernel(epanechnikov) xscale(range(10 65)) xlabel(10(10)65) ytitle("Migration Density") ///
				 xtitle("Age Migrate") title("Migration Kernel Density by age-Migrants and No Migrants") subtitle("Local polynomial smoothing") name(ker_mignomigbet_age) saving("${paper2}/PAPER/ker_mignomigbet_age.gph", replace)
twoway lpoly mig_real1 age_bracket6 if (mig_ind2==0|mig_ind2==1 | mig_ind2==2) & (age_years2>=10 & age_years2<65) & spi24chr_dro_d==0, kernel(epanechnikov) xlabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47" 5 "48-57") ytitle("Migration Density") ///
				 xtitle("Age Migrate (bracket)") title("Migration Kernel Density by age-Migrants and No Migrants") subtitle("Local polynomial smoothing") name(ker_mignomigbet_age_bracket) saving("${paper2}/PAPER/ker_mignomigbet_age_bracket.gph", replace)			


*** Defining sample
global sample "mig_ind2==0|mig_ind2==1 | mig_ind2==2"
global folder "mig_nomig" 
global sk "12" /*spei and spi using scale*/
global drought_index "spi${sk}chr_dro_d2 spi${sk}chr_dro_d2ext"
*global drought_index "spi${sk}chr_i spi${sk}chr_igro spi${sk}chr_ipos spi${sk}chr_dro spi${sk}chr_dro_l2 spi${sk}chr_dro_d spi${sk}chr_dro_d2 spi${sk}chr_droext spi${sk}chr_dro_l2ext spi${sk}chr_dro_dext spi${sk}chr_dro_d2ext"
/*spei${sk}cru_i spei${sk}cru_igro spei${sk}cru_ipos spei${sk}cru_dro spei${sk}cru_dro_l2 spei${sk}cru_dro_d spei${sk}cru_dro_d2 spi${sk}cru_i spi${sk}cru_igro spi${sk}cru_ipos spi${sk}cru_dro spi${sk}cru_dro_l2 spi${sk}cru_dro_d spi${sk}cru_dro_d2"*/
global age_bracket "age_bracket6"

*Generating a new outcome migration variable to take into account mig_ind2 and use Multinomial LOGIT.
gen mig_real1_mlogit=0
replace mig_real1_mlogit=mig_ind2 if mig_real1==1
gen mig_real2_mlogit=0
replace mig_real2_mlogit=mig_ind2 if mig_real2==1

gen mig_real1_reg=mig_real1
gen mig_real2_reg=mig_real2
gen mig_real1_regife=mig_real1
gen mig_real2_regife=mig_real2
gen mig_real1_probit=mig_real1
gen mig_real2_probit=mig_real2 // those duplicates were to use them easier in the loops below
		 
****************************************
*All surveys LPM and probit. DROUGHT!!!! FOR MLOGIT https://data.princeton.edu/wws509/stata/mlogit CHECK
****************************************
foreach t in mlogit  { /*regife probit mlogit */
		estimates drop _all
		foreach migra in 2 {
		local fereg    "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}), vce(cluster dist_o)" 
		local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}), vce(cluster dist_o) factors(id yearly, 1)" 
		local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}), vce(cluster dist_o)" 
		local femlogit "primary vin_distance i.yearly           i.dist_d          if (${sample}), vce(cluster dist_o) iterate(1000) technique(nr) rrr difficult"  
	
		foreach x in  ${drought_index} { /*${drought_index}*/
		
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
					
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
					*local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
			
				foreach m in a {			
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`m'0' `fe`t''												
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'
					if ("`t'"=="regife"|"`t'"=="probit"|"`t'"=="reg"|"`t'"=="mlogit") {
							margins, dydx(`x' `x'age*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
							}
					else if ("`t'"=="xxxxx") {
						di "`t'"
						}
					}	
		drop `x'age* /*dropping each x generated of interactions*/
				}
			}		
		* Model a
		esttab `t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought.csv", ///
		indicate("Country-Year FE = *yearly*" "FE-Dest_Dist=*dist_d*") ///"Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Orig=*dist_o*"
		scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust converged) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/

		*Marginal Effects for interactions in probit-mlogit only
		esttab m`t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_mg.csv", scalars(N) ///
		se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/
}

****************************************
*All surveys LPM and probit. DROUGHT!!!! MALE-FEMALE
****************************************
foreach sex in 0 1 {
	estimates drop _all
	foreach t in mlogit  { /*reg regife probit mlogit*/
			
			foreach migra in 2 {
			local fereg    "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==`sex', vce(cluster dist_o)" 
			local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==`sex', vce(cluster dist_o) factors(id yearly, 1)" 
			local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==`sex', vce(cluster dist_o)" 
			local femlogit "primary vin_distance i.yearly           i.dist_d          if (${sample}) & sex==`sex', vce(cluster dist_o) iterate(1000) difficult rrr technique(nr)"
						
			foreach x in ${drought_index} {
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'							
							if ("`t'"=="regife"|"`t'"=="probit"|"`t'"=="reg"|"`t'"=="mlogit") {
								margins, dydx(`x' `x'age*) post /*For the margins*/
								cap estadd scalar R2_p=r2_p
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`m'`x'`migra'
							}
							else if ("`t'"=="xxxxx") {
								di "`t'"
							}
							}
				drop `x'age* /*dropping each x generated of interactions*/
					}
				}		
			* Model a
			esttab `t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'.csv", ///
			indicate("Country-Year FE = *yearly*" "FE-Dest_Dist=*dist_d*") ///"Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Orig=*dist_o*"
			scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust converged) ///
			order(eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
			replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
			*Marginal Effects for interactions in probit-mlogit only
			esttab m`t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'_mg.csv", scalars(N) se compress nogaps ///
			star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects `sex' Women=1, Men=0") /*margins also worked with reg, I will keep only for probit*/
	}
}

****************************************
*All surveys LPM and probit. DROUGHT ON FEMALE OUTCOMES, MARRIED PREGNANCY 
****************************************
rename Y* =_d
sum Yag_per_d 

*Defining sample of child-young marriage. 10-17 to keep as our age category. I prefer 13-20
gen young_girls=0
replace young_girls=1 if (age_years2>9 & age_years2<18) & sex==1
gen young_boys=0
replace young_boys=1 if (age_years2>9 & age_years2<18) & sex==0
gen young=0
replace young=1 if (age_years2>9 & age_years2<18)

* type of work of HH head 
tab work_hh_head_ag mig_ind2 if yearly==2000 & age_bracket6!=., column

* lobola
tab k_lobola mig_ind2 if yearly==2000 & age_bracket6!=. , column

* Married girls more likely to drop-out school or drop out for pregnancy in destination
tab noedu_mar_preg mig_ind2 if yearly==2000 & age_bracket6!=., column

*Married girls more likely to get pregnant in destination district (after migrating)
tab hh_d40 mig_ind2 if yearly==2000 & age_bracket6!=., column 
rename hh_d40 pregn

*Migrants for marriage are married more? in destination district (after migrating).
tab hh_b24 mig_ind2 if yearly==2000 & age_bracket6!=. & young_girls==1, column

gen marri=0 if hh_b24!=.
replace marri=1 if (hh_b24==1|hh_b24==2) /*married for monogamous or polygamous*/

*Filling up type of migrant of hh_b14 variable for no migrants
replace hh_b14=0 if hh_b14==.

*This number is closer to the real sample of mig-nomig used in the regressions
tab age_bracket6 mig_ind2 if yearly==2000

rename (work_hh_head_ag noedu_mar_preg) (hh_ag nedpr)

global outcomes "nedpr pregn marri"

estimates drop _all
foreach t in reg { /*reg regife probit */
	
			local fereg    "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o)" 
			local feregife "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o) factors(id yearly, 1)" 
			local feprobit "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o)"
								
		foreach y in ${outcomes}  {
					foreach x in ${drought_index} {	
							/*bootstrap, reps(100) seed(1):*/ `t' `y' c.`x'##i.mig_ind2 `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+7 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`x'`y'
							margins, dydx(`x' `x'age*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`x'`y'			
	
				}	
			}
	* Model a
	esttab `t'* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex1_young_outcomes.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
	order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
	replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
	
	*Marginal Effects for interactions in probit only
	*esttab mprobit*a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_outcomes_mg.csv", scalars(N) ///
	*se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/
}


****************************************
*All surveys LPM and probit. DROUGHT!!!! YOUNG BOYS AND GIRLS
****************************************
*comparing mig within vs nomig
gen mig=0 if mig_ind2!=.
replace mig=1 if mig_ind2==1|mig_ind2==2

reg mig_real2 c.spi12chr_dro_d2ext##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_boys==1, vce(cluster dist_o) /*gooddd*/
reg mig_real2 c.spi12chr_dro_d2ext##ib5.age_bracket6##i.mig primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==0, vce(cluster dist_o)
reg mig_real2 c.spi12chr_dro_d2ext##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==0, vce(cluster dist_o) /*goood*/
reg mig_real2 c.spi24chr_dro_d2##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==0, vce(cluster dist_o) /*Less*/

*girls. Results on migration between but not on marri-pregn related with droughts, but values of marri-pregn are already very high only for the fact of being migrants per se
reg mig_real2 c.spi12chr_dro_d2ext##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o) /*good*/
reg mig_real2 c.spi12chr_dro_d2ext##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==1, vce(cluster dist_o) /*good*/

reg marri c.spi24chr_dro_d2##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==1 & (mig_ind2!=1), vce(cluster dist_o) /*Interesting with 24*/
reg pregn c.spi24chr_dro_d2##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==1 & (mig_ind2!=1), vce(cluster dist_o)
reg pregn c.spi24chr_dro_d2##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==1 & (mig_ind2!=2), vce(cluster dist_o)
reg marri c.spi12chr_dro_d2##ib5.age_bracket6##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==1 & (mig_ind2!=2), vce(cluster dist_o)


foreach sex in 0 1 {
	estimates drop _all
	foreach t in mlogit  { /*reg regife probit*/
			
			foreach migra in 2 {
			local fereg    "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o)" 
			local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o) factors(id yearly, 1)" 
			local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o)" 
			local femlogit "primary vin_distance i.yearly           i.dist_d          if young==1 & sex==`sex', vce(cluster dist_o) iterate(1000) difficult technique(nr) rrr"
						
			foreach x in ${drought_index} {

				*a b, to generate reg_migra_indflows.csv
				local identif_reg0 "c.`x'##i.mig_ind2"
				local identif_regife0 "c.`x'##i.mig_ind2"
				local identif_probit0 "c.`x'##i.mig_ind2"
				local identif_mlogit0 "c.`x'" //c.`x'##i.mig_ind2
								
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`t'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+7 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`x'`migra'
							if ("`t'"=="regife"|"`t'"=="probit"|"`t'"=="reg"|"`t'"=="mlogit") {
								margins, dydx(`x'*) post /*For the margins*/
								cap estadd scalar R2_p=r2_p
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x'`migra'		
							}
							else if ("`t'"=="xxxxx") {
								di "`t'"
							}
						
					}
				}
			* Model a
			esttab `t'* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'_young.csv", ///
			indicate("Country-Year FE = *yearly*" "FE-Dest_Dist=*dist_d*") ///"Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Orig=*dist_o*"
			scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust converged) ///
			order(eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
			replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
			*Marginal Effects for interactions in probit-mlogit only
			esttab m`t'* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'_young_mg.csv", scalars(N) se compress nogaps ///
			star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects `sex' Women=1, Men=0") /*margins also worked with reg, I will keep only for probit*/
	}
}

****************************************
*All surveys LPM and probit. DROUGHT!!!! YOUNG BOYS AND GIRLS TABLE 1_pre
****************************************
global folder_tab "main_tables" /*between_district or between_and_within_district or within_district*/
global sk_tab "12" /*spei and spi using scale*/
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach x in $drought_index_tab {
	foreach mig in 1 2 { 
						gen `x'mig`mig'=0 if mig_ind2!=. & `x'!=.
						replace `x'mig`mig'=`x' if mig_ind2==`mig'
						}
}
*Changing names for the tables
label var vin_distance "Distance dist_o-dist_d"
label var primary "Dummy of primary education"

label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"

label var spi12chr_dro_d2mig1 "spi12-drought-agro (<-1) x Between Dist-MIG"
label var spi12chr_dro_d2mig2 "spi12-drought-agro (<-1) x Within Dist-MIG"

label var spi12chr_dro_d2extmig1 "spi12-drought-agro (<-2) x Between Dist-MIG"
label var spi12chr_dro_d2extmig2 "spi12-drought-agro (<-2) x Within Dist-MIG"

estimates drop _all
foreach sex in 0 1 {
	foreach x in $drought_index_tab {
				
			foreach t in mlogit { /*reg probit*/
					foreach migra in 2 {
					local fereg    "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o)" 
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==`sex', vce(cluster dist_o)" 
					local femlogit "primary vin_distance i.yearly           i.dist_d          if young==1 & sex==`sex', vce(cluster dist_o) iterate(1000) difficult technique(nr) rrr" 
				
					local identif_reg0 "c.`x' ib0.mig_ind2 `x'mig*"
					local identif_regife0 "c.`x' ib0.mig_ind2 `x'mig*"
					local identif_probit0 "c.`x' ib0.mig_ind2 `x'mig*"
					local identif_mlogit0 "c.`x'" //c.`x'##i.mig_ind2
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`t'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+7 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`x's`sex'
								if ("`t'"=="regife"|"`t'"=="probit"|"`t'"=="reg"|"`t'"=="mlogit") {
									margins, dydx(`x'*) post /*For the margins*/
									estadd scalar Ncluster=31
									cap estadd scalar R2_p=`R2_p'
									cap estadd scalar Pcorr= `Pcorr'
									estimates store m`t'`x's`sex'		
								}
								else if ("`t'"=="xxxxx") {
									di "`t'"
								}
							
						}
					}
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MEN)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab reg*spi*s1* mprobit*spi*s1* reg*spi*s0* mprobit*spi*s0* using "${results2}/9002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table1_pre_mignomig_drought_young.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr converged) drop(primary vin_distance *yearly*  *dist_*  _cons *con_sur*)  ///
order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


*probit mig_real2 i.spi12chr_dro_d2##i.mig_ind2 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young==1 & sex==1, vce(cluster dist_o) technique(bfgs) collinear
*probit mig_real2 spi12chr_dro_d2 ib5.age_bracket6 spi12chr_dro_d2age* primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==0, vce(cluster dist_o) /*better this one, not issues with convergence, shit results*/

*Interesting results. More marriage in between*****************************************
reg marri i.spi12chr_dro_d2##i.mig_ind2 primary vin_distance i.con_sur i.dist_d#i.yearly i.dist_o if young_girls==1, vce(cluster dist_o) 
probit marri i.spi12chr_dro_d2##i.mig_ind2 primary vin_distance i.con_sur i.dist_d#i.yearly i.dist_o if young_girls==1, vce(cluster dist_o)
reg mig_real2 i.spi12chr_dro_d2ext##i.mig_ind2 primary vin_distance i.con_sur i.dist_d#i.yearly i.dist_o if young_girls==1, vce(cluster dist_o)

**********************************************************************************************
** TESTING CAUSAL EFFECTS AS SUGGESTED BY LIAM IN THESIS COMMITTEE
*	MIG and dropout =f(drought) 
*	Not MIG and dropout =f(drought) 
**********************************************************************************************
*extra variables of income
foreach x in Yag Ynoag Ytransfer {
	gen `x'50=0 if `x'_per_d!=. & `x'_per_d<=1 & `x'_per_d>=0
	replace `x'50=1 if `x'_per_d>=0.5 & `x'_per_d<=1 & `x'_per_d>=0
}
rename Ytransfer50 Ytrans50

foreach v in nedpr pregn marri Yag50 Ynoag50 Ytrans50 {
	gen M_`v'=0 if mig_ind2!=. & `v'!=.
	replace M_`v'=1 if (mig_ind2==1|mig_ind2==2) & `v'==1 & mig_real1==1
	gen NM_`v'=0 if mig_ind2!=. & `v'!=.
	replace NM_`v'=1 if (mig_ind2==0) & `v'==1
	*Restricting to only those dropping out for instance
	gen M2_`v'=0 if mig_ind2!=. & `v'==1 
	replace M2_`v'=1 if (mig_ind2==1|mig_ind2==2) & `v'==1 & mig_real1==1
	}
	
global sample "mig_ind2==0|mig_ind2==1|mig_ind2==2"
global folder "mig_nomig" 
global sk "12" /*spei and spi using scale*/
global drought_index "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext" //spi${sk}chr_i spi${sk}chr_igro spi${sk}chr_ipos spi${sk}chr_dro spi${sk}chr_dro_l2 spi${sk}chr_dro_d spi${sk}chr_dro_d2 spi${sk}chr_droext spi${sk}chr_dro_l2ext spi${sk}chr_dro_dext spi${sk}chr_dro_d2ext"
/*spei${sk}cru_i spei${sk}cru_igro spei${sk}cru_ipos spei${sk}cru_dro spei${sk}cru_dro_l2 spei${sk}cru_dro_d spei${sk}cru_dro_d2 spi${sk}cru_i spi${sk}cru_igro spi${sk}cru_ipos spi${sk}cru_dro spi${sk}cru_dro_l2 spi${sk}cru_dro_d spi${sk}cru_dro_d2"*/
global age_bracket "age_bracket6"
global outcomes_mig1 "M_nedpr M_pregn M_marri M_Yag50 M_Ynoag50 M_Ytrans50"
global outcomes_mig2 "NM_nedpr NM_pregn NM_marri NM_Yag50 NM_Ynoag50 NM_Ytrans50"
global outcomes_mig3 "M2_nedpr M2_pregn M2_marri M2_Yag50 M2_Ynoag50 M2_Ytrans50" 
global outcomes_mig "$outcomes_mig1 $outcomes_mig2 $outcomes_mig3"

* a) version
estimates drop _all
foreach t in reg  { /*regife probit*/
	
			local fereg    "primary i.yearly i.con_sur i.dist_d i.dist_o if sex==1, vce(cluster dist_o)" 
			local feregife "primary i.yearly i.con_sur i.dist_d i.dist_o if sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
			local feprobit "primary i.yearly i.con_sur i.dist_d i.dist_o if sex==1, vce(cluster dist_o)" 
										
		foreach y in ${outcomes_mig}  {
				local reg_number=1
				foreach x in ${drought_index} {
			
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
							/*bootstrap, reps(100) seed(1):*/ `t' `y' c.`x' ib5.${age_bracket} `x'age* `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'spi`reg_number'`y'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'spi`reg_number'`y'
							local reg_number=`reg_number'+1
							drop `x'age* /*dropping each x generated of interactions*/
				} 
			}
	* Model a
	esttab `t'* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex1_outcomes_Liam.csv", ///
	indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") ///
	scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
	order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
	replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
	
	*Marginal Effects for interactions in probit only
	*esttab mprobit*a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_sex1_outcomes_Liam_mg.csv", scalars(N) ///
	*se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/
}

* b) version. Not many obs for age_bracket if I use young_girls. BEtter to use interaction with ##i.mig_ind2
estimates drop _all
foreach t in reg  { /*regife probit*/
	
			local fereg    "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o)" 
			local feregife "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o) factors(id yearly, 1)" 
			local feprobit "primary i.yearly i.con_sur i.dist_d i.dist_o if young_girls==1, vce(cluster dist_o)" 
										
		foreach y in ${outcomes_mig}  {
				local reg_number=1
				foreach x in ${drought_index} {
					
							/*bootstrap, reps(100) seed(1):*/  `t' `y' c.`x'##i.mig_ind2 `fe`t'' //
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+7 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'spi`reg_number'`y'
							margins, dydx(*`x'*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'spi`reg_number'`y'	
							local reg_number=`reg_number'+1
											} 
			}
	* Model a
	esttab `t'* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex1_young_outcomes_Liam.csv", ///
	indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") ///
	scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
	order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
	replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
	
	*Marginal Effects for interactions in probit only
	*esttab mprobit*a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_sex1_young_outcomes_Liam_mg.csv", scalars(N) ///
	*se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/
}


****************************************
*All surveys LPM and probit. DROUGHT!!!! MALE-FEMALE for reason 3=marriage
****************************************
global folder "mig_nomig" 
global sk "12" /*spei and spi using scale*/
global drought_index "spi${sk}chr_dro_d2 spi${sk}chr_dro_d2ext" //spi${sk}chr_i spi${sk}chr_igro spi${sk}chr_ipos spi${sk}chr_dro spi${sk}chr_dro_l2 spi${sk}chr_dro_d spi${sk}chr_dro_d2 spi${sk}chr_droext spi${sk}chr_dro_l2ext spi${sk}chr_dro_dext spi${sk}chr_dro_d2ext"
/*spei${sk}cru_i spei${sk}cru_igro spei${sk}cru_ipos spei${sk}cru_dro spei${sk}cru_dro_l2 spei${sk}cru_dro_d spei${sk}cru_dro_d2 spi${sk}cru_i spi${sk}cru_igro spi${sk}cru_ipos spi${sk}cru_dro spi${sk}cru_dro_l2 spi${sk}cru_dro_d spi${sk}cru_dro_d2"*/
global age_bracket "age_bracket6"

foreach r in 1 3 4 {
	cap drop sample_reason*
	gen sample_reason`r'=1 if (mig_ind2==0|mig_ind2==1|mig_ind2==2)
	replace sample_reason`r'=0 if reason_migrate!=`r' & (mig_ind2==1|mig_ind2==2) //excluding all not reason 3
	*global sample "sample_reason`r'==1"
	foreach sex in 0 1 {
		estimates drop _all
		foreach t in mlogit  { /*reg regife probit*/
				
				foreach migra in 2 {
				local fereg    "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sample_reason`r'==1 & sex==`sex', vce(cluster dist_o)" 
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sample_reason`r'==1 & sex==`sex', vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sample_reason`r'==1 & sex==`sex', vce(cluster dist_o)" 
				local femlogit "primary vin_distance i.yearly           i.dist_d          if sample_reason`r'==1 & sex==`sex', vce(cluster dist_o) iterate(1000) difficult technique(nr) rrr" 
							
				foreach x in ${drought_index} {
				
					foreach age in 1 2 3 4 { /*Baseline is category 5*/
							gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
							replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
							}
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x'`migra'
								if ("`t'"=="regife"|"`t'"=="probit"|"`t'"=="reg"|"`t'"=="mlogit") {
									margins, dydx(`x' `x'age*) post /*For the margins*/
									cap estadd scalar R2_p=r2_p
									estadd scalar Ncluster=31
									cap estadd scalar R2_p=`R2_p'
									cap estadd scalar Pcorr= `Pcorr'
									estimates store m`t'`m'`x'`migra'		
								}
								else if ("`t'"=="xxxxx") {
									di "`t'"
								}
							}
					drop `x'age* /*dropping each x generated of interactions*/
						}
					}		
				* Model a
				esttab `t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'_reason`r'.csv", ///
				indicate("Country-Year FE = *yearly*" "FE-Dest_Dist=*dist_d*") ///"Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Orig=*dist_o*"
				scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust converged) ///
				order(eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
				replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
				*Marginal Effects for interactions in probit only
				esttab m`t'a* using "${results2}/9002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'_reason`r'mg.csv", scalars(N) se compress nogaps ///
				star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects `sex' Women=1, Men=0") /*margins also worked with reg, I will keep only for probit*/
			}
	}
}


*************************
**** RE DOING FOR MLOGIT TABLE 7 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE INTERACIVE FE 
*************************
global folder_tab "main_tables" 
global sk_tab "12" /*spei and spi using scale*/
global drought_index "spi${sk}chr_dro_d2 spi${sk}chr_dro_d2ext" //spi${sk}chr_i spi${sk}chr_igro spi${sk}chr_ipos spi${sk}chr_dro spi${sk}chr_dro_l2 spi${sk}chr_dro_d spi${sk}chr_dro_d2 spi${sk}chr_droext spi${sk}chr_dro_l2ext spi${sk}chr_dro_dext spi${sk}chr_dro_d2ext"
/*spei${sk}cru_i spei${sk}cru_igro spei${sk}cru_ipos spei${sk}cru_dro spei${sk}cru_dro_l2 spei${sk}cru_dro_d spei${sk}cru_dro_d2 spi${sk}cru_i spi${sk}cru_igro spi${sk}cru_ipos spi${sk}cru_dro spi${sk}cru_dro_l2 spi${sk}cru_dro_d spi${sk}cru_dro_d2"*/
global age_bracket "age_bracket6"

cap drop sample_reason*
gen sample_reason3=1 if (mig_ind2==0|mig_ind2==1|mig_ind2==2)
replace sample_reason3=0 if reason_migrate!=3 & (mig_ind2==1|mig_ind2==2) //excluding all not reason 3

foreach x in spi12chr_dro_d2 spi12chr_dro_d2ext {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
			}
}

estimates drop _all
foreach t in mlogit  { 
		foreach migra in 2 {
		local femlogit "primary vin_distance i.yearly           i.dist_d          if sample_reason3==1 & sex==1, vce(cluster dist_o) iterate(1000) difficult technique(nr) rrr" 
					
		foreach x in ${drought_index} {
		
			/*
			foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
					*/
			*a b, to generate reg_migra_indflows.csv
			local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
			
				foreach m in a {
				
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra'_`t' `identif_`m'0' `fe`t''
						estadd scalar R2=e(mss)/(e(mss)+e(rss))
						estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
						estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
						estadd scalar Ncluster=31
						local R2_p=e(r2_p)
						cap estat classification
						estadd scalar Pcorr= r(P_corr)
						local Pcorr = r(P_corr)
						estimates store `t'`m'`x'`migra'
						*Margins
						margins, dydx(`x' `x'age*) post /*For the margins*/
						cap estadd scalar R2_p=r2_p
						estadd scalar Ncluster=31
						cap estadd scalar R2_p=`R2_p'
						cap estadd scalar Pcorr= `Pcorr'
						estimates store m`t'`m'`x'`migra'		
						
					}
			*drop `x'age* /*dropping each x generated of interactions*/
				}
			}
}

*Defining again as I add a new variable
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"

label var spi12chr_dro_d2age_bracket1 "spi12-drought-agro (<-1) x age (10-17)"
label var spi12chr_dro_d2age_bracket2 "spi12-drought-agro (<-1) x age (18-27)"
label var spi12chr_dro_d2age_bracket3 "spi12-drought-agro (<-1) x age (28-37)"
label var spi12chr_dro_d2age_bracket4 "spi12-drought-agro (<-1) x age (38-47)"

label var spi12chr_dro_d2extage_bracket1 "spi12-drought-agro (<-2) x age (10-17)"
label var spi12chr_dro_d2extage_bracket2 "spi12-drought-agro (<-2) x age (18-27)"
label var spi12chr_dro_d2extage_bracket3 "spi12-drought-agro (<-2) x age (28-37)"
label var spi12chr_dro_d2extage_bracket4 "spi12-drought-agro (<-2) x age (38-47)"
* Model a
local titles "& \multicolumn{2}{c}{MLOGIT SPI} & \multicolumn{2}{c}{MLOGIT SPI Ext} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ & Between & Within & Between & Within \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab mlogit*spi*22 mlogit*spi*ext2 using "${results2}/9002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table22a_pre_liketable7_pre_migra_drought_young_marriage_within_between_mlogit.tex", ///
scalars(N r2_p Ncluster) drop(*.${age_bracket} primary vin_distance *yearly*  *dist_d*  _cons)  ///
order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) unstack noomitted eform /// eform shows me the rrr coefficients
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */
*margins
local titles "& MLOGIT-MG EFFECTS & MLOGIT-MG EFFECTS \\ \cmidrule(lr){2-3} \addlinespace[-2ex] \\"
local numbers "& (1) &  (2)  \\ \hline"
esttab mmlogit*spi*22 mmlogit*spi*ext2 using "${results2}/9002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table22b_pre_liketable7_pre_migra_drought_young_marriage_within_between_mlogit.tex", ///
scalars(N Ncluster) drop( primary vin_distance )  ///
order(primary vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) /// eform shows me the rrr coefficients
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "1._predict" "0-No Mig" "2._predict" "1-Between" "3._predict" "2-Within" main )  /*width(2\hsize)  */

*******************
*I ran until here
*******************







**********************************************************************************************************
*Creating Figure of margins at baseline for sex and primary education as in Baez et al (2017), figure 2 .  ALL REASONS
**********************************************************************************************************
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
foreach t in probit { 
		estimates drop _all
		
		foreach x in spi${sk_tab}chr_dro_d2  { /*${drought_index} spi${sk}chr_i*/
		
		foreach age in 1 2 3 4 { /*Baseline is category 5*/
		
			gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age`age'=`x' if ${age_bracket}==`age'
			}
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
				local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==1, vce(cluster dist_o)" 
				local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==0, vce(cluster dist_o)" 
				local fe3 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==1, vce(cluster dist_o)" 
				local fe4 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==0, vce(cluster dist_o)"
				local fe5 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_rural==1, vce(cluster dist_o)" 
				local fe6 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_urban==0, vce(cluster dist_o)"

				foreach m in 1 2 3 4 5 6 {
				
					display "`fe`m''"
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real2 `identif_a0' `fe`m''
						margins, dydx(`x'age*) post
						estimates store `t'`x'fe`m'					
				}
				coefplot (`t'`x'fe1, label(Women)) (`t'`x'fe2, label(Men)), name(`t'`x'sex, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'sex.gph", replace) ///
									level(90) ytitle("Age*drought") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal 
				coefplot (`t'`x'fe3, label(Primary)) (`t'`x'fe4, label(No Primary)), name(`t'`x'primary, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'primary.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal
				coefplot (`t'`x'fe5, label(Rural)) (`t'`x'fe6, label(No Rural)), name(`t'`x'rural, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'rural.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal									
									
				graph combine `t'`x'sex `t'`x'primary `t'`x'rural, cols(3) name(`t'`x'all, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'all.gph", replace) ///
							title(Ave. Mg. effect of `x' by Age-CI at 90%) subtitle(All reasons to migrate) ycommon xcommon
							/*note("Note: baseline category of age: 48-57. Age<10 and Age>57 are excluded.")*/
				drop `x'age*
			}		
		
}

**********************************************************************************************************
*Creating Figure of margins at baseline for sex and primary education as in Baez et al (2017), figure 2 .  REASON 3 ONLY
**********************************************************************************************************
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
foreach t in probit { 
		estimates drop _all
		
		foreach x in spi${sk_tab}chr_dro_d2 { /*${drought_index} spi${sk}chr_i*/
		
		foreach age in 1 2 3 4 { /*Baseline is category 5*/
		
			gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age`age'=`x' if ${age_bracket}==`age'
			}
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
				local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==0 & reason_migrate==3, vce(cluster dist_o)" 
				local fe3 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe4 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==0 & reason_migrate==3, vce(cluster dist_o)"
				local fe5 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_rural==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe6 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_urban==0 & reason_migrate==3, vce(cluster dist_o)"

				foreach m in 1 2 3 4 5 6 {
				
					display "`fe`m''"
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real2 `identif_a0' `fe`m''
						margins, dydx(`x'age*) post
						estimates store `t'`x'fe`m'					
				}
				coefplot (`t'`x'fe1, label(Women)) (`t'`x'fe2, label(Men)), name(`t'`x'sex_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'sex_reason3.gph", replace) ///
									level(90) ytitle("Age*drought") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal 
				coefplot (`t'`x'fe3, label(Primary)) (`t'`x'fe4, label(No Primary)), name(`t'`x'primary_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'primary_reason3.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal
				coefplot (`t'`x'fe5, label(Rural)) (`t'`x'fe6, label(No Rural)), name(`t'`x'rural_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'rural_reason3.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal									
									
				graph combine `t'`x'sex `t'`x'primary `t'`x'rural, cols(3) name(`t'`x'all_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'all_reason3.gph", replace) ///
							title(Ave. Mg. effect of `x' by Age-CI at 90%) subtitle(Reason to migrate=marriage) ycommon xcommon
							/*note("Note: baseline category of age: 48-57. Age<10 and Age>57 are excluded.")*/
				drop `x'age*
			}		
		
}
*******************************************************************
*Robustness check by 1) spei using chrips+modis and 2) spi 2001-2016. ALL SAMPLE
******************************************************************
global drought_index1 "spei${sk}har_i spei${sk}har_igro spei${sk}har_ipos spei${sk}har_dro spei${sk}har_dro_l2 spei${sk}har_dro_d spei${sk}har_dro_d2 spei${sk}har_droext spei${sk}har_dro_l2ext spei${sk}har_dro_dext spei${sk}har_dro_d2ext"
global drought_index2 "spei${sk}tho_i spei${sk}tho_igro spei${sk}tho_ipos spei${sk}tho_dro spei${sk}tho_dro_l2 spei${sk}tho_dro_d spei${sk}tho_dro_d2 spei${sk}tho_droext spei${sk}tho_dro_l2ext spei${sk}tho_dro_dext spei${sk}tho_dro_d2ext" 
global drought_index3 "spi${sk}_0116_i spi${sk}_0116_igro spi${sk}_0116_ipos spi${sk}_0116_dro spi${sk}_0116_dro_l2 spi${sk}_0116_dro_d spi${sk}_0116_dro_d2 spi${sk}_0116_droext spi${sk}_0116_dro_l2ext spi${sk}_0116_dro_dext spi${sk}_0116_dro_d2ext"
global drought_index_rob "$drought_index1 $drought_index2 $drought_index3"

foreach t in reg probit { 
		estimates drop _all
		foreach migra in 1 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if ${sample}, vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if ${sample}, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in ${drought_index_rob} {
		
			foreach age in 1 2 3 4 { /*Baseline is category 5*/
			
				gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
				replace `x'age`age'=`x' if ${age_bracket}==`age'
				}
			*a b, to generate reg_migra_indflows.csv
			local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
			*local identif_b0 "c.`x'##ib5.${age_bracket}##mig_hht4" /*DID with whole HH migrating*/
			
				foreach m in a {
				
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
						estimates store `t'`m'`x'`migra'	
						/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
						estimates store `t'2`m'`x'`migra' */
					}	
					drop `x'age*
				}
			}		
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_rob.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
		
}

*************************************************************
** MEASUREMENT ERRORS IN MIGRATION QUESTION
*************************************************************
tab  moduleB_resp sex_hh_head if mig_real2==1 /*IF HH head is woman, she answers. If the HH head is man, 1/2 of times he answers and 1/2 wife answers*/
bys sex_hh_head: summ age_years  if mig_real2==1
bys moduleB_resp: summ age_years  if mig_real2==1

bys sex_hh_head: summ age_years  if mig_real2==1 & moduleB_resp==1
bys sex_hh_head: summ age_years  if mig_real2==1 & moduleB_resp==2 /*Difference on average age comes from woman HH head, she tends to be younger*/

gen B_resp_sex=.
replace B_resp_sex=1 if sex_hh_head==1 & moduleB_resp==1
replace B_resp_sex=2 if sex_hh_head==1 & moduleB_resp==2
replace B_resp_sex=3 if sex_hh_head==2 & moduleB_resp==1 /*Those are the majority of the options*/

label define sex_B 1 "HH HEAD(MAN)-HE answers B Module" 2 "HH HEAD(MAN)-WIFE answers B Module" 3 "HH HEAD(WOMAN)-SHE answers B Module"
label values B_resp_sex sex_B

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 3 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if B_resp_sex==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if B_resp_sex==`type' & (young_marriage==1), vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)-HE answers)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)-WIFE answers)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(WOMAN)-SHE answers)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \cmidrule(lr){10-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) & (10) & (11) & (12) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* regife*spi*s3* mprobit*spi*s3* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table13_pre_migra_drought_young_marriage_B_resp_sex.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

**********************************************************************************************************************************
******** FROM HERE? IT LOOKS LIKE RESULTS ARE COMING MAINLY WHEN WOMEN REPLIES THE QUESTIONNAIRE. MEASUREMENT ERRORS MORE WHEN A MAN REPLIES
* Assuming this, let's take sex_hh_head to see if there are differences. When woman is HH head, she almost always answers questions
*********************************************************************************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex_hh_head==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex_hh_head==`type' & (young_marriage==1), vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(WOMAN))} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table14_pre_migra_drought_young_marriage_sex_hh_head.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(<- $<-$)  /*width(2\hsize) substitute(_ \_  $  \\$  %  \% ) R2_ $R2 $R2_a _a$ _p _p$ */

************************************************************************************
* Matrilineal vs Patrilineal plays a role? Classification of language(not info of ethnicity but matches with that) from  https://www.sciencedirect.com/science/article/pii/S0264837714000945
************************************************************************************
gen patrilineal=.
replace patrilineal=1 if language_hh==4 | language_hh==6| language_hh==7|language_hh==8 |language_hh==9 |language_hh==10 |language_hh==11
replace patrilineal=0 if language_hh==1| language_hh==2 |language_hh==3 |language_hh==5

label define patri_label 1 "Patrilineal" 0 "Matrilineal"
label values patrilineal patri_label

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if patrilineal==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" /*mig_ind2==1 or 2*/
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if patrilineal==`type' & (young_marriage==1), vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (PATRILINEAL)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MATRILINEAL)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table15_pre_migra_drought_young_marriage_patrilineal.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


************************************************************************************
* Instead of Matrilineal vs Patrilineal plays a role, region? 
************************************************************************************
gen regiony=.
replace regiony=1 if region=="North"
replace regiony=2 if region=="Central"
replace regiony=3 if region=="South"

label define reg_label 1 "North" 2 "Central" 3 "South"
label values regiony reg_label

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 3 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if regiony==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" /*mig_ind2==1 or 2*/
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if regiony==`type' & (young_marriage==1), vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (NORTH)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (CENTRAL)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (SOUTH)}  \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \cmidrule(lr){10-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* regife*spi*s3* mprobit*spi*s3* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table16_pre_migra_drought_young_marriage_region.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

****************************************
*CHECKING LESS DROUGHT IN DIST D MAKES ME RECEIVE MORE MIGRANTS IN DIST D!!!!
****************************************
*Merging with main events in the community (drought-floods-epidemics-price_change), but now at dist_d
rename (drought* flood* epidemic* price_change* ) (o_=) /*_o for origin*/
preserve
	use "${work2}\com_events.dta", clear
	rename dist_o dist_d
	rename year yearly
	rename (drought* flood* epidemic* price_change* ) (d_=) /*_d for destination*/
	tempfile com
	save "`com'", replace
restore

merge m:1 survey dist_d yearly using "`com'", keep(master using match) gen(merge_eventd)
drop merge_eventd

gen d_drought4=0
sort id yearly
bys id: replace d_drought4=1 if d_drought1[_n+1]==1 /*Lagged drought*/
label variable d_drought4 "d_drought1(t-1)"

*Including data of droughts SPEI SPI indeces, but now at dist_d
rename (spi* spei*) (o_=) /*From here drought indeces are from destination*/
preserve
	use "${work2}\SPEI_SPI.dta", clear
	rename dist_o dist_d
	rename (spi* spei*) (d_=) /*added d for destination at the beginning of all variables*/
	tempfile spi
	save "`spi'", replace
restore

merge m:1 dist_d yearly using "`spi'", keep(master using match) gen(merge_tempd)
drop if merge_tempd==2 /*those are for Uganda, Tanzania and Malawi(before 2000)*/
drop merge_tempd
sort id yearly

*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER - ALL MIGRANTS by SEX; FOR WITHIN, dist_d*spi and dist_o*spi are the same variables
******************************************************************
global sk "12" /*spei and spi using scale*/
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
global age_bracket "age_bracket6"
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"

estimates drop _all
foreach type in 1 0 {
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
						
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type', vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type', vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age* c.od_`x' od_`x'age*"
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+21 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d and 5 more for interactions ==21*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* od_`x' od_`x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
									foreach a in 1 2 3 4 { /*Baseline is category 5 and we expect 4>3>2>1 with 4 most likely*/
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket  /*lincomest _cons +  `a'.age_bracket*/
											estimates store l`t'`x's`type'a`a'1
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x'+d_`x'age_bracke`a' */
											estimates store l`t'`x's`type'a`a'2
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a'+o_`x'age_bracke`a' + od_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x' +d_`x'age_bracke`a'+o_`x'+o_`x'age_bracke`a' +od_`x' +od_`x'age_bracke`a'*/
											estimates store l`t'`x's`type'a`a'3
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + o_`x'age_bracke`a' /*_cons +  `a'.age_bracket + o_`x'+o_`x'age_bracke`a'*/
											estimates store l`t'`x's`type'a`a'4
									}
							}
						}
					}
				drop d_`x'age* o_`x'age* od_`x'age* od_`x' /*dropping each x generated of interactions*/
	}
}
	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d od {
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MEN)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17_pre_migra_drought_distd_disto.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER - YOUNG MARRIAGE. FOR WITHIN, dist_d*spi and dist_o*spi are the same variables
*****************************************************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
					
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1), vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age* c.od_`x' od_`x'age*"
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+21 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d and 5 more for interactions ==21*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* od_`x' od_`x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's
							}
						}
					}
				drop d_`x'age* o_`x'age* od_`x'age* od_`x' /*dropping each x generated of interactions*/
}

	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d od {
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ &  \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab regife*spi*s* mprobit*spi*s*  using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17_pre_migra_drought_distd_disto_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */













