*********************************************************************************
* 			THIS PROGRAM BUILDS A PANEL DATA SET AS SUGGESTED BY JOSELLIN THUILLIEZ *
*			AND RUNS THE REGRESSIONS FOR INDIVIDUAL ANALYSIS
*			uses file "${work}/mig_individuals.dta" in 6000_... do file rUN THIS BEFORE
*		Identical to 3003_... file but using CRU-CHRIPS data
*                WRITTEN BY LUIS GUILLERMO BECERRA                              *
*********************************************************************************
clear
cap clear mata
clear matrix
set more off
set mem 400m
set matsize 11000
set maxvar 32000
cap log close
			
*cd "/home/l.becerra/U/PSE-Proposal Malaria and paper/INPUT"
*cd "D:\Luis Guillermo\New destiny\PSE-PPD\PhD\Paris I-Pantheon Sorbonne PSE\PSE-Proposal Malaria and paper\INPUT"
*cd "U:\PSE-Proposal Malaria and paper\INPUT"
cd "C:\Users\PSE-Proposal Malaria and paper\INPUT"

global input    "..\INPUT"
global pro    	"..\PRO V2"
global misc    	"..\MISC"
global log		"..\LOG"
global paper	"..\PAPER"
global paper2	"..\PAPER V2"
global work 	"..\WORK"
global work2 	"..\WORK V2"
global results  "..\RESULTS\panel_josellin"
global results2  "..\RESULTS V2"

*****INSTALLING PACKAGES NEEDED FOR REGRESSIONS

	*Run to install package to calculate distances
	net from http://www-personal.umich.edu/~nicholsa/stata
	net install vincenty

/*	* Install ftools (remove program if it existed previously)
	cap ado uninstall moresyntax
	cap ado uninstall ftools
	
	
	rreia/ftools/tree/master/src")

	* Install reghdfe 4.x
	cap ado uninstall reghdfe
	net install reghdfe, from("https://github.com/sergiocorreia/reghdfe/tree/master/src")

	* Install boottest for Stata 11 and 12
	if (c(version)<13) cap ado uninstall boottest
	if (c(version)<13) ssc install boottest

	* Install moremata (sometimes used by ftools but not needed for reghdfe)
	cap ssc install moremata

	* Install ivreg2, the core package
	ssc install ivreg2

	* Finally, install this package
	cap ado uninstall ivreg2hdfe
	cap ado uninstall ivreghdfe
	net install ivreghdfe, from(https://github.com/sergiocorreia/ivreg2_demo/raw/master/)
	
	ssc install reghdfe
*/
*Install file for postestimation esttab-estout 
ssc install erepost
ssc install latab
ssc install balancetable
	
use "${work2}/mig_individuals_malawi.dta", replace
*Keeping only between migrants to reduce Memory RAM use and vars
*keep if between_mig==1 & dist_o!=dist_d
*keep if mig_real==1 // keeping only migrants without considering the alternatives of migrating to other districts

keep id id_HH eaid survey country region dist_o year_mig dist_d mig_real reason_migrate vin_distance d_Malawi d_Tanzania d_Uganda country_survey d_mal_sur1-d_uga_sur4 con_sur mig_hht4 con age_years age_bracket sex rural ///
		kids5 per_hhkids5 kids5_mig per_hhkids5_mig eduyears eduhigh hhsize hh_shock* hh_geo_dist* hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD dist_dname dist_oname mig_ind2 mig_rural mig_urban language_hh hh_b14 k_* ///
		hh_e19b work_hh_head* Y Yag* agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other hh_c14 noedu_mar_preg hh_d40 hh_b24 hh_b26* rel_to_head sex_hh_head moduleB_resp ///
		sibling sibling_boy sibling_girl mig_couple
rename (agr_wge nonagr_wge crop1 crop2 livestock selfemp transfer other)  Y_=
drop if dist_d==1106 /*Dropping Likoma*/

*Fix missing dist_o for mig_ind2==2
replace dist_o=dist_d if mig_ind2==2 & survey=="Survey-2004-2005"
replace dist_oname=dist_dname if mig_ind2==2 & survey=="Survey-2004-2005"

*Filling the gaps to have balanced panel 1999-2016
gen year=year_mig
tsset id year, yearly 
tsfill, full

foreach var of varlist survey country con mig_hht4 dist_o dist_d country_survey con_sur year_mig age_years age_bracket sex rural eduyears eduhigh vin_distance ///
						eaid region kids5* per_hhkids5* hhsize mig_ind2 mig_rural mig_urban language_hh ///
					   reason_migrate hh_shock* hh_geo_dist* hh_geo_LAT_DD_MOD hh_geo_LON_DD_MOD dist_dname dist_oname hh_b14 k_* hh_e19b work_hh_head* Y* hh_c14 noedu_mar_preg hh_d40 ///
					   hh_b24 hh_b26* id_HH rel_to_head sex_hh_head moduleB_resp sibling sibling_boy sibling_girl mig_couple {
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n-1] if missing(`var')
		bys id (year_mig): replace `var' = `var'[_n+1] if missing(`var')
}		
drop d_Malawi d_Tanzania d_Uganda d_tan* d_uga* d_mal*

save "${work2}\temporal.dta", replace 
use "${work2}\temporal.dta", clear

replace vin_distance=0 if dist_d==dist_o

*Merging with main events in the community (drought-floods-epidemics-price_change)
merge m:1 survey dist_o year using "${work2}\com_events.dta", keep(master using match) gen(merge_event)
drop merge_event

*Merging with masaf in the community
merge m:1 dist_o year using "${work2}\com_masaf.dta", keep(master using match) gen(merge_masaf)
drop merge_masaf

**********************************************************
* CHECKING ROLL BACK MALARIA PROGRAM AT NATIONAL LEVEL FOR MAL-TAN-UGA
*********************************************************************
gen rollback=0
replace rollback=1 if country=="Malawi" & year>=2006
*replace rollback=1 if country=="Tanzania" & year>=2003
*replace rollback=1 if country=="Uganda" & year>=2004
label var rollback "Starting year of Roll Back Malaria Program"		
		
*Creating 2 versions of mig_real
rename mig_real mig_real1
gen mig_real2=mig_real1 
bys id: replace mig_real1=0 if year<year_mig
bys id: replace mig_real1=1 if year>year_mig  
replace mig_real2=0 if mig_real2==.	

sort id year survey con* 
order id year survey con* country* region eaid rural sex hhsize rural mig_real* year_mig reason_migrate mig_hht4 dist* vin_distance age* edu*  kids5* per_hhkids5* rollback hh_shock*

*Redifinig the age categories. Only for those >=10 and <= 57 or 60 depending on the case
gen age_migrate=0
replace age_migrate=age_years - (2016-year_mig) if survey=="Survey-2016-2017" /*Migrants in 2016-2017 Survey*/
replace age_migrate=age_years - (2013-year_mig) if survey=="Survey-2013" /*Migrants in 2013 Survey*/
replace age_migrate=age_years - (2010-year_mig) if survey=="Survey-2010-2011" /*Migrants in 2010-2011 Survey*/
replace age_migrate=age_years - (2004-year_mig) if survey=="Survey-2004-2005" /*Migrants in 2004-2005 Survey*/
replace age_migrate=0 if age_migrate==-1 /*Those that were in the mother's womb*/
replace age_migrate=. if age_migrate<0 /*Those 23 with negative age of migration. Better to missing*/

drop age_bracket
label drop AGE_BRACKET

gen age_bracket=.
replace age_bracket=1 if age_years>=10 & age_years<=15 & age_years!=.
replace age_bracket=2 if age_years>=16 & age_years<=25 & age_years!=.
replace age_bracket=3 if age_years>=26 & age_years<=35 & age_years!=.
replace age_bracket=4 if age_years>=36 & age_years<=45 & age_years!=.
replace age_bracket=5 if age_years>=46 & age_years<=55 & age_years!=.
replace age_bracket=6 if age_years>=56 & age_years<=65 & age_years!=.
label define AGE_BRACKET 1 "10-15" 2 "16-25" 3 "26-35" 4 "36-45" 5 "46-55" 6 "56-65" 
label values age_bracket AGE_BRACKET

gen age_bracket2=.
replace age_bracket2=1 if age_years>=10 & age_years<=20 & age_years!=.
replace age_bracket2=2 if age_years>=20 & age_years<=30 & age_years!=.
replace age_bracket2=3 if age_years>=30 & age_years<=40 & age_years!=.
replace age_bracket2=4 if age_years>=40 & age_years<=50 & age_years!=.
replace age_bracket2=5 if age_years>=50 & age_years<=60 & age_years!=.
label define AGE_BRACKET2 1 "10-20" 2 "20-30" 3 "30-40" 4 "40-50" 5 "50-60" 
label values age_bracket2 AGE_BRACKET2

gen age_bracket3=.
replace age_bracket3=1 if age_migrate>=10 & age_migrate<=15 & age_migrate!=.
replace age_bracket3=2 if age_migrate>=16 & age_migrate<=25 & age_migrate!=.
replace age_bracket3=3 if age_migrate>=26 & age_migrate<=35 & age_migrate!=.
replace age_bracket3=4 if age_migrate>=36 & age_migrate<=45 & age_migrate!=.
replace age_bracket3=5 if age_migrate>=46 & age_migrate<=55 & age_migrate!=.
replace age_bracket3=6 if age_migrate>=56 & age_migrate<=65 & age_migrate!=.
label define AGE_BRACKET3 1 "10-15" 2 "16-25" 3 "26-35" 4 "36-45" 5 "46-55" 6 "56-65"
label values age_bracket3 AGE_BRACKET3 

gen age_bracket4=.
replace age_bracket4=1 if age_migrate>=10 & age_migrate<=20 & age_migrate!=.
replace age_bracket4=2 if age_migrate>=20 & age_migrate<=30 & age_migrate!=.
replace age_bracket4=3 if age_migrate>=30 & age_migrate<=40 & age_migrate!=.
replace age_bracket4=4 if age_migrate>=40 & age_migrate<=50 & age_migrate!=.
replace age_bracket4=5 if age_migrate>=50 & age_migrate<=60 & age_migrate!=.
label define AGE_BRACKET4 1 "10-20" 2 "20-30" 3 "30-40" 4 "40-50" 5 "50-60" 
label values age_bracket4 AGE_BRACKET4

gen age_bracket5=.
replace age_bracket5=1 if age_migrate>=10 & age_migrate<=17 & age_migrate!=.
replace age_bracket5=2 if age_migrate>=18 & age_migrate<=27 & age_migrate!=.
replace age_bracket5=3 if age_migrate>=28 & age_migrate<=37 & age_migrate!=.
replace age_bracket5=4 if age_migrate>=38 & age_migrate<=47 & age_migrate!=.
replace age_bracket5=5 if age_migrate>=48 & age_migrate<=57 & age_migrate!=.
label define AGE_BRACKET5 1 "age (10-17)" 2 "age (18-27)" 3 "age (28-37)" 4 "age (38-47)" 5 "age (48-57)" 
label values age_bracket5 AGE_BRACKET5 

*Defining those migrating 5 years ago or less in the surveys. To keep similar age idea as in Baez-Mueller et al
gen age_ago=0
replace age_ago =age_years-age_migrate
label var age_ago "age_years-age_migrate"

*Redefining sex
label define sexx 1 "FEMALE" 0 "MALE"
gen sexx=.
replace sexx=1 if sex==2
replace sexx=0 if sex==1
drop sex
rename sexx sex
label values sex sexx

*Renaming year to avoid confusion
rename year yearly
sort id yearly
gen drought4=0
sort id yearly
bys id: replace drought4=1 if drought1[_n+1]==1 /*Lagged drought*/
label variable drought4 "drought1(t-1)"

*Generating ea different id for FE
egen ea_ID=group(eaid)

*Between district dummy
gen within_dist=0
replace within_dist=1 if mig_ind2==2

*Variable of Primary education
gen primary=(eduyears>7)
replace primary=. if eduyears==.

*Fixing some bad classifications for hh_b14. Better to missing. They declared moving inside district but report of dist_o dist_d says it was between district.
replace hh_b14=. if mig_ind2==1 & (hh_b14==5|hh_b14==7)
replace hh_b14=. if mig_ind2==2 & (hh_b14==3|hh_b14==6)

tab hh_b14 mig_ind2 /*Correctly classified*/

*Including data of droughts SPEI SPI indeces
merge m:1 dist_o yearly using "${work2}\SPEI_SPI.dta", keep(master using match) gen(merge_temp)
drop if merge_temp==2 /*those are for Uganda, Tanzania and Malawi(before 2000)*/
drop merge_temp
sort id yearly

*Table P2 and P3 for PAPER1_V2_mig_drought
matrix M = J(31,2,0)
matrix colname M = 1 2
matrix rowname M = 1101 1102 1103 1104 1105 1107 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315
tab dist_o mig_ind2 if mig_real2==1, matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("P2", replace) //modify 
putexcel A1=matrix(C), names

matrix M = J(31,2,0)
matrix colname M = 1 2
matrix rowname M = 1101 1102 1103 1104 1105 1107 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1301 1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315
tab dist_d mig_ind2 if mig_real2==1, matcell(total)
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("P3", replace) //modify
putexcel A1=matrix(C), names

label define distlabel 1101	"1101  (CHITIPA)" 1102	"1102  (KARONGA)" 1103	"1103  (NKHATABAY)" 1104	"1104  (RUMPHI)" 1105	"1105  (MZIMBA)" 1107	"1107  (MZUZU CITY)" 1201	"1201  (KASUNGU)" ///
						1202	"1202  (NKHOTA KOTA)" 1203	"1203  (NTCHISI)" 1204	"1204  (DOWA)" 1205	"1205  (SALIMA)" 1206	"1206  (LILONGWE)" 1207	"1207  (MCHINJI)" 1208	"1208  (DEDZA)"  ///
						1209 "1209  (NTCHEU)" 1210	"1210  (LILONGWE CITY)" 1301	"1301  (MANGOCHI)" 1302	"1302  (MACHINGA)" 1303	"1303  (ZOMBA)" 1304	"1304  (CHIRADZULU)" ///
						1305	"1305  (BLANTYRE)" 1306	"1306  (MWANZA)" 1307	"1307  (THYOLO)" 1308	"1308  (MULANJE)" 1309	"1309  (PHALOMBE)" 1310	"1310  (CHIKWAWA)" 1311	"1311  (NSANJE)" ///		
						1312	"1312  (BALAKA)" 1313	"1313  (NENO)" 1314	"1314  (ZOMBA CITY)" 1315	"1315  (BLANTYRE CITY)" 
label values dist_o distlabel 
label values dist_d distlabel

estpost tab dist_o mig_ind2 if mig_real2==1
est store tabp23a
estpost tab dist_d mig_ind2 if mig_real2==1
est store tabp23b
esttab tabp23a tabp23b using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_p2_p3.tex", cells("b(fmt(0) label(Obs.))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule District & \multicolumn{3}{c}{By district of origin} & \multicolumn{3}{c}{By district of destination} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7} \addlinespace[-2ex] \\ & Within Dist-MIG & Between Dist-MIG & Total & Within Dist-MIG & Between Dist-MIG & Total \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\")

*Table P4 for PAPER1_V2_mig_drought. Reason to migrate
matrix M = J(6,2,0)
matrix colname M = 1 2
matrix rowname M = "WORK RELATED/LOOK FOR WORK" "SCHOOL/STUDIES" "MARRIAGE" "FAMILY REASONS/JOIN FAMILY" "LAND/PLOT/OTHER LAND RELATED" "OTHERS"

tab reason_migrate mig_ind2 if mig_real2==1 & sex==1, matcell(total_female)
matrix C=total_female+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("P4", replace) //modify
putexcel A1=matrix(C), names

tab reason_migrate mig_ind2 if mig_real2==1 & sex==0, matcell(total_male)
matrix C=total_male+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("P4", replace) //modify
putexcel A12=matrix(C), names

estpost tab reason_migrate sex if mig_real2==1 & mig_ind2==1
est store tabp4a
estpost tab reason_migrate sex if mig_real2==1 & mig_ind2==2
est store tabp4b
esttab tabp4a tabp4b using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_p4.tex", cells("b(fmt(0) label(Obs.))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule Reason to migrate & \multicolumn{3}{c}{Between Dist-MIG} & \multicolumn{3}{c}{Within Dist-MIG} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7} \addlinespace[-2ex] \\ & Men & Women & Total & Men & Women & Total \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\")
esttab tabp4a tabp4b using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_p4_percentage.tex", cells("pct(fmt(1) label(Obs.))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule Reason to migrate & \multicolumn{3}{c}{Between Dist-MIG} & \multicolumn{3}{c}{Within Dist-MIG} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7} \addlinespace[-2ex] \\ & Men & Women & Total & Men & Women & Total \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\")

*Table P11. Droughts vs no droughts district at origin to test parallel trends
preserve
	use "${work}\WEATHER_mean_yearly.dta", clear
	keep if country=="Malawi"
	keep dist_d year *chrips* *modis*
	keep if year>1998
	rename (year dist_d) (yearly dist_o)
	tempfile wea
	save "`wea'", replace
restore
merge m:1 dist_o yearly using "`wea'", keep(master using match) gen(merge_weather)  
drop if merge_weather==2
drop merge_weather /*The not matches are for 2004-2005 survey which did not report dist_o*/

*Creating environment for the Balance Table
global balance1 "ave_rain_chrips_max ave_rain_chrips_mean ave_rain_chrips_min ave_rain_chrips_sum a2_ave_rain_chrips_mean sd_ave_rain_chrips_mean sd_ave_rain_chrips_sum ave_temp_modis_max ave_temp_modis_mean ave_temp_modis_min a2_ave_temp_modis_mean sd_ave_temp_modis_mean"
global balance2 "sex eduyears primary vin_distance per_hhkids5 mig_rural mig_urban hhsize"
global balance "$balance2 $balance1"

label var ave_rain_chrips_max "Mean of monthly maximum rainfall during year(mm)-CHIRPS" 
label var ave_rain_chrips_mean "Mean of monthly average rainfall during year(mm)-CHIRPS"
label var ave_rain_chrips_min "Mean of monthly minimim rainfall during year(mm)-CHIRPS"
label var ave_rain_chrips_sum "Mean of monthly cumulative rainfall during year(mm)-CHIRPS"
label var ave_temp_modis_max "Mean of monthly maximum temperature during year(degrees)-MODIS"
label var ave_temp_modis_mean "Mean of monthly average temperature during year(degrees)-MODIS"
label var ave_temp_modis_min "Mean of monthly minimum temperature during year(degrees)-MODIS"
label var a2_ave_rain_chrips_mean "Anomalies-Mean of monthly average rainfall during year(mm)-CHIRPS"
label var a2_ave_temp_modis_mean "Anomalies-Mean of monthly average temperature during year(degrees)-MODIS"
label var sd_ave_rain_chrips_mean "SD of monthly average rainfall during year(mm)-CHIRPS"
label var sd_ave_rain_chrips_sum "SD of monthly cumulative rainfall during year(mm)-CHIRPS"
label var sd_ave_temp_modis_mean "SD of monthly average temperature during year(degrees)-MODIS"

label var sex "Sex of the individual"
label var eduyears "Number of years of education"
label var primary "Dummy for at least primary education"
label var vin_distance "Vincenty distance dist-origin to dist-destination"
label var per_hhkids5 "Percentage of kids less than 5 years old in the Household"
label var mig_rural "Dummy for migrants coming from rural areas"
label var mig_urban "Dummy for migrants coming from urban areas"
label var hhsize "Size of the Household"

*Using EA measure. I added {l*{4}c} by {Hclclclc} in the tex file to import in overleaf. Import it directly now
*Running this regresion to define the sample for the balance tables
regife mig_real2 c.spi12chr_dro_d2##ib5.age_bracket5 primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o) factors(id yearly, 1)
gen sample_balance=e(sample)
*estimates table _all, p stats(N)	
balancetable drought1 $balance using "${results2}\7002_panel_year_drought_o\balance_table\balance_EA.tex" if age_bracket5<6 & mig_ind2==1 & sample_balance==1, replace fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///
			prehead("\begin{tabular}{l*{4}c}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Between-district Migrants} \\")
balancetable drought1 $balance using "${results2}\7002_panel_year_drought_o\balance_table\balance_EA.tex" if age_bracket5<6 & mig_ind2==2 & sample_balance==1, append fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs  ///				
			prehead("\begin{tabular}{Hclclclc}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Within-district Migrants} \\")
			
*Using SPI measure
*estimates table _all, p stats(N) /*spi24chr_dro_d2*/
balancetable spi12chr_dro_d2  $balance using "${results2}\7002_panel_year_drought_o\balance_table\balance_SPI.tex" if age_bracket5<6 & mig_ind2==1 & sample_balance==1, replace fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///
			prehead("\begin{tabular}{l*{4}c}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Between-district Migrants} \\")
balancetable spi12chr_dro_d2  $balance using "${results2}\7002_panel_year_drought_o\balance_table\balance_SPI.tex" if age_bracket5<6 & mig_ind2==2 & sample_balance==1, append fe(yearly) covariates(i.con_sur i.dist_d i.dist_o) ///
			ctitles("No Drought" "Drought" "Diff" "N") varlabels format(%9.3f) vce(cluster dist_o) observationscolumn staraux booktabs ///				
			prehead("\begin{tabular}{Hclclclc}" "\toprule" "\hline" "& \multicolumn{4}{c}{Sample: Within-district Migrants} \\")
			
*Anther Table-Descriptive Statistics. From sex onwards, statistics can be interpreted as to only migrants
tabulate age_bracket5, generate(age_bracket_)
label variable age_bracket_1 "age-bracket(10-17)"
label variable age_bracket_2 "age-bracket(18-27)"
label variable age_bracket_3 "age-bracket(28-37)"
label variable age_bracket_4 "age-bracket(38-47)"
label variable age_bracket_5 "age-bracket(48-57)"
label variable mig_real2 "Migration Dummy"
label variable drought1 "Drought reported in one EA or more in the dist-o"
label variable drought2	"Drought reported in 10\% of more of EA"
label var spi12chr_dro_d2 "Dummy spi12-drought-agro (<-1)"
label var spi12chr_dro_d2ext "Dummy spi12-drought-agro (<-2)"

*Table1

global descriptive "mig_real2 drought1 drought2 spi12chr_dro_d2 spi12chr_dro_d2ext ave_rain_chrips_mean ave_rain_chrips_sum ave_temp_modis_mean sex eduyears primary vin_distance per_hhkids5 mig_rural mig_urban hhsize age_bracket_*"
estpost summ $descriptive
est store table_des1
esttab table_des1 using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_stats1.tex", cells("count(fmt(0) label(Observations)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(2) label(Min)) max(fmt(2) label(Max))") ///
		booktabs nonum label nostar unstack noobs compress nogaps alignment(c) replace substitute("<-" "$<-$" ) mlabel(none)  nomtitles nodepvars ///
		prehead("\begin{tabular}{l*{6}{c}} \toprule\\") ///
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\")

*Table2
estpost tabstat $descriptive, by(mig_ind2) statistics(mean sd) columns(statistics) listwise
est store table_des2
esttab table_des2 using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_stats2.tex", nonumber nonotes mlabels(none) ///
		main(mean %12.2f) aux(sd %12.2f) nostar unstack noobs label compress nogaps alignment(c) replace booktabs substitute("<-" "$<-$" ) nomtitles nodepvars ///
		prehead("\begin{tabular}{l*{4}{c}} \toprule\\") /// 
		posthead(" & Between Migrants & Within Migrants & All Migrants  \\ \cmidrule(lr){1-4} \addlinespace[-2ex] \\")   
	
*Table3		
estpost tabstat $descriptive, stats(n mean sd min max) columns(statistics) listwise
est store table_des3
esttab table_des3 using "${results2}/7002_panel_year_drought_o/balance_table/descriptive_stats3.tex", nonumber nonote mlabels(none) wide ///
		cells("count(fmt(0) label(Observations)) mean(fmt(2) label(Mean)) sd(fmt(2) label(SD)) min(fmt(2) label(Min)) max(fmt(2) label(Max))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs substitute("<-" "$<-$" ) ///
		prehead("\begin{tabular}{l*{6}{c}} \toprule\\") ///
		posthead(" \cmidrule(lr){1-6} \addlinespace[-2ex] \\") 

*Kernel density of migration by age. Below 50 better??? Need to ask
graph drop _all
twoway lpoly mig_real2 age_migrate if (mig_ind2==1 | mig_ind2==2) & (age_migrate>=10 & age_migrate<65) & spi24chr_dro_d==0, kernel(epanechnikov) xscale(range(10 65)) xlabel(10(10)65) ytitle("Migration Density") ///
				 xtitle("Age Migrate") title("Migration Kernel Density by age-Between and within migrants") subtitle("Local polynomial smoothing") name(ker_migbet_age) saving("${paper2}/PAPER/ker_migbet_age.gph", replace)
twoway lpoly mig_real2 age_bracket5 if (mig_ind2==1 | mig_ind2==2) & (age_migrate>=10 & age_migrate<65) & spi24chr_dro_d==0, kernel(epanechnikov) xlabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47" 5 "48-57") ytitle("Migration Density") ///
				 xtitle("Age Migrate (bracket)") title("Migration Kernel Density by age-Between and within migrants") subtitle("Local polynomial smoothing") name(ker_migbet_age_bracket) saving("${paper2}/PAPER/ker_migbet_age_bracket.gph", replace)			
*By reason to migrate. Reason 4 (family reunion drives the weird by-modal density
foreach reason in 1 3 4 {
	twoway lpoly mig_real2 age_migrate if (mig_ind2==1 | mig_ind2==2) & (age_migrate>=10 & age_migrate<65) & spi24chr_dro_d==0 & reason_migrate==`reason', kernel(epanechnikov) xscale(range(10 65)) xlabel(10(10)65) ytitle("Migration Density") ///
				 xtitle("Age Migrate") title("Migration Kernel Density by age-Reason `reason'") subtitle("Between-within migrants (Local polynomial smoothing)") ///
				 name(ker_migbet_age_reason`reason') saving("${paper2}/PAPER/ker_migbet_age_reason`reason'.gph", replace)
	twoway lpoly mig_real2 age_bracket5 if (mig_ind2==1 | mig_ind2==2) & (age_migrate>=10 & age_migrate<65) & spi24chr_dro_d==0 & reason_migrate==`reason', kernel(epanechnikov) xlabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47" 5 "48-57") ytitle("Migration Density") ///
				 xtitle("Age Migrate (bracket)") title("Migration Kernel Density by age-Reason `reason'") subtitle("Between-within migrants(Local polynomial smoothing)") ///
				 name(ker_migbet_age_bracket_reason`reason') saving("${paper2}/PAPER/ker_migbet_age_bracket_reason`reason'.gph", replace)			
}

*** Defining sample
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
global sk "12" /*spei and spi using scale*/
global drought_index "spi${sk}chr_i spi${sk}chr_igro spi${sk}chr_ipos spi${sk}chr_dro spi${sk}chr_dro_l2 spi${sk}chr_dro_d spi${sk}chr_dro_d2 spi${sk}chr_droext spi${sk}chr_dro_l2ext spi${sk}chr_dro_dext spi${sk}chr_dro_d2ext"
/*spei${sk}cru_i spei${sk}cru_igro spei${sk}cru_ipos spei${sk}cru_dro spei${sk}cru_dro_l2 spei${sk}cru_dro_d spei${sk}cru_dro_d2 spi${sk}cru_i spi${sk}cru_igro spi${sk}cru_ipos spi${sk}cru_dro spi${sk}cru_dro_l2 spi${sk}cru_dro_d spi${sk}cru_dro_d2"*/
global age_bracket "age_bracket5"
			 
****************************************
*All surveys LPM and probit. DROUGHT!!!!
****************************************
foreach t in reg probit { /*probit*/
		estimates drop _all
		foreach migra in 1 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}), vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}), vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in  ${drought_index} { /*${drought_index}*/
		
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
					
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
					*local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
			
				foreach m in a {			
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
						estimates store `t'1`m'`x'`migra'					
						eststo m`t'`m'`x'`migra': margins, dydx(`x'age*) post /*For the margins*/						
												
						/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
						estimates store `t'2`m'`x'_`migra' */
					}	
		drop `x'age* /*dropping each x generated of interactions*/
				}
			}		
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
}
*Marginal Effects for interactions in probit only
esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_mg.csv", scalars(N) ///
se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/

****************************************
*All surveys LPM and probit. DROUGHT!!!! MALE-FEMALE
****************************************
foreach sex in 0 1 {
	estimates drop _all
	foreach t in reg probit { /*probit*/
			
			foreach migra in 1 2 {
			local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==`sex', vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
			local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}) & sex==`sex', vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
			
			foreach x in ${drought_index} {
			
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
				*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
				*local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x'age*) post /*For the margins*/	
							/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
							estimates store `t'2`m'`x'_`migra' */
						}
				drop `x'age* /*dropping each x generated of interactions*/
					}
				}		
			* Model a
			esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_sex`sex'.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
			order(eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
			replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
	}
	*Marginal Effects for interactions in probit only
	esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_sex`sex'_mg.csv", scalars(N) ///
	se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects `sex' Women=1, Men=0") /*margins also worked with reg, I will keep only for probit*/
}


****************************************
*All surveys LPM and probit. DROUGHT!!!! URBAN-RURAL. Those self-declared as urban or rural
****************************************
foreach r in rural urban { 
	estimates drop _all
	foreach t in reg probit { /*probit*/
			
			foreach migra in 1 2 {
			local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_`r'==1, vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
			local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}) & mig_`r'==1, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
			
			foreach x in ${drought_index} {
			
				foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
				}
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
				*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
				*local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x'age*) post /*For the margins*/
							/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
							estimates store `t'2`m'`x'_`migra' */
						}
					drop `x'age* /*dropping each x generated of interactions*/
					}
				}		
			* Model a
			esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_`r'.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
			order(eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
			replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
	}
	*Marginal Effects for interactions in probit only
	esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_`r'_mg.csv", scalars(N) ///
	se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects `r'") /*margins also worked with reg, I will keep only for probit*/
}

******************************************************************************************************************************
*All surveys LPM and probit. DROUGHT!!!! REASON TO MIGRATE!!!!!! IMPORTANT REASONS ARE 1(work) AND 3(marriage), NOT 4(family)
******************************************************************************************************************************
foreach reason in 1 3 4 {
	foreach t in reg probit { /*probit*/
		estimates drop _all			
			foreach migra in 1 2 {
			
				local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & reason_migrate==`reason', vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
				local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}) & reason_migrate==`reason', vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
			
				foreach x in ${drought_index} {
				
					foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
					
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								estimates store `t'`m'`x'`migra'
								eststo m`t'`m'`x'`migra': margins, dydx(`x'age*) post /*For the margins*/
								/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
								estimates store `t'2`m'`x'_`migra'`reason' */
							}	
						drop `x'age* /*dropping each x generated of interactions*/
					}
				}	
		* Run estout/esttab
		esttab `t'* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_reason`reason'.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts for reason `reason' 1-work 3-marriagedivorce 4-family -individual migrants") /*drop(0.rollback*)*/
		}
	*Marginal Effects for interactions in probit only
	esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_reason`reason'_mg.csv", scalars(N) ///
	se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-Mg effects reason `reason'. 1-work 3-marriage 4-family -individual migrants") /*margins also worked with reg, I will keep only for probit*/	
}

****************************************************************
*Hypothesis: those migrating for marriage are mainly girls (83%)
****************************************************************
tab sex if reason_migrate ==3

sum age_migrate if yearly==1999 & reason_migrate==3 & (age_migrate>12 & age_migrate<21) & sex==1 & mig_ind2==1 /*My hyphotesis is that HH send girls or sell them to guys because they can't afford  to live and hh send them abroad*/
gen young_marriage=0
*replace young_marriage=1 if reason_migrate==3 & (age_migrate>12 & age_migrate<21) & sex==1
replace young_marriage=1 if reason_migrate==3 & sex==1 /*Better like this and check age_bracket*/
tab age_migrate age_bracket if young_marriage==1 & mig_real2==1 & mig_ind2==1 /*Between district*/
tab age_migrate age_bracket if young_marriage==1 & mig_real2==1 & mig_ind2==2 /*Within district*/
** MANY OF FEMALE YOUNG MIGRANTS ARE mig_ind2==2, within district!!!!! TEST SHOULD BE OVER ALL THE SAMPLE

foreach reason in 3 {
	estimates drop _all
	foreach t in reg probit { 	
			foreach migra in 1 2 {
			
				local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if young_marriage==1, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
			
				foreach x in ${drought_index} {
				
					foreach age in 1 2 3 4 { /*Baseline is category 5*/
							gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
							replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
					*local identif_b0 "c.`x'##ib6.age_bracket##c.young_marriage" /*DID*/
					foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								estimates store `t'`m'`x'`migra'	
								eststo m`t'`m'`x'`migra': margins, dydx(`x'age*) post /*For the margins*/
								/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
								estimates store `t'2`m'`x'_`migra'`reason' */
							}
						drop `x'age* /*dropping each x generated of interactions*/
					}
				}	
		* Run estout/esttab
		esttab `t'* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_reason`reason'_young_marriage.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts for reason `reason' 1-work 3-marriagedivorce 4-family -individual migrants") /*drop(0.rollback*)*/
		}
	*Marginal Effects for interactions in probit only
	esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_drought_reason`reason'_young_marriage_mg.csv", scalars(N) ///
	se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-Mg effects reason `reason'. 1-work 3-marriage 4-family -individual migrants") /*margins also worked with reg, I will keep only for probit*/	
}
/*
****************************************
*Collapsing to get migration flows by year and dist_d dist_o and map it in ARCGIS. Only for between district(mig_real2==1) and not for 2004/2005 as their dist_o are missing
****************************************
preserve
	collapse (sum) mig_real2 if mig_ind2==1, by(dist_d dist_o yearly)
	drop if dist_o==.
	merge m:1 dist_d using "${work}\CENTROIDS_WGS84_d.dta", keep(master using match) gen(merge_d)
	drop if merge_d==2
	drop country dist_dname id merge_d
	rename *_wgs84 *_wgs84_d
	rename dist_d dist_dd 
	rename dist_o dist_d /*to merge with dist_o. I will change it back*/
	merge m:1 dist_d using "${work}\CENTROIDS_WGS84_d.dta", keep(master using match) gen(merge_o)
	drop if merge_o==2
	drop country dist_dname id merge_o
	rename dist_d dist_o
	rename dist_dd dist_d
	rename *_wgs84 *_wgs84_o
	export excel using "${work2}/mig_flows_byyear.xlsx", firstrow(variables) replace
restore

preserve
	collapse (sum) mig_real2 if mig_ind2==1, by(dist_d dist_o)
	drop if dist_o==.
	merge m:1 dist_d using "${work}\CENTROIDS_WGS84_d.dta", keep(master using match) gen(merge_d)
	drop if merge_d==2
	drop country dist_dname id merge_d
	rename *_wgs84 *_wgs84_d
	rename dist_d dist_dd 
	rename dist_o dist_d /*to merge with dist_o. I will change it back*/
	merge m:1 dist_d using "${work}\CENTROIDS_WGS84_d.dta", keep(master using match) gen(merge_o)
	drop if merge_o==2
	drop country dist_dname id merge_o
	rename dist_d dist_o
	rename dist_dd dist_d
	rename *_wgs84 *_wgs84_o
	export excel using "${work2}/mig_flows_allyear.xlsx", firstrow(variables) replace
restore
*/
/*
****************************************
*All surveys LPM and probit. MASAF!!!
****************************************
*Testing hypothesis that MASAF programs at the dist_o can cushion or not the migration decisions. Restricted sample only for 2004,2010,2013,2016 survey-years is the only info we can get
bys id: gen masaf_sample=sum(mig_real2) if masaf!=. /*those with masaf info 2004,2010,2013,2016 and migrating in one of these years*/
*bys id: egen t=sum(mig_real2) if yearly==2004|yearly==2010|yearly==2013|yearly==2016
foreach t in reg probit { /*probit*/
		estimates drop _all
		foreach migra in 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & masaf_sample==1, vce(cluster dist_o)" /* iterate(100)*/
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}) & masaf_sample==1, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in ${drought_index} {
			foreach j in 1 2 3 {
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x'##ib6.age_bracket##c.masaf_dum`j'" /*DID*/
				local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							estimates store `t'1`m'`x'`j'_`migra'	
							/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
							estimates store `t'2`m'`x'`j'_`migra' */
					}									
				}
			}
		}
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_masaf.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
}

****************************************
*All surveys LPM and probit. HETEROGENEOUS EFFECTS FOR BETWEEN DISTRICT VS WITHIN DISTRICT
****************************************
foreach t in reg probit { /*probit*/
		estimates drop _all
		foreach migra in 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==1 | mig_ind2==2, vce(cluster dist_o)" /*  all */
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if mig_ind2==1 | mig_ind2==2, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in ${drought_index} {
			*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x'##ib6.age_bracket##c.within_dist" /*DID*/
				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							estimates store `t'1`m'`x'_`migra'	
							/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
							estimates store `t'2`m'`x'_`migra' */
					}									
			}
		}
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/between_and_within_district/`t'_migra_drought_between_within.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
}
*/
**********************************************************************************************************
*Creating Figure of margins at baseline for sex and primary education as in Baez et al (2017), figure 2 .  ALL REASONS
**********************************************************************************************************
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
foreach t in probit { 
		estimates drop _all
		
		foreach x in spi${sk_tab}chr_dro_d2  { /*${drought_index} spi${sk}chr_i*/
		
		foreach age in 1 2 3 4 { /*Baseline is category 5*/
		
			gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age`age'=`x' if ${age_bracket}==`age'
			}
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
				local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==1, vce(cluster dist_o)" 
				local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==0, vce(cluster dist_o)" 
				local fe3 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==1, vce(cluster dist_o)" 
				local fe4 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==0, vce(cluster dist_o)"
				local fe5 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_rural==1, vce(cluster dist_o)" 
				local fe6 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_urban==0, vce(cluster dist_o)"

				foreach m in 1 2 3 4 5 6 {
				
					display "`fe`m''"
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real2 `identif_a0' `fe`m''
						margins, dydx(`x'age*) post
						estimates store `t'`x'fe`m'					
				}
				coefplot (`t'`x'fe1, label(Women)) (`t'`x'fe2, label(Men)), name(`t'`x'sex, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'sex.gph", replace) ///
									level(90) ytitle("Age*drought") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal 
				coefplot (`t'`x'fe3, label(Primary)) (`t'`x'fe4, label(No Primary)), name(`t'`x'primary, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'primary.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal
				coefplot (`t'`x'fe5, label(Rural)) (`t'`x'fe6, label(No Rural)), name(`t'`x'rural, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'rural.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal									
									
				graph combine `t'`x'sex `t'`x'primary `t'`x'rural, cols(3) name(`t'`x'all, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'all.gph", replace) ///
							title(Ave. Mg. effect of `x' by Age-CI at 90%) subtitle(All reasons to migrate) ycommon xcommon
							/*note("Note: baseline category of age: 48-57. Age<10 and Age>57 are excluded.")*/
				drop `x'age*
			}		
		
}

**********************************************************************************************************
*Creating Figure of margins at baseline for sex and primary education as in Baez et al (2017), figure 2 .  REASON 3 ONLY
**********************************************************************************************************
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "between_and_within_district" /*between_district or between_and_within_district or within_district*/
foreach t in probit { 
		estimates drop _all
		
		foreach x in spi${sk_tab}chr_dro_d2 { /*${drought_index} spi${sk}chr_i*/
		
		foreach age in 1 2 3 4 { /*Baseline is category 5*/
		
			gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age`age'=`x' if ${age_bracket}==`age'
			}
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
				local fe1 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe2 "eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & sex==0 & reason_migrate==3, vce(cluster dist_o)" 
				local fe3 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe4 "sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & primary==0 & reason_migrate==3, vce(cluster dist_o)"
				local fe5 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_rural==1 & reason_migrate==3, vce(cluster dist_o)" 
				local fe6 "eduyears sex vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}) & mig_urban==0 & reason_migrate==3, vce(cluster dist_o)"

				foreach m in 1 2 3 4 5 6 {
				
					display "`fe`m''"
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real2 `identif_a0' `fe`m''
						margins, dydx(`x'age*) post
						estimates store `t'`x'fe`m'					
				}
				coefplot (`t'`x'fe1, label(Women)) (`t'`x'fe2, label(Men)), name(`t'`x'sex_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'sex_reason3.gph", replace) ///
									level(90) ytitle("Age*drought") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal 
				coefplot (`t'`x'fe3, label(Primary)) (`t'`x'fe4, label(No Primary)), name(`t'`x'primary_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'primary_reason3.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal
				coefplot (`t'`x'fe5, label(Rural)) (`t'`x'fe6, label(No Rural)), name(`t'`x'rural_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'rural_reason3.gph", replace) ///
									level(90) ytitle("") ylabel(1 "10-17" 2 "18-27" 3 "28-37" 4 "38-47") ///
									xline(0, lcolor(red) lpattern(dash)) horizontal									
									
				graph combine `t'`x'sex `t'`x'primary `t'`x'rural, cols(3) name(`t'`x'all_r3, replace) saving("${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/marginsplot/`t'`x'all_reason3.gph", replace) ///
							title(Ave. Mg. effect of `x' by Age-CI at 90%) subtitle(Reason to migrate=marriage) ycommon xcommon
							/*note("Note: baseline category of age: 48-57. Age<10 and Age>57 are excluded.")*/
				drop `x'age*
			}		
		
}
*******************************************************************
*Robustness check by 1) spei using chrips+modis and 2) spi 2001-2016. ALL SAMPLE
******************************************************************
global drought_index1 "spei${sk}har_i spei${sk}har_igro spei${sk}har_ipos spei${sk}har_dro spei${sk}har_dro_l2 spei${sk}har_dro_d spei${sk}har_dro_d2 spei${sk}har_droext spei${sk}har_dro_l2ext spei${sk}har_dro_dext spei${sk}har_dro_d2ext"
global drought_index2 "spei${sk}tho_i spei${sk}tho_igro spei${sk}tho_ipos spei${sk}tho_dro spei${sk}tho_dro_l2 spei${sk}tho_dro_d spei${sk}tho_dro_d2 spei${sk}tho_droext spei${sk}tho_dro_l2ext spei${sk}tho_dro_dext spei${sk}tho_dro_d2ext" 
global drought_index3 "spi${sk}_0116_i spi${sk}_0116_igro spi${sk}_0116_ipos spi${sk}_0116_dro spi${sk}_0116_dro_l2 spi${sk}_0116_dro_d spi${sk}_0116_dro_d2 spi${sk}_0116_droext spi${sk}_0116_dro_l2ext spi${sk}_0116_dro_dext spi${sk}_0116_dro_d2ext"
global drought_index_rob "$drought_index1 $drought_index2 $drought_index3"

foreach t in reg probit { 
		estimates drop _all
		foreach migra in 1 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if ${sample}, vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if ${sample}, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in ${drought_index_rob} {
		
			foreach age in 1 2 3 4 { /*Baseline is category 5*/
			
				gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
				replace `x'age`age'=`x' if ${age_bracket}==`age'
				}
			*a b, to generate reg_migra_indflows.csv
			local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/
			*local identif_b0 "c.`x'##ib5.${age_bracket}##mig_hht4" /*DID with whole HH migrating*/
			
				foreach m in a {
				
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
						estimates store `t'`m'`x'`migra'	
						/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
						estimates store `t'2`m'`x'`migra' */
					}	
					drop `x'age*
				}
			}		
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_rob.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
		
}
********************************
**Robustness check by 1) spei using chrips+modis and 2) spi 2001-2016. CHILD MARRIAGE SAMPLE
********************************
foreach t in reg probit { 
		foreach reason in 3 {
			estimates drop _all
			foreach migra in 1 2 {
			
				local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if young_marriage==1, vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
			
				foreach x in ${drought_index_rob} {
				
					foreach age in 1 2 3 4 { /*Baseline is category 5*/
				
					gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age`age'=`x' if ${age_bracket}==`age'
					}
					
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" /*DID*/ 
					*local identif_b0 "c.`x'##ib6.age_bracket##c.young_marriage" /*DID*/
					foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								estimates store `t'`m'`x'`migra'`reason'	
								/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
								estimates store `t'2`m'`x'`migra'`reason' */
							}
							drop `x'age*
					}
				}	
		* Run estout/esttab
		esttab `t'* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_drought_reason`reason'_young_marriage_rob.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts for reason `reason' 1-work 3-marriagedivorce 4-family -individual migrants") /*drop(0.rollback*)*/
		}
}

****************************************
* Robustness Check by 3) SPI lagged. ALL SAMPLE
****************************************
foreach t in reg probit { /*probit*/
		estimates drop _all
		foreach migra in 1 2 {
		local fe1 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (${sample}), vce(cluster dist_o)" /* if survey!="Survey-2016-2017"*/
		local fe2 "sex eduyears vin_distance i.yearly i.con_sur i.dist_d i.dist_o i.ea_ID if (${sample}), vce(cluster ea_ID)" /*makes more sense for dist_o droughts using EA, not here. Also, takes a lot of time*/
		
		foreach x in  ${drought_index} { /*${drought_index}*/
		
				foreach age in 1 2 3 4 { /*Baseline is category 6*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					sort id yearly
					bys id: gen l`x'age_bracket`age'=`x'age_bracket`age'[_n-1]
					}
					
					local identif_a0 "c.L.`x' ib5.${age_bracket} l`x'age*" /*DID in this way to calculate the correct marginal effects of the interactions*/
					*local identif_a0 "c.`x'##ib6.age_bracket" /*DID*/
					*local identif_b0 "c.`x'##ib6.age_bracket##mig_hht4" /*DID with whole HH migrating*/
			
				foreach m in a {			
						/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
						estimates store `t'`m'`x'`migra'					
						eststo m`t'`m'`x'`migra': margins, dydx(l`x'age*) post /*For the margins*/						
												
						/*bootstrap, reps(100) seed(1): `t' mig_real`migra' `identif_`m'0' `fe2'
						estimates store `t'2`m'`x'_`migra' */
					}	
		drop `x'age* l`x'age*/*dropping each x generated of interactions*/
				}
			}		
		* Model a
		esttab `t'*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/`t'_migra_lagdrought.csv", indicate("Country-Year and Country-Survey FE = *yearly* *con_sur*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*") scalars(N r2 r2_a r2_within r2_a_within r2_p pr2 F df_m df_r df_a_initial df_a N_clust) ///
		order(sex eduyears vin_distance) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) ///
		replace title("Migration induced by droughts-individual migrants") /*drop(0.rollback*)*/
}
*Marginal Effects for interactions in probit only
esttab mprobit*a* using "${results2}/7002_panel_year_drought_o/scale_${sk}/${folder}/probit_migra_lagdrought_mg.csv", scalars(N) ///
se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) width(200%) replace title("Migration induced by droughts-individual migrants-Mg effects") /*margins also worked with reg, I will keep only for probit*/


*******************************
** MAIN TABLES AFTER DECIDING WITH KATRIN
*******************************

*************************
**** TABLE 4************* BETWEEN and WITHIN MIGRANTS-All SEX
*************************
global sample_tab "mig_ind2==1" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder_tab "main_tables" /*between_district or between_and_within_district or within_district*/
global sk_tab "12" /*spei and spi using scale*/
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext drought2 drought3"
global age_bracket "age_bracket5"

estimates drop _all
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
		foreach t in reg probit {
				foreach migra in 2 {
				local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
*Changing names for the tables
label var vin_distance "Distance dist_o-dist_d"
label var eduyears "Years of education"
label var primary "Dummy of primary education"

label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
label var drought2 "drought1 (10\%)"
label var drought3 "drought2 (20\%)"

label var spi12chr_dro_d2age_bracket1 "spi12-drought-agro (<-1) x age (10-17)"
label var spi12chr_dro_d2age_bracket2 "spi12-drought-agro (<-1) x age (18-27)"
label var spi12chr_dro_d2age_bracket3 "spi12-drought-agro (<-1) x age (28-37)"
label var spi12chr_dro_d2age_bracket4 "spi12-drought-agro (<-1) x age (38-47)"

label var spi12chr_dro_d2extage_bracket1 "spi12-drought-agro (<-2) x age (10-17)"
label var spi12chr_dro_d2extage_bracket2 "spi12-drought-agro (<-2) x age (18-27)"
label var spi12chr_dro_d2extage_bracket3 "spi12-drought-agro (<-2) x age (28-37)"
label var spi12chr_dro_d2extage_bracket4 "spi12-drought-agro (<-2) x age (38-47)"


label var drought2age_bracket1 "drought1 (10\%) x age (10-17)"
label var drought2age_bracket2 "drought1 (10\%) x age (18-27)"
label var drought2age_bracket3 "drought1 (10\%) x age (28-37)"
label var drought2age_bracket4 "drought1 (10\%) x age (38-47)"

label var drought3age_bracket1 "drought2 (20\%) x age (10-17)"
label var drought3age_bracket2 "drought2 (20\%) x age (18-27)"
label var drought3age_bracket3 "drought2 (20\%) x age (28-37)"
label var drought3age_bracket4 "drought2 (20\%) x age (38-47)"
		
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months} & \multicolumn{6}{c}{Drought using EA} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi* probit*spi* mprobit*a*spi* reg*drought* probit*drought* mprobit*a*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table4_migra_drought_all.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 5************* BETWEEN and WITHIN MIGRANTS-SEX==1 women
*************************
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in reg probit {
				foreach migra in 2 {
				local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months} & \multicolumn{6}{c}{Drought using EA} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi* probit*spi* mprobit*a*spi* reg*drought* probit*drought* mprobit*a*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table5_migra_drought_sex1.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 6************* WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE 
*************************
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}
	Already generated 
	*/
		foreach t in reg probit {
				foreach migra in 2 {
				local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}

local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months} & \multicolumn{6}{c}{Drought using EA} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi* probit*spi* mprobit*a*spi* reg*drought* probit*drought* mprobit*a*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table6_migra_drought_young_marriage.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 7************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`type'	
								eststo m`t'`x's`type': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s2* probit*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table7_migra_drought_young_marriage_within_between.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 8************* BETWEEN MIGRANTS reason==1 
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`sex'	
								eststo m`t'`x's`sex': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s0* probit*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table8_migra_drought_between_reason1.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 9************* WITHIN MIGRANTS reason==1
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==2, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`sex'	
								eststo m`t'`x's`sex': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s0* probit*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table9_migra_drought_within_reason1.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 10************* BETWEEN MIGRANTS reason==3
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`sex'	
								eststo m`t'`x's`sex': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s0* probit*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table10_migra_drought_between_reason3.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 11************* WITHIN MIGRANTS reason==3
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==2, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`sex'	
								eststo m`t'`x's`sex': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s0* probit*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table11_migra_drought_within_reason3.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 12************* BETWEEN and WITHIN MIGRANTS-All SEX, adding spi${sk_tab}chr_dro_l2 to compare
*************************
global drought_index_tab2 "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext spi${sk_tab}chr_dro_l2"
drop spi*age_bracket*
estimates drop _all
foreach x in $drought_index_tab2 {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}	
		foreach t in reg probit {
				foreach migra in 2 {
				local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							estimates store `t'`m'`x'`migra'	
							eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
*Defining again as I add a new variable
label var spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2)"
label var spi${sk_tab}chr_dro_l2ext "spi12- \% months drought-agro (<-2)"

label var spi12chr_dro_d2age_bracket1 "spi12-drought-agro (<-1) x age (10-17)"
label var spi12chr_dro_d2age_bracket2 "spi12-drought-agro (<-1) x age (18-27)"
label var spi12chr_dro_d2age_bracket3 "spi12-drought-agro (<-1) x age (28-37)"
label var spi12chr_dro_d2age_bracket4 "spi12-drought-agro (<-1) x age (38-47)"

label var spi12chr_dro_d2extage_bracket1 "spi12-drought-agro (<-2) x age (10-17)"
label var spi12chr_dro_d2extage_bracket2 "spi12-drought-agro (<-2) x age (18-27)"
label var spi12chr_dro_d2extage_bracket3 "spi12-drought-agro (<-2) x age (28-37)"
label var spi12chr_dro_d2extage_bracket4 "spi12-drought-agro (<-2) x age (38-47)"

label var spi12chr_dro_l2age_bracket1 "spi12- \% months drought-agro (<-2) x age (10-17)"
label var spi12chr_dro_l2age_bracket2 "spi12- \% months drought-agro (<-2) x age (18-27)"
label var spi12chr_dro_l2age_bracket3 "spi12- \% months drought-agro (<-2) x age (28-37)"
label var spi12chr_dro_l2age_bracket4 "spi12- \% months drought-agro (<-2) x age (38-47)"
	
local titles "& \multicolumn{9}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-10}  \addlinespace[-2ex] \\ & \multicolumn{3}{c}{OLS} & \multicolumn{3}{c}{PROBIT} & \multicolumn{3}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-4} \cmidrule(lr){5-7} \cmidrule(lr){8-10} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) \\ \hline"
esttab reg*spi* probit*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table12_migra_drought_all_extraspi.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})

*************************
**** TABLE 13 (LIKE TABLE 4 but with regife)************* BETWEEN and WITHIN MIGRANTS-All SEX. Option of regife for FACTOR MODEL
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext drought2 drought3"
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}*/
		foreach t in reg regife {
				foreach migra in 2 {
				local fereg "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o)" 
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o) factors(id yearly, 1)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p)))
							estadd scalar Ncluster=31
							estimates store `t'`m'`x'`migra'	
							*eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} & \multicolumn{4}{c}{Drought using EA} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{OLS Interactive FE} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab rega*spi* regifea*spi* rega*drought* regifea*drought*  using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table13_migra_drought_all.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N R2 R2_a Ncluster Pcorr) /// /*r2 and R2 have the same results. I added a scalar because regife does not calculate it*/
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes) drop(5.${age_bracket})

*************************
**** TABLE 14************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-REASON 1 AND 3 TOGETHER-WOMEN AND MEN
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in reg probit {
					foreach migra in 2 {
					local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & (reason_migrate==1|reason_migrate==3), vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								estimates store `t'`m'`x's`type'	
								eststo m`t'`x's`type': margins, dydx(`x' `x'age*) post /*For the margins*/
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{6}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-7} \cmidrule(lr){8-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS} & \multicolumn{2}{c}{PROBIT} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab reg*spi*s1* probit*spi*s1* mprobit*spi*s1* reg*spi*s2* probit*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table14_migra_drought_young_marriage_within_between.tex", ///
indicate("Country-Year FE = *yearly*" "Country-Survey FE = *con_sur*" "Dest-Dist FE=*dist_d*" "Dest-Orig FE=*dist_o*") scalars(N r2 r2_a r2_p N_clust Pcorr) ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace width(2\hsize) wrap nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(No Yes N_clust $N_clust$ main ) drop(5.${age_bracket})


*******************************
* BEAMER TABLES PRESENTATION AND NOW ON, FOR MAIN TEXT
******************************
*************************
**** TABLE 4 BEAMER ************* BETWEEN and WITHIN MIGRANTS-All SEX
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext drought2 drought3"
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					}*/

		foreach t in regife {
				foreach migra in 2 {
				local fe1 "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2), vce(cluster dist_o) factors(id yearly, 1)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe1'
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p)))
							estadd scalar Ncluster=31
							estimates store `t'`m'`x'`migra'	
							*eststo m`t'`m'`x'`migra': margins, dydx(`x' `x'age*) post /*For the margins*/
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{2}{c}{SPI-Cumulative drought for 12 months} & \multicolumn{2}{c}{Drought using EA} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{OLS Interactive FE} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab reg*spi* reg*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table4_pre_migra_drought_all.tex", ///
scalars(N R2 R2_a Ncluster) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$") onecell /*width(2\hsize)  */

*************************
**** TABLE 5 BEAMER  *************  BETWEEN and WITHIN MIGRANTS-SEX==1 women
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table5_pre_migra_drought_sex1.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 5a BEAMER *************  BETWEEN and WITHIN MIGRANTS-SEX==1 women EA areas
*************************
global drought_ea_tab "drought2 drought3"
estimates drop _all
foreach x in $drought_ea_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra' 
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{Drought using EA} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab regife*drought* mprobit*a*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table5a_pre_migra_drought_sex1.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 6 BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE  Interactive FE
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table6_pre_migra_drought_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 6a BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE  Interactive FE
*************************
global drought_ea_tab "drought2 drought3"
estimates drop _all
foreach x in $drought_ea_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab regife*drought* mprobit*a*drought* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table6a_pre_migra_drought_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


*************************
**** TABLE 7 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE INTERACIVE FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table7_pre_migra_drought_young_marriage_within_between.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 8 BEAMER ************* BETWEEN MIGRANTS reason==1 
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								eststo m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table8_pre_migra_drought_between_reason1.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 9 BEAMER ************* WITHIN MIGRANTS reason==1 
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==2, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==2, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								eststo m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table9_pre_migra_drought_within_reason1.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 10 BEAMER ************* WITHIN MIGRANTS reason==3 Interactive FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==1, vce(cluster dist_o)"
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {	
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Inbteractive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table10_pre_migra_drought_between_reason3.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 11 BEAMER ************* WITHIN MIGRANTS reason==3 Interactive FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==2, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==3 & mig_ind2==2, vce(cluster dist_o)"
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {	
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table11_pre_migra_drought_within_reason3.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 12 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE and WORK RELATED INTERACIVE FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & (reason_migrate==1 | reason_migrate==3), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & (reason_migrate==1 | reason_migrate==3), vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table12_pre_migra_drought_reason1-3_within-between.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*******************************
* MECHANISMS
*******************************

************************************************************************************
* MECHANISMS 1: Non agro related activities more likely to pay lobola-bride price in destination district
************************************************************************************
rename Y* =_d
tab Yag_per_d 

*Defining sample of child-young marriage
gen young_girls=0
replace young_girls=1 if (age_migrate>12 & age_migrate<20) & sex==1
bys reason_migrate: sum Yag_per_d if young_girls==1 /*More agro income for marriage*/

* Using type of work of HH head. For all surveys but not info for many
tab work_hh_head_ag reason_migrate if mig_real2==1, column /*We can say that for all the reasons, in 92% of the cases the HH_head does not work in agriculture. Good to know those numbers for not migrants or all sample by survey*/
tab mig_ind2 work_hh_head_ag if mig_real2==1 & reason_migrate==1, row
tab mig_ind2 work_hh_head_ag if mig_real2==1 & reason_migrate==3, row
tab mig_ind2 work_hh_head_ag if mig_real2==1 & reason_migrate==4, row

estpost tab reason_migrate work_hh_head_ag if mig_real2==1
est store mecha1a
esttab mecha1a using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism1a.tex", cells("b(fmt(0) label(Observ.)) rowpct(fmt(1) label(Percentage))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule Type of Migrant & \multicolumn{2}{c}{HH head NO working on Agri.} & \multicolumn{2}{c}{HH head working on Agri.} & \multicolumn{2}{c}{Total} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \cmidrule(lr){6-7} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\") 

***************************************************************************************
* MECHANISM 2: Info of LOBOLA or marriage costs in the last year. For those migrating in t-1 of survey. Difficult to say something, very small sample and it could be that bride-price is paid in other ways and by different years
**************************************************************************************
matrix M = J(18,2,0)
matrix colname M = Lobola No_Lobola
matrix rowname M = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17
tab age_ago k_lobola if yearly==2000, matcell(total)  /*Among those who had lobola's payments, they were made 0-2 years ago. That's all I could say. restricted to one year to have total of individuals*/
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A31=matrix(C), names
tab age_migrate age_ago  if k_lobola==1 & yearly==2005 & age_ago<=2
tab age_migrate age_ago  if yearly==2005 & age_ago<=2

************************************************************************************
* MECHANISMS 3b-3c: Married girls more likely to drop-out school or get pregnant in destination district (after migrating). Question for 3 surveys only 2004-2005 2010-2011 2016-2017
************************************************************************************
matrix M = J(6,2,0)
matrix colname M = drop_out_others drop_out_mar_preg
matrix rowname M = "WORK RELATED/LOOK" "FOR SCHOOL/STUDIES" "MARRIAGE" "FAMILY REASONS/FOLLOW" "LAND/PLOT/OTHER LAND" "OTHERS"
tab reason_migrate noedu_mar_preg if mig_real2==1, matcell(total) /*Importantly, 1/2 of migrants drop-out school and important portion for marriage-pregnancy*/
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A57=matrix(C), names

estpost tab reason_migrate noedu_mar_preg if mig_real2==1
est store mecha3b
esttab mecha3b using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism3b.tex", cells("b(fmt(0) label(Observ.)) rowpct(fmt(1) label(Percentage))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule Reason to migrate & \multicolumn{2}{c}{Drop-out school - other reasons} & \multicolumn{2}{c}{Drop-out school for marriage-pregnancy} & \multicolumn{2}{c}{Total} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \cmidrule(lr){6-7} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\")
		
*EXTRA INFO FOR T-TESTS IN THE TEXT of previous table mechanism3b.tex
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("t_test_JODE_pub") //where to put the results
putexcel A21=matrix(C), names

*MArriage-MIG vs others-MIG
prtesti `=C[3,1]+C[3,2]' `=C[3,2]' `=C[1,1]+C[1,2]+C[2,1]+C[2,2]+C[4,1]+C[4,2]+C[5,1]+C[5,2]+C[6,1]+C[6,2]' `=C[1,2]+C[2,2]+C[4,2]+C[5,2]+C[6,2]', count
local p2 = 2*(normprob(-abs(r(z))))
if r(z) < 0 {
 local p1 = `p2'/2
 local p3 = 1 - `p1'
}
else {
  local p3 = `p2'/2
  local p1 = 1 - `p3'
}
display `"p1=`p1'; p2=`p2'; p3=`p3'"'
putexcel D24=matrix(r(z))
putexcel E24="p1=`p1'; p2=`p2'; p3=`p3'"

matrix M = J(18,2,0)
matrix colname M = drop_out_others drop_out_mar_preg
matrix rowname M = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17
tab age_ago noedu_mar_preg if mig_real2==1, matcell(total) /*Big portion of drop-outs are for those migrating 5 years ago */
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A65=matrix(C), names

estpost tab age_ago noedu_mar_preg if mig_real2==1
est store mecha3c
esttab mecha3c using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism3c.tex", cells("b(fmt(0) label(Observ.))") ///
		nostar unstack noobs compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-4} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{c*{4}{c}} \toprule Years ago to migrate & Drop-out for other reasons & Drop-out for marriage-pregnancy & Total \\ \cmidrule(lr){2-4} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-4} \addlinespace[-2ex] \\")

************************************************************************************
* MECHANISMS 4: Married girls more likely to get pregnant in destination district (after migrating). Question for 3 surveys only 2004-2005 2010-2011 2013
************************************************************************************
matrix M = J(6,2,0)
matrix colname M = pregnancy_24_months no_pregnancy_24_months
matrix rowname M = "WORK RELATED/LOOK" "FOR SCHOOL/STUDIES" "MARRIAGE" "FAMILY REASONS/FOLLOW" "LAND/PLOT/OTHER LAND" "OTHERS"
tab reason_migrate hh_d40 if mig_real2==1, matcell(total) /*migrants for marriage are more likely pregnant*/
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace)  //modify
putexcel A91=matrix(C), names

estpost tab reason_migrate hh_d40 if mig_real2==1
est store mecha4b
esttab mecha4b using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism4b.tex", cells("b(fmt(0) label(Observ.)) rowpct(fmt(1) label(Percentage))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-7} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{7}{c}} \toprule Reason to migrate & \multicolumn{2}{c}{Pregnancy} & \multicolumn{2}{c}{No Pregnancy} & \multicolumn{2}{c}{Total} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \cmidrule(lr){6-7} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-7} \addlinespace[-2ex] \\")

*EXTRA INFO FOR T-TESTS IN THE TEXT of previous table mechanism4b.tex
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("t_test_JODE_pub") //where to put the results
putexcel A30=matrix(C), names

*MArriage-MIG vs others-MIG
prtesti `=C[3,1]+C[3,2]' `=C[3,1]' `=C[1,1]+C[1,2]+C[2,1]+C[2,2]+C[4,1]+C[4,2]+C[5,1]+C[5,2]+C[6,1]+C[6,2]' `=C[1,1]+C[2,1]+C[4,1]+C[5,1]+C[6,1]', count
local p2 = 2*(normprob(-abs(r(z))))
if r(z) < 0 {
 local p1 = `p2'/2
 local p3 = 1 - `p1'
}
else {
  local p3 = `p2'/2
  local p1 = 1 - `p3'
}
display `"p1=`p1'; p2=`p2'; p3=`p3'"'
putexcel D33=matrix(r(z))
putexcel E33="p1=`p1'; p2=`p2'; p3=`p3'"

matrix M = J(15,2,0)
matrix colname M = pregnancy_24_months no_pregnancy_24_months
matrix rowname M = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14
tab age_ago hh_d40 if mig_real2==1, matcell(total)  /*migrants for marriage are more likely pregnant in the last 5 years*/
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A99=matrix(C), names

estpost tab age_ago hh_d40 if mig_real2==1
est store mecha4c
esttab mecha4c using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism4c.tex", cells("b(fmt(0) label(Observ.))") ///
		nostar unstack noobs compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-4} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{c*{4}{c}} \toprule Years ago to migrate & Pregnancy & No Pregnancy & Total \\ \cmidrule(lr){2-4} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-4} \addlinespace[-2ex] \\")

************************************************************************************
* MECHANISMS 5: Migrants for marriage are married more? in destination district (after migrating). 
************************************************************************************
matrix M = J(6,6,0)
matrix colname M = marry_mono marry_poly separated divorced widow never_married
matrix rowname M = "WORK RELATED/LOOK" "FOR SCHOOL/STUDIES" "MARRIAGE" "FAMILY REASONS/FOLLOW" "LAND/PLOT/OTHER LAND" "OTHERS"
tab reason_migrate hh_b24 if yearly==2000, matcell(total) 
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A122=matrix(C), names

estpost tab reason_migrate hh_b24 if mig_real2==1
est store mecha5b
esttab mecha5b using "${results2}/7002_panel_year_drought_o/mechanism_tables/mechanism5b.tex", cells("b(fmt(0) label(Observ.))") ///
		nostar unstack noobs label compress nogaps alignment(c) replace booktabs nonumber nonote wide mlabels(none) nomtitle ///
		eqlabels(none) varlabels(`e(labels)', blist(Total \cmidrule(lr){1-8} \addlinespace[-2ex])) /// 
		prehead("\begin{tabular}{l*{8}{c}} \toprule  & Monogamous & Polygamous & Separated & Divorced & Widowed & Never married & Total \\ \cmidrule(lr){2-8} \addlinespace[-2ex] \\") /// /*substitute("<-" "$<-$" )*/
		posthead(" \cmidrule(lr){1-8} \addlinespace[-2ex] \\")
		
matrix M = J(18,6,0)
matrix colname M = marry_mono marry_poly separated divorced widow never_married
matrix rowname M = 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17
tab age_ago hh_b24 if yearly==2000, matcell(total) 
matrix C=total+M
putexcel set "${results2}/MIG_descriptive.xlsx", sheet("Mechanisms", replace) //modify
putexcel A130=matrix(C), names

tab age_migrate hh_b24 if yearly==2000 & age_ago<=5 & age_migrate<30

*************************************************************
** MEASUREMENT ERRORS IN MIGRATION QUESTION
*************************************************************
tab  moduleB_resp sex_hh_head if mig_real2==1 /*IF HH head is woman, she answers. If the HH head is man, 1/2 of times he answers and 1/2 wife answers*/
bys sex_hh_head: summ age_years  if mig_real2==1
bys moduleB_resp: summ age_years  if mig_real2==1

bys sex_hh_head: summ age_years  if mig_real2==1 & moduleB_resp==1
bys sex_hh_head: summ age_years  if mig_real2==1 & moduleB_resp==2 /*Difference on average age comes from woman HH head, she tends to be younger*/

gen B_resp_sex=.
replace B_resp_sex=1 if sex_hh_head==1 & moduleB_resp==1
replace B_resp_sex=2 if sex_hh_head==1 & moduleB_resp==2
replace B_resp_sex=3 if sex_hh_head==2 & moduleB_resp==1 /*Those are the majority of the options*/

label define sex_B 1 "HH HEAD(MAN)-HE answers B Module" 2 "HH HEAD(MAN)-WIFE answers B Module" 3 "HH HEAD(WOMAN)-SHE answers B Module"
label values B_resp_sex sex_B

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 3 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if B_resp_sex==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if B_resp_sex==`type' & (young_marriage==1), vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)-HE answers)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)-WIFE answers)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(WOMAN)-SHE answers)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \cmidrule(lr){10-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) & (10) & (11) & (12) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* regife*spi*s3* mprobit*spi*s3* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table13_pre_migra_drought_young_marriage_B_resp_sex.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

**********************************************************************************************************************************
******** FROM HERE? IT LOOKS LIKE RESULTS ARE COMING MAINLY WHEN WOMEN REPLIES THE QUESTIONNAIRE. MEASUREMENT ERRORS MORE WHEN A MAN REPLIES
* Assuming this, let's take sex_hh_head to see if there are differences. When woman is HH head, she almost always answers questions
*********************************************************************************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex_hh_head==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex_hh_head==`type' & (young_marriage==1), vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(MAN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (HH HEAD(WOMAN))} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table14_pre_migra_drought_young_marriage_sex_hh_head.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute(<- $<-$)  /*width(2\hsize) substitute(_ \_  $  \\$  %  \% ) R2_ $R2 $R2_a _a$ _p _p$ */

************************************************************************************
* Matrilineal vs Patrilineal plays a role? Classification of language(not info of ethnicity but matches with that) from  https://www.sciencedirect.com/science/article/pii/S0264837714000945
************************************************************************************
gen patrilineal=.
replace patrilineal=1 if language_hh==4 | language_hh==6| language_hh==7|language_hh==8 |language_hh==9 |language_hh==10 |language_hh==11
replace patrilineal=0 if language_hh==1| language_hh==2 |language_hh==3 |language_hh==5

label define patri_label 1 "Patrilineal" 0 "Matrilineal"
label values patrilineal patri_label

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if patrilineal==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" /*mig_ind2==1 or 2*/
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if patrilineal==`type' & (young_marriage==1), vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (PATRILINEAL)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MATRILINEAL)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table15_pre_migra_drought_young_marriage_patrilineal.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


************************************************************************************
* Instead of Matrilineal vs Patrilineal plays a role, region? 
************************************************************************************
gen regiony=.
replace regiony=1 if region=="North"
replace regiony=2 if region=="Central"
replace regiony=3 if region=="South"

label define reg_label 1 "North" 2 "Central" 3 "South"
label values regiony reg_label

estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 3 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if regiony==`type' & (young_marriage==1), vce(cluster dist_o) factors(id yearly, 1)" /*mig_ind2==1 or 2*/
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if regiony==`type' & (young_marriage==1), vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (NORTH)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (CENTRAL)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (SOUTH)}  \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \cmidrule(lr){10-13} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \cmidrule(lr){10-11} \cmidrule(lr){12-13} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) & (9) &  (10) &  (11) &  (12) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* regife*spi*s3* mprobit*spi*s3* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table16_pre_migra_drought_young_marriage_region.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*********
*Small test to see aggregated migration dist_o for droughts
***********
preserve
collapse (sum) mig_real2 (mean) spi12chr* spi24chr*, by(dist_d dist_o yearly)
/*foreach x in ${drought_index} {
	reg mig_real2 `x' i.yearly i.dist_d i.dist_o, vce(cluster dist_o)
	estimates store reg`x'
}
esttab reg* , indicate("Country-Year FE = *yearly*" "FE-Dest_Dist=*dist_d*" "FE-Dest_Orig=*dist_o*")
*/
save "${work2}\mig_flow_dist_o.dta", replace
restore

****************************************
*CHECKING LESS DROUGHT IN DIST D MAKES ME RECEIVE MORE MIGRANTS IN DIST D!!!!
****************************************
*Merging with main events in the community (drought-floods-epidemics-price_change), but now at dist_d
rename (drought* flood* epidemic* price_change* ) (o_=) /*_o for origin*/
preserve
	use "${work2}\com_events.dta", clear
	rename dist_o dist_d
	rename year yearly
	rename (drought* flood* epidemic* price_change* ) (d_=) /*_d for destination*/
	tempfile com
	save "`com'", replace
restore

merge m:1 survey dist_d yearly using "`com'", keep(master using match) gen(merge_eventd)
drop merge_eventd

gen d_drought4=0
sort id yearly
bys id: replace d_drought4=1 if d_drought1[_n+1]==1 /*Lagged drought*/
label variable d_drought4 "d_drought1(t-1)"

*Including data of droughts SPEI SPI indeces, but now at dist_d
rename (spi* spei*) (o_=) /*From here drought indeces are from destination*/
preserve
	use "${work2}\SPEI_SPI.dta", clear
	rename dist_o dist_d
	rename (spi* spei*) (d_=) /*added d for destination at the beginning of all variables*/
	tempfile spi
	save "`spi'", replace
restore

merge m:1 dist_d yearly using "`spi'", keep(master using match) gen(merge_tempd)
drop if merge_tempd==2 /*those are for Uganda, Tanzania and Malawi(before 2000)*/
drop merge_tempd
sort id yearly

*********
*Small test to see aggregated migration dist_d for droughts
***********
preserve
collapse (sum) mig_real2 (mean) d_spi12chr* d_spi24chr*, by(dist_d dist_o yearly)
/*
reg mig_real2 spi12chr_i i.yearly i.dist_d i.dist_o, vce(cluster dist_d)
*/
save "${work2}\mig_flow_dist_d.dta", replace
restore

*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER - ALL MIGRANTS by SEX; FOR WITHIN, dist_d*spi and dist_o*spi are the same variables so TABLES ONLY USING BETWEEN MAKE SENSE
******************************************************************
global sk_tab "12" /*spei and spi using scale*/
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "main_tables" /*between_district or between_and_within_district or within_district*/
global age_bracket "age_bracket5"

estimates drop _all
foreach type in 1 0 {
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
						
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type' & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type' & mig_ind2==1, vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age* c.od_`x' od_`x'age*"
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+21 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d and 5 more for interactions ==21*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`x's`type'	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* od_`x' od_`x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
									/*
									foreach a in 1 2 3 4 { /*Baseline is category 5 and we expect 4>3>2>1 with 4 most likely*/
											estimates restore `t'`m'`x'`type'
											lincomest `a'.age_bracket  /*lincomest _cons +  `a'.age_bracket*/
											estimates store l`t'`x'`type'`a'1
											estimates restore `t'`m'`x'`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x'+d_`x'age_bracke`a' */
											estimates store l`t'`x'`type'`a'2
											estimates restore `t'`m'`x'`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a'+o_`x'age_bracke`a' + od_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x' +d_`x'age_bracke`a'+o_`x'+o_`x'age_bracke`a' +od_`x' +od_`x'age_bracke`a'*/
											estimates store l`t'`x'`type'`a'3
											estimates restore `t'`m'`x'`type'
											lincomest `a'.age_bracket + o_`x'age_bracke`a' /*_cons +  `a'.age_bracket + o_`x'+o_`x'age_bracke`a'*/
											estimates store l`t'`x'`type'`a'4
									}
									*/
							}
						}
					}
				drop d_`x'age* o_`x'age* od_`x'age* od_`x' /*dropping each x generated of interactions*/
	}
}
	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d od {
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MEN)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17_pre_migra_drought_distd_disto.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///				
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$" "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */

*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER - YOUNG MARRIAGE. FOR WITHIN, dist_d*spi and dist_o*spi are the same variables so TABLES ONLY USING BETWEEN MAKE SENSE
*****************************************************************
drop d_*age_bracke* o_*age_bracke* od_*age_bracke* od_spi12chr_dro_d2 od_spi12chr_dro_d2ext
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
					
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1) & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1) & mig_ind2==1, vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age* c.od_`x' od_`x'age*"
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+21 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d and 5 more for interactions ==21*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* od_`x' od_`x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's
							}
						}
					}
				drop d_`x'age* o_`x'age* od_`x'age* od_`x' /*dropping each x generated of interactions*/
}

	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d od {
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ &  \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab regife*spi*s* mprobit*spi*s*  using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17_pre_migra_drought_distd_disto_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$" "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */



*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER BUT NO INTERACTION NOW- ALL MIGRANTS by SEX; FOR WITHIN, dist_d*spi and dist_o*spi are the same variables so TABLES ONLY USING BETWEEN MAKE SENSE
******************************************************************
drop d_*age_bracke* o_*age_bracke* od_*age_bracke* od_spi12chr_dro_d2 od_spi12chr_dro_d2ext
global sk_tab "12" /*spei and spi using scale*/
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
global sample "mig_ind2==1 | mig_ind2==2" /* mig_ind2==1 or mig_ind2==1 | mig_ind2==2 or mig_ind2==2*/
global folder "main_tables" /*between_district or between_and_within_district or within_district*/
global age_bracket "age_bracket5"

estimates drop _all
foreach type in 1 0 {
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					*gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					*replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					*gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
						
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type' & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`type' & mig_ind2==1, vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age* " //c.od_`x' od_`x'age*
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+16 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d now no interactions ==16*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* ) post /*For the margins od_`x' od_`x'age**/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
									/*
									foreach a in 1 2 3 4 { /*Baseline is category 5 and we expect 4>3>2>1 with 4 most likely*/
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket  /*lincomest _cons +  `a'.age_bracket*/
											estimates store l`t'`x's`type'a`a'1
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x'+d_`x'age_bracke`a' */
											estimates store l`t'`x's`type'a`a'2
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + d_`x'age_bracke`a'+o_`x'age_bracke`a' + od_`x'age_bracke`a' /*_cons +  `a'.age_bracket + d_`x' +d_`x'age_bracke`a'+o_`x'+o_`x'age_bracke`a' +od_`x' +od_`x'age_bracke`a'*/
											estimates store l`t'`x's`type'a`a'3
											estimates restore `t'`m'`x's`type'
											lincomest `a'.age_bracket + o_`x'age_bracke`a' /*_cons +  `a'.age_bracket + o_`x'+o_`x'age_bracke`a'*/
											estimates store l`t'`x's`type'a`a'4
									}
									*/
							}
						}
					}
				drop d_`x'age* o_`x'age*  /*dropping each x generated of interactions od_`x'age* od_`x'*/
	}
}
	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					*gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					*replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					*gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d { /*od*/
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (MEN)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17b_pre_migra_drought_distd_disto.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///				
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$" "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */

*****************************************************************
***** INCLUDING DROUGHTS_D AND DROUGHT_O TOGETHER - YOUNG MARRIAGE NOT INTERACTION. FOR WITHIN, dist_d*spi and dist_o*spi are the same variables so TABLES ONLY USING BETWEEN MAKE SENSE
*****************************************************************
drop d_*age_bracke* o_*age_bracke*
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
	foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					*gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					*replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					*gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
					
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1) & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (young_marriage==1) & mig_ind2==1, vce(cluster dist_o) iter(100)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.o_`x' ib5.${age_bracket} o_`x'age* c.d_`x' d_`x'age*" //c.od_`x' od_`x'age*
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))							
								estadd scalar pr=17+31+31+4+16 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11+5 more for dist_d and no for interactions ==16*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's	
								margins, dydx(o_`x' o_`x'age* d_`x' d_`x'age* ) post /*For the margins od_`x' od_`x'age**/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's
							}
						}
					}
				drop d_`x'age* o_`x'age*  /*dropping each x generated of interactions od_`x'age* od_`x'*/
}

	*Labels
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen d_`x'age_bracke`age'=0 if ${age_bracket}!=. & d_`x'!=.
					replace d_`x'age_bracke`age'=d_`x' if ${age_bracket}==`age'
					gen o_`x'age_bracke`age'=0 if ${age_bracket}!=. & o_`x'!=.
					replace o_`x'age_bracke`age'=o_`x' if ${age_bracket}==`age'
					*gen od_`x'age_bracke`age'=0 if o_`x'age_bracke`age'!=. & d_`x'age_bracke`age'!=.
					*replace od_`x'age_bracke`age'=o_`x'age_bracke`age'*d_`x'age_bracke`age' if ${age_bracket}==`age'
					}
					*Generating the extra baseline category for the interaction
					*gen od_`x'=o_`x'*d_`x' if o_`x'!=. & d_`x'!=.
}
foreach t in o d { /*od*/
	label var `t'_spi${sk_tab}chr_dro_d2 "spi12-drought-agro (<-1) dist-`t'"
	label var `t'_spi${sk_tab}chr_dro_d2ext "spi12-drought-agro (<-2) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke1 "spi12-drought-agro (<-1) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke2 "spi12-drought-agro (<-1) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke3 "spi12-drought-agro (<-1) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2age_bracke4 "spi12-drought-agro (<-1) x age (38-47) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke1 "spi12-drought-agro (<-2) x age (10-17) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke2 "spi12-drought-agro (<-2) x age (18-27) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke3 "spi12-drought-agro (<-2) x age (28-37) dist-`t'"
	label var `t'_spi12chr_dro_d2extage_bracke4 "spi12-drought-agro (<-2) x age (38-47) dist-`t'"
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (WOMEN)} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ &  \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5}  \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4)  \\ \hline"
esttab regife*spi*s* mprobit*spi*s*  using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table17b_pre_migra_drought_distd_disto_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$" "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */


*************************************************************************************************************************
*************************************************************************************************************************
**** DOING TABLES BEAMER 5-6-7-8 ADDING WHOLE HH MIGRATING AS CONTROL OR INTERACTION. ASKED BY REFEREES TO TEST ****************
*************************************************************************************************************************
*************************************************************************************************************************
drop d_*
rename (o_*) (*) // to bring back names without o_*
*************************
**** TABLE 5 BEAMER  *************  BETWEEN and WITHIN MIGRANTS-SEX==1 women
*************************
global sk_tab "12" /*spei and spi using scale*/
global folder_tab "main_tables" 
global age_bracket "age_bracket5"
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all

*For age
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
	}
}
*For age and whole HH migrated
foreach x in $drought_index_tab {
	gen `x'HH=0 if `x'!=. & mig_hht4!=.
	replace `x'HH=`x' if mig_hht4==1
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'HHage_bracket`age'=0 if ${age_bracket}!=. & `x'!=. & mig_hht4!=.
			replace `x'HHage_bracket`age'=`x' if ${age_bracket}==`age' & mig_hht4==1
	}
}

*Defining again as I add a new variable
label var spi${sk_tab}chr_dro_d2HH "spi12-drought-agro (<-1)-all HH mig"
label var spi${sk_tab}chr_dro_d2extHH "spi12-drought-agro (<-2)-all HH mig"

label var spi12chr_dro_d2HHage_bracket1 "spi12-drought-agro (<-1) x age (10-17)-all HH mig"
label var spi12chr_dro_d2HHage_bracket2 "spi12-drought-agro (<-1) x age (18-27)-all HH mig"
label var spi12chr_dro_d2HHage_bracket3 "spi12-drought-agro (<-1) x age (28-37)-all HH mig"
label var spi12chr_dro_d2HHage_bracket4 "spi12-drought-agro (<-1) x age (38-47)-all HH mig"

label var spi12chr_dro_d2extHHage_bracket1 "spi12-drought-agro (<-2) x age (10-17)-all HH mig"
label var spi12chr_dro_d2extHHage_bracket2 "spi12-drought-agro (<-2) x age (18-27)-all HH mig"
label var spi12chr_dro_d2extHHage_bracket3 "spi12-drought-agro (<-2) x age (28-37)-all HH mig"
label var spi12chr_dro_d2extHHage_bracket4 "spi12-drought-agro (<-2) x age (38-47)-all HH mig"

foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_hht4 i.mig_hht4#ib5.${age_bracket} `x'HH*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age* `x'HH*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table18_pre_liketable5_pre_migra_drought_sex1_wholeHH.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_hht4)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 6 BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE  Interactive FE
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_hht4 i.mig_hht4#ib5.${age_bracket} `x'HH*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age* `x'HH*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table19_pre_liketable6_pre_migra_drought_young_marriage_wholeHH.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_hht4)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */

*************************
**** TABLE 7 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE INTERACIVE FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_hht4 i.mig_hht4#ib5.${age_bracket} `x'HH*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age* `x'HH*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table20_pre_liketable7_pre_migra_drought_young_marriage_within_between_wholeHH.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_hht4)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


*************************
**** TABLE 8 BEAMER ************* BETWEEN MIGRANTS reason==1 
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_hht4 i.mig_hht4#ib5.${age_bracket} `x'HH*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age* `x'HH*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								eststo m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table21_pre_liketable8_pre_migra_drought_between_reason1_wholeHH.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_hht4)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" main )  /*width(2\hsize)  */


*************************************************************************************************************************
*************************************************************************************************************************
**** DOING TABLES BEAMER 5-6-7-8 INSTEAD OF WHOLE HH MIGRATING AS INTERACTION, SIBLINGS. ASKED BY REFEREES TO TEST ****************
*************************************************************************************************************************
*************************************************************************************************************************
************************* TABLE 22 are in file 9002, so next table here goes to 23
**** TABLE 5 BEAMER  *************  BETWEEN and WITHIN MIGRANTS-SEX==1 women
*************************
global sk_tab "12" /*spei and spi using scale*/
global folder_tab "main_tables" 
global age_bracket "age_bracket5"
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all

*For age
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'age`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age`age'=`x' if ${age_bracket}==`age'
	}
}
*For age and SIBLING
rename (sibling sibling_boy sibling_girl) (sib sboy sgirl)
foreach y in sib sboy sgirl {
	foreach x in $drought_index_tab {
		gen `x'`y'=0 if `x'!=. & `y'!=.
		replace `x'`y'=`x' if `y'==1
		foreach age in 1 2 3 4 { /*Baseline is category 5*/
				gen `x'`y'age`age'=0 if ${age_bracket}!=. & `x'!=. & `y'!=.
				replace `x'`y'age`age'=`x' if ${age_bracket}==`age' & `y'==1
		}
	}
}

*Defining again as I add a new variable
label var spi12chr_dro_d2 "spi12-drought-agro (<-1)"
label var spi12chr_dro_d2ext "spi12-drought-agro (<-2)"
label var spi12chr_dro_d2age1 "spi12-drought-agro (<-1) x age (10-17)"
label var spi12chr_dro_d2age2 "spi12-drought-agro (<-1) x age (18-27)"
label var spi12chr_dro_d2age3 "spi12-drought-agro (<-1) x age (28-37)"
label var spi12chr_dro_d2age4 "spi12-drought-agro (<-1) x age (38-47)"
label var spi12chr_dro_d2extage1 "spi12-drought-agro (<-2) x age (10-17)"
label var spi12chr_dro_d2extage2 "spi12-drought-agro (<-2) x age (18-27)"
label var spi12chr_dro_d2extage3 "spi12-drought-agro (<-2) x age (28-37)"
label var spi12chr_dro_d2extage4 "spi12-drought-agro (<-2) x age (38-47)"
	
label var sib "Having sibling at home"
label var spi12chr_dro_d2sib "spi12-drought-agro(<-1) x sibling"
label var spi12chr_dro_d2extsib "spi12-drought-agro(<-2) x sibling"

label var spi12chr_dro_d2sibage1 "spi12-drought-agro(<-1) x age(10-17) x sibling"
label var spi12chr_dro_d2sibage2 "spi12-drought-agro(<-1) x age(18-27) x sibling"
label var spi12chr_dro_d2sibage3 "spi12-drought-agro(<-1) x age(28-37) x sibling"
label var spi12chr_dro_d2sibage4 "spi12-drought-agro(<-1) x age(38-47) x sibling"

label var spi12chr_dro_d2extsibage1 "spi12-drought-agro(<-2) x age(10-17) x sibling"
label var spi12chr_dro_d2extsibage2 "spi12-drought-agro(<-2) x age(18-27) x sibling"
label var spi12chr_dro_d2extsibage3 "spi12-drought-agro(<-2) x age(28-37) x sibling"
label var spi12chr_dro_d2extsibage4 "spi12-drought-agro(<-2) x age(38-47) x sibling"

label var sboy "Having sibling at home-boy"
label var spi12chr_dro_d2sboy "spi12-drought-agro(<-1) x sibling boy"
label var spi12chr_dro_d2extsboy "spi12-drought-agro(<-2) x sibling boy"

label var spi12chr_dro_d2sboyage1 "spi12-drought-agro(<-1) x age(10-17) x sibling boy"
label var spi12chr_dro_d2sboyage2 "spi12-drought-agro(<-1) x age(18-27) x sibling boy"
label var spi12chr_dro_d2sboyage3 "spi12-drought-agro(<-1) x age(28-37) x sibling boy"
label var spi12chr_dro_d2sboyage4 "spi12-drought-agro(<-1) x age(38-47) x sibling boy"

label var spi12chr_dro_d2extsboyage1 "spi12-drought-agro(<-2) x age(10-17) x sibling boy"
label var spi12chr_dro_d2extsboyage2 "spi12-drought-agro(<-2) x age(18-27) x sibling boy"
label var spi12chr_dro_d2extsboyage3 "spi12-drought-agro(<-2) x age(28-37) x sibling boy"
label var spi12chr_dro_d2extsboyage4 "spi12-drought-agro(<-2) x age(38-47) x sibling boy"

label var sgirl "Having sibling at home-girl"
label var spi12chr_dro_d2sgirl "spi12-drought-agro(<-1) x sibling girl"
label var spi12chr_dro_d2extsgirl "spi12-drought-agro(<-2) x sibling girl"

label var spi12chr_dro_d2sgirlage1 "spi12-drought-agro(<-1) x age(10-17) x sibling girl"
label var spi12chr_dro_d2sgirlage2 "spi12-drought-agro(<-1) x age(18-27) x sibling girl"
label var spi12chr_dro_d2sgirlage3 "spi12-drought-agro(<-1) x age(28-37) x sibling girl"
label var spi12chr_dro_d2sgirlage4 "spi12-drought-agro(<-1) x age(38-47) x sibling girl"

label var spi12chr_dro_d2extsgirlage1 "spi12-drought-agro(<-2) x age(10-17) x sibling girl"
label var spi12chr_dro_d2extsgirlage2 "spi12-drought-agro(<-2) x age(18-27) x sibling girl"
label var spi12chr_dro_d2extsgirlage3 "spi12-drought-agro(<-2) x age(28-37) x sibling girl"
label var spi12chr_dro_d2extsgirlage4 "spi12-drought-agro(<-2) x age(38-47) x sibling girl"

foreach y in sib sboy sgirl {
		estimates drop _all
		foreach x in $drought_index_tab {
			/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
							gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
							replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
							} Already generated*/
				foreach t in regife probit {
						foreach migra in 2 {
						local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
						local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
				
						*a b, to generate reg_migra_indflows.csv
						local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.`y' i.`y'#ib5.${age_bracket} `x'`y'*" 				
							foreach m in a {
							
									/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
									estadd scalar R2=e(mss)/(e(mss)+e(rss))
									estadd scalar p`t'=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
									estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
									estadd scalar Ncluster=31
									local R2_p=e(r2_p)
									cap estat classification
									estadd scalar Pcorr= r(P_corr)
									local Pcorr = r(P_corr)
									estimates store `t'`m'`x'`migra'	
									margins, dydx(`x' `x'age* `x'`y'*) post /*For the margins*/
									cap estadd scalar R2_p=r2_p
									estadd scalar Ncluster=31
									cap estadd scalar R2_p=`R2_p'
									cap estadd scalar Pcorr= `Pcorr'
									estimates store m`t'`m'`x'`migra'
								}
							}
						}
						*drop `x'age* /*dropping each x generated of interactions*/
		}
				
		local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
		*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
		local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
		esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table23_pre_liketable5_pre_migra_drought_sex1_`y'.tex", ///
		scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.`y')  ///
		order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
		replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */
}

*************************
**** TABLE 6 BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE(reason 3 and Women)  Interactive FE
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach y in sib sboy sgirl {
		estimates drop _all
		foreach x in $drought_index_tab {
			/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
							gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
							replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
							} Already generated*/
				foreach t in regife probit {
						foreach migra in 2 {
						local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
						local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
						*a b, to generate reg_migra_indflows.csv
						local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.`y' i.`y'#ib5.${age_bracket} `x'`y'*" 				
							foreach m in a {
							
									/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
									estadd scalar R2=e(mss)/(e(mss)+e(rss))
									estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
									estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
									estadd scalar Ncluster=31
									local R2_p=e(r2_p)
									cap estat classification
									estadd scalar Pcorr= r(P_corr)
									local Pcorr = r(P_corr)
									estimates store `t'`m'`x'`migra'	
									margins, dydx(`x' `x'age* `x'`y'*) post /*For the margins*/
									estadd scalar Ncluster=31
									cap estadd scalar R2_p=`R2_p'
									cap estadd scalar Pcorr= `Pcorr'
									estimates store m`t'`m'`x'`migra'
								}
							}
						}
						*drop `x'age* /*dropping each x generated of interactions*/
		}
				
		local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
		*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
		local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
		esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table24_pre_liketable6_pre_migra_drought_young_marriage_`y'.tex", ///
		scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.`y')  ///
		order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
		replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */
}

*************************
**** TABLE 7 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE(reason 3 women) INTERACIVE FE
*************************
foreach y in sib sboy sgirl {
		estimates drop _all
		global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
		foreach type in 1 2 {
			foreach x in $drought_index_tab {
				/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
								gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
								replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
								}
				Already generated 
				*/
					foreach t in regife probit {
							foreach migra in 2 {
							local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
							local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o) iterate(100)" 
							*a b, to generate reg_migra_indflows.csv
							local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.`y' i.`y'#ib5.${age_bracket} `x'`y'*" 				
								foreach m in a {
								
										/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
										estadd scalar R2=e(mss)/(e(mss)+e(rss))
										estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
										estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
										estadd scalar Ncluster=31
										local R2_p=e(r2_p)
										cap estat classification
										estadd scalar Pcorr= r(P_corr)
										local Pcorr = r(P_corr)
										estimates store `t'`m'`x's`type'	
										margins, dydx(`x' `x'age* `x'`y'*) post /*For the margins*/
										estadd scalar Ncluster=31
										cap estadd scalar R2_p=`R2_p'
										cap estadd scalar Pcorr= `Pcorr'
										estimates store m`t'`x's`type'
									}
								}
							}
							*drop `x'age* /*dropping each x generated of interactions*/
			}
		}
		local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
		*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
		local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
		esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table25_pre_liketable7_pre_migra_drought_young_marriage_within_between_`y'.tex", ///
		scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.`y')  ///
		order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
		replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */
}

*************************
**** TABLE 8 BEAMER ************* BETWEEN MIGRANTS reason==1 
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach y in sib sboy sgirl {
	estimates drop _all
	foreach sex in 1 0 {
		foreach x in $drought_index_tab {
			/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
							gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
							replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
							}
			Already generated 
			*/
				foreach t in regife probit {
						foreach migra in 2 {
						local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
						local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
				
						*a b, to generate reg_migra_indflows.csv
						local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.`y' i.`y'#ib5.${age_bracket} `x'`y'*" 				
							foreach m in a {
							
									/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
									estadd scalar R2=e(mss)/(e(mss)+e(rss))
									estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
									estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
									estadd scalar Ncluster=31
									local R2_p=e(r2_p)
									cap estat classification
									estadd scalar Pcorr= r(P_corr)
									local Pcorr = r(P_corr)
									estimates store `t'`m'`x's`sex'	
									margins, dydx(`x' `x'age* `x'`y'*) post /*For the margins*/
									estadd scalar Ncluster=31
									cap estadd scalar R2_p=`R2_p'
									cap estadd scalar Pcorr= `Pcorr'
									eststo m`t'`x's`sex'
								}
							}
						}
						*drop `x'age* /*dropping each x generated of interactions*/
		}
	}
	local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
	*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
	local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
	esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table26_pre_liketable8_pre_migra_drought_between_reason1_`y'.tex", ///
	scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.`y')  ///
	order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
	replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */
}



*************************************************************************************************************************
*************************************************************************************************************************
*********************** DOING TABLES BEAMER 6 and 8 ADDING DIST_O*YEAR FE  **********************************************
*************************************************************************************************************************
*************************************************************************************************************************
*************************
**** TABLE 6 BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE  Interactive FE. ADDING DIST_O*YEAR FE
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
global folder_tab "main_tables" 
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.con_sur i.yearly##i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.con_sur i.yearly##i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table27_pre_liketable6_pre_migra_drought_young_marriage.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */

*************************
**** TABLE 8 BEAMER ************* BETWEEN MIGRANTS reason==1. ADDING DIST_O*YEAR FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.con_sur i.yearly##i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.con_sur i.yearly##i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+11 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=11*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								eststo m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table28_pre_liketable8_pre_migra_drought_between_reason1.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket} primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */




*************************************************************************************************************************
*************************************************************************************************************************
**** DOING TABLES BEAMER 5-6-7-8 ADDING WHOLE COUPLE of HH MIGRATING AS INTERACTION. ASKED BY REFEREES TO TEST ****************
*************************************************************************************************************************
*************************************************************************************************************************
*************************
**** TABLE 5 BEAMER  *************  BETWEEN and WITHIN MIGRANTS-SEX==1 women
*************************
global sk_tab "12" /*spei and spi using scale*/
global folder_tab "main_tables" 
global age_bracket "age_bracket5"
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all

*For age
foreach x in $drought_index_tab {
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
			replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
	}
}
*For age and whole couple of HH migrated
foreach x in $drought_index_tab {
	gen `x'CP=0 if `x'!=. & mig_couple!=.
	replace `x'CP=`x' if mig_couple==1
	foreach age in 1 2 3 4 { /*Baseline is category 5*/
			gen `x'CPage_bracket`age'=0 if ${age_bracket}!=. & `x'!=. & mig_couple!=.
			replace `x'CPage_bracket`age'=`x' if ${age_bracket}==`age' & mig_couple==1
	}
}

*Defining again as I add a new variable
label var spi${sk_tab}chr_dro_d2CP "spi12-drought-agro (<-1)-couple HH mig"
label var spi${sk_tab}chr_dro_d2extCP "spi12-drought-agro (<-2)-couple HH mig"

label var spi12chr_dro_d2CPage_bracket1 "spi12-drought-agro (<-1) x age (10-17)-couple HH mig"
label var spi12chr_dro_d2CPage_bracket2 "spi12-drought-agro (<-1) x age (18-27)-couple HH mig"
label var spi12chr_dro_d2CPage_bracket3 "spi12-drought-agro (<-1) x age (28-37)-couple HH mig"
label var spi12chr_dro_d2CPage_bracket4 "spi12-drought-agro (<-1) x age (38-47)-couple HH mig"

label var spi12chr_dro_d2extCPage_bracket1 "spi12-drought-agro (<-2) x age (10-17)-couple HH mig"
label var spi12chr_dro_d2extCPage_bracket2 "spi12-drought-agro (<-2) x age (18-27)-couple HH mig"
label var spi12chr_dro_d2extCPage_bracket3 "spi12-drought-agro (<-2) x age (28-37)-couple HH mig"
label var spi12chr_dro_d2extCPage_bracket4 "spi12-drought-agro (<-2) x age (38-47)-couple HH mig"

foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if (mig_ind2==1 | mig_ind2==2) & sex==1, vce(cluster dist_o)" 
		
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_couple i.mig_couple#ib5.${age_bracket} `x'CP*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar p`t'=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(p`t')))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age* `x'CP*) post /*For the margins*/
							cap estadd scalar R2_p=r2_p
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table29_pre_liketable5_pre_migra_drought_sex1_wholeCOUPLE.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_couple)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */

*************************
**** TABLE 6 BEAMER *************  WITHIN AND BETWEEN MIGRANTS-YOUNG MARRIAGE  Interactive FE
*************************
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
estimates drop _all
foreach x in $drought_index_tab {
	/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
					gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
					replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
					} Already generated*/
		foreach t in regife probit {
				foreach migra in 2 {
				local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
				local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if young_marriage==1, vce(cluster dist_o)" 
				*a b, to generate reg_migra_indflows.csv
				local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_couple i.mig_couple#ib5.${age_bracket} `x'CP*" 				
					foreach m in a {
					
							/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
							estadd scalar R2=e(mss)/(e(mss)+e(rss))
							estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
							estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
							estadd scalar Ncluster=31
							local R2_p=e(r2_p)
							cap estat classification
							estadd scalar Pcorr= r(P_corr)
							local Pcorr = r(P_corr)
							estimates store `t'`m'`x'`migra'	
							margins, dydx(`x' `x'age* `x'CP*) post /*For the margins*/
							estadd scalar Ncluster=31
							cap estadd scalar R2_p=`R2_p'
							cap estadd scalar Pcorr= `Pcorr'
							estimates store m`t'`m'`x'`migra'
						}
					}
				}
				*drop `x'age* /*dropping each x generated of interactions*/
}
		
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months} \\ \cmidrule(lr){2-5}  \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) \\ \hline"
esttab regife*spi* mprobit*a*spi* using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table30_pre_liketable6_pre_migra_drought_young_marriage_wholeCOUPLE.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_couple)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */

*************************
**** TABLE 7 BEAMER ************* WITHIN AND BETWEEN MIGRANTS (SPLIT SAMPLE)-YOUNG MARRIAGE INTERACIVE FE
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach type in 1 2 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if mig_ind2==`type' & young_marriage==1, vce(cluster dist_o)" 
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_couple i.mig_couple#ib5.${age_bracket} `x'CP*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`type'	
								margins, dydx(`x' `x'age* `x'CP*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								estimates store m`t'`x's`type'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Between)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Within)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s2* mprobit*spi*s2* ///
using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table31_pre_liketable7_pre_migra_drought_young_marriage_within_between_wholeCOUPLE.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_couple)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */


*************************
**** TABLE 8 BEAMER ************* BETWEEN MIGRANTS reason==1 
*************************
estimates drop _all
global drought_index_tab "spi${sk_tab}chr_dro_d2 spi${sk_tab}chr_dro_d2ext"
foreach sex in 1 0 {
	foreach x in $drought_index_tab {
		/*foreach age in 1 2 3 4 { /*Baseline is category 5*/
						gen `x'age_bracket`age'=0 if ${age_bracket}!=. & `x'!=.
						replace `x'age_bracket`age'=`x' if ${age_bracket}==`age'
						}
		Already generated 
		*/
			foreach t in regife probit {
					foreach migra in 2 {
					local feregife "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o) factors(id yearly, 1)" 
					local feprobit "primary vin_distance i.yearly i.con_sur i.dist_d i.dist_o if sex==`sex' & reason_migrate==1 & mig_ind2==1, vce(cluster dist_o)" 
			
					*a b, to generate reg_migra_indflows.csv
					local identif_a0 "c.`x' ib5.${age_bracket} `x'age* i.mig_couple i.mig_couple#ib5.${age_bracket} `x'CP*" 				
						foreach m in a {
						
								/*bootstrap, reps(100) seed(1):*/ `t' mig_real`migra' `identif_`m'0' `fe`t''
								estadd scalar R2=e(mss)/(e(mss)+e(rss))
								estadd scalar pr=17+31+31+4+19 /*number of coefficients yearly=17 dist_o=31 dist_d=31 con_sur=4 main coef (no constant)=19 now here*/
								estadd scalar R2_a=1-(1-e(R2))*((e(N)-1)/(e(N)-1-e(pr)))
								estadd scalar Ncluster=31
								local R2_p=e(r2_p)
								cap estat classification
								estadd scalar Pcorr= r(P_corr)
								local Pcorr = r(P_corr)
								estimates store `t'`m'`x's`sex'	
								margins, dydx(`x' `x'age* `x'CP*) post /*For the margins*/
								estadd scalar Ncluster=31
								cap estadd scalar R2_p=`R2_p'
								cap estadd scalar Pcorr= `Pcorr'
								eststo m`t'`x's`sex'
							}
						}
					}
					*drop `x'age* /*dropping each x generated of interactions*/
	}
}
local titles "& \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Women)} & \multicolumn{4}{c}{SPI-Cumulative drought for 12 months (Men)} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-9} \addlinespace[-2ex] \\ & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} & \multicolumn{2}{c}{OLS Interactive FE} & \multicolumn{2}{c}{PROBIT-MG EFFECTS} \\ \cmidrule(lr){2-3} \cmidrule(lr){4-5} \cmidrule(lr){6-7} \cmidrule(lr){8-9} \addlinespace[-2ex] \\"
*local subtitles "Migration: &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} &  \shortstack{Model B} &  \shortstack{Model J} \\"
local numbers "& (1) &  (2) &  (3) &  (4) & (5) &  (6) &  (7) &  (8) \\ \hline"
esttab regife*spi*s1* mprobit*spi*s1* regife*spi*s0* mprobit*spi*s0* ///
using "${results2}/7002_panel_year_drought_o/scale_${sk_tab}/${folder_tab}/table32_pre_liketable8_pre_migra_drought_between_reason1_wholeCOUPLE.tex", ///
scalars(N R2 R2_a R2_p Ncluster Pcorr) drop(*.${age_bracket}* primary vin_distance *yearly* *con_sur* *dist_d* *dist_o* _cons *.mig_couple)  ///
order(primary vin_distance *age_bracket5*) se compress nogaps star(* 0.10 ** 0.05 *** 0.01) alignment(c) ///
replace nonumber booktabs note label mlabels(none) posthead("`titles'" "`numbers'") substitute("<-" "$<-$" "R2_a" "$ R2_a$"  "R2_p" "$ R2_p$" main )  /*width(2\hsize)  */


